
#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 1911
 * transforms:
 *    ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul', 'a@8', 128) => ('ishl', 'a', 7)
 *    ('imul', 'a@16', 32768) => ('ishl', 'a', 15)
 *    ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31)
 *    ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63)
 *    ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b'))
 *    ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b')))
 *    ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b'))
 *    ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b'))
 *    ('udiv', 'a', 1) => a
 *    ('idiv', 'a', 1) => a
 *    ('umod', 'a', 1) => 0
 *    ('imod', 'a', 1) => 0
 *    ('imod', 'a', -1) => 0
 *    ('irem', 'a', 1) => 0
 *    ('irem', 'a', -1) => 0
 *    ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b'))
 *    ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b')))
 *    ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b')))))
 *    ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b'))
 *    ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b')))
 *    ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b'))
 *    ('~fneg', ('fneg', 'a')) => a
 *    ('ineg', ('ineg', 'a')) => a
 *    ('fabs', ('fneg', 'a')) => ('fabs', 'a')
 *    ('fabs', ('u2f', 'a')) => ('u2f', 'a')
 *    ('iabs', ('iabs', 'a')) => ('iabs', 'a')
 *    ('iabs', ('ineg', 'a')) => ('iabs', 'a')
 *    ('f2b', ('fneg', 'a')) => ('f2b', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('~fadd', 'a', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a
 *    ('iadd', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', -1) => -1
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd'))
 *    ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c'))
 *    ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a'))
 *    ('~fmul', 'a', 0.0) => 0.0
 *    ('fmul', 'a@16', 0.0) => 0.0
 *    ('fmul', 'a@32', 0.0) => 0.0
 *    ('fmulz', 'a', 0.0) => 0.0
 *    ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a', 'a') => ('fmul', 'a', 'a')
 *    ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b')
 *    ('imul', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', -1) => a
 *    ('~fmul', 'a', 1.0) => a
 *    ('~fmulz', 'a', 1.0) => a
 *    ('fmul(is_only_used_as_float)', 'a', 1.0) => a
 *    ('imul', 'a', 1) => a
 *    ('fmul', 'a', -1.0) => ('fneg', 'a')
 *    ('imul', 'a', -1) => ('ineg', 'a')
 *    ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a')
 *    ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a')
 *    ('~ffma', 0.0, 'a', 'b') => b
 *    ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b')
 *    ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b')
 *    ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~flrp', 'a', 'b', 0.0) => a
 *    ('~flrp', 'a', 'b', 1.0) => b
 *    ('~flrp', 'a', 'a', 'b') => a
 *    ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b')
 *    ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('sdot_4x8_iadd', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd', 'a', 0, 'b') => b
 *    ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd_sat', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 0, 'a', 'b') => b
 *    ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b
 *    ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b')
 *    ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b')
 *    ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a')
 *    ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ffloor', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('fadd', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('ffract', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a')))
 *    ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e'))
 *    ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y')
 *    ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b'))
 *    ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b'))
 *    ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b'))
 *    ('fsum2', 'a') => ('fadd', 'a.x', 'a.y')
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd'))
 *    ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c'))
 *    ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 7))
 *    ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 15))
 *    ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 31))
 *    ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 63))
 *    ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b'))
 *    ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b'))
 *    ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b'))
 *    ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b'))
 *    ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b')
 *    ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b')
 *    ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1)
 *    ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1)
 *    ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2)
 *    ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2)
 *    ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16)
 *    ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16)
 *    ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16)
 *    ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24)
 *    ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24)
 *    ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd'))
 *    ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd'))
 *    ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b')
 *    ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b')
 *    ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b')
 *    ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b')
 *    ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b')
 *    ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b')
 *    ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b')
 *    ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b')
 *    ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False
 *    ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False
 *    ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False
 *    ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False
 *    ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a')
 *    ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a')
 *    ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b')
 *    ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b')
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b')
 *    ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b')
 *    ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b')
 *    ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b')
 *    ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0)
 *    ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0)
 *    ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b'))
 *    ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0)
 *    ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0)
 *    ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0)
 *    ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0)
 *    ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0)
 *    ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0)
 *    ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a')
 *    ('fneu', ('b2f', 'a@1'), 0.0) => a
 *    ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a')
 *    ('ine', ('b2i', 'a@1'), 0) => a
 *    ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('u2f', 'a'), 0.0) => True
 *    ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a')
 *    ('flt', ('u2f', 'a'), 0.0) => False
 *    ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a')
 *    ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0)
 *    ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a')
 *    ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0)
 *    ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a')
 *    ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0)
 *    ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0)
 *    ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0)
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a'))
 *    ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b'))
 *    ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b')))
 *    ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b')))
 *    ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0))
 *    ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b')
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c')
 *    ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b')
 *    ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b')
 *    ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b')
 *    ('~fmin', 'a', 'a') => a
 *    ('~fmax', 'a', 'a') => a
 *    ('imin', 'a', 'a') => a
 *    ('imax', 'a', 'a') => a
 *    ('umin', 'a', 'a') => a
 *    ('umin', 'a', 0) => 0
 *    ('umin', 'a', -1) => a
 *    ('umax', 'a', 'a') => a
 *    ('umax', 'a', 0) => a
 *    ('umax', 'a', -1) => -1
 *    ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b')
 *    ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b')
 *    ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b')
 *    ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b')
 *    ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b')
 *    ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b')
 *    ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c')
 *    ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c')
 *    ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c')
 *    ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c')
 *    ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c')
 *    ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c')
 *    ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b')
 *    ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0)
 *    ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0)
 *    ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0)
 *    ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0)
 *    ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a'))
 *    ('~fmin', 'a', ('fabs', 'a')) => a
 *    ('imin', 'a', ('iabs', 'a')) => a
 *    ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a
 *    ('imax', 'a', ('ineg', ('iabs', 'a'))) => a
 *    ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a')
 *    ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a')
 *    ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a')
 *    ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a'))
 *    ('fsat', ('b2f', 'a')) => ('b2f', 'a')
 *    ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0)
 *    ('fsat', ('fsat', 'a')) => ('fsat', 'a')
 *    ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b')))
 *    ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b')))
 *    ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c')
 *    ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c')
 *    ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c')
 *    ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b'))
 *    ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b'))
 *    ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a'))
 *    ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a'))
 *    ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b'))
 *    ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255)
 *    ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c'))
 *    ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c')
 *    ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c'))
 *    ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c')
 *    ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c'))
 *    ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c'))
 *    ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c'))
 *    ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c')
 *    ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c'))
 *    ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c')
 *    ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c'))
 *    ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c'))
 *    ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a')
 *    ('~f2i16', ('i2f', 'a@16')) => a
 *    ('~f2i16', ('u2f', 'a@16')) => a
 *    ('~f2u16', ('i2f', 'a@16')) => a
 *    ('~f2u16', ('u2f', 'a@16')) => a
 *    ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a'))
 *    ('f2f16', ('f2f32', 'a@16')) => a
 *    ('i2i16', ('i2i32', 'a@16')) => a
 *    ('u2u16', ('u2u32', 'a@16')) => a
 *    ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a')
 *    ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a')
 *    ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a')
 *    ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a')
 *    ('f2f16', ('f2f64', 'a@16')) => a
 *    ('i2i16', ('i2i64', 'a@16')) => a
 *    ('u2u16', ('u2u64', 'a@16')) => a
 *    ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a')
 *    ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a')
 *    ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a')
 *    ('~f2i32', ('i2f', 'a@32')) => a
 *    ('~f2i32', ('u2f', 'a@32')) => a
 *    ('~f2u32', ('i2f', 'a@32')) => a
 *    ('~f2u32', ('u2f', 'a@32')) => a
 *    ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a'))
 *    ('f2f32', ('f2f64', 'a@32')) => a
 *    ('i2i32', ('i2i64', 'a@32')) => a
 *    ('u2u32', ('u2u64', 'a@32')) => a
 *    ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a')
 *    ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a')
 *    ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a')
 *    ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a')
 *    ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a')
 *    ('~f2i64', ('i2f', 'a@64')) => a
 *    ('~f2i64', ('u2f', 'a@64')) => a
 *    ('~f2u64', ('i2f', 'a@64')) => a
 *    ('~f2u64', ('u2f', 'a@64')) => a
 *    ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a'))
 *    ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a')
 *    ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a')
 *    ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a')
 *    ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a')
 *    ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a')
 *    ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a')
 *    ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a')
 *    ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a')
 *    ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b')
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b')
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b')
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i8', 'a@8')) => a
 *    ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i16', 'a@16')) => a
 *    ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i32', 'a@32')) => a
 *    ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i64', 'a@64')) => a
 *    ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b')
 *    ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a')
 *    ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a')
 *    ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a')
 *    ('ior', 'a', ('ieq', 'a', False)) => True
 *    ('ior', 'a', ('inot', 'a')) => -1
 *    ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b')
 *    ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b'))
 *    ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0))
 *    ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0))
 *    ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b')
 *    ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a')
 *    ('~fge', 'a', ('fmin', 'b', 'a')) => True
 *    ('~fge', ('fmax', 'a', 'b'), 'a') => True
 *    ('flt', 'a', ('fmin', 'b', 'a')) => False
 *    ('flt', ('fmax', 'a', 'b'), 'a') => False
 *    ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b')
 *    ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a')
 *    ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b')
 *    ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a')
 *    ('ige', 'a', ('imin', 'b', 'a')) => True
 *    ('ige', ('imax', 'a', 'b'), 'a') => True
 *    ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b')
 *    ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a')
 *    ('uge', 'a', ('umin', 'b', 'a')) => True
 *    ('uge', ('umax', 'a', 'b'), 'a') => True
 *    ('ilt', 'a', ('imin', 'b', 'a')) => False
 *    ('ilt', ('imax', 'a', 'b'), 'a') => False
 *    ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b')
 *    ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a')
 *    ('ult', 'a', ('umin', 'b', 'a')) => False
 *    ('ult', ('umax', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b')
 *    ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a')
 *    ('ult', 'a', ('iand', 'b', 'a')) => False
 *    ('ult', ('ior', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('iand', 'b', 'a')) => True
 *    ('uge', ('ior', 'a', 'b'), 'a') => True
 *    ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b'))
 *    ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b')
 *    ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b')
 *    ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b')
 *    ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b')
 *    ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b')
 *    ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b'))
 *    ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b'))
 *    ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b'))
 *    ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b'))
 *    ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y'))
 *    ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0)
 *    ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0)
 *    ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y'))
 *    ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y'))
 *    ('ball_iequal3', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('ieq', 'a.z', 'b.z'))
 *    ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w')))
 *    ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y'))
 *    ('bany_inequal3', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ine', 'a.z', 'b.z'))
 *    ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w')))
 *    ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y'))
 *    ('ball_fequal3', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('feq', 'a.z', 'b.z'))
 *    ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w')))
 *    ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y'))
 *    ('bany_fnequal3', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('fneu', 'a.z', 'b.z'))
 *    ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w')))
 *    ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0)
 *    ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0)
 *    ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b'))
 *    ('iand', 'a@bool16', 1.0) => ('b2f', 'a')
 *    ('iand', 'a@bool32', 1.0) => ('b2f', 'a')
 *    ('flt', ('fneg', ('b2f', 'a@1')), 0) => a
 *    ('ilt', 'a', 'a') => False
 *    ('ige', 'a', 'a') => True
 *    ('ieq', 'a', 'a') => True
 *    ('ine', 'a', 'a') => False
 *    ('ult', 'a', 'a') => False
 *    ('uge', 'a', 'a') => True
 *    ('flt', 'a', 'a') => False
 *    ('fge', 'a(is_a_number)', 'a') => True
 *    ('feq', 'a(is_a_number)', 'a') => True
 *    ('fneu', 'a(is_a_number)', 'a') => False
 *    ('iand', 'a', 'a') => a
 *    ('iand', 'a', -1) => a
 *    ('iand', 'a', 0) => 0
 *    ('ior', 'a', 'a') => a
 *    ('ior', 'a', 0) => a
 *    ('ior', 'a', True) => True
 *    ('ixor', 'a', 'a') => 0
 *    ('ixor', 'a', 0) => a
 *    ('inot', ('inot', 'a')) => a
 *    ('ior', ('iand', 'a', 'b'), 'b') => b
 *    ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b')
 *    ('iand', ('ior', 'a', 'b'), 'b') => b
 *    ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b')
 *    ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b'))
 *    ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b'))
 *    ('ishl', 0, 'a') => 0
 *    ('ishl', 'a', 0) => a
 *    ('ishr', 0, 'a') => 0
 *    ('ishr', 'a', 0) => a
 *    ('ushr', 0, 'a') => 0
 *    ('ushr', 'a', 0) => a
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b')
 *    ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b')))
 *    ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b')))
 *    ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b')))
 *    ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b')))
 *    ('~fexp2', ('flog2', 'a')) => a
 *    ('~flog2', ('fexp2', 'a')) => a
 *    ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b')
 *    ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 'a', 1.0) => a
 *    ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a')
 *    ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 2.0, 'a') => ('fexp2', 'a')
 *    ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a
 *    ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a')
 *    ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a'))
 *    ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a'))
 *    ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a'))
 *    ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a'))
 *    ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a'))
 *    ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a'))
 *    ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a'))
 *    ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b'))
 *    ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0))
 *    ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fdiv', 1.0, 'a') => ('frcp', 'a')
 *    ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b'))
 *    ('~frcp', ('frcp', 'a')) => a
 *    ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a')
 *    ('fsqrt', 'a') => ('frcp', ('frsq', 'a'))
 *    ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a')
 *    ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))
 *    ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))
 *    ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0)
 *    ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0)
 *    ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0)
 *    ('ieq', 'a', True) => a
 *    ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a')
 *    ('ine', 'a', False) => a
 *    ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a')
 *    ('bcsel', 'a', True, False) => a
 *    ('bcsel', 'a', False, True) => ('inot', 'a')
 *    ('bcsel', True, 'b', 'c') => b
 *    ('bcsel', False, 'b', 'c') => c
 *    ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel', 'a', 'b', 'b') => b
 *    ('~fcsel', 'a', 'b', 'b') => b
 *    ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1'))
 *    ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a')))
 *    ('bcsel', 'a', 1, 0) => ('b2i', 'a@1')
 *    ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a'))
 *    ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a')
 *    ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a
 *    ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a')
 *    ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a')
 *    ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2i', ('ftrunc', 'a')) => ('f2i', 'a')
 *    ('f2u', ('ftrunc', 'a')) => ('f2u', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('i2b', ('iabs', 'a')) => ('i2b', 'a')
 *    ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0)
 *    ('f2fmp', ('f2f32', 'a@16')) => a
 *    ('i2imp', ('i2i32', 'a@16')) => a
 *    ('i2imp', ('u2u32', 'a@16')) => a
 *    ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a')
 *    ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a')
 *    ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a')
 *    ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a')
 *    ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('f2f32', ('f2fmp', 'a@32')) => a
 *    ('i2i32', ('i2imp', 'a@32')) => a
 *    ('u2u32', ('i2imp', 'a@32')) => a
 *    ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a')
 *    ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a')
 *    ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a')
 *    ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a')
 *    ('~f2f32', ('f2f64', 'a@32')) => a
 *    ('ffloor', 'a(is_integral)') => a
 *    ('fceil', 'a(is_integral)') => a
 *    ('ftrunc', 'a(is_integral)') => a
 *    ('~ffract', 'a(is_integral)') => 0.0
 *    ('fabs', 'a(is_not_negative)') => a
 *    ('iabs', 'a(is_not_negative)') => a
 *    ('fsat', 'a(is_not_positive)') => 0.0
 *    ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a')
 *    ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0)
 *    ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0)
 *    ('fneu', 'a(is_not_zero)', 0.0) => True
 *    ('feq', 'a(is_not_zero)', 0.0) => False
 *    ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True
 *    ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True
 *    ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True
 *    ('ine', 'a(is_not_zero)', 0) => True
 *    ('ieq', 'a(is_not_zero)', 0) => False
 *    ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True
 *    ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('ult', 0, 'a(is_gt_zero)') => True
 *    ('ult', 'a', 0) => False
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b
 *    ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b')
 *    ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a
 *    ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a
 *    ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a
 *    ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a
 *    ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a
 *    ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a
 *    ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c'))
 *    ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1)
 *    ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3)
 *    ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7)
 *    ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1)
 *    ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3)
 *    ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7)
 *    ('iand', 255, 'a') => ('extract_u8', 'a', 0)
 *    ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2))
 *    ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1))
 *    ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b'))
 *    ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b'))
 *    ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0)
 *    ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1)
 *    ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2)
 *    ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3)
 *    ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0)
 *    ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1)
 *    ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2)
 *    ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3)
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0)
 *    ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1)
 *    ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0)
 *    ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1)
 *    ('iand', 65535, 'a') => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1)
 *    ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0)
 *    ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1)
 *    ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a'))
 *    ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32))
 *    ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16))
 *    ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a')
 *    ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32))
 *    ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16))
 *    ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a')
 *    ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a')
 *    ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a')
 *    ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a'))
 *    ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0))
 *    ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a')
 *    ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0)
 *    ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0)
 *    ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd')
 *    ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6)
 *    ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5)
 *    ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4)
 *    ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3)
 *    ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0)
 *    ('ussub_4x8_vc4', 'a', 0) => a
 *    ('ussub_4x8_vc4', 'a', -1) => 0
 *    ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b'))
 *    ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b'))
 *    ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b'))
 *    ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b'))
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b'))
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c')
 *    ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b'))
 *    ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b')
 *    ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b')
 *    ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b')
 *    ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a
 *    ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd')
 *    ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b'))))
 *    ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a'))
 *    ('usub_borrow@32', 'a', 'b') => ('b2i', ('ult', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base'))
 *    ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807))
 *    ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base'))
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits'))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits'))
 *    ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b')
 *    ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c')
 *    ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits')
 *    ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits')
 *    ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset')
 *    ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset')
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b')))
 *    ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits')))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1)))
 *    ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value'))
 *    ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value'))
 *    ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value'))
 *    ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value')))
 *    ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24)
 *    ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255)
 *    ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16)
 *    ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535)
 *    ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0)
 *    ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0)
 *    ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0)))
 *    ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0)))
 *    ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a')))
 *    ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a'))
 *    ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16)))
 *    ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a'))
 *    ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16))
 *    ('isign', 'a') => ('imin', ('imax', 'a', -1), 1)
 *    ('imin', ('imax', 'a', -1), 1) => ('isign', 'a')
 *    ('imax', ('imin', 'a', 1), -1) => ('isign', 'a')
 *    ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0)))
 *    ('amul', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215))
 *    ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c')
 *    ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b')
 *    ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c')
 *    ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b')
 *    ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b')
 *    ('imad24_ir3', 'a', 0, 'c') => c
 *    ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c')
 *    ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c')
 *    ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('imul24', 'a', 0) => 0
 *    ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'c', 'b')
 *    ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'c', 'b')
 *    ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b')))
 *    ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b')))
 *    ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b')))
 *    ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b')))
 *    ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b')))
 *    ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b')))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b')))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b')))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('f2b1', ('b2f', 'a@1')) => a
 *    ('i2b1', ('b2i', 'a@1')) => a
 *    ('f2b8', ('b2f', 'a@8')) => a
 *    ('i2b8', ('b2i', 'a@8')) => a
 *    ('f2b16', ('b2f', 'a@16')) => a
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('f2b32', ('b2f', 'a@32')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2f', ('b2f', 'a')) => ('b2f', 'a')
 *    ('f2u', ('b2f', 'a')) => ('b2i', 'a')
 *    ('f2i', ('b2f', 'a')) => ('b2i', 'a')
 *    ('u2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('u2u', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('i2i', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2i1', 'a@1') => a
 *    ('i2i8', 'a@8') => a
 *    ('i2i16', 'a@16') => a
 *    ('i2i32', 'a@32') => a
 *    ('i2i64', 'a@64') => a
 *    ('u2u1', 'a@1') => a
 *    ('u2u8', 'a@8') => a
 *    ('u2u16', 'a@16') => a
 *    ('u2u32', 'a@32') => a
 *    ('u2u64', 'a@64') => a
 *    ('f2f16', 'a@16') => a
 *    ('f2f32', 'a@32') => a
 *    ('f2f64', 'a@64') => a
 *    ('b2b1', 'a@1') => a
 *    ('b2b8', 'a@8') => a
 *    ('b2b16', 'a@16') => a
 *    ('b2b32', 'a@32') => a
 *    ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b')))
 *    ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b')))
 *    ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a')
 *    ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a')
 *    ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a')
 *    ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a')
 *    ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10)))
 *    ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23))
 *    ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20)))
 *    ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x')
 *    ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x')
 *    ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b')
 *    ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b')
 *    ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b')
 *    ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b')
 *    ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b')
 *    ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b')
 *    ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b')
 *    ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b')
 *    ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b')
 *    ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b')
 *    ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b')
 *    ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b')
 *    ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b')
 *    ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b')
 *    ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b')
 *    ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b')
 *    ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b')
 *    ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b')
 *    ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b')
 *    ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a')
 *    ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd'))
 *    ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd'))
 *    ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd'))
 *    ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd'))
 *    ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd'))
 *    ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c'))
 *    ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd'))
 *    ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c'))
 *    ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd'))
 *    ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c'))
 *    ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd'))
 *    ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c'))
 *    ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd'))
 *    ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c'))
 *    ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd'))
 *    ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c'))
 *    ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd'))
 *    ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd'))
 *    ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd'))
 *    ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd'))
 *    ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd'))
 *    ('fddx', 'a') => 0.0
 *    ('fddx_fine', 'a') => 0.0
 *    ('fddx_coarse', 'a') => 0.0
 *    ('fddy', 'a') => 0.0
 *    ('fddy_fine', 'a') => 0.0
 *    ('fddy_coarse', 'a') => 0.0
 *    ('umul_low', '#a(is_lower_half_zero)', 'b') => 0
 *    ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c
 *    ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b'))
 *    ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b'))
 *    ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b'))
 *    ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b'))
 *    ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216))
 *    ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b'))
 *    ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b'))
 *    ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b'))
 *    ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b'))
 *    ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b'))
 *    ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'))
 *    ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))
 *    ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'))
 *    ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'))
 *    ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'))
 *    ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd'))
 *    ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd'))
 *    ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd'))
 *    ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd'))
 *    ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd'))
 */


static const nir_search_value_union nir_opt_algebraic_values[] = {
   /* ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('imul', 'a@8', 128) => ('ishl', 'a', 7) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x80 /* 128 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 6, 7 },
      -1,
   } },

   /* replace1_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 9 },
      -1,
   } },

   /* ('imul', 'a@16', 32768) => ('ishl', 'a', 15) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x8000 /* 32768 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 12 },
      -1,
   } },

   /* replace2_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf /* 15 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 14 },
      -1,
   } },

   /* ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x80000000 /* 2147483648 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 17 },
      -1,
   } },

   /* replace3_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 19 },
      -1,
   } },

   /* ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x8000000000000000 /* 9223372036854775808 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 22 },
      -1,
   } },

   /* replace4_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3f /* 63 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 24 },
      -1,
   } },

   /* ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search5_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 26 },
      -1,
   } },

   /* replace5_0_0 -> 0 in the cache */
   /* replace5_0_1_0_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 28 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 30 },
      -1,
   } },

   /* ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 33 },
      -1,
   } },

   /* replace6_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 37 },
      -1,
   } },

   /* ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b'))) */
   /* search7_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 39 },
      -1,
   } },

   /* replace7_0_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 42 },
      -1,
   } },
   /* replace7_1_0 -> 21 in the cache */
   /* replace7_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 44 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 43, 45 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search8_0_0 -> 16 in the cache */
   /* search8_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 47 },
      -1,
   } },

   /* replace8_0 -> 16 in the cache */
   /* replace8_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search9_0_0 -> 16 in the cache */
   /* search9_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 50 },
      -1,
   } },

   /* replace9_0 -> 16 in the cache */
   /* replace9_1 -> 36 in the cache */
   /* replace9 -> 49 in the cache */

   /* ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b')) */
   /* search10_0 -> 16 in the cache */
   /* search10_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace10_0_0 -> 16 in the cache */
   /* replace10_0_1 -> 36 in the cache */
   /* replace10_0 -> 49 in the cache */
   /* replace10_1_0 -> 16 in the cache */
   /* replace10_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 53 },
      -1,
   } },

   /* ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b')) */
   /* search11_0 -> 16 in the cache */
   /* search11_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace11_0_0 -> 16 in the cache */
   /* replace11_0_1 -> 36 in the cache */
   /* replace11_0 -> 49 in the cache */
   /* replace11_1_0 -> 16 in the cache */
   /* replace11_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 56 },
      -1,
   } },

   /* ('udiv', 'a', 1) => a */
   /* search12_0 -> 32 in the cache */
   /* search12_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace12 -> 32 in the cache */

   /* ('idiv', 'a', 1) => a */
   /* search13_0 -> 32 in the cache */
   /* search13_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace13 -> 32 in the cache */

   /* ('umod', 'a', 1) => 0 */
   /* search14_0 -> 32 in the cache */
   /* search14_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('imod', 'a', 1) => 0 */
   /* search15_0 -> 32 in the cache */
   /* search15_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace15 -> 61 in the cache */

   /* ('imod', 'a', -1) => 0 */
   /* search16_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace16 -> 61 in the cache */

   /* ('irem', 'a', 1) => 0 */
   /* search17_0 -> 32 in the cache */
   /* search17_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace17 -> 61 in the cache */

   /* ('irem', 'a', -1) => 0 */
   /* search18_0 -> 32 in the cache */
   /* search18_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace18 -> 61 in the cache */

   /* ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b')) */
   /* search19_0 -> 0 in the cache */
   /* search19_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace19_0 -> 0 in the cache */
   /* replace19_1_0 -> 3 in the cache */
   /* replace19_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b'))) */
   /* search20_0 -> 0 in the cache */
   /* search20_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace20_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_1_0 -> 3 in the cache */
   /* replace20_1_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 4 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 72 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b'))))) */
   /* search21_0 -> 0 in the cache */
   /* search21_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace21_0_0_0 -> 0 in the cache */
   /* replace21_0_0 -> 70 in the cache */
   /* replace21_0_1_0_0 -> 0 in the cache */
   /* replace21_0_1_0 -> 71 in the cache */
   /* replace21_0_1_1_0_0 -> 3 in the cache */
   /* replace21_0_1_1_0 -> 28 in the cache */
   /* replace21_0_1_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 75 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 76 },
      -1,
   } },

   /* ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search22_0 -> 0 in the cache */
   /* search22_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace22_0 -> 0 in the cache */
   /* replace22_1_0 -> 3 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 80 },
      -1,
   } },

   /* ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search23_0 -> 0 in the cache */
   /* search23_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace23_0 -> 0 in the cache */
   /* replace23_1_0 -> 3 in the cache */
   /* replace23_1_1 -> 79 in the cache */
   /* replace23_1 -> 80 in the cache */
   /* replace23 -> 81 in the cache */

   /* ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b')) */
   /* search24_0 -> 0 in the cache */
   /* search24_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace24_0_0_0 -> 0 in the cache */
   /* replace24_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace24_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 84, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace24_2_0 -> 0 in the cache */
   /* replace24_2_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 85, 86, 87 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b'))) */
   /* search25_0 -> 0 in the cache */
   /* search25_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace25_0 -> 0 in the cache */
   /* replace25_1_0_0_0 -> 0 in the cache */
   /* replace25_1_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 86 },
      -1,
   } },
   /* replace25_1_0_1_0 -> 0 in the cache */
   /* replace25_1_0_1_1_0 -> 3 in the cache */
   /* replace25_1_0_1_1_1 -> 79 in the cache */
   /* replace25_1_0_1_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 80 },
      -1,
   } },
   /* replace25_1_0_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 90, 91, 0 },
      -1,
   } },
   /* replace25_1_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 92, 93 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 0, 94 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b')) */
   /* search26_0 -> 0 in the cache */
   /* search26_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace26_0 -> 0 in the cache */
   /* replace26_1_0 -> 3 in the cache */
   /* replace26_1 -> 28 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 28 },
      -1,
   } },

   /* ('~fneg', ('fneg', 'a')) => a */
   /* search27_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace27 -> 32 in the cache */

   /* ('ineg', ('ineg', 'a')) => a */
   /* search28_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace28 -> 32 in the cache */

   /* ('fabs', ('fneg', 'a')) => ('fabs', 'a') */
   /* search29_0_0 -> 32 in the cache */
   /* search29_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace29_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('fabs', ('u2f', 'a')) => ('u2f', 'a') */
   /* search30_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace30_0 -> 32 in the cache */
   /* replace30 -> 104 in the cache */

   /* ('iabs', ('iabs', 'a')) => ('iabs', 'a') */
   /* search31_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace31_0 -> 32 in the cache */
   /* replace31 -> 106 in the cache */

   /* ('iabs', ('ineg', 'a')) => ('iabs', 'a') */
   /* search32_0_0 -> 32 in the cache */
   /* search32_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace32_0 -> 32 in the cache */
   /* replace32 -> 106 in the cache */

   /* ('f2b', ('fneg', 'a')) => ('f2b', 'a') */
   /* search33_0_0 -> 32 in the cache */
   /* search33_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace33_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search34_0_0 -> 32 in the cache */
   /* search34_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace34_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fadd', 'a', 0.0) => a */
   /* search35_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace35 -> 32 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a */
   /* search36_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 115 },
      1,
   } },

   /* replace36 -> 11 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a */
   /* search37_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 117 },
      1,
   } },

   /* replace37 -> 16 in the cache */

   /* ('iadd', 'a', 0) => a */
   /* search38_0 -> 32 in the cache */
   /* search38_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace38 -> 32 in the cache */

   /* ('usadd_4x8_vc4', 'a', 0) => a */
   /* search39_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace39 -> 16 in the cache */

   /* ('usadd_4x8_vc4', 'a', -1) => -1 */
   /* search40_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace40 -> 122 in the cache */

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search41_1_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 126, 128 },
      -1,
   } },

   /* replace41_0 -> 124 in the cache */
   /* replace41_1_0 -> 125 in the cache */
   /* replace41_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 124, 130 },
      -1,
   } },

   /* ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search42_0_0 -> 16 in the cache */
   /* search42_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* search42_1_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 16, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 132, 134 },
      -1,
   } },

   /* replace42_0 -> 16 in the cache */
   /* replace42_1_0 -> 36 in the cache */
   /* replace42_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 16, 136 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search43_0 -> 0 in the cache */
   /* search43_1 -> 3 in the cache */
   /* search43_2_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 0, 138, 139 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 140 },
      -1,
   } },

   /* replace43_0 -> 0 in the cache */
   /* replace43_1_0 -> 3 in the cache */
   /* replace43_1_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3, 138 },
      -1,
   } },
   /* replace43_2 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 142, 139 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search44_0 -> 0 in the cache */
   /* search44_1 -> 3 in the cache */
   /* search44_2_0 -> 0 in the cache */
   /* search44_2_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 138 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 144 },
      -1,
   } },

   /* replace44_0 -> 0 in the cache */
   /* replace44_1_0 -> 3 in the cache */
   /* replace44_1_1 -> 138 in the cache */
   /* replace44_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 0, 142 },
      -1,
   } },

   /* ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 147, 148 },
      0,
   } },
   /* search45_1_0 -> 147 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 147, 150, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 149, 152 },
      -1,
   } },

   /* replace45_0 -> 147 in the cache */
   /* replace45_1_0 -> 148 in the cache */
   /* replace45_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 148, 150 },
      -1,
   } },
   /* replace45_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 147, 154, 151 },
      -1,
   } },

   /* ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd')) */
   /* search46_0 -> 147 in the cache */
   /* search46_1_0 -> 148 in the cache */
   /* search46_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 150 },
      0,
   } },
   /* search46_2_0 -> 148 in the cache */
   /* search46_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 147, 156, 157 },
      -1,
   } },

   /* replace46_0 -> 148 in the cache */
   /* replace46_1_0 -> 147 in the cache */
   /* replace46_1_1 -> 150 in the cache */
   /* replace46_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 147, 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 148, 159 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search47_0 -> 16 in the cache */
   /* search47_1 -> 36 in the cache */
   /* search47_2_0 -> 16 in the cache */
   /* search47_2_1 -> 133 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 133, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 162 },
      -1,
   } },

   /* replace47_0 -> 16 in the cache */
   /* replace47_1_0 -> 36 in the cache */
   /* replace47_1_1 -> 133 in the cache */
   /* replace47_1 -> 136 in the cache */
   /* replace47_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 136, 161 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search48_0 -> 16 in the cache */
   /* search48_1 -> 36 in the cache */
   /* search48_2_0 -> 16 in the cache */
   /* search48_2_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 133 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 165 },
      -1,
   } },

   /* replace48_0 -> 16 in the cache */
   /* replace48_1_0 -> 36 in the cache */
   /* replace48_1_1 -> 133 in the cache */
   /* replace48_1 -> 136 in the cache */
   /* replace48 -> 137 in the cache */

   /* ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search49_0_0 -> 16 in the cache */
   /* search49_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      0,
   } },
   /* search49_1_0 -> 16 in the cache */
   /* search49_1_1 -> 133 in the cache */
   /* search49_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 16, 133, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 167, 168 },
      -1,
   } },

   /* replace49_0 -> 16 in the cache */
   /* replace49_1_0 -> 36 in the cache */
   /* replace49_1_1 -> 133 in the cache */
   /* replace49_1 -> 136 in the cache */
   /* replace49_2 -> 161 in the cache */
   /* replace49 -> 164 in the cache */

   /* ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd')) */
   /* search50_0 -> 16 in the cache */
   /* search50_1_0 -> 36 in the cache */
   /* search50_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 133 },
      0,
   } },
   /* search50_2_0 -> 36 in the cache */
   /* search50_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 36, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 16, 170, 171 },
      -1,
   } },

   /* replace50_0 -> 36 in the cache */
   /* replace50_1_0 -> 16 in the cache */
   /* replace50_1_1 -> 133 in the cache */
   /* replace50_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 36, 173 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search51_0_0 -> 124 in the cache */
   /* search51_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search51_1_0 -> 124 in the cache */
   /* search51_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 175, 176 },
      -1,
   } },

   /* replace51_0 -> 124 in the cache */
   /* replace51_1_0 -> 125 in the cache */
   /* replace51_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 124, 178 },
      -1,
   } },

   /* ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c')) */
   /* search52_0_0 -> 124 in the cache */
   /* search52_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search52_1_0 -> 124 in the cache */
   /* search52_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 180, 181 },
      -1,
   } },

   /* replace52_0 -> 124 in the cache */
   /* replace52_1_0 -> 125 in the cache */
   /* replace52_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 124, 183 },
      -1,
   } },

   /* ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c')) */
   /* search53_0_0 -> 124 in the cache */
   /* search53_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search53_1_0 -> 124 in the cache */
   /* search53_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 185, 186 },
      -1,
   } },

   /* replace53_0 -> 124 in the cache */
   /* replace53_1_0 -> 125 in the cache */
   /* replace53_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 124, 188 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   /* search54_0_0 -> 32 in the cache */
   /* search54_0 -> 98 in the cache */
   /* search54_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace54 -> 113 in the cache */

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search55_0_0 -> 32 in the cache */
   /* search55_0 -> 100 in the cache */
   /* search55_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 100, 32 },
      -1,
   } },

   /* replace55 -> 61 in the cache */

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   /* search56_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search56_1_0 -> 0 in the cache */
   /* search56_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 192, 193 },
      -1,
   } },

   /* replace56 -> 3 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search57_0 -> 0 in the cache */
   /* search57_1_0_0 -> 0 in the cache */
   /* search57_1_0 -> 192 in the cache */
   /* search57_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 192, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 0, 195 },
      -1,
   } },

   /* replace57 -> 3 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search58_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search58_1_0 -> 0 in the cache */
   /* search58_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 197, 198 },
      -1,
   } },

   /* replace58 -> 3 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search59_0 -> 0 in the cache */
   /* search59_1_0_0 -> 0 in the cache */
   /* search59_1_0 -> 197 in the cache */
   /* search59_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 197, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 0, 200 },
      -1,
   } },

   /* replace59 -> 3 in the cache */

   /* ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a')) */
   /* search60_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search60_1_0_0 -> 32 in the cache */
   /* search60_1_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 203 },
      -1,
   } },

   /* replace60_0_0 -> 32 in the cache */
   /* replace60_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 103 },
      -1,
   } },

   /* ('~fmul', 'a', 0.0) => 0.0 */
   /* search61_0 -> 32 in the cache */
   /* search61_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace61 -> 113 in the cache */

   /* ('fmul', 'a@16', 0.0) => 0.0 */
   /* search62_0 -> 11 in the cache */
   /* search62_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 115 },
      -1,
   } },

   /* replace62 -> 115 in the cache */

   /* ('fmul', 'a@32', 0.0) => 0.0 */
   /* search63_0 -> 16 in the cache */
   /* search63_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace63 -> 117 in the cache */

   /* ('fmulz', 'a', 0.0) => 0.0 */
   /* search64_0 -> 16 in the cache */
   /* search64_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace64 -> 117 in the cache */

   /* ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b') */
   /* search65_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 210 },
      -1,
   } },

   /* replace65_0 -> 16 in the cache */
   /* replace65_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 213, 214 },
      -1,
   } },

   /* replace66_0 -> 16 in the cache */
   /* replace66_1 -> 36 in the cache */
   /* replace66 -> 212 in the cache */

   /* ('fmulz', 'a', 'a') => ('fmul', 'a', 'a') */
   /* search67_0 -> 16 in the cache */
   /* search67_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* replace67_0 -> 16 in the cache */
   /* replace67_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search68_0 -> 16 in the cache */
   /* search68_1 -> 210 in the cache */
   /* search68_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 210, 133 },
      -1,
   } },

   /* replace68_0 -> 16 in the cache */
   /* replace68_1 -> 36 in the cache */
   /* replace68_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search69_0 -> 213 in the cache */
   /* search69_1 -> 214 in the cache */
   /* search69_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 213, 214, 133 },
      -1,
   } },

   /* replace69_0 -> 16 in the cache */
   /* replace69_1 -> 36 in the cache */
   /* replace69_2 -> 133 in the cache */
   /* replace69 -> 219 in the cache */

   /* ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b') */
   /* search70_0 -> 16 in the cache */
   /* search70_1 -> 16 in the cache */
   /* search70_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* replace70_0 -> 16 in the cache */
   /* replace70_1 -> 16 in the cache */
   /* replace70_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* ('imul', 'a', 0) => 0 */
   /* search71_0 -> 32 in the cache */
   /* search71_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace71 -> 61 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', 0) => 0 */
   /* search72_0 -> 16 in the cache */
   /* search72_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace72 -> 120 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', -1) => a */
   /* search73_0 -> 16 in the cache */
   /* search73_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace73 -> 16 in the cache */

   /* ('~fmul', 'a', 1.0) => a */
   /* search74_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 226 },
      -1,
   } },

   /* replace74 -> 32 in the cache */

   /* ('~fmulz', 'a', 1.0) => a */
   /* search75_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 228 },
      -1,
   } },

   /* replace75 -> 16 in the cache */

   /* ('fmul(is_only_used_as_float)', 'a', 1.0) => a */
   /* search76_0 -> 32 in the cache */
   /* search76_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 226 },
      1,
   } },

   /* replace76 -> 32 in the cache */

   /* ('imul', 'a', 1) => a */
   /* search77_0 -> 32 in the cache */
   /* search77_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 35 },
      -1,
   } },

   /* replace77 -> 32 in the cache */

   /* ('fmul', 'a', -1.0) => ('fneg', 'a') */
   /* search78_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 232 },
      -1,
   } },

   /* replace78_0 -> 32 in the cache */
   /* replace78 -> 98 in the cache */

   /* ('imul', 'a', -1) => ('ineg', 'a') */
   /* search79_0 -> 32 in the cache */
   /* search79_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace79_0 -> 32 in the cache */
   /* replace79 -> 100 in the cache */

   /* ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a') */
   /* search80_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search80_1_0 -> 32 in the cache */
   /* search80_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 235, 236 },
      -1,
   } },

   /* replace80_0_0 -> 32 in the cache */
   /* replace80_0 -> 103 in the cache */
   /* replace80_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 103, 32 },
      -1,
   } },

   /* ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a') */
   /* search81_0_0_0 -> 32 in the cache */
   /* search81_0_0 -> 235 in the cache */
   /* search81_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 235, 32 },
      -1,
   } },
   /* search81_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 239, 32 },
      -1,
   } },

   /* replace81_0_0 -> 32 in the cache */
   /* replace81_0 -> 103 in the cache */
   /* replace81_1 -> 32 in the cache */
   /* replace81 -> 238 in the cache */

   /* ('~ffma', 0.0, 'a', 'b') => b */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search82_1 -> 0 in the cache */
   /* search82_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 241, 0, 3 },
      -1,
   } },

   /* replace82 -> 3 in the cache */

   /* ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search83_0 -> 115 in the cache */
   /* search83_1 -> 11 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 115, 11, 243 },
      1,
   } },

   /* replace83 -> 243 in the cache */

   /* ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search84_0 -> 117 in the cache */
   /* search84_1 -> 16 in the cache */
   /* search84_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 117, 16, 36 },
      1,
   } },

   /* replace84 -> 36 in the cache */

   /* ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b') */
   /* search85_0 -> 117 in the cache */
   /* search85_1 -> 16 in the cache */
   /* search85_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 117, 16, 36 },
      -1,
   } },

   /* replace85_0 -> 117 in the cache */
   /* replace85_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 117, 36 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search86_0 -> 0 in the cache */
   /* search86_1 -> 3 in the cache */
   /* search86_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 0, 3, 241 },
      -1,
   } },

   /* replace86_0 -> 0 in the cache */
   /* replace86_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search87_0 -> 11 in the cache */
   /* search87_1 -> 243 in the cache */
   /* search87_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 243, 115 },
      -1,
   } },

   /* replace87_0 -> 11 in the cache */
   /* replace87_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 243 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search88_0 -> 16 in the cache */
   /* search88_1 -> 36 in the cache */
   /* search88_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace88_0 -> 16 in the cache */
   /* replace88_1 -> 36 in the cache */
   /* replace88 -> 212 in the cache */

   /* ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b') */
   /* search89_0 -> 16 in the cache */
   /* search89_1 -> 36 in the cache */
   /* search89_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace89_0 -> 16 in the cache */
   /* replace89_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search90_1 -> 0 in the cache */
   /* search90_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 255, 0, 3 },
      -1,
   } },

   /* replace90_0 -> 0 in the cache */
   /* replace90_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   /* search91_0 -> 228 in the cache */
   /* search91_1 -> 16 in the cache */
   /* search91_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 228, 16, 36 },
      -1,
   } },

   /* replace91_0 -> 16 in the cache */
   /* replace91_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search92_1 -> 0 in the cache */
   /* search92_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 260, 0, 3 },
      -1,
   } },

   /* replace92_0_0 -> 0 in the cache */
   /* replace92_0 -> 197 in the cache */
   /* replace92_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 197, 3 },
      -1,
   } },

   /* ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search93_1 -> 16 in the cache */
   /* search93_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 263, 16, 36 },
      -1,
   } },

   /* replace93_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 16 },
      -1,
   } },
   /* replace93_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 265, 36 },
      -1,
   } },

   /* ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search94_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 267, 268, 127 },
      -1,
   } },

   /* replace94_0_0 -> 124 in the cache */
   /* replace94_0_1 -> 125 in the cache */
   /* replace94_0 -> 126 in the cache */
   /* replace94_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 126, 127 },
      -1,
   } },

   /* ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search95_1 -> 33 in the cache */
   /* search95_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 271, 33, 133 },
      -1,
   } },

   /* replace95_0_0 -> 16 in the cache */
   /* replace95_0_1 -> 36 in the cache */
   /* replace95_0 -> 132 in the cache */
   /* replace95_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 132, 133 },
      -1,
   } },

   /* ('~flrp', 'a', 'b', 0.0) => a */
   /* search96_0 -> 0 in the cache */
   /* search96_1 -> 3 in the cache */
   /* search96_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 241 },
      -1,
   } },

   /* replace96 -> 0 in the cache */

   /* ('~flrp', 'a', 'b', 1.0) => b */
   /* search97_0 -> 0 in the cache */
   /* search97_1 -> 3 in the cache */
   /* search97_2 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 255 },
      -1,
   } },

   /* replace97 -> 3 in the cache */

   /* ('~flrp', 'a', 'a', 'b') => a */
   /* search98_0 -> 0 in the cache */
   /* search98_1 -> 0 in the cache */
   /* search98_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 0, 3 },
      -1,
   } },

   /* replace98 -> 0 in the cache */

   /* ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b') */
   /* search99_0 -> 241 in the cache */
   /* search99_1 -> 0 in the cache */
   /* search99_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 241, 0, 3 },
      -1,
   } },

   /* replace99_0 -> 0 in the cache */
   /* replace99_1 -> 3 in the cache */
   /* replace99 -> 249 in the cache */

   /* ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search100_0 -> 124 in the cache */
   /* search100_1_0 -> 124 in the cache */
   /* search100_1_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 124, 125 },
      0,
   } },
   /* search100_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 124, 278, 127 },
      -1,
   } },

   /* replace100_0_0 -> 125 in the cache */
   /* replace100_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 125, 127 },
      -1,
   } },
   /* replace100_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 280, 124 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 0, 'b') => b */
   /* search101_0 -> 16 in the cache */
   /* search101_1 -> 120 in the cache */
   /* search101_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace101 -> 36 in the cache */

   /* ('udot_4x8_uadd', 'a', 0, 'b') => b */
   /* search102_0 -> 16 in the cache */
   /* search102_1 -> 120 in the cache */
   /* search102_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace102 -> 36 in the cache */

   /* ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search103_0 -> 16 in the cache */
   /* search103_1 -> 120 in the cache */
   /* search103_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace103 -> 36 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 0, 'b') => b */
   /* search104_0 -> 16 in the cache */
   /* search104_1 -> 120 in the cache */
   /* search104_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace104 -> 36 in the cache */

   /* ('sdot_2x16_iadd', 'a', 0, 'b') => b */
   /* search105_0 -> 16 in the cache */
   /* search105_1 -> 120 in the cache */
   /* search105_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace105 -> 36 in the cache */

   /* ('udot_2x16_uadd', 'a', 0, 'b') => b */
   /* search106_0 -> 16 in the cache */
   /* search106_1 -> 120 in the cache */
   /* search106_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace106 -> 36 in the cache */

   /* ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b */
   /* search107_0 -> 16 in the cache */
   /* search107_1 -> 120 in the cache */
   /* search107_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace107 -> 36 in the cache */

   /* ('udot_2x16_uadd_sat', 'a', 0, 'b') => b */
   /* search108_0 -> 16 in the cache */
   /* search108_1 -> 120 in the cache */
   /* search108_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace108 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 'a', 0, 'b') => b */
   /* search109_0 -> 16 in the cache */
   /* search109_1 -> 120 in the cache */
   /* search109_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 120, 36 },
      -1,
   } },

   /* replace109 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 0, 'a', 'b') => b */
   /* search110_0 -> 120 in the cache */
   /* search110_1 -> 16 in the cache */
   /* search110_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 120, 16, 36 },
      -1,
   } },

   /* replace110 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search111_0 -> 16 in the cache */
   /* search111_1 -> 120 in the cache */
   /* search111_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 120, 36 },
      -1,
   } },

   /* replace111 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b */
   /* search112_0 -> 120 in the cache */
   /* search112_1 -> 16 in the cache */
   /* search112_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 120, 16, 36 },
      -1,
   } },

   /* replace112 -> 36 in the cache */

   /* ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search113_0_0 -> 16 in the cache */
   /* search113_0_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 295, 296 },
      -1,
   } },

   /* replace113_0 -> 16 in the cache */
   /* replace113_1 -> 36 in the cache */
   /* replace113_2_0 -> 133 in the cache */
   /* replace113_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search114_0_0 -> 16 in the cache */
   /* search114_0_1 -> 36 in the cache */
   /* search114_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   /* search114_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 300, 296 },
      -1,
   } },

   /* replace114_0 -> 16 in the cache */
   /* replace114_1 -> 36 in the cache */
   /* replace114_2_0 -> 133 in the cache */
   /* replace114_2_1 -> 161 in the cache */
   /* replace114_2 -> 298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search115_0_0 -> 16 in the cache */
   /* search115_0_1 -> 36 in the cache */
   /* search115_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 294 },
      0,
   } },
   /* search115_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 303, 296 },
      -1,
   } },

   /* replace115_0 -> 16 in the cache */
   /* replace115_1 -> 36 in the cache */
   /* replace115_2_0 -> 133 in the cache */
   /* replace115_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 1,
      { 16, 36, 305 },
      -1,
   } },

   /* ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search116_0_0 -> 16 in the cache */
   /* search116_0_1 -> 36 in the cache */
   /* search116_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   /* search116_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 307, 296 },
      -1,
   } },

   /* replace116_0 -> 16 in the cache */
   /* replace116_1 -> 36 in the cache */
   /* replace116_2_0 -> 133 in the cache */
   /* replace116_2_1 -> 161 in the cache */
   /* replace116_2 -> 298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search117_0_0 -> 16 in the cache */
   /* search117_0_1 -> 36 in the cache */
   /* search117_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   /* search117_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 310, 296 },
      -1,
   } },

   /* replace117_0 -> 16 in the cache */
   /* replace117_1 -> 36 in the cache */
   /* replace117_2_0 -> 133 in the cache */
   /* replace117_2_1 -> 161 in the cache */
   /* replace117_2 -> 298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search118_0_1 -> 36 in the cache */
   /* search118_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search118_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 314, 133 },
      -1,
   } },

   /* replace118_0 -> 16 in the cache */
   /* replace118_1 -> 36 in the cache */
   /* replace118_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search119_0_0 -> 313 in the cache */
   /* search119_0_1 -> 36 in the cache */
   /* search119_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search119_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 317, 133 },
      -1,
   } },

   /* replace119_0 -> 16 in the cache */
   /* replace119_1 -> 36 in the cache */
   /* replace119_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search120_0_0 -> 313 in the cache */
   /* search120_0_1 -> 36 in the cache */
   /* search120_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 313, 36, 120 },
      -1,
   } },
   /* search120_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 320, 133 },
      -1,
   } },

   /* replace120_0 -> 16 in the cache */
   /* replace120_1 -> 36 in the cache */
   /* replace120_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search121_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search121_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 323, 120 },
      -1,
   } },
   /* search121_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 324, 133 },
      -1,
   } },

   /* replace121_0 -> 16 in the cache */
   /* replace121_1 -> 36 in the cache */
   /* replace121_2 -> 133 in the cache */
   /* replace121 -> 322 in the cache */

   /* ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c') */
   /* search122_0_0 -> 313 in the cache */
   /* search122_0_1 -> 36 in the cache */
   /* search122_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search122_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 326, 133 },
      -1,
   } },

   /* replace122_0 -> 16 in the cache */
   /* replace122_1 -> 36 in the cache */
   /* replace122_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c') */
   /* search123_0_0 -> 313 in the cache */
   /* search123_0_1 -> 36 in the cache */
   /* search123_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search123_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 329, 133 },
      -1,
   } },

   /* replace123_0 -> 16 in the cache */
   /* replace123_1 -> 36 in the cache */
   /* replace123_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search124_0 -> 271 in the cache */
   /* search124_1 -> 33 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace124_0_0 -> 16 in the cache */
   /* replace124_0_1 -> 36 in the cache */
   /* replace124_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace124_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 334, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search125_0 -> 271 in the cache */
   /* search125_1 -> 33 in the cache */
   /* search125_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace125_0_0 -> 16 in the cache */
   /* replace125_0_1 -> 36 in the cache */
   /* replace125_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace125_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 337, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search126_0 -> 271 in the cache */
   /* search126_1 -> 33 in the cache */
   /* search126_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 271, 33, 332 },
      -1,
   } },

   /* replace126_0_0 -> 16 in the cache */
   /* replace126_0_1 -> 36 in the cache */
   /* replace126_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },
   /* replace126_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 340, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search127_0 -> 271 in the cache */
   /* search127_1 -> 33 in the cache */
   /* search127_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace127_0_0 -> 16 in the cache */
   /* replace127_0_1 -> 36 in the cache */
   /* replace127_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace127_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 343, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search128_0 -> 271 in the cache */
   /* search128_1 -> 33 in the cache */
   /* search128_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace128_0_0 -> 16 in the cache */
   /* replace128_0_1 -> 36 in the cache */
   /* replace128_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace128_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 346, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search129_0 -> 271 in the cache */
   /* search129_1 -> 33 in the cache */
   /* search129_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace129_0_0 -> 16 in the cache */
   /* replace129_0_1 -> 36 in the cache */
   /* replace129_0_2 -> 120 in the cache */
   /* replace129_0 -> 334 in the cache */
   /* replace129_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 334, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search130_0 -> 271 in the cache */
   /* search130_1 -> 33 in the cache */
   /* search130_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace130_0_0 -> 16 in the cache */
   /* replace130_0_1 -> 36 in the cache */
   /* replace130_0_2 -> 120 in the cache */
   /* replace130_0 -> 337 in the cache */
   /* replace130_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 337, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search131_0 -> 271 in the cache */
   /* search131_1 -> 33 in the cache */
   /* search131_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 271, 33, 332 },
      -1,
   } },

   /* replace131_0_0 -> 16 in the cache */
   /* replace131_0_1 -> 36 in the cache */
   /* replace131_0_2 -> 120 in the cache */
   /* replace131_0 -> 340 in the cache */
   /* replace131_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 340, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search132_0 -> 271 in the cache */
   /* search132_1 -> 33 in the cache */
   /* search132_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace132_0_0 -> 16 in the cache */
   /* replace132_0_1 -> 36 in the cache */
   /* replace132_0_2 -> 120 in the cache */
   /* replace132_0 -> 343 in the cache */
   /* replace132_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 343, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search133_0 -> 271 in the cache */
   /* search133_1 -> 33 in the cache */
   /* search133_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace133_0_0 -> 16 in the cache */
   /* replace133_0_1 -> 36 in the cache */
   /* replace133_0_2 -> 120 in the cache */
   /* replace133_0 -> 346 in the cache */
   /* replace133_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 346, 133 },
      -1,
   } },

   /* ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search134_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 358, 117 },
      -1,
   } },
   /* search134_0_1 -> 117 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 359, 117, 360 },
      -1,
   } },
   /* search134_1_0_0 -> 360 in the cache */
   /* search134_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      2, 1,
      { 360, 117 },
      -1,
   } },
   /* search134_1_1 -> 117 in the cache */
   /* search134_1_2 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 362, 117, 358 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 361, 363 },
      -1,
   } },

   /* replace134_0 -> 360 in the cache */
   /* replace134_1 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 360, 358 },
      -1,
   } },

   /* ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b') */
   /* search135_0 -> 16 in the cache */
   /* search135_1_0_0 -> 16 in the cache */
   /* search135_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 16, 117 },
      -1,
   } },
   /* search135_1_1 -> 117 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 366, 117, 367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 16, 368 },
      -1,
   } },

   /* replace135_0 -> 16 in the cache */
   /* replace135_1 -> 36 in the cache */
   /* replace135 -> 254 in the cache */

   /* ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search136_0_0_0 -> 358 in the cache */
   /* search136_0_0_1 -> 117 in the cache */
   /* search136_0_0 -> 359 in the cache */
   /* search136_0_1 -> 117 in the cache */
   /* search136_0_2 -> 360 in the cache */
   /* search136_0 -> 361 in the cache */
   /* search136_1_0_0 -> 360 in the cache */
   /* search136_1_0_1 -> 117 in the cache */
   /* search136_1_0 -> 362 in the cache */
   /* search136_1_1 -> 117 in the cache */
   /* search136_1_2 -> 358 in the cache */
   /* search136_1 -> 363 in the cache */
   /* search136_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 361, 363, 133 },
      -1,
   } },

   /* replace136_0 -> 360 in the cache */
   /* replace136_1 -> 358 in the cache */
   /* replace136_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 360, 358, 133 },
      -1,
   } },

   /* ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search137_0 -> 16 in the cache */
   /* search137_1_0_0 -> 16 in the cache */
   /* search137_1_0_1 -> 117 in the cache */
   /* search137_1_0 -> 366 in the cache */
   /* search137_1_1 -> 117 in the cache */
   /* search137_1_2 -> 367 in the cache */
   /* search137_1 -> 368 in the cache */
   /* search137_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 16, 368, 133 },
      -1,
   } },

   /* replace137_0 -> 16 in the cache */
   /* replace137_1 -> 36 in the cache */
   /* replace137_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search138_0 -> 16 in the cache */
   /* search138_1 -> 36 in the cache */
   /* search138_2 -> 133 in the cache */
   /* search138 -> 316 in the cache */

   /* replace138_0_0_0_0_0 -> 16 in the cache */
   /* replace138_0_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace138_0_0_0_1_0 -> 36 in the cache */
   /* replace138_0_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 374, 375 },
      -1,
   } },
   /* replace138_0_0_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace138_0_0_1_1_0 -> 36 in the cache */
   /* replace138_0_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 378, 379 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 376, 380 },
      -1,
   } },
   /* replace138_0_1_0_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 382 },
      -1,
   } },
   /* replace138_0_1_0_1_0 -> 36 in the cache */
   /* replace138_0_1_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 383, 384 },
      -1,
   } },
   /* replace138_0_1_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 386 },
      -1,
   } },
   /* replace138_0_1_1_1_0 -> 36 in the cache */
   /* replace138_0_1_1_1_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 387, 388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 385, 389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 381, 390 },
      -1,
   } },
   /* replace138_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 391, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search139_0 -> 16 in the cache */
   /* search139_1 -> 36 in the cache */
   /* search139_2 -> 133 in the cache */
   /* search139 -> 319 in the cache */

   /* replace139_0_0_0_0_0 -> 16 in the cache */
   /* replace139_0_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace139_0_0_0_1_0 -> 36 in the cache */
   /* replace139_0_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 393, 394 },
      -1,
   } },
   /* replace139_0_0_1_0_0 -> 16 in the cache */
   /* replace139_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace139_0_0_1_1_0 -> 36 in the cache */
   /* replace139_0_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 396, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 395, 398 },
      -1,
   } },
   /* replace139_0_1_0_0_0 -> 16 in the cache */
   /* replace139_0_1_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 382 },
      -1,
   } },
   /* replace139_0_1_0_1_0 -> 36 in the cache */
   /* replace139_0_1_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 400, 401 },
      -1,
   } },
   /* replace139_0_1_1_0_0 -> 16 in the cache */
   /* replace139_0_1_1_0_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 386 },
      -1,
   } },
   /* replace139_0_1_1_1_0 -> 36 in the cache */
   /* replace139_0_1_1_1_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 403, 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 402, 405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 399, 406 },
      -1,
   } },
   /* replace139_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 407, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search140_0 -> 16 in the cache */
   /* search140_1 -> 36 in the cache */
   /* search140_2 -> 133 in the cache */
   /* search140 -> 322 in the cache */

   /* replace140_0_0_0_0_0 -> 16 in the cache */
   /* replace140_0_0_0_0_1 -> 120 in the cache */
   /* replace140_0_0_0_0 -> 374 in the cache */
   /* replace140_0_0_0_1_0 -> 36 in the cache */
   /* replace140_0_0_0_1_1 -> 120 in the cache */
   /* replace140_0_0_0_1 -> 394 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 374, 394 },
      -1,
   } },
   /* replace140_0_0_1_0_0 -> 16 in the cache */
   /* replace140_0_0_1_0_1 -> 377 in the cache */
   /* replace140_0_0_1_0 -> 378 in the cache */
   /* replace140_0_0_1_1_0 -> 36 in the cache */
   /* replace140_0_0_1_1_1 -> 377 in the cache */
   /* replace140_0_0_1_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 378, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 409, 410 },
      -1,
   } },
   /* replace140_0_1_0_0_0 -> 16 in the cache */
   /* replace140_0_1_0_0_1 -> 382 in the cache */
   /* replace140_0_1_0_0 -> 383 in the cache */
   /* replace140_0_1_0_1_0 -> 36 in the cache */
   /* replace140_0_1_0_1_1 -> 382 in the cache */
   /* replace140_0_1_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 383, 401 },
      -1,
   } },
   /* replace140_0_1_1_0_0 -> 16 in the cache */
   /* replace140_0_1_1_0_1 -> 386 in the cache */
   /* replace140_0_1_1_0 -> 387 in the cache */
   /* replace140_0_1_1_1_0 -> 36 in the cache */
   /* replace140_0_1_1_1_1 -> 386 in the cache */
   /* replace140_0_1_1_1 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 387, 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 412, 413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 411, 414 },
      -1,
   } },
   /* replace140_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 415, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search141_0 -> 16 in the cache */
   /* search141_1 -> 36 in the cache */
   /* search141_2 -> 133 in the cache */
   /* search141 -> 328 in the cache */

   /* replace141_0_0_0_0 -> 16 in the cache */
   /* replace141_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace141_0_0_1_0 -> 36 in the cache */
   /* replace141_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 417, 418 },
      -1,
   } },
   /* replace141_0_1_0_0 -> 16 in the cache */
   /* replace141_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace141_0_1_1_0 -> 36 in the cache */
   /* replace141_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 420, 421 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 419, 422 },
      -1,
   } },
   /* replace141_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 423, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search142_0 -> 16 in the cache */
   /* search142_1 -> 36 in the cache */
   /* search142_2 -> 133 in the cache */
   /* search142 -> 331 in the cache */

   /* replace142_0_0_0_0 -> 16 in the cache */
   /* replace142_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace142_0_0_1_0 -> 36 in the cache */
   /* replace142_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 425, 426 },
      -1,
   } },
   /* replace142_0_1_0_0 -> 16 in the cache */
   /* replace142_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace142_0_1_1_0 -> 36 in the cache */
   /* replace142_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 428, 429 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 427, 430 },
      -1,
   } },
   /* replace142_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 431, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search143_0 -> 16 in the cache */
   /* search143_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 433 },
      -1,
   } },

   /* replace143_0 -> 16 in the cache */
   /* replace143_1 -> 36 in the cache */
   /* replace143_2 -> 133 in the cache */
   /* replace143 -> 319 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search144_0 -> 16 in the cache */
   /* search144_1 -> 36 in the cache */
   /* search144_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace144_0_0_0_0_0 -> 16 in the cache */
   /* replace144_0_0_0_0_1 -> 120 in the cache */
   /* replace144_0_0_0_0 -> 393 in the cache */
   /* replace144_0_0_0_1_0 -> 36 in the cache */
   /* replace144_0_0_0_1_1 -> 120 in the cache */
   /* replace144_0_0_0_1 -> 394 in the cache */
   /* replace144_0_0_0 -> 395 in the cache */
   /* replace144_0_0_1_0_0 -> 16 in the cache */
   /* replace144_0_0_1_0_1 -> 377 in the cache */
   /* replace144_0_0_1_0 -> 396 in the cache */
   /* replace144_0_0_1_1_0 -> 36 in the cache */
   /* replace144_0_0_1_1_1 -> 377 in the cache */
   /* replace144_0_0_1_1 -> 397 in the cache */
   /* replace144_0_0_1 -> 398 in the cache */
   /* replace144_0_0 -> 399 in the cache */
   /* replace144_0_1_0_0_0 -> 16 in the cache */
   /* replace144_0_1_0_0_1 -> 382 in the cache */
   /* replace144_0_1_0_0 -> 400 in the cache */
   /* replace144_0_1_0_1_0 -> 36 in the cache */
   /* replace144_0_1_0_1_1 -> 382 in the cache */
   /* replace144_0_1_0_1 -> 401 in the cache */
   /* replace144_0_1_0 -> 402 in the cache */
   /* replace144_0_1_1_0_0 -> 16 in the cache */
   /* replace144_0_1_1_0_1 -> 386 in the cache */
   /* replace144_0_1_1_0 -> 403 in the cache */
   /* replace144_0_1_1_1_0 -> 36 in the cache */
   /* replace144_0_1_1_1_1 -> 386 in the cache */
   /* replace144_0_1_1_1 -> 404 in the cache */
   /* replace144_0_1_1 -> 405 in the cache */
   /* replace144_0_1 -> 406 in the cache */
   /* replace144_0 -> 407 in the cache */
   /* replace144_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 8,
      { 407, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search145_0 -> 16 in the cache */
   /* search145_1 -> 36 in the cache */
   /* search145_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace145_0_0_0_0_0 -> 16 in the cache */
   /* replace145_0_0_0_0_1 -> 120 in the cache */
   /* replace145_0_0_0_0 -> 374 in the cache */
   /* replace145_0_0_0_1_0 -> 36 in the cache */
   /* replace145_0_0_0_1_1 -> 120 in the cache */
   /* replace145_0_0_0_1 -> 375 in the cache */
   /* replace145_0_0_0 -> 376 in the cache */
   /* replace145_0_0_1_0_0 -> 16 in the cache */
   /* replace145_0_0_1_0_1 -> 377 in the cache */
   /* replace145_0_0_1_0 -> 378 in the cache */
   /* replace145_0_0_1_1_0 -> 36 in the cache */
   /* replace145_0_0_1_1_1 -> 377 in the cache */
   /* replace145_0_0_1_1 -> 379 in the cache */
   /* replace145_0_0_1 -> 380 in the cache */
   /* replace145_0_0 -> 381 in the cache */
   /* replace145_0_1_0_0_0 -> 16 in the cache */
   /* replace145_0_1_0_0_1 -> 382 in the cache */
   /* replace145_0_1_0_0 -> 383 in the cache */
   /* replace145_0_1_0_1_0 -> 36 in the cache */
   /* replace145_0_1_0_1_1 -> 382 in the cache */
   /* replace145_0_1_0_1 -> 384 in the cache */
   /* replace145_0_1_0 -> 385 in the cache */
   /* replace145_0_1_1_0_0 -> 16 in the cache */
   /* replace145_0_1_1_0_1 -> 386 in the cache */
   /* replace145_0_1_1_0 -> 387 in the cache */
   /* replace145_0_1_1_1_0 -> 36 in the cache */
   /* replace145_0_1_1_1_1 -> 386 in the cache */
   /* replace145_0_1_1_1 -> 388 in the cache */
   /* replace145_0_1_1 -> 389 in the cache */
   /* replace145_0_1 -> 390 in the cache */
   /* replace145_0 -> 391 in the cache */
   /* replace145_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 391, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search146_0 -> 16 in the cache */
   /* search146_1 -> 36 in the cache */
   /* search146_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* replace146_0_0_0_0_0 -> 16 in the cache */
   /* replace146_0_0_0_0_1 -> 120 in the cache */
   /* replace146_0_0_0_0 -> 374 in the cache */
   /* replace146_0_0_0_1_0 -> 36 in the cache */
   /* replace146_0_0_0_1_1 -> 120 in the cache */
   /* replace146_0_0_0_1 -> 394 in the cache */
   /* replace146_0_0_0 -> 409 in the cache */
   /* replace146_0_0_1_0_0 -> 16 in the cache */
   /* replace146_0_0_1_0_1 -> 377 in the cache */
   /* replace146_0_0_1_0 -> 378 in the cache */
   /* replace146_0_0_1_1_0 -> 36 in the cache */
   /* replace146_0_0_1_1_1 -> 377 in the cache */
   /* replace146_0_0_1_1 -> 397 in the cache */
   /* replace146_0_0_1 -> 410 in the cache */
   /* replace146_0_0 -> 411 in the cache */
   /* replace146_0_1_0_0_0 -> 16 in the cache */
   /* replace146_0_1_0_0_1 -> 382 in the cache */
   /* replace146_0_1_0_0 -> 383 in the cache */
   /* replace146_0_1_0_1_0 -> 36 in the cache */
   /* replace146_0_1_0_1_1 -> 382 in the cache */
   /* replace146_0_1_0_1 -> 401 in the cache */
   /* replace146_0_1_0 -> 412 in the cache */
   /* replace146_0_1_1_0_0 -> 16 in the cache */
   /* replace146_0_1_1_0_1 -> 386 in the cache */
   /* replace146_0_1_1_0 -> 387 in the cache */
   /* replace146_0_1_1_1_0 -> 36 in the cache */
   /* replace146_0_1_1_1_1 -> 386 in the cache */
   /* replace146_0_1_1_1 -> 404 in the cache */
   /* replace146_0_1_1 -> 413 in the cache */
   /* replace146_0_1 -> 414 in the cache */
   /* replace146_0 -> 415 in the cache */
   /* replace146_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 415, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search147_0 -> 16 in the cache */
   /* search147_1 -> 36 in the cache */
   /* search147_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace147_0_0_0_0 -> 16 in the cache */
   /* replace147_0_0_0_1 -> 120 in the cache */
   /* replace147_0_0_0 -> 425 in the cache */
   /* replace147_0_0_1_0 -> 36 in the cache */
   /* replace147_0_0_1_1 -> 120 in the cache */
   /* replace147_0_0_1 -> 426 in the cache */
   /* replace147_0_0 -> 427 in the cache */
   /* replace147_0_1_0_0 -> 16 in the cache */
   /* replace147_0_1_0_1 -> 377 in the cache */
   /* replace147_0_1_0 -> 428 in the cache */
   /* replace147_0_1_1_0 -> 36 in the cache */
   /* replace147_0_1_1_1 -> 377 in the cache */
   /* replace147_0_1_1 -> 429 in the cache */
   /* replace147_0_1 -> 430 in the cache */
   /* replace147_0 -> 431 in the cache */
   /* replace147_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 4,
      { 431, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search148_0 -> 16 in the cache */
   /* search148_1 -> 36 in the cache */
   /* search148_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace148_0_0_0_0 -> 16 in the cache */
   /* replace148_0_0_0_1 -> 120 in the cache */
   /* replace148_0_0_0 -> 417 in the cache */
   /* replace148_0_0_1_0 -> 36 in the cache */
   /* replace148_0_0_1_1 -> 120 in the cache */
   /* replace148_0_0_1 -> 418 in the cache */
   /* replace148_0_0 -> 419 in the cache */
   /* replace148_0_1_0_0 -> 16 in the cache */
   /* replace148_0_1_0_1 -> 377 in the cache */
   /* replace148_0_1_0 -> 420 in the cache */
   /* replace148_0_1_1_0 -> 36 in the cache */
   /* replace148_0_1_1_1 -> 377 in the cache */
   /* replace148_0_1_1 -> 421 in the cache */
   /* replace148_0_1 -> 422 in the cache */
   /* replace148_0 -> 423 in the cache */
   /* replace148_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 4,
      { 423, 133 },
      -1,
   } },

   /* ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search149_0 -> 11 in the cache */
   /* search149_1 -> 243 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 243, 446 },
      -1,
   } },

   /* replace149_0 -> 445 in the cache */
   /* replace149_1 -> 243 in the cache */
   /* replace149_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 243, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search150_0 -> 11 in the cache */
   /* search150_1_0 -> 11 in the cache */
   /* search150_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 449, 450 },
      -1,
   } },

   /* replace150_0_0 -> 243 in the cache */
   /* replace150_0_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 243, 450 },
      -1,
   } },
   /* replace150_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 452, 11 },
      -1,
   } },

   /* ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search151_0_0 -> 11 in the cache */
   /* search151_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 243 },
      0,
   } },
   /* search151_1_0 -> 11 in the cache */
   /* search151_1_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 11, 450 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 454, 455, 456 },
      -1,
   } },

   /* replace151_0_0 -> 243 in the cache */
   /* replace151_0_1 -> 450 in the cache */
   /* replace151_0_2 -> 456 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 243, 450, 456 },
      -1,
   } },
   /* replace151_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 458, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search152_0 -> 11 in the cache */
   /* search152_1_0 -> 11 in the cache */
   /* search152_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 243 },
      0,
   } },
   /* search152_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 460, 450 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace152_0_1 -> 243 in the cache */
   /* replace152_0_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 462, 243, 450 },
      -1,
   } },
   /* replace152_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 463, 11 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search153_0_0 -> 11 in the cache */
   /* search153_0_1_0 -> 462 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 462, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 467 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search153_1_1 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 469, 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 468, 470 },
      -1,
   } },

   /* replace153_0 -> 11 in the cache */
   /* replace153_1 -> 469 in the cache */
   /* replace153_2 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 469, 465 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search154_0_0 -> 11 in the cache */
   /* search154_0_1_0_0 -> 462 in the cache */
   /* search154_0_1_0_1_0 -> 465 in the cache */
   /* search154_0_1_0_1 -> 466 in the cache */
   /* search154_0_1_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 473 },
      -1,
   } },
   /* search154_1_0 -> 469 in the cache */
   /* search154_1_1_0 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 469, 475 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 474, 476 },
      -1,
   } },

   /* replace154_0 -> 11 in the cache */
   /* replace154_1 -> 469 in the cache */
   /* replace154_2_0 -> 465 in the cache */
   /* replace154_2 -> 475 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 469, 475 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search155_0 -> 11 in the cache */
   /* search155_1_0 -> 465 in the cache */
   /* search155_1_1_0 -> 469 in the cache */
   /* search155_1_1_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 469, 479 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 465, 480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 481 },
      -1,
   } },

   /* replace155_0 -> 11 in the cache */
   /* replace155_1 -> 469 in the cache */
   /* replace155_2 -> 465 in the cache */
   /* replace155 -> 472 in the cache */

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search156_0_0 -> 11 in the cache */
   /* search156_0_1_0 -> 462 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 462, 485 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 486 },
      -1,
   } },
   /* search156_1_0 -> 469 in the cache */
   /* search156_1_1_0 -> 483 in the cache */
   /* search156_1_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 469, 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 487, 488 },
      -1,
   } },

   /* replace156_0 -> 483 in the cache */
   /* replace156_1 -> 469 in the cache */
   /* replace156_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 469, 11 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search157_0 -> 11 in the cache */
   /* search157_1_0_0 -> 483 in the cache */
   /* search157_1_0 -> 484 in the cache */
   /* search157_1_1_0 -> 469 in the cache */
   /* search157_1_1_1_0 -> 11 in the cache */
   /* search157_1_1_1 -> 479 in the cache */
   /* search157_1_1 -> 480 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 484, 480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 491 },
      -1,
   } },

   /* replace157_0 -> 483 in the cache */
   /* replace157_1 -> 469 in the cache */
   /* replace157_2 -> 11 in the cache */
   /* replace157 -> 490 in the cache */

   /* ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search158_0 -> 11 in the cache */
   /* search158_1_0 -> 462 in the cache */
   /* search158_1_1_0_0 -> 483 in the cache */
   /* search158_1_1_0 -> 484 in the cache */
   /* search158_1_1 -> 485 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 462, 485 },
      -1,
   } },
   /* search158_2_0 -> 469 in the cache */
   /* search158_2_1_0 -> 483 in the cache */
   /* search158_2_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 469, 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 11, 493, 494 },
      -1,
   } },

   /* replace158_0 -> 483 in the cache */
   /* replace158_1 -> 469 in the cache */
   /* replace158_2 -> 11 in the cache */
   /* replace158 -> 490 in the cache */

   /* ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search159_1_0 -> 483 in the cache */
   /* search159_1 -> 484 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 497 },
      -1,
   } },
   /* search159_2_1_0 -> 483 in the cache */
   /* search159_2_1 -> 484 in the cache */
   /* search159_2_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 498, 484, 497 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 496, 484, 499 },
      -1,
   } },

   /* replace159_0 -> 483 in the cache */
   /* replace159_1 -> 496 in the cache */
   /* replace159_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 496, 497 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search160_1_0 -> 243 in the cache */
   /* search160_1_1_0 -> 497 in the cache */
   /* search160_1_1 -> 498 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 243, 498 },
      -1,
   } },
   /* search160_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 503, 504, 497 },
      -1,
   } },

   /* replace160_0 -> 502 in the cache */
   /* replace160_1 -> 243 in the cache */
   /* replace160_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 243, 497 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search161_0_0 -> 502 in the cache */
   /* search161_0 -> 503 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 507 },
      -1,
   } },
   /* search161_1_1 -> 469 in the cache */
   /* search161_1_2 -> 456 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 508, 469, 456 },
      -1,
   } },
   /* search161_2_0 -> 507 in the cache */
   /* search161_2_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 507, 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 503, 509, 510 },
      -1,
   } },

   /* replace161_0 -> 502 in the cache */
   /* replace161_1 -> 456 in the cache */
   /* replace161_2_0 -> 507 in the cache */
   /* replace161_2_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 507, 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 502, 456, 512 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search162_0 -> 462 in the cache */
   /* search162_1_0_0_0 -> 462 in the cache */
   /* search162_1_0_0_1_0 -> 11 in the cache */
   /* search162_1_0_0_1 -> 479 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 462, 479 },
      -1,
   } },
   /* search162_1_0_1_0 -> 462 in the cache */
   /* search162_1_0_1_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 462, 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 514, 516 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 462, 518 },
      -1,
   } },

   /* replace162_0 -> 243 in the cache */
   /* replace162_1 -> 462 in the cache */
   /* replace162_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 243, 462, 11 },
      -1,
   } },

   /* ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search163_0 -> 16 in the cache */
   /* search163_1 -> 36 in the cache */
   /* search163_2_0 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 36, 521 },
      -1,
   } },

   /* replace163_0 -> 445 in the cache */
   /* replace163_1 -> 36 in the cache */
   /* replace163_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 36, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search164_0 -> 16 in the cache */
   /* search164_1_0 -> 16 in the cache */
   /* search164_1_1 -> 36 in the cache */
   /* search164_1 -> 259 in the cache */
   /* search164_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 259, 133 },
      -1,
   } },

   /* replace164_0_0 -> 36 in the cache */
   /* replace164_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 36, 133 },
      -1,
   } },
   /* replace164_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 525, 16 },
      -1,
   } },

   /* ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search165_0_0 -> 16 in the cache */
   /* search165_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search165_1_0 -> 16 in the cache */
   /* search165_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 133 },
      0,
   } },
   /* search165_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 527, 528, 161 },
      -1,
   } },

   /* replace165_0_0 -> 36 in the cache */
   /* replace165_0_1 -> 133 in the cache */
   /* replace165_0_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 133, 161 },
      -1,
   } },
   /* replace165_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 530, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search166_0 -> 16 in the cache */
   /* search166_1_0 -> 16 in the cache */
   /* search166_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search166_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 532, 133 },
      -1,
   } },

   /* replace166_0_0 -> 228 in the cache */
   /* replace166_0_1 -> 36 in the cache */
   /* replace166_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 228, 36, 133 },
      -1,
   } },
   /* replace166_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 534, 16 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search167_0_0 -> 16 in the cache */
   /* search167_0_1_0 -> 228 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 538 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search167_1_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 540, 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 539, 541 },
      -1,
   } },

   /* replace167_0 -> 16 in the cache */
   /* replace167_1 -> 540 in the cache */
   /* replace167_2 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 540, 536 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search168_0_0 -> 16 in the cache */
   /* search168_0_1_0_0 -> 228 in the cache */
   /* search168_0_1_0_1_0 -> 536 in the cache */
   /* search168_0_1_0_1 -> 537 in the cache */
   /* search168_0_1_0 -> 538 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 544 },
      -1,
   } },
   /* search168_1_0 -> 540 in the cache */
   /* search168_1_1_0 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 540, 546 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 545, 547 },
      -1,
   } },

   /* replace168_0 -> 16 in the cache */
   /* replace168_1 -> 540 in the cache */
   /* replace168_2_0 -> 536 in the cache */
   /* replace168_2 -> 546 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 540, 546 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search169_0 -> 16 in the cache */
   /* search169_1_0 -> 536 in the cache */
   /* search169_1_1_0 -> 540 in the cache */
   /* search169_1_1_1_0 -> 16 in the cache */
   /* search169_1_1_1 -> 265 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 540, 265 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 536, 550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 551 },
      -1,
   } },

   /* replace169_0 -> 16 in the cache */
   /* replace169_1 -> 540 in the cache */
   /* replace169_2 -> 536 in the cache */
   /* replace169 -> 543 in the cache */

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search170_0_0 -> 16 in the cache */
   /* search170_0_1_0 -> 228 in the cache */
   /* search170_0_1_1_0_0 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 555 },
      -1,
   } },
   /* search170_1_0 -> 540 in the cache */
   /* search170_1_1_0 -> 483 in the cache */
   /* search170_1_1 -> 553 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 540, 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 556, 557 },
      -1,
   } },

   /* replace170_0 -> 483 in the cache */
   /* replace170_1 -> 540 in the cache */
   /* replace170_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 540, 16 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search171_0 -> 16 in the cache */
   /* search171_1_0_0 -> 483 in the cache */
   /* search171_1_0 -> 553 in the cache */
   /* search171_1_1_0 -> 540 in the cache */
   /* search171_1_1_1_0 -> 16 in the cache */
   /* search171_1_1_1 -> 265 in the cache */
   /* search171_1_1 -> 550 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 553, 550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 560 },
      -1,
   } },

   /* replace171_0 -> 483 in the cache */
   /* replace171_1 -> 540 in the cache */
   /* replace171_2 -> 16 in the cache */
   /* replace171 -> 559 in the cache */

   /* ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search172_0 -> 16 in the cache */
   /* search172_1_0 -> 228 in the cache */
   /* search172_1_1_0_0 -> 483 in the cache */
   /* search172_1_1_0 -> 553 in the cache */
   /* search172_1_1 -> 554 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 228, 554 },
      -1,
   } },
   /* search172_2_0 -> 540 in the cache */
   /* search172_2_1_0 -> 483 in the cache */
   /* search172_2_1 -> 553 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 540, 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 16, 562, 563 },
      -1,
   } },

   /* replace172_0 -> 483 in the cache */
   /* replace172_1 -> 540 in the cache */
   /* replace172_2 -> 16 in the cache */
   /* replace172 -> 559 in the cache */

   /* ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   /* search173_0 -> 358 in the cache */
   /* search173_1_0 -> 483 in the cache */
   /* search173_1 -> 553 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 565 },
      -1,
   } },
   /* search173_2_1_0 -> 483 in the cache */
   /* search173_2_1 -> 553 in the cache */
   /* search173_2_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 566, 553, 565 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 358, 553, 567 },
      -1,
   } },

   /* replace173_0 -> 483 in the cache */
   /* replace173_1 -> 358 in the cache */
   /* replace173_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 358, 565 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search174_0_0 -> 502 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search174_1_0 -> 36 in the cache */
   /* search174_1_1_0 -> 565 in the cache */
   /* search174_1_1 -> 566 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 566 },
      -1,
   } },
   /* search174_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 570, 571, 565 },
      -1,
   } },

   /* replace174_0 -> 502 in the cache */
   /* replace174_1 -> 36 in the cache */
   /* replace174_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 36, 565 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search175_0_0 -> 502 in the cache */
   /* search175_0 -> 570 in the cache */
   /* search175_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 360 },
      -1,
   } },
   /* search175_1_1 -> 540 in the cache */
   /* search175_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 574, 540, 161 },
      -1,
   } },
   /* search175_2_0 -> 360 in the cache */
   /* search175_2_1 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 360, 540 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 570, 575, 576 },
      -1,
   } },

   /* replace175_0 -> 502 in the cache */
   /* replace175_1 -> 161 in the cache */
   /* replace175_2_0 -> 360 in the cache */
   /* replace175_2_1 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 360, 540 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 502, 161, 578 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search176_0 -> 228 in the cache */
   /* search176_1_0_0_0 -> 228 in the cache */
   /* search176_1_0_0_1_0 -> 16 in the cache */
   /* search176_1_0_0_1 -> 265 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 265 },
      -1,
   } },
   /* search176_1_0_1_0 -> 228 in the cache */
   /* search176_1_0_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 228, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 580, 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 583 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 228, 584 },
      -1,
   } },

   /* replace176_0 -> 36 in the cache */
   /* replace176_1 -> 228 in the cache */
   /* replace176_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 228, 16 },
      -1,
   } },

   /* ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search177_0 -> 21 in the cache */
   /* search177_1 -> 41 in the cache */
   /* search177_2_0 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 41, 587 },
      -1,
   } },

   /* replace177_0 -> 445 in the cache */
   /* replace177_1 -> 41 in the cache */
   /* replace177_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 41, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search178_0 -> 21 in the cache */
   /* search178_1_0 -> 21 in the cache */
   /* search178_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 590, 591 },
      -1,
   } },

   /* replace178_0_0 -> 41 in the cache */
   /* replace178_0_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 41, 591 },
      -1,
   } },
   /* replace178_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 593, 21 },
      -1,
   } },

   /* ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search179_0_0 -> 21 in the cache */
   /* search179_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search179_1_0 -> 21 in the cache */
   /* search179_1_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 21, 591 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 595, 596, 597 },
      -1,
   } },

   /* replace179_0_0 -> 41 in the cache */
   /* replace179_0_1 -> 591 in the cache */
   /* replace179_0_2 -> 597 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 591, 597 },
      -1,
   } },
   /* replace179_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 599, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search180_0 -> 21 in the cache */
   /* search180_1_0 -> 21 in the cache */
   /* search180_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search180_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 601, 591 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace180_0_1 -> 41 in the cache */
   /* replace180_0_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 603, 41, 591 },
      -1,
   } },
   /* replace180_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 604, 21 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search181_0_0 -> 21 in the cache */
   /* search181_0_1_0 -> 603 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 603, 607 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 608 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search181_1_1 -> 606 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 610, 606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 609, 611 },
      -1,
   } },

   /* replace181_0 -> 21 in the cache */
   /* replace181_1 -> 610 in the cache */
   /* replace181_2 -> 606 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 610, 606 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search182_0_0 -> 21 in the cache */
   /* search182_0_1_0_0 -> 603 in the cache */
   /* search182_0_1_0_1_0 -> 606 in the cache */
   /* search182_0_1_0_1 -> 607 in the cache */
   /* search182_0_1_0 -> 608 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 608 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 614 },
      -1,
   } },
   /* search182_1_0 -> 610 in the cache */
   /* search182_1_1_0 -> 606 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 610, 616 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 615, 617 },
      -1,
   } },

   /* replace182_0 -> 21 in the cache */
   /* replace182_1 -> 610 in the cache */
   /* replace182_2_0 -> 606 in the cache */
   /* replace182_2 -> 616 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 610, 616 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search183_0 -> 21 in the cache */
   /* search183_1_0 -> 606 in the cache */
   /* search183_1_1_0 -> 610 in the cache */
   /* search183_1_1_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 610, 620 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 606, 621 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 622 },
      -1,
   } },

   /* replace183_0 -> 21 in the cache */
   /* replace183_1 -> 610 in the cache */
   /* replace183_2 -> 606 in the cache */
   /* replace183 -> 613 in the cache */

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search184_0_0 -> 21 in the cache */
   /* search184_0_1_0 -> 603 in the cache */
   /* search184_0_1_1_0_0 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 603, 625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 626 },
      -1,
   } },
   /* search184_1_0 -> 610 in the cache */
   /* search184_1_1_0 -> 483 in the cache */
   /* search184_1_1 -> 624 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 610, 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 627, 628 },
      -1,
   } },

   /* replace184_0 -> 483 in the cache */
   /* replace184_1 -> 610 in the cache */
   /* replace184_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 610, 21 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search185_0 -> 21 in the cache */
   /* search185_1_0_0 -> 483 in the cache */
   /* search185_1_0 -> 624 in the cache */
   /* search185_1_1_0 -> 610 in the cache */
   /* search185_1_1_1_0 -> 21 in the cache */
   /* search185_1_1_1 -> 620 in the cache */
   /* search185_1_1 -> 621 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 624, 621 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 631 },
      -1,
   } },

   /* replace185_0 -> 483 in the cache */
   /* replace185_1 -> 610 in the cache */
   /* replace185_2 -> 21 in the cache */
   /* replace185 -> 630 in the cache */

   /* ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search186_0 -> 21 in the cache */
   /* search186_1_0 -> 603 in the cache */
   /* search186_1_1_0_0 -> 483 in the cache */
   /* search186_1_1_0 -> 624 in the cache */
   /* search186_1_1 -> 625 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 603, 625 },
      -1,
   } },
   /* search186_2_0 -> 610 in the cache */
   /* search186_2_1_0 -> 483 in the cache */
   /* search186_2_1 -> 624 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 610, 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 21, 633, 634 },
      -1,
   } },

   /* replace186_0 -> 483 in the cache */
   /* replace186_1 -> 610 in the cache */
   /* replace186_2 -> 21 in the cache */
   /* replace186 -> 630 in the cache */

   /* ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search187_1_0 -> 483 in the cache */
   /* search187_1 -> 624 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 637 },
      -1,
   } },
   /* search187_2_1_0 -> 483 in the cache */
   /* search187_2_1 -> 624 in the cache */
   /* search187_2_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 638, 624, 637 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 636, 624, 639 },
      -1,
   } },

   /* replace187_0 -> 483 in the cache */
   /* replace187_1 -> 636 in the cache */
   /* replace187_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 636, 637 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search188_0_0 -> 502 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search188_1_0 -> 41 in the cache */
   /* search188_1_1_0 -> 637 in the cache */
   /* search188_1_1 -> 638 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 41, 638 },
      -1,
   } },
   /* search188_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 642, 643, 637 },
      -1,
   } },

   /* replace188_0 -> 502 in the cache */
   /* replace188_1 -> 41 in the cache */
   /* replace188_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 41, 637 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search189_0_0 -> 502 in the cache */
   /* search189_0 -> 642 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 646 },
      -1,
   } },
   /* search189_1_1 -> 610 in the cache */
   /* search189_1_2 -> 597 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 647, 610, 597 },
      -1,
   } },
   /* search189_2_0 -> 646 in the cache */
   /* search189_2_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 646, 610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 642, 648, 649 },
      -1,
   } },

   /* replace189_0 -> 502 in the cache */
   /* replace189_1 -> 597 in the cache */
   /* replace189_2_0 -> 646 in the cache */
   /* replace189_2_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 646, 610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 502, 597, 651 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search190_0 -> 603 in the cache */
   /* search190_1_0_0_0 -> 603 in the cache */
   /* search190_1_0_0_1_0 -> 21 in the cache */
   /* search190_1_0_0_1 -> 620 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 603, 620 },
      -1,
   } },
   /* search190_1_0_1_0 -> 603 in the cache */
   /* search190_1_0_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 603, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 653, 655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 656 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 603, 657 },
      -1,
   } },

   /* replace190_0 -> 41 in the cache */
   /* replace190_1 -> 603 in the cache */
   /* replace190_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 603, 21 },
      -1,
   } },

   /* ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search191_0_0 -> 147 in the cache */
   /* search191_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 147, 148 },
      0,
   } },
   /* search191_1_0 -> 147 in the cache */
   /* search191_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 147, 150 },
      0,
   } },
   /* search191_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 660, 661, 151 },
      -1,
   } },

   /* replace191_0_0 -> 148 in the cache */
   /* replace191_0_1 -> 150 in the cache */
   /* replace191_0_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 148, 150, 151 },
      -1,
   } },
   /* replace191_1 -> 147 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 663, 147 },
      -1,
   } },

   /* ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a') */
   /* search192_0 -> 0 in the cache */
   /* search192_1 -> 241 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 241, 665 },
      -1,
   } },

   /* replace192_0_0_0 -> 0 in the cache */
   /* replace192_0_0 -> 197 in the cache */
   /* replace192_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 197, 665 },
      -1,
   } },
   /* replace192_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 667, 0 },
      -1,
   } },

   /* ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search193_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace193_0_0 -> 32 in the cache */
   /* replace193_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   /* replace193_1_0_0_0 -> 32 in the cache */
   /* replace193_1_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 103 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 671 },
      -1,
   } },
   /* replace193_2_0_0 -> 32 in the cache */
   /* replace193_2_0 -> 103 in the cache */
   /* replace193_2 -> 671 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 670, 672, 671 },
      -1,
   } },

   /* ('ffloor', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search194_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace194_0 -> 32 in the cache */
   /* replace194_1_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 32, 675 },
      -1,
   } },

   /* ('fadd', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search195_0 -> 32 in the cache */
   /* search195_1_0_0 -> 32 in the cache */
   /* search195_1_0 -> 675 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 32, 677 },
      -1,
   } },

   /* replace195_0 -> 32 in the cache */
   /* replace195 -> 674 in the cache */

   /* ('ffract', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search196_0 -> 32 in the cache */
   /* search196 -> 675 in the cache */

   /* replace196_0 -> 32 in the cache */
   /* replace196_1_0 -> 32 in the cache */
   /* replace196_1 -> 674 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 32, 674 },
      -1,
   } },

   /* ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a'))) */
   /* search197_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace197_0_0_0 -> 32 in the cache */
   /* replace197_0_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 681 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search198_0 -> 11 in the cache */
   /* search198_1 -> 243 in the cache */
   /* search198_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 243, 450 },
      -1,
   } },

   /* replace198_0_0 -> 11 in the cache */
   /* replace198_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace198_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 684, 450 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search199_0 -> 16 in the cache */
   /* search199_1 -> 36 in the cache */
   /* search199_2 -> 133 in the cache */
   /* search199 -> 219 in the cache */

   /* replace199_0_0 -> 16 in the cache */
   /* replace199_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace199_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 686, 133 },
      -1,
   } },

   /* ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search200_0 -> 21 in the cache */
   /* search200_1 -> 41 in the cache */
   /* search200_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 591 },
      -1,
   } },

   /* replace200_0_0 -> 21 in the cache */
   /* replace200_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace200_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 689, 591 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search201_0 -> 16 in the cache */
   /* search201_1 -> 36 in the cache */
   /* search201_2 -> 133 in the cache */
   /* search201 -> 373 in the cache */

   /* replace201_0_0 -> 16 in the cache */
   /* replace201_0_1 -> 36 in the cache */
   /* replace201_0 -> 132 in the cache */
   /* replace201_1 -> 133 in the cache */
   /* replace201 -> 273 in the cache */

   /* ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search202_0 -> 11 in the cache */
   /* search202_1 -> 243 in the cache */
   /* search202_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 243, 450 },
      -1,
   } },

   /* replace202_0_0 -> 11 in the cache */
   /* replace202_0_1 -> 243 in the cache */
   /* replace202_0 -> 684 in the cache */
   /* replace202_1 -> 450 in the cache */
   /* replace202 -> 685 in the cache */

   /* ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search203_0 -> 16 in the cache */
   /* search203_1 -> 36 in the cache */
   /* search203_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace203_0_0 -> 16 in the cache */
   /* replace203_0_1 -> 36 in the cache */
   /* replace203_0 -> 686 in the cache */
   /* replace203_1 -> 133 in the cache */
   /* replace203 -> 687 in the cache */

   /* ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search204_0 -> 21 in the cache */
   /* search204_1 -> 41 in the cache */
   /* search204_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 591 },
      -1,
   } },

   /* replace204_0_0 -> 21 in the cache */
   /* replace204_0_1 -> 41 in the cache */
   /* replace204_0 -> 689 in the cache */
   /* replace204_1 -> 591 in the cache */
   /* replace204 -> 690 in the cache */

   /* ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search205_0 -> 16 in the cache */
   /* search205_1 -> 36 in the cache */
   /* search205_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace205_0_0 -> 16 in the cache */
   /* replace205_0_1 -> 36 in the cache */
   /* replace205_0 -> 132 in the cache */
   /* replace205_1 -> 133 in the cache */
   /* replace205 -> 273 in the cache */

   /* ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 695 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 696 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 698, 699 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_iand,
      2, 2,
      { 697, 700 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 3,
      { 701, 702 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 4,
      { 703, 704 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace206_1_0_0_0 -> 698 in the cache */
   /* replace206_1_0_0_1 -> 699 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 698, 699 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 707, 708 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 709, 710 },
      -1,
   } },
   /* replace206_2_0 -> 708 in the cache */
   /* replace206_2_1 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 708, 710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 706, 711, 712 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b') */
   /* search207_0 -> 0 in the cache */
   /* search207_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   /* replace207_0_3 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 715, 716, 717, 255 },
      -1,
   } },
   /* replace207_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 718, 3 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search208_0_0 -> 147 in the cache */
   /* search208_0_1 -> 148 in the cache */
   /* search208_0_2 -> 150 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 147, 148, 150, 720 },
      -1,
   } },
   /* search208_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 721, 151 },
      -1,
   } },

   /* replace208_0_0 -> 147 in the cache */
   /* replace208_0_1 -> 148 in the cache */
   /* replace208_0_2 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 147, 148, 150 },
      -1,
   } },
   /* replace208_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 723, 151 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search209_0_0 -> 0 in the cache */
   /* search209_0_1 -> 241 in the cache */
   /* search209_0_2 -> 241 in the cache */
   /* search209_0_3 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 0, 241, 241, 241 },
      -1,
   } },
   /* search209_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 725, 3 },
      -1,
   } },

   /* replace209_0 -> 0 in the cache */
   /* replace209_1 -> 3 in the cache */
   /* replace209 -> 249 in the cache */

   /* ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search210_0_0 -> 124 in the cache */
   /* search210_0_1 -> 125 in the cache */
   { .constant = {
      { nir_search_value_constant, -3 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search210_0_3 -> 727 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 124, 125, 727, 727 },
      -1,
   } },
   /* search210_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 728, 127 },
      -1,
   } },

   /* replace210_0_0 -> 124 in the cache */
   /* replace210_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace210_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 730, 127 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search211_0_0 -> 147 in the cache */
   /* search211_0_1 -> 148 in the cache */
   /* search211_0_2 -> 150 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 147, 148, 150, 732 },
      -1,
   } },
   /* search211_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 733, 151 },
      -1,
   } },

   /* replace211_0_0 -> 147 in the cache */
   /* replace211_0_1 -> 148 in the cache */
   /* replace211_0_2 -> 150 in the cache */
   /* replace211_0 -> 723 in the cache */
   /* replace211_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 723, 151 },
      -1,
   } },

   /* ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search212_0_0 -> 0 in the cache */
   /* search212_0_1 -> 241 in the cache */
   /* search212_0_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 0, 241, 241 },
      -1,
   } },
   /* search212_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 736, 3 },
      -1,
   } },

   /* replace212_0 -> 0 in the cache */
   /* replace212_1 -> 3 in the cache */
   /* replace212 -> 249 in the cache */

   /* ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search213_0_0 -> 124 in the cache */
   /* search213_0_1 -> 125 in the cache */
   /* search213_0_2 -> 727 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 124, 125, 727 },
      -1,
   } },
   /* search213_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 738, 127 },
      -1,
   } },

   /* replace213_0_0 -> 124 in the cache */
   /* replace213_0_1 -> 125 in the cache */
   /* replace213_0 -> 730 in the cache */
   /* replace213_1 -> 127 in the cache */
   /* replace213 -> 731 in the cache */

   /* ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search214_0_0 -> 0 in the cache */
   /* search214_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 0, 241 },
      -1,
   } },
   /* search214_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 740, 3 },
      -1,
   } },

   /* replace214_0 -> 0 in the cache */
   /* replace214_1 -> 3 in the cache */
   /* replace214 -> 249 in the cache */

   /* ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y') */
   /* search215_0 -> 32 in the cache */
   /* search215_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 32, 226 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      -1, 0,
      { 743, 744 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b')) */
   /* search216_0 -> 0 in the cache */
   /* search216_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace216_0_0 -> 0 in the cache */
   /* replace216_0_1 -> 3 in the cache */
   /* replace216_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b')) */
   /* search217_0 -> 0 in the cache */
   /* search217_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace217_0_0 -> 0 in the cache */
   /* replace217_0_1 -> 3 in the cache */
   /* replace217_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum3,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b')) */
   /* search218_0 -> 0 in the cache */
   /* search218_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace218_0_0 -> 0 in the cache */
   /* replace218_0_1 -> 3 in the cache */
   /* replace218_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum4,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fsum2', 'a') => ('fadd', 'a.x', 'a.y') */
   /* search219_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace219_0 -> 743 in the cache */
   /* replace219_1 -> 744 in the cache */
   /* replace219 -> 745 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 753 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 754 },
      0,
   } },
   /* search220_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 755, 226 },
      -1,
   } },

   /* replace220_0_0 -> 226 in the cache */
   /* replace220_0_1_0 -> 32 in the cache */
   /* replace220_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 226, 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 757 },
      -1,
   } },

   /* ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd')) */
   /* search221_0_0_0 -> 124 in the cache */
   /* search221_0_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 268 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 759, 760 },
      -1,
   } },
   /* search221_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 761, 296 },
      -1,
   } },

   /* replace221_0_0 -> 124 in the cache */
   /* replace221_0_1_0 -> 125 in the cache */
   /* replace221_0_1_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 125, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 763 },
      -1,
   } },
   /* replace221_1_0 -> 127 in the cache */
   /* replace221_1_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 127, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 764, 765 },
      -1,
   } },

   /* ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c')) */
   /* search222_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 767 },
      -1,
   } },
   /* search222_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 768, 294 },
      -1,
   } },

   /* replace222_0 -> 0 in the cache */
   /* replace222_1_0 -> 3 in the cache */
   /* replace222_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 770 },
      -1,
   } },

   /* ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search223_0_0 -> 6 in the cache */
   /* search223_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search223_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 772, 294 },
      -1,
   } },

   /* replace223_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 774 },
      -1,
   } },
   /* replace223_0_0_1_0 -> 133 in the cache */
   /* replace223_0_0_1_1 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 774 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 775, 776 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 777, 778 },
      -1,
   } },
   /* replace223_1_0 -> 6 in the cache */
   /* replace223_1_1_0 -> 36 in the cache */
   /* replace223_1_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 780 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 779, 781, 782 },
      -1,
   } },

   /* ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search224_0_0 -> 6 in the cache */
   /* search224_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search224_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 784, 294 },
      -1,
   } },

   /* replace224_0_0_0_0 -> 36 in the cache */
   /* replace224_0_0_0_1 -> 774 in the cache */
   /* replace224_0_0_0 -> 775 in the cache */
   /* replace224_0_0_1_0 -> 133 in the cache */
   /* replace224_0_0_1_1 -> 774 in the cache */
   /* replace224_0_0_1 -> 776 in the cache */
   /* replace224_0_0 -> 777 in the cache */
   /* replace224_0_1 -> 778 in the cache */
   /* replace224_0 -> 779 in the cache */
   /* replace224_1_0 -> 6 in the cache */
   /* replace224_1_1_0 -> 36 in the cache */
   /* replace224_1_1_1 -> 133 in the cache */
   /* replace224_1_1 -> 780 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 780 },
      -1,
   } },
   /* replace224_2 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 779, 786, 782 },
      -1,
   } },

   /* ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 7)) */
   /* search225_0_0 -> 6 in the cache */
   /* search225_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search225_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 788, 294 },
      -1,
   } },

   /* replace225_0 -> 6 in the cache */
   /* replace225_1_0_0_0 -> 36 in the cache */
   /* replace225_1_0_0_1 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 774 },
      -1,
   } },
   /* replace225_1_0_1_0 -> 133 in the cache */
   /* replace225_1_0_1_1 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 774 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 790, 791 },
      -1,
   } },
   /* replace225_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 792, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 6, 793 },
      -1,
   } },

   /* ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search226_0_0 -> 11 in the cache */
   /* search226_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search226_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 795, 294 },
      -1,
   } },

   /* replace226_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 797 },
      -1,
   } },
   /* replace226_0_0_1_0 -> 133 in the cache */
   /* replace226_0_0_1_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 797 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 798, 799 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 800, 801 },
      -1,
   } },
   /* replace226_1_0 -> 11 in the cache */
   /* replace226_1_1_0 -> 36 in the cache */
   /* replace226_1_1_1 -> 133 in the cache */
   /* replace226_1_1 -> 780 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 780 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 802, 803, 804 },
      -1,
   } },

   /* ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search227_0_0 -> 11 in the cache */
   /* search227_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search227_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 806, 294 },
      -1,
   } },

   /* replace227_0_0_0_0 -> 36 in the cache */
   /* replace227_0_0_0_1 -> 797 in the cache */
   /* replace227_0_0_0 -> 798 in the cache */
   /* replace227_0_0_1_0 -> 133 in the cache */
   /* replace227_0_0_1_1 -> 797 in the cache */
   /* replace227_0_0_1 -> 799 in the cache */
   /* replace227_0_0 -> 800 in the cache */
   /* replace227_0_1 -> 801 in the cache */
   /* replace227_0 -> 802 in the cache */
   /* replace227_1_0 -> 11 in the cache */
   /* replace227_1_1_0 -> 36 in the cache */
   /* replace227_1_1_1 -> 133 in the cache */
   /* replace227_1_1 -> 780 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 780 },
      -1,
   } },
   /* replace227_2 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 802, 808, 804 },
      -1,
   } },

   /* ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 15)) */
   /* search228_0_0 -> 11 in the cache */
   /* search228_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search228_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 810, 294 },
      -1,
   } },

   /* replace228_0 -> 11 in the cache */
   /* replace228_1_0_0_0 -> 36 in the cache */
   /* replace228_1_0_0_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 797 },
      -1,
   } },
   /* replace228_1_0_1_0 -> 133 in the cache */
   /* replace228_1_0_1_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 797 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 812, 813 },
      -1,
   } },
   /* replace228_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 814, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 11, 815 },
      -1,
   } },

   /* ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search229_0_0 -> 16 in the cache */
   /* search229_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search229_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 817, 294 },
      -1,
   } },

   /* replace229_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 819 },
      -1,
   } },
   /* replace229_0_0_1_0 -> 133 in the cache */
   /* replace229_0_0_1_1 -> 819 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 819 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 820, 821 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x20 /* 32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 822, 823 },
      -1,
   } },
   /* replace229_1_0 -> 16 in the cache */
   /* replace229_1_1_0 -> 36 in the cache */
   /* replace229_1_1_1 -> 133 in the cache */
   /* replace229_1_1 -> 780 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 780 },
      -1,
   } },
   /* replace229_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 824, 825, 120 },
      -1,
   } },

   /* ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search230_0_0 -> 16 in the cache */
   /* search230_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search230_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 827, 294 },
      -1,
   } },

   /* replace230_0_0_0_0 -> 36 in the cache */
   /* replace230_0_0_0_1 -> 819 in the cache */
   /* replace230_0_0_0 -> 820 in the cache */
   /* replace230_0_0_1_0 -> 133 in the cache */
   /* replace230_0_0_1_1 -> 819 in the cache */
   /* replace230_0_0_1 -> 821 in the cache */
   /* replace230_0_0 -> 822 in the cache */
   /* replace230_0_1 -> 823 in the cache */
   /* replace230_0 -> 824 in the cache */
   /* replace230_1_0 -> 16 in the cache */
   /* replace230_1_1_0 -> 36 in the cache */
   /* replace230_1_1_1 -> 133 in the cache */
   /* replace230_1_1 -> 780 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 780 },
      -1,
   } },
   /* replace230_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 824, 829, 120 },
      -1,
   } },

   /* ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 31)) */
   /* search231_0_0 -> 16 in the cache */
   /* search231_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search231_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 831, 294 },
      -1,
   } },

   /* replace231_0 -> 16 in the cache */
   /* replace231_1_0_0_0 -> 36 in the cache */
   /* replace231_1_0_0_1 -> 819 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 819 },
      -1,
   } },
   /* replace231_1_0_1_0 -> 133 in the cache */
   /* replace231_1_0_1_1 -> 819 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 819 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 833, 834 },
      -1,
   } },
   /* replace231_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 835, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 16, 836 },
      -1,
   } },

   /* ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search232_0_0 -> 21 in the cache */
   /* search232_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search232_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 838, 294 },
      -1,
   } },

   /* replace232_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 840 },
      -1,
   } },
   /* replace232_0_0_1_0 -> 133 in the cache */
   /* replace232_0_0_1_1 -> 840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 840 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 841, 842 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x40 /* 64 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 843, 844 },
      -1,
   } },
   /* replace232_1_0 -> 21 in the cache */
   /* replace232_1_1_0 -> 36 in the cache */
   /* replace232_1_1_1 -> 133 in the cache */
   /* replace232_1_1 -> 780 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 780 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 845, 846, 847 },
      -1,
   } },

   /* ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search233_0_0 -> 21 in the cache */
   /* search233_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search233_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 849, 294 },
      -1,
   } },

   /* replace233_0_0_0_0 -> 36 in the cache */
   /* replace233_0_0_0_1 -> 840 in the cache */
   /* replace233_0_0_0 -> 841 in the cache */
   /* replace233_0_0_1_0 -> 133 in the cache */
   /* replace233_0_0_1_1 -> 840 in the cache */
   /* replace233_0_0_1 -> 842 in the cache */
   /* replace233_0_0 -> 843 in the cache */
   /* replace233_0_1 -> 844 in the cache */
   /* replace233_0 -> 845 in the cache */
   /* replace233_1_0 -> 21 in the cache */
   /* replace233_1_1_0 -> 36 in the cache */
   /* replace233_1_1_1 -> 133 in the cache */
   /* replace233_1_1 -> 780 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 780 },
      -1,
   } },
   /* replace233_2 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 845, 851, 847 },
      -1,
   } },

   /* ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 63)) */
   /* search234_0_0 -> 21 in the cache */
   /* search234_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search234_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 853, 294 },
      -1,
   } },

   /* replace234_0 -> 21 in the cache */
   /* replace234_1_0_0_0 -> 36 in the cache */
   /* replace234_1_0_0_1 -> 840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 840 },
      -1,
   } },
   /* replace234_1_0_1_0 -> 133 in the cache */
   /* replace234_1_0_1_1 -> 840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 840 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 855, 856 },
      -1,
   } },
   /* replace234_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 857, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 21, 858 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search235_0_0 -> 6 in the cache */
   /* search235_0_1 -> 33 in the cache */
   /* search235_0 -> 784 in the cache */
   /* search235_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 784, 36 },
      -1,
   } },

   /* replace235_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace235_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 861, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 862 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search236_0_0 -> 6 in the cache */
   /* search236_0_1 -> 33 in the cache */
   /* search236_0 -> 788 in the cache */
   /* search236_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 788, 36 },
      -1,
   } },

   /* replace236_0 -> 6 in the cache */
   /* replace236_1_0 -> 861 in the cache */
   /* replace236_1_1 -> 36 in the cache */
   /* replace236_1 -> 862 in the cache */
   /* replace236 -> 863 in the cache */

   /* ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b')) */
   /* search237_0_0 -> 6 in the cache */
   /* search237_0_1 -> 33 in the cache */
   /* search237_0 -> 772 in the cache */
   /* search237_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 772, 36 },
      -1,
   } },

   /* replace237_0 -> 6 in the cache */
   /* replace237_1_0 -> 861 in the cache */
   /* replace237_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 861, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 866 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search238_0_0 -> 11 in the cache */
   /* search238_0_1 -> 33 in the cache */
   /* search238_0 -> 806 in the cache */
   /* search238_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 806, 36 },
      -1,
   } },

   /* replace238_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace238_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 869, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 870 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search239_0_0 -> 11 in the cache */
   /* search239_0_1 -> 33 in the cache */
   /* search239_0 -> 810 in the cache */
   /* search239_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 810, 36 },
      -1,
   } },

   /* replace239_0 -> 11 in the cache */
   /* replace239_1_0 -> 869 in the cache */
   /* replace239_1_1 -> 36 in the cache */
   /* replace239_1 -> 870 in the cache */
   /* replace239 -> 871 in the cache */

   /* ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b')) */
   /* search240_0_0 -> 11 in the cache */
   /* search240_0_1 -> 33 in the cache */
   /* search240_0 -> 795 in the cache */
   /* search240_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 795, 36 },
      -1,
   } },

   /* replace240_0 -> 11 in the cache */
   /* replace240_1_0 -> 869 in the cache */
   /* replace240_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 869, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 874 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search241_0_0 -> 16 in the cache */
   /* search241_0_1 -> 33 in the cache */
   /* search241_0 -> 827 in the cache */
   /* search241_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 827, 36 },
      -1,
   } },

   /* replace241_0 -> 16 in the cache */
   /* replace241_1_0 -> 819 in the cache */
   /* replace241_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 819, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 877 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search242_0_0 -> 16 in the cache */
   /* search242_0_1 -> 33 in the cache */
   /* search242_0 -> 831 in the cache */
   /* search242_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 831, 36 },
      -1,
   } },

   /* replace242_0 -> 16 in the cache */
   /* replace242_1_0 -> 819 in the cache */
   /* replace242_1_1 -> 36 in the cache */
   /* replace242_1 -> 877 in the cache */
   /* replace242 -> 878 in the cache */

   /* ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b')) */
   /* search243_0_0 -> 16 in the cache */
   /* search243_0_1 -> 33 in the cache */
   /* search243_0 -> 817 in the cache */
   /* search243_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 817, 36 },
      -1,
   } },

   /* replace243_0 -> 16 in the cache */
   /* replace243_1_0 -> 819 in the cache */
   /* replace243_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 819, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 881 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search244_0_0 -> 21 in the cache */
   /* search244_0_1 -> 33 in the cache */
   /* search244_0 -> 849 in the cache */
   /* search244_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 849, 36 },
      -1,
   } },

   /* replace244_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   /* replace244_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 884, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 885 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search245_0_0 -> 21 in the cache */
   /* search245_0_1 -> 33 in the cache */
   /* search245_0 -> 853 in the cache */
   /* search245_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 853, 36 },
      -1,
   } },

   /* replace245_0 -> 21 in the cache */
   /* replace245_1_0 -> 884 in the cache */
   /* replace245_1_1 -> 36 in the cache */
   /* replace245_1 -> 885 in the cache */
   /* replace245 -> 886 in the cache */

   /* ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b')) */
   /* search246_0_0 -> 21 in the cache */
   /* search246_0_1 -> 33 in the cache */
   /* search246_0 -> 838 in the cache */
   /* search246_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 838, 36 },
      -1,
   } },

   /* replace246_0 -> 21 in the cache */
   /* replace246_1_0 -> 884 in the cache */
   /* replace246_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 884, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 889 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b') */
   /* search247_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 891 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 892, 893 },
      -1,
   } },

   /* replace247_0 -> 16 in the cache */
   /* replace247_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b') */
   /* search248_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 896 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 897, 898 },
      -1,
   } },

   /* replace248_0 -> 0 in the cache */
   /* replace248_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b') */
   /* search249_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      11,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 901 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffe /* 4294967294 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 902, 903 },
      -1,
   } },

   /* replace249_0_0 -> 16 in the cache */
   /* replace249_0_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 903 },
      -1,
   } },
   /* replace249_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 905, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b') */
   /* search250_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 907 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffc /* 4294967292 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 908, 909 },
      -1,
   } },

   /* replace250_0_0 -> 16 in the cache */
   /* replace250_0_1 -> 909 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 909 },
      -1,
   } },
   /* replace250_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 911, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b') */
   /* search251_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      12,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 913 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff8 /* 4294967288 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 914, 915 },
      -1,
   } },

   /* replace251_0_0 -> 16 in the cache */
   /* replace251_0_1 -> 915 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 915 },
      -1,
   } },
   /* replace251_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 917, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b') */
   /* search252_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 919 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff0 /* 4294967280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 920, 921 },
      -1,
   } },

   /* replace252_0_0 -> 16 in the cache */
   /* replace252_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 921 },
      -1,
   } },
   /* replace252_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 923, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b') */
   /* search253_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      14,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 925 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffe0 /* 4294967264 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 926, 927 },
      -1,
   } },

   /* replace253_0_0 -> 16 in the cache */
   /* replace253_0_1 -> 927 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 927 },
      -1,
   } },
   /* replace253_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 929, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b') */
   /* search254_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      15,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 931 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffc0 /* 4294967232 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 932, 933 },
      -1,
   } },

   /* replace254_0_0 -> 16 in the cache */
   /* replace254_0_1 -> 933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 933 },
      -1,
   } },
   /* replace254_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 935, 36 },
      -1,
   } },

   /* ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1) */
   /* search255_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 937 },
      -1,
   } },
   /* search255_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 938, 377 },
      -1,
   } },

   /* replace255_0 -> 16 in the cache */
   /* replace255_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 377 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1) */
   /* search256_0_0 -> 16 in the cache */
   /* search256_0_1 -> 377 in the cache */
   /* search256_0 -> 940 in the cache */
   /* search256_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 940, 903 },
      -1,
   } },

   /* replace256_0 -> 16 in the cache */
   /* replace256_1 -> 377 in the cache */
   /* replace256 -> 940 in the cache */

   /* ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1) */
   /* search257_0_0 -> 16 in the cache */
   /* search257_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* search257_1 -> 937 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 942, 937 },
      -1,
   } },

   /* replace257_0 -> 16 in the cache */
   /* replace257_1 -> 377 in the cache */
   /* replace257 -> 942 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2) */
   /* search258_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffff /* 1073741823 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 944 },
      -1,
   } },
   /* search258_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 945, 382 },
      -1,
   } },

   /* replace258_0 -> 16 in the cache */
   /* replace258_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 382 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2) */
   /* search259_0_0 -> 16 in the cache */
   /* search259_0_1 -> 382 in the cache */
   /* search259_0 -> 947 in the cache */
   /* search259_1 -> 909 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 947, 909 },
      -1,
   } },

   /* replace259_0 -> 16 in the cache */
   /* replace259_1 -> 382 in the cache */
   /* replace259 -> 947 in the cache */

   /* ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2) */
   /* search260_0_0 -> 16 in the cache */
   /* search260_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 382 },
      -1,
   } },
   /* search260_1 -> 944 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 949, 944 },
      -1,
   } },

   /* replace260_0 -> 16 in the cache */
   /* replace260_1 -> 382 in the cache */
   /* replace260 -> 949 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16) */
   /* search261_0_0 -> 16 in the cache */
   /* search261_0_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 797 },
      -1,
   } },
   /* search261_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 951, 801 },
      -1,
   } },

   /* replace261_0 -> 16 in the cache */
   /* replace261_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 801 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16) */
   /* search262_0_0 -> 16 in the cache */
   /* search262_0_1 -> 801 in the cache */
   /* search262_0 -> 953 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff0000 /* 4294901760 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 953, 954 },
      -1,
   } },

   /* replace262_0 -> 16 in the cache */
   /* replace262_1 -> 801 in the cache */
   /* replace262 -> 953 in the cache */

   /* ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16) */
   /* search263_0_0 -> 16 in the cache */
   /* search263_0_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 801 },
      -1,
   } },
   /* search263_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 956, 797 },
      -1,
   } },

   /* replace263_0 -> 16 in the cache */
   /* replace263_1 -> 801 in the cache */
   /* replace263 -> 956 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24) */
   /* search264_0_0 -> 16 in the cache */
   /* search264_0_1 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 774 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 958, 959 },
      -1,
   } },

   /* replace264_0 -> 16 in the cache */
   /* replace264_1 -> 959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 959 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24) */
   /* search265_0_0 -> 16 in the cache */
   /* search265_0_1 -> 959 in the cache */
   /* search265_0 -> 961 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 961, 962 },
      -1,
   } },

   /* replace265_0 -> 16 in the cache */
   /* replace265_1 -> 959 in the cache */
   /* replace265 -> 961 in the cache */

   /* ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24) */
   /* search266_0_0 -> 16 in the cache */
   /* search266_0_1 -> 959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 959 },
      -1,
   } },
   /* search266_1 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 964, 774 },
      -1,
   } },

   /* replace266_0 -> 16 in the cache */
   /* replace266_1 -> 959 in the cache */
   /* replace266 -> 964 in the cache */

   /* ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c')) */
   /* search267_0_0 -> 0 in the cache */
   /* search267_0_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 767 },
      -1,
   } },
   /* search267_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 966, 294 },
      -1,
   } },

   /* replace267_0_0 -> 0 in the cache */
   /* replace267_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 133 },
      -1,
   } },
   /* replace267_1_0 -> 3 in the cache */
   /* replace267_1_1 -> 133 in the cache */
   /* replace267_1 -> 770 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 968, 770 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c')) */
   /* search268_0_0 -> 124 in the cache */
   /* search268_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 124, 268 },
      0,
   } },
   /* search268_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 970, 760 },
      -1,
   } },

   /* replace268_0_0 -> 124 in the cache */
   /* replace268_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace268_1_0 -> 125 in the cache */
   /* replace268_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 972, 973 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd')) */
   /* search269_0_0_0 -> 147 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 147, 975 },
      0,
   } },
   /* search269_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 976, 150 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 977, 978 },
      -1,
   } },

   /* replace269_0_0_0 -> 147 in the cache */
   /* replace269_0_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 147, 150 },
      -1,
   } },
   /* replace269_0_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 2,
      { 980, 151 },
      -1,
   } },
   /* replace269_1_0 -> 148 in the cache */
   /* replace269_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 981, 982 },
      -1,
   } },

   /* ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd')) */
   /* search270_0_0_0 -> 124 in the cache */
   /* search270_0_0_1 -> 268 in the cache */
   /* search270_0_0 -> 970 in the cache */
   /* search270_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 970, 127 },
      0,
   } },
   /* search270_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 984, 296 },
      -1,
   } },

   /* replace270_0_0_0 -> 124 in the cache */
   /* replace270_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace270_0_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 986, 161 },
      -1,
   } },
   /* replace270_1_0 -> 125 in the cache */
   /* replace270_1_1 -> 161 in the cache */
   /* replace270_1 -> 763 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 987, 763 },
      -1,
   } },

   /* ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 989, 990 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 991 },
      -1,
   } },

   /* replace271_0 -> 0 in the cache */
   /* replace271_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b') */
   /* search272_0_0 -> 989 in the cache */
   /* search272_0_1 -> 990 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 989, 990 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 994 },
      -1,
   } },

   /* replace272_0 -> 0 in the cache */
   /* replace272_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b') */
   /* search273_0_0 -> 0 in the cache */
   /* search273_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 997 },
      -1,
   } },

   /* replace273_0 -> 0 in the cache */
   /* replace273_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b') */
   /* search274_0_0 -> 0 in the cache */
   /* search274_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1000 },
      -1,
   } },

   /* replace274_0 -> 0 in the cache */
   /* replace274_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b') */
   /* search275_0_0 -> 0 in the cache */
   /* search275_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1003 },
      -1,
   } },

   /* replace275_0 -> 0 in the cache */
   /* replace275_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b') */
   /* search276_0_0 -> 0 in the cache */
   /* search276_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1006 },
      -1,
   } },

   /* replace276_0 -> 0 in the cache */
   /* replace276_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b') */
   /* search277_0_0 -> 0 in the cache */
   /* search277_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1009 },
      -1,
   } },

   /* replace277_0 -> 0 in the cache */
   /* replace277_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b') */
   /* search278_0_0 -> 0 in the cache */
   /* search278_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1012 },
      -1,
   } },

   /* replace278_0 -> 0 in the cache */
   /* replace278_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b') */
   /* search279_0_0 -> 0 in the cache */
   /* search279_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1015 },
      -1,
   } },

   /* replace279_0 -> 0 in the cache */
   /* replace279_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b') */
   /* search280_0_0 -> 0 in the cache */
   /* search280_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1018 },
      -1,
   } },

   /* replace280_0 -> 0 in the cache */
   /* replace280_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False */
   /* search281_0_0 -> 0 in the cache */
   /* search281_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search281_1_0 -> 0 in the cache */
   /* search281_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1021, 1022 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_FALSE /* False */ },
   } },

   /* ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False */
   /* search282_0_0 -> 0 in the cache */
   /* search282_0_1 -> 3 in the cache */
   /* search282_0 -> 996 in the cache */
   /* search282_1_0 -> 3 in the cache */
   /* search282_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 996, 1025 },
      -1,
   } },

   /* replace282 -> 1024 in the cache */

   /* ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False */
   /* search283_0_0 -> 0 in the cache */
   /* search283_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search283_1_0 -> 0 in the cache */
   /* search283_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1027, 1028 },
      -1,
   } },

   /* replace283 -> 1024 in the cache */

   /* ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False */
   /* search284_0_0 -> 0 in the cache */
   /* search284_0_1 -> 3 in the cache */
   /* search284_0 -> 1011 in the cache */
   /* search284_1_0 -> 3 in the cache */
   /* search284_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1011, 1030 },
      -1,
   } },

   /* replace284 -> 1024 in the cache */

   /* ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False */
   /* search285_0_0 -> 0 in the cache */
   /* search285_0_1 -> 3 in the cache */
   /* search285_0 -> 1014 in the cache */
   /* search285_1_0 -> 3 in the cache */
   /* search285_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1014, 1032 },
      -1,
   } },

   /* replace285 -> 1024 in the cache */

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search286_0_0 -> 0 in the cache */
   /* search286_0 -> 197 in the cache */
   /* search286_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 197, 1034 },
      -1,
   } },

   /* replace286_0 -> 3 in the cache */
   /* replace286_1 -> 0 in the cache */
   /* replace286 -> 1025 in the cache */

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search287_0_0 -> 0 in the cache */
   /* search287_0 -> 197 in the cache */
   /* search287_1_0 -> 3 in the cache */
   /* search287_1 -> 1034 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 197, 1034 },
      -1,
   } },

   /* replace287_0 -> 3 in the cache */
   /* replace287_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search288_0_0 -> 0 in the cache */
   /* search288_0 -> 197 in the cache */
   /* search288_1_0 -> 3 in the cache */
   /* search288_1 -> 1034 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 197, 1034 },
      -1,
   } },

   /* replace288_0 -> 3 in the cache */
   /* replace288_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search289_0_0 -> 0 in the cache */
   /* search289_0 -> 197 in the cache */
   /* search289_1_0 -> 3 in the cache */
   /* search289_1 -> 1034 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 197, 1034 },
      -1,
   } },

   /* replace289_0 -> 3 in the cache */
   /* replace289_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search290_0_0 -> 32 in the cache */
   /* search290_0 -> 98 in the cache */
   /* search290_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 98, 232 },
      -1,
   } },

   /* replace290_0 -> 226 in the cache */
   /* replace290_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 226, 32 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search291_0 -> 232 in the cache */
   /* search291_1_0 -> 32 in the cache */
   /* search291_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 232, 98 },
      -1,
   } },

   /* replace291_0 -> 32 in the cache */
   /* replace291_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 226 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search292_0_0 -> 32 in the cache */
   /* search292_0 -> 98 in the cache */
   /* search292_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 98, 232 },
      -1,
   } },

   /* replace292_0 -> 226 in the cache */
   /* replace292_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 226, 32 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search293_0 -> 232 in the cache */
   /* search293_1_0 -> 32 in the cache */
   /* search293_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 232, 98 },
      -1,
   } },

   /* replace293_0 -> 32 in the cache */
   /* replace293_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 226 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search294_0_0 -> 32 in the cache */
   /* search294_0 -> 98 in the cache */
   /* search294_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 232 },
      -1,
   } },

   /* replace294_0 -> 226 in the cache */
   /* replace294_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 226, 32 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search295_0 -> 232 in the cache */
   /* search295_1_0 -> 32 in the cache */
   /* search295_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 232, 98 },
      -1,
   } },

   /* replace295_0 -> 32 in the cache */
   /* replace295_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 226 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1055 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1054, 1056 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace296_1 -> 1055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1058, 1055 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search297_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1060, 1061 },
      -1,
   } },

   /* replace297_0 -> 0 in the cache */
   /* replace297_1 -> 3 in the cache */
   /* replace297 -> 993 in the cache */

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search298_0_0 -> 0 in the cache */
   /* search298_0 -> 1060 in the cache */
   /* search298_1 -> 1061 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1060, 1061 },
      -1,
   } },

   /* replace298_0 -> 0 in the cache */
   /* replace298_1 -> 3 in the cache */
   /* replace298 -> 1002 in the cache */

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search299_0_0 -> 0 in the cache */
   /* search299_0 -> 1060 in the cache */
   /* search299_1 -> 1061 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1060, 1061 },
      -1,
   } },

   /* replace299_0 -> 0 in the cache */
   /* replace299_1 -> 3 in the cache */
   /* replace299 -> 999 in the cache */

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search300_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      0,
   } },
   /* search300_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1065, 226 },
      -1,
   } },

   /* replace300_0 -> 32 in the cache */
   /* replace300_1 -> 226 in the cache */
   /* replace300 -> 1049 in the cache */

   /* ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a') */
   /* search301_0 -> 113 in the cache */
   /* search301_1_0 -> 32 in the cache */
   /* search301_1 -> 1065 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 1065 },
      -1,
   } },

   /* replace301_0 -> 113 in the cache */
   /* replace301_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },

   /* ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a') */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search302_1_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 706 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1069, 1070 },
      -1,
   } },

   /* replace302_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a') */
   /* search303_0_0_0 -> 706 in the cache */
   /* search303_0_0 -> 1070 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1070 },
      -1,
   } },
   /* search303_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1073, 1069 },
      -1,
   } },

   /* replace303_0 -> 706 in the cache */
   /* replace303 -> 1072 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search304_0_0_0 -> 706 in the cache */
   /* search304_0_0 -> 1070 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1070, 1076 },
      -1,
   } },
   /* search304_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1077, 1069 },
      -1,
   } },

   /* replace304_0 -> 706 in the cache */
   /* replace304_1 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 706, 1075 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search305_0_0 -> 706 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search305_0_2_0 -> 1075 in the cache */
   /* search305_0_2 -> 1076 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1080, 1076 },
      -1,
   } },
   /* search305_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1081, 1069 },
      -1,
   } },

   /* replace305_0 -> 706 in the cache */
   /* replace305_1 -> 1075 in the cache */
   /* replace305 -> 1079 in the cache */

   /* ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search306_0_0 -> 706 in the cache */
   /* search306_0 -> 1070 in the cache */
   /* search306_1_0_0 -> 1075 in the cache */
   /* search306_1_0 -> 1076 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1076 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1070, 1083 },
      -1,
   } },

   /* replace306_0 -> 706 in the cache */
   /* replace306_1 -> 1075 in the cache */
   /* replace306 -> 1079 in the cache */

   /* ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b') */
   /* search307_0_0_0 -> 706 in the cache */
   /* search307_0_0 -> 1070 in the cache */
   /* search307_0_1_0 -> 1075 in the cache */
   /* search307_0_1 -> 1076 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 1070, 1076 },
      -1,
   } },
   /* search307_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1085, 1069 },
      -1,
   } },

   /* replace307_0 -> 706 in the cache */
   /* replace307_1 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 706, 1075 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b') */
   /* search308_0_0 -> 706 in the cache */
   /* search308_0_1_0 -> 1075 in the cache */
   /* search308_0_1 -> 1076 in the cache */
   /* search308_0_2 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1076, 1069 },
      -1,
   } },
   /* search308_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1088, 1069 },
      -1,
   } },

   /* replace308_0 -> 706 in the cache */
   /* replace308_1 -> 1075 in the cache */
   /* replace308 -> 1087 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b') */
   /* search309_0_0_0 -> 706 in the cache */
   /* search309_0_0 -> 1070 in the cache */
   /* search309_0_1_0_0 -> 1075 in the cache */
   /* search309_0_1_0 -> 1076 in the cache */
   /* search309_0_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1070, 1083 },
      -1,
   } },
   /* search309_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1090, 1069 },
      -1,
   } },

   /* replace309_0 -> 706 in the cache */
   /* replace309_1 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 706, 1075 },
      -1,
   } },

   /* ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b') */
   /* search310_0_0 -> 706 in the cache */
   /* search310_0 -> 1070 in the cache */
   /* search310_1_0 -> 1075 in the cache */
   /* search310_1 -> 1076 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1070, 1076 },
      -1,
   } },

   /* replace310_0 -> 706 in the cache */
   /* replace310_1 -> 1075 in the cache */
   /* replace310 -> 1092 in the cache */

   /* ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b') */
   /* search311_0_0_0 -> 706 in the cache */
   /* search311_0_0 -> 1070 in the cache */
   /* search311_0 -> 1073 in the cache */
   /* search311_1_0_0 -> 1075 in the cache */
   /* search311_1_0 -> 1076 in the cache */
   /* search311_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1073, 1083 },
      -1,
   } },

   /* replace311_0 -> 706 in the cache */
   /* replace311_1 -> 1075 in the cache */
   /* replace311 -> 1092 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search312_0_0_0 -> 706 in the cache */
   /* search312_0_0 -> 1070 in the cache */
   /* search312_0_1_0 -> 1075 in the cache */
   /* search312_0_1 -> 1076 in the cache */
   /* search312_0 -> 1077 in the cache */
   /* search312_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1077, 1069 },
      -1,
   } },

   /* replace312_0_0 -> 706 in the cache */
   /* replace312_0_1 -> 1075 in the cache */
   /* replace312_0 -> 1079 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1079 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search313_0_0 -> 706 in the cache */
   /* search313_0_1 -> 1080 in the cache */
   /* search313_0_2_0 -> 1075 in the cache */
   /* search313_0_2 -> 1076 in the cache */
   /* search313_0 -> 1081 in the cache */
   /* search313_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1081, 1069 },
      -1,
   } },

   /* replace313_0_0 -> 706 in the cache */
   /* replace313_0_1 -> 1075 in the cache */
   /* replace313_0 -> 1079 in the cache */
   /* replace313 -> 1096 in the cache */

   /* ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search314_0_0 -> 706 in the cache */
   /* search314_0 -> 1070 in the cache */
   /* search314_1_0_0 -> 1075 in the cache */
   /* search314_1_0 -> 1076 in the cache */
   /* search314_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1070, 1083 },
      -1,
   } },

   /* replace314_0_0 -> 706 in the cache */
   /* replace314_0_1 -> 1075 in the cache */
   /* replace314_0 -> 1079 in the cache */
   /* replace314 -> 1096 in the cache */

   /* ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search315_0_0_0 -> 706 in the cache */
   /* search315_0_0 -> 1070 in the cache */
   /* search315_0_1_0 -> 1075 in the cache */
   /* search315_0_1 -> 1076 in the cache */
   /* search315_0 -> 1085 in the cache */
   /* search315_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1085, 1069 },
      -1,
   } },

   /* replace315_0_0 -> 706 in the cache */
   /* replace315_0_1 -> 1075 in the cache */
   /* replace315_0 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1087 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search316_0_0 -> 706 in the cache */
   /* search316_0_1_0 -> 1075 in the cache */
   /* search316_0_1 -> 1076 in the cache */
   /* search316_0_2 -> 1069 in the cache */
   /* search316_0 -> 1088 in the cache */
   /* search316_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1088, 1069 },
      -1,
   } },

   /* replace316_0_0 -> 706 in the cache */
   /* replace316_0_1 -> 1075 in the cache */
   /* replace316_0 -> 1087 in the cache */
   /* replace316 -> 1100 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b') */
   /* search317_0_0_0 -> 706 in the cache */
   /* search317_0_0 -> 1070 in the cache */
   /* search317_0_1_0_0 -> 1075 in the cache */
   /* search317_0_1_0 -> 1076 in the cache */
   /* search317_0_1 -> 1083 in the cache */
   /* search317_0 -> 1090 in the cache */
   /* search317_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1090, 1069 },
      -1,
   } },

   /* replace317_0 -> 706 in the cache */
   /* replace317_1 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 706, 1075 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b') */
   /* search318_0_0 -> 706 in the cache */
   /* search318_0 -> 1070 in the cache */
   /* search318_1_0 -> 1075 in the cache */
   /* search318_1 -> 1076 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1070, 1076 },
      -1,
   } },

   /* replace318_0 -> 706 in the cache */
   /* replace318_1 -> 1075 in the cache */
   /* replace318 -> 1103 in the cache */

   /* ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b') */
   /* search319_0_0_0 -> 706 in the cache */
   /* search319_0_0 -> 1070 in the cache */
   /* search319_0 -> 1073 in the cache */
   /* search319_1_0_0 -> 1075 in the cache */
   /* search319_1_0 -> 1076 in the cache */
   /* search319_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1073, 1083 },
      -1,
   } },

   /* replace319_0 -> 706 in the cache */
   /* replace319_1 -> 1075 in the cache */
   /* replace319 -> 1103 in the cache */

   /* ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b') */
   /* search320_0_0_0_0 -> 706 in the cache */
   /* search320_0_0_0 -> 1070 in the cache */
   /* search320_0_0_1_0 -> 1075 in the cache */
   /* search320_0_0_1 -> 1076 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1070, 1076 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1106 },
      -1,
   } },
   /* search320_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1107, 1069 },
      -1,
   } },

   /* replace320_0 -> 706 in the cache */
   /* replace320_1 -> 1075 in the cache */
   /* replace320 -> 1079 in the cache */

   /* ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search321_0 -> 1069 in the cache */
   /* search321_1_0_0 -> 706 in the cache */
   /* search321_1_0 -> 1070 in the cache */
   /* search321_1_1_0 -> 1075 in the cache */
   /* search321_1_1 -> 1076 in the cache */
   /* search321_1 -> 1106 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1069, 1106 },
      -1,
   } },

   /* replace321_0 -> 706 in the cache */
   /* replace321_1 -> 1075 in the cache */
   /* replace321 -> 1079 in the cache */

   /* ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search322_0_0_0_0 -> 706 in the cache */
   /* search322_0_0_0 -> 1070 in the cache */
   /* search322_0_0_1_0 -> 1075 in the cache */
   /* search322_0_0_1 -> 1076 in the cache */
   /* search322_0_0 -> 1106 in the cache */
   /* search322_0 -> 1107 in the cache */
   /* search322_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1107, 1069 },
      -1,
   } },

   /* replace322_0_0 -> 706 in the cache */
   /* replace322_0_1 -> 1075 in the cache */
   /* replace322_0 -> 1079 in the cache */
   /* replace322 -> 1096 in the cache */

   /* ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search323_0 -> 1069 in the cache */
   /* search323_1_0_0 -> 706 in the cache */
   /* search323_1_0 -> 1070 in the cache */
   /* search323_1_1_0 -> 1075 in the cache */
   /* search323_1_1 -> 1076 in the cache */
   /* search323_1 -> 1106 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1069, 1106 },
      -1,
   } },

   /* replace323_0_0 -> 706 in the cache */
   /* replace323_0_1 -> 1075 in the cache */
   /* replace323_0 -> 1079 in the cache */
   /* replace323 -> 1096 in the cache */

   /* ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0) */
   /* search324_0 -> 32 in the cache */
   /* search324_1_0 -> 32 in the cache */
   /* search324_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace324_0 -> 32 in the cache */
   /* replace324_1 -> 113 in the cache */
   /* replace324 -> 670 in the cache */

   /* ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0) */
   /* search325_0 -> 32 in the cache */
   /* search325_1_0 -> 32 in the cache */
   /* search325_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace325_0 -> 32 in the cache */
   /* replace325_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 113 },
      -1,
   } },

   /* ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1116 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1118 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1117, 1119 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1115, 1121 },
      -1,
   } },
   /* search326_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 1122, 113 },
      -1,
   } },

   /* replace326_0_0 -> 1115 in the cache */
   /* replace326_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1115, 113 },
      -1,
   } },
   /* replace326_1_0 -> 1116 in the cache */
   /* replace326_1_1 -> 1118 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1116, 1118 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1124, 1125 },
      -1,
   } },

   /* ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0) */
   /* search327_0_0 -> 0 in the cache */
   /* search327_0_1 -> 3 in the cache */
   /* search327_0 -> 257 in the cache */
   /* search327_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 257, 0 },
      -1,
   } },

   /* replace327_0 -> 3 in the cache */
   /* replace327_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 241 },
      -1,
   } },

   /* ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0) */
   /* search328_0_0 -> 0 in the cache */
   /* search328_0_1 -> 3 in the cache */
   /* search328_0 -> 257 in the cache */
   /* search328_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 257, 0 },
      -1,
   } },

   /* replace328_0 -> 3 in the cache */
   /* replace328_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 241 },
      -1,
   } },

   /* ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0) */
   /* search329_0_0 -> 0 in the cache */
   /* search329_0_1 -> 3 in the cache */
   /* search329_0 -> 198 in the cache */
   /* search329_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 198, 0 },
      -1,
   } },

   /* replace329_0 -> 3 in the cache */
   /* replace329_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 241 },
      -1,
   } },

   /* ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0) */
   /* search330_0_0 -> 0 in the cache */
   /* search330_0_1 -> 3 in the cache */
   /* search330_0 -> 198 in the cache */
   /* search330_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 198, 0 },
      -1,
   } },

   /* replace330_0 -> 3 in the cache */
   /* replace330_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 241 },
      -1,
   } },

   /* ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search331_0_0 -> 124 in the cache */
   /* search331_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 124, 268 },
      0,
   } },
   /* search331_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1135, 760 },
      -1,
   } },

   /* replace331_0 -> 124 in the cache */
   /* replace331_1_0 -> 127 in the cache */
   /* replace331_1_1_0 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 127, 1137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 124, 1138 },
      -1,
   } },

   /* ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search332_0_0_0 -> 124 in the cache */
   /* search332_0_0_1 -> 268 in the cache */
   /* search332_0_0 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1135 },
      0,
   } },
   /* search332_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1140, 760 },
      -1,
   } },

   /* replace332_0_0_0 -> 127 in the cache */
   /* replace332_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 127, 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1142 },
      -1,
   } },
   /* replace332_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1143, 124 },
      -1,
   } },

   /* ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search333_0_0 -> 124 in the cache */
   /* search333_0_1 -> 268 in the cache */
   /* search333_0 -> 1135 in the cache */
   /* search333_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1135, 760 },
      -1,
   } },

   /* replace333_0 -> 124 in the cache */
   /* replace333_1_0 -> 127 in the cache */
   /* replace333_1_1_0 -> 125 in the cache */
   /* replace333_1_1 -> 1137 in the cache */
   /* replace333_1 -> 1138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 124, 1138 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search334_0_0_0 -> 124 in the cache */
   /* search334_0_0_1 -> 268 in the cache */
   /* search334_0_0 -> 1135 in the cache */
   /* search334_0 -> 1140 in the cache */
   /* search334_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1140, 760 },
      -1,
   } },

   /* replace334_0_0_0 -> 127 in the cache */
   /* replace334_0_0_1 -> 125 in the cache */
   /* replace334_0_0 -> 1142 in the cache */
   /* replace334_0 -> 1143 in the cache */
   /* replace334_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1143, 124 },
      -1,
   } },

   /* ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search335_0_0 -> 124 in the cache */
   /* search335_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 124, 268 },
      0,
   } },
   /* search335_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1149, 760 },
      -1,
   } },

   /* replace335_0 -> 124 in the cache */
   /* replace335_1_0 -> 127 in the cache */
   /* replace335_1_1_0 -> 125 in the cache */
   /* replace335_1_1 -> 1137 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 127, 1137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 124, 1151 },
      -1,
   } },

   /* ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search336_0_0_0 -> 124 in the cache */
   /* search336_0_0_1 -> 268 in the cache */
   /* search336_0_0 -> 1149 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1149 },
      0,
   } },
   /* search336_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1153, 760 },
      -1,
   } },

   /* replace336_0_0_0 -> 127 in the cache */
   /* replace336_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 127, 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1155 },
      -1,
   } },
   /* replace336_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1156, 124 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search337_0_0 -> 124 in the cache */
   /* search337_0_1 -> 268 in the cache */
   /* search337_0 -> 1149 in the cache */
   /* search337_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1149, 760 },
      -1,
   } },

   /* replace337_0 -> 124 in the cache */
   /* replace337_1_0 -> 127 in the cache */
   /* replace337_1_1_0 -> 125 in the cache */
   /* replace337_1_1 -> 1137 in the cache */
   /* replace337_1 -> 1151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 124, 1151 },
      -1,
   } },

   /* ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search338_0_0_0 -> 124 in the cache */
   /* search338_0_0_1 -> 268 in the cache */
   /* search338_0_0 -> 1149 in the cache */
   /* search338_0 -> 1153 in the cache */
   /* search338_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1153, 760 },
      -1,
   } },

   /* replace338_0_0_0 -> 127 in the cache */
   /* replace338_0_0_1 -> 125 in the cache */
   /* replace338_0_0 -> 1155 in the cache */
   /* replace338_0 -> 1156 in the cache */
   /* replace338_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1156, 124 },
      -1,
   } },

   /* ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0) */
   /* search339_0_0 -> 0 in the cache */
   /* search339_0_1 -> 3 in the cache */
   /* search339_0 -> 193 in the cache */
   /* search339_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 193, 0 },
      -1,
   } },

   /* replace339_0 -> 3 in the cache */
   /* replace339_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0) */
   /* search340_0_0 -> 0 in the cache */
   /* search340_0_1 -> 3 in the cache */
   /* search340_0 -> 193 in the cache */
   /* search340_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 193, 0 },
      -1,
   } },

   /* replace340_0 -> 3 in the cache */
   /* replace340_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a') */
   /* search341_0_0 -> 706 in the cache */
   /* search341_0 -> 1070 in the cache */
   /* search341_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1070, 1069 },
      -1,
   } },

   /* replace341_0 -> 706 in the cache */
   /* replace341 -> 1072 in the cache */

   /* ('fneu', ('b2f', 'a@1'), 0.0) => a */
   /* search342_0_0 -> 706 in the cache */
   /* search342_0 -> 1070 in the cache */
   /* search342_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1070, 1069 },
      -1,
   } },

   /* replace342 -> 706 in the cache */

   /* ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a') */
   /* search343_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 706 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1168, 1169 },
      -1,
   } },

   /* replace343_0 -> 706 in the cache */
   /* replace343 -> 1072 in the cache */

   /* ('ine', ('b2i', 'a@1'), 0) => a */
   /* search344_0_0 -> 706 in the cache */
   /* search344_0 -> 1168 in the cache */
   /* search344_1 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1168, 1169 },
      -1,
   } },

   /* replace344 -> 706 in the cache */

   /* ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search345_0_0 -> 32 in the cache */
   /* search345_0 -> 104 in the cache */
   /* search345_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 104, 1069 },
      -1,
   } },

   /* replace345_0 -> 32 in the cache */
   /* replace345_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search346_0_0 -> 32 in the cache */
   /* search346_0 -> 104 in the cache */
   /* search346_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 104, 1069 },
      -1,
   } },

   /* replace346_0 -> 32 in the cache */
   /* replace346_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('fge', ('u2f', 'a'), 0.0) => True */
   /* search347_0_0 -> 32 in the cache */
   /* search347_0 -> 104 in the cache */
   /* search347_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 104, 1069 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_TRUE /* True */ },
   } },

   /* ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a') */
   /* search348_0 -> 1069 in the cache */
   /* search348_1_0 -> 32 in the cache */
   /* search348_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1069, 104 },
      -1,
   } },

   /* replace348_0 -> 61 in the cache */
   /* replace348_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('u2f', 'a'), 0.0) => False */
   /* search349_0_0 -> 32 in the cache */
   /* search349_0 -> 104 in the cache */
   /* search349_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 104, 1069 },
      -1,
   } },

   /* replace349 -> 1024 in the cache */

   /* ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a') */
   /* search350_0 -> 1069 in the cache */
   /* search350_1_0 -> 32 in the cache */
   /* search350_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1069, 104 },
      -1,
   } },

   /* replace350_0 -> 61 in the cache */
   /* replace350_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search351_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search351_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1183, 1069 },
      -1,
   } },

   /* replace351_0 -> 32 in the cache */
   /* replace351_1 -> 61 in the cache */
   /* replace351 -> 1173 in the cache */

   /* ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search352_0_0 -> 32 in the cache */
   /* search352_0 -> 1183 in the cache */
   /* search352_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1183, 1069 },
      -1,
   } },

   /* replace352_0 -> 32 in the cache */
   /* replace352_1 -> 61 in the cache */
   /* replace352 -> 1175 in the cache */

   /* ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0) */
   /* search353_0_0 -> 32 in the cache */
   /* search353_0 -> 1183 in the cache */
   /* search353_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1183, 1069 },
      -1,
   } },

   /* replace353_0 -> 32 in the cache */
   /* replace353_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a') */
   /* search354_0 -> 1069 in the cache */
   /* search354_1_0 -> 32 in the cache */
   /* search354_1 -> 1183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1069, 1183 },
      -1,
   } },

   /* replace354_0 -> 61 in the cache */
   /* replace354_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0) */
   /* search355_0_0 -> 32 in the cache */
   /* search355_0 -> 1183 in the cache */
   /* search355_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1183, 1069 },
      -1,
   } },

   /* replace355_0 -> 32 in the cache */
   /* replace355_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a') */
   /* search356_0 -> 1069 in the cache */
   /* search356_1_0 -> 32 in the cache */
   /* search356_1 -> 1183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1069, 1183 },
      -1,
   } },

   /* replace356_0 -> 61 in the cache */
   /* replace356_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0) */
   /* search357_0 -> 113 in the cache */
   /* search357_1_0 -> 32 in the cache */
   /* search357_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace357_0 -> 32 in the cache */
   /* replace357_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0) */
   /* search358_0_0_0 -> 32 in the cache */
   /* search358_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 103 },
      -1,
   } },
   /* search358_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1196, 113 },
      -1,
   } },

   /* replace358_0 -> 32 in the cache */
   /* replace358_1 -> 113 in the cache */
   /* replace358 -> 1195 in the cache */

   /* ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0) */
   /* search359_0 -> 113 in the cache */
   /* search359_1_0 -> 32 in the cache */
   /* search359_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace359_0 -> 32 in the cache */
   /* replace359_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search360_0_0_0 -> 32 in the cache */
   /* search360_0_0 -> 103 in the cache */
   /* search360_0 -> 1196 in the cache */
   /* search360_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1196, 113 },
      -1,
   } },

   /* replace360_0 -> 32 in the cache */
   /* replace360_1 -> 113 in the cache */
   /* replace360 -> 1199 in the cache */

   /* ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a')) */
   /* search361_0_0 -> 32 in the cache */
   /* search361_0_1 -> 113 in the cache */
   /* search361_0 -> 1114 in the cache */
   /* search361_1_0 -> 226 in the cache */
   /* search361_1_1 -> 32 in the cache */
   /* search361_1 -> 1047 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1114, 1047 },
      -1,
   } },

   /* replace361_0 -> 32 in the cache */
   /* replace361_1_0 -> 32 in the cache */
   /* replace361_1 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 202 },
      -1,
   } },

   /* ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b')) */
   /* search362_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 706 },
      0,
   } },
   /* search362_1_0 -> 1075 in the cache */
   /* search362_1 -> 1076 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1203, 1076 },
      -1,
   } },

   /* replace362_0_0 -> 706 in the cache */
   /* replace362_0_1 -> 1075 in the cache */
   /* replace362_0 -> 1079 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1079 },
      -1,
   } },

   /* ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b'))) */
   /* search363_0_0_0 -> 706 in the cache */
   /* search363_0_0 -> 1203 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1203 },
      0,
   } },
   /* search363_1_0_0 -> 1075 in the cache */
   /* search363_1_0 -> 1076 in the cache */
   /* search363_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1206, 1083 },
      -1,
   } },

   /* replace363_0_0_0 -> 706 in the cache */
   /* replace363_0_0_1 -> 1075 in the cache */
   /* replace363_0_0 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1208 },
      -1,
   } },

   /* ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search364_0_0 -> 706 in the cache */
   /* search364_0 -> 1203 in the cache */
   /* search364_1_0 -> 1075 in the cache */
   /* search364_1 -> 1076 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1203, 1076 },
      -1,
   } },

   /* replace364_0_0 -> 706 in the cache */
   /* replace364_0_1 -> 1075 in the cache */
   /* replace364_0 -> 1087 in the cache */
   /* replace364 -> 1208 in the cache */

   /* ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b'))) */
   /* search365_0_0_0 -> 706 in the cache */
   /* search365_0_0 -> 1203 in the cache */
   /* search365_0 -> 1206 in the cache */
   /* search365_1_0_0 -> 1075 in the cache */
   /* search365_1_0 -> 1076 in the cache */
   /* search365_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1206, 1083 },
      -1,
   } },

   /* replace365_0_0_0 -> 706 in the cache */
   /* replace365_0_0_1 -> 1075 in the cache */
   /* replace365_0_0 -> 1079 in the cache */
   /* replace365_0 -> 1205 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1205 },
      -1,
   } },

   /* ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0)) */
   /* search366_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 706 },
      -1,
   } },
   /* search366_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1213, 767 },
      -1,
   } },

   /* replace366_0 -> 706 in the cache */
   /* replace366_1_0 -> 3 in the cache */
   /* replace366_1_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3, 255 },
      -1,
   } },
   /* replace366_2_0 -> 3 in the cache */
   /* replace366_2_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 3, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 1215, 1216 },
      -1,
   } },

   /* ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b') */
   /* search367_0_0 -> 0 in the cache */
   /* search367_0_1_0 -> 3 in the cache */
   /* search367_0_1 -> 1034 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1034 },
      0,
   } },
   /* search367_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1218, 241 },
      -1,
   } },

   /* replace367_0 -> 0 in the cache */
   /* replace367_1 -> 3 in the cache */
   /* replace367 -> 996 in the cache */

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search368_0_0_0 -> 32 in the cache */
   /* search368_0_0 -> 103 in the cache */
   /* search368_0 -> 1196 in the cache */
   /* search368_1 -> 113 in the cache */
   /* search368 -> 1200 in the cache */

   /* replace368_0 -> 32 in the cache */
   /* replace368_1 -> 113 in the cache */
   /* replace368 -> 1199 in the cache */

   /* ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search369_0_0 -> 1058 in the cache */
   /* search369_0_1 -> 1055 in the cache */
   /* search369_0 -> 1059 in the cache */
   /* search369_1 -> 1058 in the cache */
   /* search369_2 -> 1055 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1059, 1058, 1055 },
      -1,
   } },

   /* replace369_0 -> 1055 in the cache */
   /* replace369_1 -> 1058 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1055, 1058 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search370_0_0 -> 0 in the cache */
   /* search370_0_1 -> 3 in the cache */
   /* search370_0 -> 996 in the cache */
   /* search370_1 -> 3 in the cache */
   /* search370_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 996, 3, 0 },
      -1,
   } },

   /* replace370_0 -> 0 in the cache */
   /* replace370_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search371_0_0 -> 0 in the cache */
   /* search371_0_1 -> 3 in the cache */
   /* search371_0 -> 993 in the cache */
   /* search371_1 -> 3 in the cache */
   /* search371_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 993, 3, 0 },
      -1,
   } },

   /* replace371_0 -> 0 in the cache */
   /* replace371_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search372_0_0 -> 1058 in the cache */
   /* search372_0_1 -> 1055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1058, 1055 },
      -1,
   } },
   /* search372_1 -> 1058 in the cache */
   /* search372_2 -> 1055 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1226, 1058, 1055 },
      -1,
   } },

   /* replace372_0 -> 1055 in the cache */
   /* replace372_1 -> 1058 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1055, 1058 },
      -1,
   } },

   /* ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c') */
   /* search373_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search373_1 -> 125 in the cache */
   /* search373_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1229, 125, 127 },
      -1,
   } },

   /* replace373_0_0 -> 32 in the cache */
   /* replace373_0_1 -> 61 in the cache */
   /* replace373_0 -> 1173 in the cache */
   /* replace373_1 -> 125 in the cache */
   /* replace373_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1173, 125, 127 },
      -1,
   } },

   /* ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b') */
   /* search374_0_0 -> 706 in the cache */
   /* search374_0 -> 1072 in the cache */
   /* search374_1 -> 125 in the cache */
   /* search374_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1072, 125, 127 },
      -1,
   } },

   /* replace374_0 -> 706 in the cache */
   /* replace374_1 -> 127 in the cache */
   /* replace374_2 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 127, 125 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd') */
   /* search375_0 -> 706 in the cache */
   /* search375_1_0 -> 706 in the cache */
   /* search375_1_1 -> 148 in the cache */
   /* search375_1_2 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 148, 150 },
      -1,
   } },
   /* search375_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1234, 151 },
      -1,
   } },

   /* replace375_0 -> 706 in the cache */
   /* replace375_1 -> 148 in the cache */
   /* replace375_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 148, 151 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd') */
   /* search376_0 -> 706 in the cache */
   /* search376_1 -> 148 in the cache */
   /* search376_2_0 -> 706 in the cache */
   /* search376_2_1 -> 150 in the cache */
   /* search376_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 148, 1237 },
      -1,
   } },

   /* replace376_0 -> 706 in the cache */
   /* replace376_1 -> 148 in the cache */
   /* replace376_2 -> 151 in the cache */
   /* replace376 -> 1236 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search377_0 -> 706 in the cache */
   /* search377_1_0 -> 1075 in the cache */
   /* search377_1_1 -> 699 in the cache */
   /* search377_1_2 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 699, 708 },
      -1,
   } },
   /* search377_2_0 -> 1075 in the cache */
   /* search377_2_1 -> 699 in the cache */
   /* search377_2_2 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 699, 710 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1239, 1240 },
      -1,
   } },

   /* replace377_0 -> 1075 in the cache */
   /* replace377_1 -> 699 in the cache */
   /* replace377_2_0 -> 706 in the cache */
   /* replace377_2_1 -> 708 in the cache */
   /* replace377_2_2 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 708, 710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 699, 1242 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search378_0 -> 706 in the cache */
   /* search378_1_0 -> 1075 in the cache */
   /* search378_1_1 -> 699 in the cache */
   /* search378_1_2 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 699, 708 },
      0,
   } },
   /* search378_2_0 -> 1075 in the cache */
   /* search378_2_1 -> 699 in the cache */
   /* search378_2_2 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 699, 710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1244, 1245 },
      -1,
   } },

   /* replace378_0 -> 1075 in the cache */
   /* replace378_1 -> 699 in the cache */
   /* replace378_2_0 -> 706 in the cache */
   /* replace378_2_1 -> 708 in the cache */
   /* replace378_2_2 -> 710 in the cache */
   /* replace378_2 -> 1242 in the cache */
   /* replace378 -> 1243 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search379_0 -> 706 in the cache */
   /* search379_1_0 -> 1075 in the cache */
   /* search379_1_1 -> 150 in the cache */
   /* search379_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 150, 151 },
      -1,
   } },
   /* search379_2_0 -> 1075 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search379_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 1248, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1247, 1249 },
      -1,
   } },

   /* replace379_0 -> 1075 in the cache */
   /* replace379_1_0 -> 706 in the cache */
   /* replace379_1_1 -> 150 in the cache */
   /* replace379_1_2 -> 1248 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 150, 1248 },
      -1,
   } },
   /* replace379_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 1251, 151 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search380_0 -> 706 in the cache */
   /* search380_1_0 -> 1075 in the cache */
   /* search380_1_1 -> 150 in the cache */
   /* search380_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 150, 151 },
      0,
   } },
   /* search380_2_0 -> 1075 in the cache */
   /* search380_2_1 -> 1248 in the cache */
   /* search380_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1075, 1248, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1253, 1254 },
      -1,
   } },

   /* replace380_0 -> 1075 in the cache */
   /* replace380_1_0 -> 706 in the cache */
   /* replace380_1_1 -> 150 in the cache */
   /* replace380_1_2 -> 1248 in the cache */
   /* replace380_1 -> 1251 in the cache */
   /* replace380_2 -> 151 in the cache */
   /* replace380 -> 1252 in the cache */

   /* ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b') */
   /* search381_0 -> 706 in the cache */
   /* search381_1 -> 1177 in the cache */
   /* search381_2 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1177, 1075 },
      -1,
   } },

   /* replace381_0 -> 706 in the cache */
   /* replace381_1 -> 1075 in the cache */
   /* replace381 -> 1079 in the cache */

   /* ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b') */
   /* search382_0 -> 706 in the cache */
   /* search382_1 -> 706 in the cache */
   /* search382_2 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 706, 1075 },
      -1,
   } },

   /* replace382_0 -> 706 in the cache */
   /* replace382_1 -> 1075 in the cache */
   /* replace382 -> 1079 in the cache */

   /* ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b') */
   /* search383_0 -> 706 in the cache */
   /* search383_1 -> 1075 in the cache */
   /* search383_2 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1075, 1024 },
      -1,
   } },

   /* replace383_0 -> 706 in the cache */
   /* replace383_1 -> 1075 in the cache */
   /* replace383 -> 1087 in the cache */

   /* ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b') */
   /* search384_0 -> 706 in the cache */
   /* search384_1 -> 1075 in the cache */
   /* search384_2 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1075, 706 },
      -1,
   } },

   /* replace384_0 -> 706 in the cache */
   /* replace384_1 -> 1075 in the cache */
   /* replace384 -> 1087 in the cache */

   /* ('~fmin', 'a', 'a') => a */
   /* search385_0 -> 32 in the cache */
   /* search385_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace385 -> 32 in the cache */

   /* ('~fmax', 'a', 'a') => a */
   /* search386_0 -> 32 in the cache */
   /* search386_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace386 -> 32 in the cache */

   /* ('imin', 'a', 'a') => a */
   /* search387_0 -> 32 in the cache */
   /* search387_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace387 -> 32 in the cache */

   /* ('imax', 'a', 'a') => a */
   /* search388_0 -> 32 in the cache */
   /* search388_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace388 -> 32 in the cache */

   /* ('umin', 'a', 'a') => a */
   /* search389_0 -> 32 in the cache */
   /* search389_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace389 -> 32 in the cache */

   /* ('umin', 'a', 0) => 0 */
   /* search390_0 -> 32 in the cache */
   /* search390_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace390 -> 61 in the cache */

   /* ('umin', 'a', -1) => a */
   /* search391_0 -> 32 in the cache */
   /* search391_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace391 -> 32 in the cache */

   /* ('umax', 'a', 'a') => a */
   /* search392_0 -> 32 in the cache */
   /* search392_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace392 -> 32 in the cache */

   /* ('umax', 'a', 0) => a */
   /* search393_0 -> 32 in the cache */
   /* search393_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace393 -> 32 in the cache */

   /* ('umax', 'a', -1) => -1 */
   /* search394_0 -> 32 in the cache */
   /* search394_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace394 -> 63 in the cache */

   /* ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b') */
   /* search395_0_0 -> 0 in the cache */
   /* search395_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search395_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1270, 3 },
      -1,
   } },

   /* replace395_0 -> 0 in the cache */
   /* replace395_1 -> 3 in the cache */
   /* replace395 -> 1223 in the cache */

   /* ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b') */
   /* search396_0_0 -> 0 in the cache */
   /* search396_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search396_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1272, 3 },
      -1,
   } },

   /* replace396_0 -> 0 in the cache */
   /* replace396_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b') */
   /* search397_0_0 -> 0 in the cache */
   /* search397_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search397_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1275, 3 },
      -1,
   } },

   /* replace397_0 -> 0 in the cache */
   /* replace397_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b') */
   /* search398_0_0 -> 0 in the cache */
   /* search398_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search398_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1278, 3 },
      -1,
   } },

   /* replace398_0 -> 0 in the cache */
   /* replace398_1 -> 3 in the cache */
   /* replace398 -> 1225 in the cache */

   /* ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b') */
   /* search399_0_0 -> 0 in the cache */
   /* search399_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search399_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1280, 3 },
      -1,
   } },

   /* replace399_0 -> 0 in the cache */
   /* replace399_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b') */
   /* search400_0_0 -> 0 in the cache */
   /* search400_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search400_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1283, 3 },
      -1,
   } },

   /* replace400_0 -> 0 in the cache */
   /* replace400_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c') */
   /* search401_0_0_0 -> 124 in the cache */
   /* search401_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search401_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 2,
      { 1286, 127 },
      -1,
   } },
   /* search401_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 1287, 124 },
      -1,
   } },

   /* replace401_0_0 -> 124 in the cache */
   /* replace401_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace401_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1289, 127 },
      -1,
   } },

   /* ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c') */
   /* search402_0_0_0 -> 124 in the cache */
   /* search402_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search402_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 2,
      { 1291, 127 },
      -1,
   } },
   /* search402_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 3,
      { 1292, 124 },
      -1,
   } },

   /* replace402_0_0 -> 124 in the cache */
   /* replace402_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace402_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1294, 127 },
      -1,
   } },

   /* ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c') */
   /* search403_0_0_0 -> 124 in the cache */
   /* search403_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search403_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 2,
      { 1296, 127 },
      -1,
   } },
   /* search403_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 3,
      { 1297, 124 },
      -1,
   } },

   /* replace403_0_0 -> 124 in the cache */
   /* replace403_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace403_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1299, 127 },
      -1,
   } },

   /* ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c') */
   /* search404_0_0_0 -> 124 in the cache */
   /* search404_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search404_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 1301, 127 },
      -1,
   } },
   /* search404_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 1302, 124 },
      -1,
   } },

   /* replace404_0_0 -> 124 in the cache */
   /* replace404_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace404_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1304, 127 },
      -1,
   } },

   /* ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c') */
   /* search405_0_0_0 -> 124 in the cache */
   /* search405_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search405_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 2,
      { 1306, 127 },
      -1,
   } },
   /* search405_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 1307, 124 },
      -1,
   } },

   /* replace405_0_0 -> 124 in the cache */
   /* replace405_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace405_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1309, 127 },
      -1,
   } },

   /* ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c') */
   /* search406_0_0_0 -> 124 in the cache */
   /* search406_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search406_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 2,
      { 1311, 127 },
      -1,
   } },
   /* search406_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 3,
      { 1312, 124 },
      -1,
   } },

   /* replace406_0_0 -> 124 in the cache */
   /* replace406_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace406_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1314, 127 },
      -1,
   } },

   /* ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b') */
   /* search407_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 706 },
      -1,
   } },
   /* search407_1_0 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1316, 1317 },
      -1,
   } },

   /* replace407_0 -> 706 in the cache */
   /* replace407_1 -> 1075 in the cache */
   /* replace407 -> 1103 in the cache */

   /* ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b') */
   /* search408_0_0 -> 706 in the cache */
   /* search408_0 -> 1316 in the cache */
   /* search408_1_0 -> 1075 in the cache */
   /* search408_1 -> 1317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1316, 1317 },
      -1,
   } },

   /* replace408_0 -> 706 in the cache */
   /* replace408_1 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 706, 1075 },
      -1,
   } },

   /* ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search409_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 706 },
      -1,
   } },
   /* search409_1_0 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1321, 1322 },
      -1,
   } },

   /* replace409_0 -> 706 in the cache */
   /* replace409_1 -> 1075 in the cache */
   /* replace409 -> 1103 in the cache */

   /* ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b') */
   /* search410_0_0 -> 706 in the cache */
   /* search410_0 -> 1321 in the cache */
   /* search410_1_0 -> 1075 in the cache */
   /* search410_1 -> 1322 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1321, 1322 },
      -1,
   } },

   /* replace410_0 -> 706 in the cache */
   /* replace410_1 -> 1075 in the cache */
   /* replace410 -> 1320 in the cache */

   /* ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search411_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 706 },
      -1,
   } },
   /* search411_1_0 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1325, 1326 },
      -1,
   } },

   /* replace411_0 -> 706 in the cache */
   /* replace411_1 -> 1075 in the cache */
   /* replace411 -> 1103 in the cache */

   /* ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b') */
   /* search412_0_0 -> 706 in the cache */
   /* search412_0 -> 1325 in the cache */
   /* search412_1_0 -> 1075 in the cache */
   /* search412_1 -> 1326 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1325, 1326 },
      -1,
   } },

   /* replace412_0 -> 706 in the cache */
   /* replace412_1 -> 1075 in the cache */
   /* replace412 -> 1320 in the cache */

   /* ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search413_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 706 },
      -1,
   } },
   /* search413_1_0 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1329, 1330 },
      -1,
   } },

   /* replace413_0 -> 706 in the cache */
   /* replace413_1 -> 1075 in the cache */
   /* replace413 -> 1103 in the cache */

   /* ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b') */
   /* search414_0_0 -> 706 in the cache */
   /* search414_0 -> 1329 in the cache */
   /* search414_1_0 -> 1075 in the cache */
   /* search414_1 -> 1330 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1329, 1330 },
      -1,
   } },

   /* replace414_0 -> 706 in the cache */
   /* replace414_1 -> 1075 in the cache */
   /* replace414 -> 1320 in the cache */

   /* ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search415_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 706 },
      -1,
   } },
   /* search415_1_0 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1333, 1334 },
      -1,
   } },

   /* replace415_0 -> 706 in the cache */
   /* replace415_1 -> 1075 in the cache */
   /* replace415 -> 1103 in the cache */

   /* ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b') */
   /* search416_0_0 -> 706 in the cache */
   /* search416_0 -> 1333 in the cache */
   /* search416_1_0 -> 1075 in the cache */
   /* search416_1 -> 1334 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1333, 1334 },
      -1,
   } },

   /* replace416_0 -> 706 in the cache */
   /* replace416_1 -> 1075 in the cache */
   /* replace416 -> 1320 in the cache */

   /* ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search417_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 706 },
      -1,
   } },
   /* search417_1_0 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1337, 1338 },
      -1,
   } },

   /* replace417_0 -> 706 in the cache */
   /* replace417_1 -> 1075 in the cache */
   /* replace417 -> 1103 in the cache */

   /* ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b') */
   /* search418_0_0 -> 706 in the cache */
   /* search418_0 -> 1337 in the cache */
   /* search418_1_0 -> 1075 in the cache */
   /* search418_1 -> 1338 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1337, 1338 },
      -1,
   } },

   /* replace418_0 -> 706 in the cache */
   /* replace418_1 -> 1075 in the cache */
   /* replace418 -> 1320 in the cache */

   /* ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search419_0_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 706 },
      -1,
   } },
   /* search419_1_0 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1341, 1342 },
      -1,
   } },

   /* replace419_0 -> 706 in the cache */
   /* replace419_1 -> 1075 in the cache */
   /* replace419 -> 1103 in the cache */

   /* ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b') */
   /* search420_0_0 -> 706 in the cache */
   /* search420_0 -> 1341 in the cache */
   /* search420_1_0 -> 1075 in the cache */
   /* search420_1 -> 1342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1341, 1342 },
      -1,
   } },

   /* replace420_0 -> 706 in the cache */
   /* replace420_1 -> 1075 in the cache */
   /* replace420 -> 1320 in the cache */

   /* ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0) */
   /* search421_0 -> 6 in the cache */
   /* search421_1_0_0 -> 6 in the cache */
   /* search421_1_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 1346 },
      -1,
   } },

   /* replace421_0 -> 6 in the cache */
   /* replace421_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 6, 782 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0) */
   /* search422_0_0 -> 6 in the cache */
   /* search422_0_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 6, 7 },
      -1,
   } },
   /* search422_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1349, 782 },
      -1,
   } },

   /* replace422_0 -> 6 in the cache */
   /* replace422_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 782 },
      -1,
   } },

   /* ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0) */
   /* search423_0_0 -> 6 in the cache */
   /* search423_0_1 -> 7 in the cache */
   /* search423_0 -> 1349 in the cache */
   /* search423_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1349, 7 },
      -1,
   } },

   /* replace423_0 -> 6 in the cache */
   /* replace423_1 -> 782 in the cache */
   /* replace423 -> 1351 in the cache */

   /* ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0) */
   /* search424_0_0 -> 6 in the cache */
   /* search424_0_1 -> 7 in the cache */
   /* search424_0 -> 1349 in the cache */
   /* search424_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1349, 782 },
      -1,
   } },

   /* replace424_0 -> 6 in the cache */
   /* replace424_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 782 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0) */
   /* search425_0_0 -> 6 in the cache */
   /* search425_0_1 -> 7 in the cache */
   /* search425_0 -> 1349 in the cache */
   /* search425_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1349, 7 },
      -1,
   } },

   /* replace425_0 -> 6 in the cache */
   /* replace425_1 -> 782 in the cache */
   /* replace425 -> 1354 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search426_0_0 -> 6 in the cache */
   /* search426_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   /* search426_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1356, 782 },
      -1,
   } },

   /* replace426_0 -> 6 in the cache */
   /* replace426_1 -> 782 in the cache */
   /* replace426 -> 1354 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search427_0_0 -> 6 in the cache */
   /* search427_0_1 -> 9 in the cache */
   /* search427_0 -> 1356 in the cache */
   /* search427_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1356, 782 },
      -1,
   } },

   /* replace427_0 -> 6 in the cache */
   /* replace427_1 -> 782 in the cache */
   /* replace427 -> 1351 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0) */
   /* search428_0_0 -> 6 in the cache */
   /* search428_0_1 -> 9 in the cache */
   /* search428_0 -> 1356 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1356, 1359 },
      -1,
   } },

   /* replace428_0 -> 6 in the cache */
   /* replace428_1 -> 782 in the cache */
   /* replace428 -> 1354 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0) */
   /* search429_0_0 -> 6 in the cache */
   /* search429_0_1 -> 9 in the cache */
   /* search429_0 -> 1356 in the cache */
   /* search429_1 -> 1359 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1356, 1359 },
      -1,
   } },

   /* replace429_0 -> 6 in the cache */
   /* replace429_1 -> 782 in the cache */
   /* replace429 -> 1351 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search430_0_0 -> 6 in the cache */
   /* search430_0_1 -> 9 in the cache */
   /* search430_0 -> 1345 in the cache */
   /* search430_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1345, 782 },
      -1,
   } },

   /* replace430_0 -> 6 in the cache */
   /* replace430_1 -> 782 in the cache */
   /* replace430 -> 1354 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search431_0_0 -> 6 in the cache */
   /* search431_0_1 -> 9 in the cache */
   /* search431_0 -> 1345 in the cache */
   /* search431_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1345, 782 },
      -1,
   } },

   /* replace431_0 -> 6 in the cache */
   /* replace431_1 -> 782 in the cache */
   /* replace431 -> 1351 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0) */
   /* search432_0_0 -> 6 in the cache */
   /* search432_0_1 -> 9 in the cache */
   /* search432_0 -> 1345 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1345, 1364 },
      -1,
   } },

   /* replace432_0 -> 6 in the cache */
   /* replace432_1 -> 782 in the cache */
   /* replace432 -> 1354 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0) */
   /* search433_0_0 -> 6 in the cache */
   /* search433_0_1 -> 9 in the cache */
   /* search433_0 -> 1345 in the cache */
   /* search433_1 -> 1364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1345, 1364 },
      -1,
   } },

   /* replace433_0 -> 6 in the cache */
   /* replace433_1 -> 782 in the cache */
   /* replace433 -> 1351 in the cache */

   /* ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0) */
   /* search434_0 -> 11 in the cache */
   /* search434_1_0_0 -> 11 in the cache */
   /* search434_1_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1368 },
      -1,
   } },

   /* replace434_0 -> 11 in the cache */
   /* replace434_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 11, 804 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0) */
   /* search435_0_0 -> 11 in the cache */
   /* search435_0_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 11, 12 },
      -1,
   } },
   /* search435_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1371, 804 },
      -1,
   } },

   /* replace435_0 -> 11 in the cache */
   /* replace435_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 804 },
      -1,
   } },

   /* ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0) */
   /* search436_0_0 -> 11 in the cache */
   /* search436_0_1 -> 12 in the cache */
   /* search436_0 -> 1371 in the cache */
   /* search436_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1371, 12 },
      -1,
   } },

   /* replace436_0 -> 11 in the cache */
   /* replace436_1 -> 804 in the cache */
   /* replace436 -> 1373 in the cache */

   /* ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0) */
   /* search437_0_0 -> 11 in the cache */
   /* search437_0_1 -> 12 in the cache */
   /* search437_0 -> 1371 in the cache */
   /* search437_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1371, 804 },
      -1,
   } },

   /* replace437_0 -> 11 in the cache */
   /* replace437_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 804 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0) */
   /* search438_0_0 -> 11 in the cache */
   /* search438_0_1 -> 12 in the cache */
   /* search438_0 -> 1371 in the cache */
   /* search438_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1371, 12 },
      -1,
   } },

   /* replace438_0 -> 11 in the cache */
   /* replace438_1 -> 804 in the cache */
   /* replace438 -> 1376 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search439_0_0 -> 11 in the cache */
   /* search439_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   /* search439_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1378, 804 },
      -1,
   } },

   /* replace439_0 -> 11 in the cache */
   /* replace439_1 -> 804 in the cache */
   /* replace439 -> 1376 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search440_0_0 -> 11 in the cache */
   /* search440_0_1 -> 14 in the cache */
   /* search440_0 -> 1378 in the cache */
   /* search440_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1378, 804 },
      -1,
   } },

   /* replace440_0 -> 11 in the cache */
   /* replace440_1 -> 804 in the cache */
   /* replace440 -> 1373 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0) */
   /* search441_0_0 -> 11 in the cache */
   /* search441_0_1 -> 14 in the cache */
   /* search441_0 -> 1378 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1378, 1381 },
      -1,
   } },

   /* replace441_0 -> 11 in the cache */
   /* replace441_1 -> 804 in the cache */
   /* replace441 -> 1376 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0) */
   /* search442_0_0 -> 11 in the cache */
   /* search442_0_1 -> 14 in the cache */
   /* search442_0 -> 1378 in the cache */
   /* search442_1 -> 1381 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1378, 1381 },
      -1,
   } },

   /* replace442_0 -> 11 in the cache */
   /* replace442_1 -> 804 in the cache */
   /* replace442 -> 1373 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search443_0_0 -> 11 in the cache */
   /* search443_0_1 -> 14 in the cache */
   /* search443_0 -> 1367 in the cache */
   /* search443_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1367, 804 },
      -1,
   } },

   /* replace443_0 -> 11 in the cache */
   /* replace443_1 -> 804 in the cache */
   /* replace443 -> 1376 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search444_0_0 -> 11 in the cache */
   /* search444_0_1 -> 14 in the cache */
   /* search444_0 -> 1367 in the cache */
   /* search444_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1367, 804 },
      -1,
   } },

   /* replace444_0 -> 11 in the cache */
   /* replace444_1 -> 804 in the cache */
   /* replace444 -> 1373 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0) */
   /* search445_0_0 -> 11 in the cache */
   /* search445_0_1 -> 14 in the cache */
   /* search445_0 -> 1367 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1367, 1386 },
      -1,
   } },

   /* replace445_0 -> 11 in the cache */
   /* replace445_1 -> 804 in the cache */
   /* replace445 -> 1376 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0) */
   /* search446_0_0 -> 11 in the cache */
   /* search446_0_1 -> 14 in the cache */
   /* search446_0 -> 1367 in the cache */
   /* search446_1 -> 1386 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1367, 1386 },
      -1,
   } },

   /* replace446_0 -> 11 in the cache */
   /* replace446_1 -> 804 in the cache */
   /* replace446 -> 1373 in the cache */

   /* ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0) */
   /* search447_0 -> 16 in the cache */
   /* search447_1_0_0 -> 16 in the cache */
   /* search447_1_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1390 },
      -1,
   } },

   /* replace447_0 -> 16 in the cache */
   /* replace447_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0) */
   /* search448_0_0 -> 16 in the cache */
   /* search448_0_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 17 },
      -1,
   } },
   /* search448_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1393, 120 },
      -1,
   } },

   /* replace448_0 -> 16 in the cache */
   /* replace448_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0) */
   /* search449_0_0 -> 16 in the cache */
   /* search449_0_1 -> 17 in the cache */
   /* search449_0 -> 1393 in the cache */
   /* search449_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1393, 17 },
      -1,
   } },

   /* replace449_0 -> 16 in the cache */
   /* replace449_1 -> 120 in the cache */
   /* replace449 -> 1395 in the cache */

   /* ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0) */
   /* search450_0_0 -> 16 in the cache */
   /* search450_0_1 -> 17 in the cache */
   /* search450_0 -> 1393 in the cache */
   /* search450_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1393, 120 },
      -1,
   } },

   /* replace450_0 -> 16 in the cache */
   /* replace450_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0) */
   /* search451_0_0 -> 16 in the cache */
   /* search451_0_1 -> 17 in the cache */
   /* search451_0 -> 1393 in the cache */
   /* search451_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1393, 17 },
      -1,
   } },

   /* replace451_0 -> 16 in the cache */
   /* replace451_1 -> 120 in the cache */
   /* replace451 -> 1398 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search452_0_0 -> 16 in the cache */
   /* search452_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   /* search452_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1400, 120 },
      -1,
   } },

   /* replace452_0 -> 16 in the cache */
   /* replace452_1 -> 120 in the cache */
   /* replace452 -> 1398 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search453_0_0 -> 16 in the cache */
   /* search453_0_1 -> 19 in the cache */
   /* search453_0 -> 1400 in the cache */
   /* search453_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1400, 120 },
      -1,
   } },

   /* replace453_0 -> 16 in the cache */
   /* replace453_1 -> 120 in the cache */
   /* replace453 -> 1395 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0) */
   /* search454_0_0 -> 16 in the cache */
   /* search454_0_1 -> 19 in the cache */
   /* search454_0 -> 1400 in the cache */
   /* search454_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1400, 377 },
      -1,
   } },

   /* replace454_0 -> 16 in the cache */
   /* replace454_1 -> 120 in the cache */
   /* replace454 -> 1398 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0) */
   /* search455_0_0 -> 16 in the cache */
   /* search455_0_1 -> 19 in the cache */
   /* search455_0 -> 1400 in the cache */
   /* search455_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1400, 377 },
      -1,
   } },

   /* replace455_0 -> 16 in the cache */
   /* replace455_1 -> 120 in the cache */
   /* replace455 -> 1395 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search456_0_0 -> 16 in the cache */
   /* search456_0_1 -> 19 in the cache */
   /* search456_0 -> 1389 in the cache */
   /* search456_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1389, 120 },
      -1,
   } },

   /* replace456_0 -> 16 in the cache */
   /* replace456_1 -> 120 in the cache */
   /* replace456 -> 1398 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search457_0_0 -> 16 in the cache */
   /* search457_0_1 -> 19 in the cache */
   /* search457_0 -> 1389 in the cache */
   /* search457_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1389, 120 },
      -1,
   } },

   /* replace457_0 -> 16 in the cache */
   /* replace457_1 -> 120 in the cache */
   /* replace457 -> 1395 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0) */
   /* search458_0_0 -> 16 in the cache */
   /* search458_0_1 -> 19 in the cache */
   /* search458_0 -> 1389 in the cache */
   /* search458_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1389, 122 },
      -1,
   } },

   /* replace458_0 -> 16 in the cache */
   /* replace458_1 -> 120 in the cache */
   /* replace458 -> 1398 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0) */
   /* search459_0_0 -> 16 in the cache */
   /* search459_0_1 -> 19 in the cache */
   /* search459_0 -> 1389 in the cache */
   /* search459_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1389, 122 },
      -1,
   } },

   /* replace459_0 -> 16 in the cache */
   /* replace459_1 -> 120 in the cache */
   /* replace459 -> 1395 in the cache */

   /* ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0) */
   /* search460_0 -> 21 in the cache */
   /* search460_1_0_0 -> 21 in the cache */
   /* search460_1_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1409 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 1410 },
      -1,
   } },

   /* replace460_0 -> 21 in the cache */
   /* replace460_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 847 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0) */
   /* search461_0_0 -> 21 in the cache */
   /* search461_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 22 },
      -1,
   } },
   /* search461_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1413, 847 },
      -1,
   } },

   /* replace461_0 -> 21 in the cache */
   /* replace461_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 847 },
      -1,
   } },

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0) */
   /* search462_0_0 -> 21 in the cache */
   /* search462_0_1 -> 22 in the cache */
   /* search462_0 -> 1413 in the cache */
   /* search462_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1413, 22 },
      -1,
   } },

   /* replace462_0 -> 21 in the cache */
   /* replace462_1 -> 847 in the cache */
   /* replace462 -> 1415 in the cache */

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0) */
   /* search463_0_0 -> 21 in the cache */
   /* search463_0_1 -> 22 in the cache */
   /* search463_0 -> 1413 in the cache */
   /* search463_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1413, 847 },
      -1,
   } },

   /* replace463_0 -> 21 in the cache */
   /* replace463_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 847 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0) */
   /* search464_0_0 -> 21 in the cache */
   /* search464_0_1 -> 22 in the cache */
   /* search464_0 -> 1413 in the cache */
   /* search464_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1413, 22 },
      -1,
   } },

   /* replace464_0 -> 21 in the cache */
   /* replace464_1 -> 847 in the cache */
   /* replace464 -> 1418 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search465_0_0 -> 21 in the cache */
   /* search465_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   /* search465_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1420, 847 },
      -1,
   } },

   /* replace465_0 -> 21 in the cache */
   /* replace465_1 -> 847 in the cache */
   /* replace465 -> 1418 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search466_0_0 -> 21 in the cache */
   /* search466_0_1 -> 24 in the cache */
   /* search466_0 -> 1420 in the cache */
   /* search466_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1420, 847 },
      -1,
   } },

   /* replace466_0 -> 21 in the cache */
   /* replace466_1 -> 847 in the cache */
   /* replace466 -> 1415 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0) */
   /* search467_0_0 -> 21 in the cache */
   /* search467_0_1 -> 24 in the cache */
   /* search467_0 -> 1420 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1420, 1423 },
      -1,
   } },

   /* replace467_0 -> 21 in the cache */
   /* replace467_1 -> 847 in the cache */
   /* replace467 -> 1418 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0) */
   /* search468_0_0 -> 21 in the cache */
   /* search468_0_1 -> 24 in the cache */
   /* search468_0 -> 1420 in the cache */
   /* search468_1 -> 1423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1420, 1423 },
      -1,
   } },

   /* replace468_0 -> 21 in the cache */
   /* replace468_1 -> 847 in the cache */
   /* replace468 -> 1415 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search469_0_0 -> 21 in the cache */
   /* search469_0_1 -> 24 in the cache */
   /* search469_0 -> 1409 in the cache */
   /* search469_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1409, 847 },
      -1,
   } },

   /* replace469_0 -> 21 in the cache */
   /* replace469_1 -> 847 in the cache */
   /* replace469 -> 1418 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search470_0_0 -> 21 in the cache */
   /* search470_0_1 -> 24 in the cache */
   /* search470_0 -> 1409 in the cache */
   /* search470_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1409, 847 },
      -1,
   } },

   /* replace470_0 -> 21 in the cache */
   /* replace470_1 -> 847 in the cache */
   /* replace470 -> 1415 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0) */
   /* search471_0_0 -> 21 in the cache */
   /* search471_0_1 -> 24 in the cache */
   /* search471_0 -> 1409 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1409, 1428 },
      -1,
   } },

   /* replace471_0 -> 21 in the cache */
   /* replace471_1 -> 847 in the cache */
   /* replace471 -> 1418 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0) */
   /* search472_0_0 -> 21 in the cache */
   /* search472_0_1 -> 24 in the cache */
   /* search472_0 -> 1409 in the cache */
   /* search472_1 -> 1428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1409, 1428 },
      -1,
   } },

   /* replace472_0 -> 21 in the cache */
   /* replace472_1 -> 847 in the cache */
   /* replace472 -> 1415 in the cache */

   /* ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a')) */
   /* search473_0 -> 32 in the cache */
   /* search473_1_0 -> 32 in the cache */
   /* search473_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace473_0_0 -> 32 in the cache */
   /* replace473_0 -> 103 in the cache */
   /* replace473 -> 1196 in the cache */

   /* ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a')) */
   /* search474_0 -> 32 in the cache */
   /* search474_1_0 -> 32 in the cache */
   /* search474_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace474_0_0 -> 32 in the cache */
   /* replace474_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 106 },
      -1,
   } },

   /* ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a')) */
   /* search475_0 -> 32 in the cache */
   /* search475_1_0_0 -> 32 in the cache */
   /* search475_1_0 -> 103 in the cache */
   /* search475_1 -> 1196 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 1196 },
      -1,
   } },

   /* replace475_0_0 -> 32 in the cache */
   /* replace475_0 -> 103 in the cache */
   /* replace475 -> 1196 in the cache */

   /* ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a')) */
   /* search476_0 -> 32 in the cache */
   /* search476_1_0_0 -> 32 in the cache */
   /* search476_1_0 -> 106 in the cache */
   /* search476_1 -> 1433 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 1433 },
      -1,
   } },

   /* replace476_0_0 -> 32 in the cache */
   /* replace476_0 -> 106 in the cache */
   /* replace476 -> 1433 in the cache */

   /* ('~fmin', 'a', ('fabs', 'a')) => a */
   /* search477_0 -> 32 in the cache */
   /* search477_1_0 -> 32 in the cache */
   /* search477_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace477 -> 32 in the cache */

   /* ('imin', 'a', ('iabs', 'a')) => a */
   /* search478_0 -> 32 in the cache */
   /* search478_1_0 -> 32 in the cache */
   /* search478_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace478 -> 32 in the cache */

   /* ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a */
   /* search479_0 -> 32 in the cache */
   /* search479_1_0_0 -> 32 in the cache */
   /* search479_1_0 -> 103 in the cache */
   /* search479_1 -> 1196 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 1196 },
      -1,
   } },

   /* replace479 -> 32 in the cache */

   /* ('imax', 'a', ('ineg', ('iabs', 'a'))) => a */
   /* search480_0 -> 32 in the cache */
   /* search480_1_0_0 -> 32 in the cache */
   /* search480_1_0 -> 106 in the cache */
   /* search480_1 -> 1433 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 1433 },
      -1,
   } },

   /* replace480 -> 32 in the cache */

   /* ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a') */
   /* search481_0 -> 32 in the cache */
   /* search481_1_0 -> 32 in the cache */
   /* search481_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace481_0 -> 32 in the cache */
   /* replace481 -> 103 in the cache */

   /* ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a') */
   /* search482_0 -> 32 in the cache */
   /* search482_1_0 -> 32 in the cache */
   /* search482_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace482_0 -> 32 in the cache */
   /* replace482 -> 106 in the cache */

   /* ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a') */
   /* search483_0 -> 32 in the cache */
   /* search483_1_0 -> 32 in the cache */
   /* search483_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace483_0 -> 32 in the cache */
   /* replace483 -> 103 in the cache */

   /* ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a') */
   /* search484_0 -> 32 in the cache */
   /* search484_1_0 -> 32 in the cache */
   /* search484_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace484_0 -> 32 in the cache */
   /* replace484 -> 106 in the cache */

   /* ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a') */
   /* search485_0_0 -> 32 in the cache */
   /* search485_0 -> 103 in the cache */
   /* search485_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 103, 113 },
      -1,
   } },

   /* replace485_0 -> 32 in the cache */
   /* replace485 -> 103 in the cache */

   /* ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a') */
   /* search486_0_0 -> 32 in the cache */
   /* search486_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search486_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1445, 226 },
      -1,
   } },

   /* replace486_0 -> 32 in the cache */
   /* replace486 -> 202 in the cache */

   /* ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a') */
   /* search487_0_0 -> 32 in the cache */
   /* search487_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 226 },
      -1,
   } },
   /* search487_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1447, 113 },
      -1,
   } },

   /* replace487_0 -> 32 in the cache */
   /* replace487 -> 202 in the cache */

   /* ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search488_0_0 -> 32 in the cache */
   /* search488_0_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 232 },
      -1,
   } },
   /* search488_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1449, 113 },
      -1,
   } },

   /* replace488_0_0_0 -> 32 in the cache */
   /* replace488_0_0 -> 98 in the cache */
   /* replace488_0 -> 203 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 203 },
      -1,
   } },

   /* ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search489_0_0 -> 32 in the cache */
   /* search489_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search489_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1452, 232 },
      -1,
   } },

   /* replace489_0_0_0 -> 32 in the cache */
   /* replace489_0_0 -> 98 in the cache */
   /* replace489_0 -> 203 in the cache */
   /* replace489 -> 1451 in the cache */

   /* ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a')) */
   /* search490_0_0 -> 32 in the cache */
   /* search490_0 -> 235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 235 },
      -1,
   } },

   /* replace490_0_0 -> 113 in the cache */
   /* replace490_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1455 },
      -1,
   } },

   /* ('fsat', ('b2f', 'a')) => ('b2f', 'a') */
   /* search491_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1457 },
      -1,
   } },

   /* replace491_0 -> 32 in the cache */
   /* replace491 -> 1457 in the cache */

   /* ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0) */
   /* search492_0 -> 32 in the cache */
   /* search492 -> 202 in the cache */

   /* replace492_0_0 -> 32 in the cache */
   /* replace492_0_1 -> 113 in the cache */
   /* replace492_0 -> 1445 in the cache */
   /* replace492_1 -> 226 in the cache */
   /* replace492 -> 1446 in the cache */

   /* ('fsat', ('fsat', 'a')) => ('fsat', 'a') */
   /* search493_0_0 -> 32 in the cache */
   /* search493_0 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 202 },
      -1,
   } },

   /* replace493_0 -> 32 in the cache */
   /* replace493 -> 202 in the cache */

   /* ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search494_0_0_0 -> 0 in the cache */
   /* search494_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1460 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1461 },
      -1,
   } },

   /* replace494_0_0_0 -> 0 in the cache */
   /* replace494_0_0 -> 197 in the cache */
   /* replace494_0_1_0 -> 3 in the cache */
   /* replace494_0_1 -> 1034 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 197, 1034 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1463 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b')) */
   /* search495_0_0_0 -> 0 in the cache */
   /* search495_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1465 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1466 },
      -1,
   } },

   /* replace495_0_0_0 -> 0 in the cache */
   /* replace495_0_0 -> 197 in the cache */
   /* replace495_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 197, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1468 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b')) */
   /* search496_0_0_0 -> 16 in the cache */
   /* search496_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1470 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1471 },
      -1,
   } },

   /* replace496_0_0_0 -> 16 in the cache */
   /* replace496_0_0 -> 265 in the cache */
   /* replace496_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 265, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1473 },
      -1,
   } },

   /* ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search497_0_0_0 -> 0 in the cache */
   /* search497_0_0_1 -> 3 in the cache */
   /* search497_0_0 -> 1465 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 1465 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1475 },
      -1,
   } },

   /* replace497_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace497_0_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1477, 1478 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1479 },
      -1,
   } },

   /* ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c') */
   /* search498_0_0_0_0 -> 124 in the cache */
   /* search498_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search498_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 2,
      { 1481, 127 },
      -1,
   } },
   /* search498_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 3,
      { 1482, 125 },
      -1,
   } },
   /* search498_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 4,
      { 1483, 127 },
      -1,
   } },

   /* replace498_0_0 -> 124 in the cache */
   /* replace498_0_1 -> 125 in the cache */
   /* replace498_0 -> 1289 in the cache */
   /* replace498_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1289, 127 },
      -1,
   } },

   /* ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c') */
   /* search499_0_0_0_0 -> 124 in the cache */
   /* search499_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search499_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 2,
      { 1486, 127 },
      -1,
   } },
   /* search499_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 3,
      { 1487, 125 },
      -1,
   } },
   /* search499_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 1488, 127 },
      -1,
   } },

   /* replace499_0_0 -> 124 in the cache */
   /* replace499_0_1 -> 125 in the cache */
   /* replace499_0 -> 1299 in the cache */
   /* replace499_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1299, 127 },
      -1,
   } },

   /* ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c') */
   /* search500_0_0_0_0 -> 124 in the cache */
   /* search500_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search500_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 2,
      { 1491, 127 },
      -1,
   } },
   /* search500_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 3,
      { 1492, 125 },
      -1,
   } },
   /* search500_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 4,
      { 1493, 127 },
      -1,
   } },

   /* replace500_0_0 -> 124 in the cache */
   /* replace500_0_1 -> 125 in the cache */
   /* replace500_0 -> 1294 in the cache */
   /* replace500_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1294, 127 },
      -1,
   } },

   /* ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b')) */
   /* search501_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1496, 1497 },
      -1,
   } },

   /* replace501_0_0 -> 0 in the cache */
   /* replace501_0_1 -> 3 in the cache */
   /* replace501_0 -> 1223 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1223 },
      -1,
   } },

   /* ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b')) */
   /* search502_0_0 -> 0 in the cache */
   /* search502_0 -> 1496 in the cache */
   /* search502_1 -> 1497 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1496, 1497 },
      -1,
   } },

   /* replace502_0_0 -> 0 in the cache */
   /* replace502_0_1 -> 3 in the cache */
   /* replace502_0 -> 1225 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1225 },
      -1,
   } },

   /* ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a')) */
   /* search503_0_0_0 -> 1058 in the cache */
   /* search503_0_0_1 -> 1055 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 1058, 1055 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1502 },
      -1,
   } },
   /* search503_1 -> 1058 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1503, 1058 },
      -1,
   } },

   /* replace503_0_0 -> 1058 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1058 },
      -1,
   } },
   /* replace503_1_0 -> 1055 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1055 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1505, 1506 },
      -1,
   } },

   /* ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a')) */
   /* search504_0_0_0 -> 1058 in the cache */
   /* search504_0_0_1 -> 1055 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 1058, 1055 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1508 },
      -1,
   } },
   /* search504_1 -> 1058 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1509, 1058 },
      -1,
   } },

   /* replace504_0_0_0 -> 1058 in the cache */
   /* replace504_0_0 -> 1505 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1505 },
      -1,
   } },
   /* replace504_1_0 -> 1055 in the cache */
   /* replace504_1 -> 1506 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1511, 1506 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1513 },
      -1,
   } },
   /* search505_0_1 -> 1497 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1514, 1497 },
      0,
   } },
   /* search505_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1515, 241 },
      -1,
   } },

   /* replace505_0_0_0 -> 0 in the cache */
   /* replace505_0_0 -> 197 in the cache */
   /* replace505_0_1 -> 3 in the cache */
   /* replace505_0 -> 262 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 262 },
      -1,
   } },

   /* ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255) */
   /* search506_0_0_0 -> 32 in the cache */
   /* search506_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 61 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1518, 1519 },
      -1,
   } },
   /* search506_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 2,
      { 1520, 61 },
      -1,
   } },

   /* replace506_0_0 -> 32 in the cache */
   /* replace506_0_1 -> 61 in the cache */
   /* replace506_0 -> 1518 in the cache */
   /* replace506_1 -> 1519 in the cache */
   /* replace506 -> 1520 in the cache */

   /* ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search507_0_0 -> 124 in the cache */
   /* search507_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search507_1_0 -> 124 in the cache */
   /* search507_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1522, 1523 },
      -1,
   } },

   /* replace507_0 -> 124 in the cache */
   /* replace507_1_0 -> 125 in the cache */
   /* replace507_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 124, 1525 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   /* search508_0_0 -> 0 in the cache */
   /* search508_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 665 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search508_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1528, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1527, 1529 },
      -1,
   } },

   /* replace508_0_0 -> 0 in the cache */
   /* replace508_0_1 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1528 },
      -1,
   } },
   /* replace508_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1531, 665 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search509_0_0 -> 124 in the cache */
   /* search509_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search509_1_0 -> 124 in the cache */
   /* search509_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1533, 1534 },
      -1,
   } },

   /* replace509_0 -> 124 in the cache */
   /* replace509_1_0 -> 125 in the cache */
   /* replace509_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 124, 1536 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search510_0_0 -> 0 in the cache */
   /* search510_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search510_1_0 -> 1528 in the cache */
   /* search510_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1528, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1538, 1539 },
      -1,
   } },

   /* replace510_0_0 -> 0 in the cache */
   /* replace510_0_1 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1528 },
      -1,
   } },
   /* replace510_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1541, 665 },
      -1,
   } },

   /* ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search511_0_0 -> 124 in the cache */
   /* search511_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 268 },
      -1,
   } },
   /* search511_1_0 -> 124 in the cache */
   /* search511_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1543, 1544 },
      -1,
   } },

   /* replace511_0 -> 124 in the cache */
   /* replace511_1_0 -> 125 in the cache */
   /* replace511_1_1 -> 127 in the cache */
   /* replace511_1 -> 1525 in the cache */
   /* replace511 -> 1526 in the cache */

   /* ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search512_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1546, 665 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search512_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1548, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1547, 1549 },
      -1,
   } },

   /* replace512_0_0 -> 0 in the cache */
   /* replace512_0_1 -> 1528 in the cache */
   /* replace512_0 -> 1531 in the cache */
   /* replace512_1 -> 665 in the cache */
   /* replace512 -> 1532 in the cache */

   /* ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search513_0_0 -> 124 in the cache */
   /* search513_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 268 },
      -1,
   } },
   /* search513_1_0 -> 124 in the cache */
   /* search513_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1551, 1552 },
      -1,
   } },

   /* replace513_0 -> 124 in the cache */
   /* replace513_1_0 -> 125 in the cache */
   /* replace513_1_1 -> 127 in the cache */
   /* replace513_1 -> 1536 in the cache */
   /* replace513 -> 1537 in the cache */

   /* ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search514_0_0 -> 1546 in the cache */
   /* search514_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1546, 665 },
      -1,
   } },
   /* search514_1_0 -> 1548 in the cache */
   /* search514_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1548, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1554, 1555 },
      -1,
   } },

   /* replace514_0_0 -> 0 in the cache */
   /* replace514_0_1 -> 1528 in the cache */
   /* replace514_0 -> 1541 in the cache */
   /* replace514_1 -> 665 in the cache */
   /* replace514 -> 1542 in the cache */

   /* ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search515_0_0 -> 124 in the cache */
   /* search515_0_1 -> 125 in the cache */
   /* search515_0 -> 1522 in the cache */
   /* search515_1_0 -> 124 in the cache */
   /* search515_1_1 -> 127 in the cache */
   /* search515_1 -> 1523 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1522, 1523 },
      -1,
   } },

   /* replace515_0 -> 124 in the cache */
   /* replace515_1_0 -> 125 in the cache */
   /* replace515_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 124, 1558 },
      -1,
   } },

   /* ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   /* search516_0_0 -> 0 in the cache */
   /* search516_0_1 -> 665 in the cache */
   /* search516_0 -> 1527 in the cache */
   /* search516_1_0 -> 1528 in the cache */
   /* search516_1_1 -> 665 in the cache */
   /* search516_1 -> 1529 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1527, 1529 },
      -1,
   } },

   /* replace516_0_0 -> 0 in the cache */
   /* replace516_0_1 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1528 },
      -1,
   } },
   /* replace516_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1561, 665 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search517_0_0 -> 124 in the cache */
   /* search517_0_1 -> 125 in the cache */
   /* search517_0 -> 1533 in the cache */
   /* search517_1_0 -> 124 in the cache */
   /* search517_1_1 -> 127 in the cache */
   /* search517_1 -> 1534 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1533, 1534 },
      -1,
   } },

   /* replace517_0 -> 124 in the cache */
   /* replace517_1_0 -> 125 in the cache */
   /* replace517_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 124, 1564 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search518_0_0 -> 0 in the cache */
   /* search518_0_1 -> 665 in the cache */
   /* search518_0 -> 1538 in the cache */
   /* search518_1_0 -> 1528 in the cache */
   /* search518_1_1 -> 665 in the cache */
   /* search518_1 -> 1539 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1538, 1539 },
      -1,
   } },

   /* replace518_0_0 -> 0 in the cache */
   /* replace518_0_1 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1528 },
      -1,
   } },
   /* replace518_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1567, 665 },
      -1,
   } },

   /* ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search519_0_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 1569 },
      -1,
   } },
   /* search519_1_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 1571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1570, 1572 },
      -1,
   } },

   /* replace519_0 -> 124 in the cache */
   /* replace519_1_0 -> 125 in the cache */
   /* replace519_1_1 -> 127 in the cache */
   /* replace519_1 -> 1558 in the cache */
   /* replace519 -> 1559 in the cache */

   /* ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search520_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1574, 665 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search520_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1576, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1575, 1577 },
      -1,
   } },

   /* replace520_0_0 -> 0 in the cache */
   /* replace520_0_1 -> 1528 in the cache */
   /* replace520_0 -> 1561 in the cache */
   /* replace520_1 -> 665 in the cache */
   /* replace520 -> 1562 in the cache */

   /* ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search521_0_0 -> 124 in the cache */
   /* search521_0_1 -> 1569 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 1569 },
      -1,
   } },
   /* search521_1_0 -> 124 in the cache */
   /* search521_1_1 -> 1571 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 1571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1579, 1580 },
      -1,
   } },

   /* replace521_0 -> 124 in the cache */
   /* replace521_1_0 -> 125 in the cache */
   /* replace521_1_1 -> 127 in the cache */
   /* replace521_1 -> 1564 in the cache */
   /* replace521 -> 1565 in the cache */

   /* ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search522_0_0 -> 1574 in the cache */
   /* search522_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1574, 665 },
      -1,
   } },
   /* search522_1_0 -> 1576 in the cache */
   /* search522_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1576, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1582, 1583 },
      -1,
   } },

   /* replace522_0_0 -> 0 in the cache */
   /* replace522_0_1 -> 1528 in the cache */
   /* replace522_0 -> 1567 in the cache */
   /* replace522_1 -> 665 in the cache */
   /* replace522 -> 1568 in the cache */

   /* ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c')) */
   /* search523_0_0 -> 124 in the cache */
   /* search523_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search523_1_0 -> 124 in the cache */
   /* search523_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1585, 1586 },
      -1,
   } },

   /* replace523_0 -> 124 in the cache */
   /* replace523_1_0 -> 125 in the cache */
   /* replace523_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 124, 1588 },
      -1,
   } },

   /* ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c') */
   /* search524_0_0 -> 0 in the cache */
   /* search524_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search524_1_0 -> 1528 in the cache */
   /* search524_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1528, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1590, 1591 },
      -1,
   } },

   /* replace524_0_0 -> 0 in the cache */
   /* replace524_0_1 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 1528 },
      -1,
   } },
   /* replace524_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1593, 665 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c')) */
   /* search525_0_0 -> 124 in the cache */
   /* search525_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search525_1_0 -> 124 in the cache */
   /* search525_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1595, 1596 },
      -1,
   } },

   /* replace525_0 -> 124 in the cache */
   /* replace525_1_0 -> 125 in the cache */
   /* replace525_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 124, 1598 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c') */
   /* search526_0_0 -> 0 in the cache */
   /* search526_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search526_1_0 -> 1528 in the cache */
   /* search526_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1528, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1600, 1601 },
      -1,
   } },

   /* replace526_0_0 -> 0 in the cache */
   /* replace526_0_1 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 1528 },
      -1,
   } },
   /* replace526_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1603, 665 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c')) */
   /* search527_0_0 -> 124 in the cache */
   /* search527_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search527_1_0 -> 124 in the cache */
   /* search527_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1605, 1606 },
      -1,
   } },

   /* replace527_0 -> 124 in the cache */
   /* replace527_1_0 -> 125 in the cache */
   /* replace527_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 124, 1608 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c') */
   /* search528_0_0 -> 0 in the cache */
   /* search528_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search528_1_0 -> 1528 in the cache */
   /* search528_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1528, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1610, 1611 },
      -1,
   } },

   /* replace528_0_0 -> 0 in the cache */
   /* replace528_0_1 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 1528 },
      -1,
   } },
   /* replace528_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1613, 665 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c')) */
   /* search529_0_0 -> 124 in the cache */
   /* search529_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search529_1_0 -> 124 in the cache */
   /* search529_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1615, 1616 },
      -1,
   } },

   /* replace529_0 -> 124 in the cache */
   /* replace529_1_0 -> 125 in the cache */
   /* replace529_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 124, 1618 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c') */
   /* search530_0_0 -> 0 in the cache */
   /* search530_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search530_1_0 -> 1528 in the cache */
   /* search530_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1528, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1620, 1621 },
      -1,
   } },

   /* replace530_0_0 -> 0 in the cache */
   /* replace530_0_1 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 1528 },
      -1,
   } },
   /* replace530_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1623, 665 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c')) */
   /* search531_0_0 -> 124 in the cache */
   /* search531_0_1 -> 125 in the cache */
   /* search531_0 -> 1585 in the cache */
   /* search531_1_0 -> 124 in the cache */
   /* search531_1_1 -> 127 in the cache */
   /* search531_1 -> 1586 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1585, 1586 },
      -1,
   } },

   /* replace531_0 -> 124 in the cache */
   /* replace531_1_0 -> 125 in the cache */
   /* replace531_1_1 -> 127 in the cache */
   /* replace531_1 -> 1598 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 124, 1598 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c') */
   /* search532_0_0 -> 0 in the cache */
   /* search532_0_1 -> 665 in the cache */
   /* search532_0 -> 1590 in the cache */
   /* search532_1_0 -> 1528 in the cache */
   /* search532_1_1 -> 665 in the cache */
   /* search532_1 -> 1591 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1590, 1591 },
      -1,
   } },

   /* replace532_0_0 -> 0 in the cache */
   /* replace532_0_1 -> 1528 in the cache */
   /* replace532_0 -> 1603 in the cache */
   /* replace532_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1603, 665 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c')) */
   /* search533_0_0 -> 124 in the cache */
   /* search533_0_1 -> 125 in the cache */
   /* search533_0 -> 1595 in the cache */
   /* search533_1_0 -> 124 in the cache */
   /* search533_1_1 -> 127 in the cache */
   /* search533_1 -> 1596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1595, 1596 },
      -1,
   } },

   /* replace533_0 -> 124 in the cache */
   /* replace533_1_0 -> 125 in the cache */
   /* replace533_1_1 -> 127 in the cache */
   /* replace533_1 -> 1588 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 124, 1588 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c') */
   /* search534_0_0 -> 0 in the cache */
   /* search534_0_1 -> 665 in the cache */
   /* search534_0 -> 1600 in the cache */
   /* search534_1_0 -> 1528 in the cache */
   /* search534_1_1 -> 665 in the cache */
   /* search534_1 -> 1601 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1600, 1601 },
      -1,
   } },

   /* replace534_0_0 -> 0 in the cache */
   /* replace534_0_1 -> 1528 in the cache */
   /* replace534_0 -> 1593 in the cache */
   /* replace534_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1593, 665 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c')) */
   /* search535_0_0 -> 124 in the cache */
   /* search535_0_1 -> 125 in the cache */
   /* search535_0 -> 1605 in the cache */
   /* search535_1_0 -> 124 in the cache */
   /* search535_1_1 -> 127 in the cache */
   /* search535_1 -> 1606 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1605, 1606 },
      -1,
   } },

   /* replace535_0 -> 124 in the cache */
   /* replace535_1_0 -> 125 in the cache */
   /* replace535_1_1 -> 127 in the cache */
   /* replace535_1 -> 1618 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 124, 1618 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c') */
   /* search536_0_0 -> 0 in the cache */
   /* search536_0_1 -> 665 in the cache */
   /* search536_0 -> 1610 in the cache */
   /* search536_1_0 -> 1528 in the cache */
   /* search536_1_1 -> 665 in the cache */
   /* search536_1 -> 1611 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1610, 1611 },
      -1,
   } },

   /* replace536_0_0 -> 0 in the cache */
   /* replace536_0_1 -> 1528 in the cache */
   /* replace536_0 -> 1623 in the cache */
   /* replace536_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1623, 665 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c')) */
   /* search537_0_0 -> 124 in the cache */
   /* search537_0_1 -> 125 in the cache */
   /* search537_0 -> 1615 in the cache */
   /* search537_1_0 -> 124 in the cache */
   /* search537_1_1 -> 127 in the cache */
   /* search537_1 -> 1616 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1615, 1616 },
      -1,
   } },

   /* replace537_0 -> 124 in the cache */
   /* replace537_1_0 -> 125 in the cache */
   /* replace537_1_1 -> 127 in the cache */
   /* replace537_1 -> 1608 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 124, 1608 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c') */
   /* search538_0_0 -> 0 in the cache */
   /* search538_0_1 -> 665 in the cache */
   /* search538_0 -> 1620 in the cache */
   /* search538_1_0 -> 1528 in the cache */
   /* search538_1_1 -> 665 in the cache */
   /* search538_1 -> 1621 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1620, 1621 },
      -1,
   } },

   /* replace538_0_0 -> 0 in the cache */
   /* replace538_0_1 -> 1528 in the cache */
   /* replace538_0 -> 1613 in the cache */
   /* replace538_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1613, 665 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search539_0_0_0 -> 0 in the cache */
   /* search539_0_0_1 -> 665 in the cache */
   /* search539_0_0 -> 1527 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1527, 1641 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search539_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1643, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1642, 1644 },
      -1,
   } },

   /* replace539_0_0_0 -> 0 in the cache */
   /* replace539_0_0_1 -> 1643 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 1643 },
      -1,
   } },
   /* replace539_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1646, 665 },
      -1,
   } },
   /* replace539_1 -> 1641 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1647, 1641 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search540_0_0_0 -> 0 in the cache */
   /* search540_0_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 665 },
      -1,
   } },
   /* search540_0_1 -> 1641 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1649, 1641 },
      0,
   } },
   /* search540_1_0 -> 1643 in the cache */
   /* search540_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1643, 665 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1650, 1651 },
      -1,
   } },

   /* replace540_0_0_0 -> 0 in the cache */
   /* replace540_0_0_1 -> 1643 in the cache */
   /* replace540_0_0 -> 1646 in the cache */
   /* replace540_0_1 -> 665 in the cache */
   /* replace540_0 -> 1647 in the cache */
   /* replace540_1 -> 1641 in the cache */
   /* replace540 -> 1648 in the cache */

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search541_0_0_0 -> 147 in the cache */
   /* search541_0_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 148 },
      0,
   } },
   /* search541_0_1 -> 1641 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1653, 1641 },
      0,
   } },
   /* search541_1_0 -> 147 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 1655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1654, 1656 },
      -1,
   } },

   /* replace541_0_0 -> 147 in the cache */
   /* replace541_0_1_0 -> 148 in the cache */
   /* replace541_0_1_1 -> 1655 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      true,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 1655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 147, 1658 },
      -1,
   } },
   /* replace541_1 -> 1641 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1659, 1641 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search542_0_0_0 -> 147 in the cache */
   /* search542_0_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 148 },
      -1,
   } },
   /* search542_0_1 -> 1641 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1661, 1641 },
      0,
   } },
   /* search542_1_0 -> 147 in the cache */
   /* search542_1_1 -> 1655 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 1655 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1662, 1663 },
      -1,
   } },

   /* replace542_0_0 -> 147 in the cache */
   /* replace542_0_1_0 -> 148 in the cache */
   /* replace542_0_1_1 -> 1655 in the cache */
   /* replace542_0_1 -> 1658 in the cache */
   /* replace542_0 -> 1659 in the cache */
   /* replace542_1 -> 1641 in the cache */
   /* replace542 -> 1660 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b') */
   /* search543_0_0 -> 989 in the cache */
   /* search543_0_1 -> 990 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 989, 990 },
      -1,
   } },
   /* search543_1_0 -> 3 in the cache */
   /* search543_1_1 -> 0 in the cache */
   /* search543_1 -> 1025 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1665, 1025 },
      -1,
   } },

   /* replace543_0 -> 0 in the cache */
   /* replace543_1 -> 3 in the cache */
   /* replace543 -> 999 in the cache */

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search544_0_0 -> 115 in the cache */
   /* search544_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search544_1_0 -> 243 in the cache */
   /* search544_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 243, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1667, 1668 },
      -1,
   } },

   /* replace544_0 -> 115 in the cache */
   /* replace544_1_0 -> 11 in the cache */
   /* replace544_1_1_0 -> 243 in the cache */
   /* replace544_1_1 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 11, 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1670 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search545_0_0 -> 115 in the cache */
   /* search545_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search545_1_0 -> 243 in the cache */
   /* search545_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 243, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1672, 1673 },
      -1,
   } },

   /* replace545_0 -> 115 in the cache */
   /* replace545_1_0 -> 11 in the cache */
   /* replace545_1_1_0 -> 243 in the cache */
   /* replace545_1_1 -> 515 in the cache */
   /* replace545_1 -> 1670 in the cache */
   /* replace545 -> 1671 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search546_0_0 -> 115 in the cache */
   /* search546_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search546_1_0 -> 243 in the cache */
   /* search546_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 243, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1675, 1676 },
      -1,
   } },

   /* replace546_0 -> 115 in the cache */
   /* replace546_1_0 -> 11 in the cache */
   /* replace546_1_1_0 -> 243 in the cache */
   /* replace546_1_1 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 11, 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1678 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search547_0_0 -> 115 in the cache */
   /* search547_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search547_1_0 -> 243 in the cache */
   /* search547_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 243, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1680, 1681 },
      -1,
   } },

   /* replace547_0 -> 115 in the cache */
   /* replace547_1_0 -> 11 in the cache */
   /* replace547_1_1_0 -> 243 in the cache */
   /* replace547_1_1 -> 515 in the cache */
   /* replace547_1 -> 1678 in the cache */
   /* replace547 -> 1679 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search548_0_0 -> 115 in the cache */
   /* search548_0_1 -> 11 in the cache */
   /* search548_0 -> 1667 in the cache */
   /* search548_1_0 -> 243 in the cache */
   /* search548_1_1 -> 115 in the cache */
   /* search548_1 -> 1668 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1667, 1668 },
      -1,
   } },

   /* replace548_0 -> 115 in the cache */
   /* replace548_1_0 -> 11 in the cache */
   /* replace548_1_1_0 -> 243 in the cache */
   /* replace548_1_1 -> 515 in the cache */
   /* replace548_1 -> 1678 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1678 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search549_0_0 -> 115 in the cache */
   /* search549_0_1 -> 11 in the cache */
   /* search549_0 -> 1672 in the cache */
   /* search549_1_0 -> 243 in the cache */
   /* search549_1_1 -> 115 in the cache */
   /* search549_1 -> 1673 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1672, 1673 },
      -1,
   } },

   /* replace549_0 -> 115 in the cache */
   /* replace549_1_0 -> 11 in the cache */
   /* replace549_1_1_0 -> 243 in the cache */
   /* replace549_1_1 -> 515 in the cache */
   /* replace549_1 -> 1678 in the cache */
   /* replace549 -> 1684 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search550_0_0 -> 115 in the cache */
   /* search550_0_1 -> 11 in the cache */
   /* search550_0 -> 1675 in the cache */
   /* search550_1_0 -> 243 in the cache */
   /* search550_1_1 -> 115 in the cache */
   /* search550_1 -> 1676 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1675, 1676 },
      -1,
   } },

   /* replace550_0 -> 115 in the cache */
   /* replace550_1_0 -> 11 in the cache */
   /* replace550_1_1_0 -> 243 in the cache */
   /* replace550_1_1 -> 515 in the cache */
   /* replace550_1 -> 1670 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1670 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search551_0_0 -> 115 in the cache */
   /* search551_0_1 -> 11 in the cache */
   /* search551_0 -> 1680 in the cache */
   /* search551_1_0 -> 243 in the cache */
   /* search551_1_1 -> 115 in the cache */
   /* search551_1 -> 1681 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1680, 1681 },
      -1,
   } },

   /* replace551_0 -> 115 in the cache */
   /* replace551_1_0 -> 11 in the cache */
   /* replace551_1_1_0 -> 243 in the cache */
   /* replace551_1_1 -> 515 in the cache */
   /* replace551_1 -> 1670 in the cache */
   /* replace551 -> 1687 in the cache */

   /* ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search552_0_0 -> 11 in the cache */
   /* search552_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 115 },
      -1,
   } },
   /* search552_1 -> 462 in the cache */
   /* search552_2_0_0_0_0 -> 115 in the cache */
   /* search552_2_0_0_0_1 -> 11 in the cache */
   /* search552_2_0_0_0 -> 1672 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1672 },
      -1,
   } },
   /* search552_2_0_1_0_0_0 -> 11 in the cache */
   /* search552_2_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1691 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1692 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1690, 1693 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1694 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1689, 462, 1695 },
      -1,
   } },

   /* replace552_0_0_0_0 -> 11 in the cache */
   /* replace552_0_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1697 },
      -1,
   } },
   /* replace552_0_1_0_0_0 -> 11 in the cache */
   /* replace552_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1699 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1700 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1698, 1701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1702 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search553_0 -> 706 in the cache */
   /* search553_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 243 },
      0,
   } },
   /* search553_2_0 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1704, 1705 },
      -1,
   } },

   /* replace553_0_0 -> 706 in the cache */
   /* replace553_0_1 -> 243 in the cache */
   /* replace553_0_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 243, 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1707 },
      -1,
   } },

   /* ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a') */
   /* search554_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1709 },
      -1,
   } },

   /* replace554_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('~f2i16', ('i2f', 'a@16')) => a */
   /* search555_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1712 },
      -1,
   } },

   /* replace555 -> 11 in the cache */

   /* ('~f2i16', ('u2f', 'a@16')) => a */
   /* search556_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1714 },
      -1,
   } },

   /* replace556 -> 11 in the cache */

   /* ('~f2u16', ('i2f', 'a@16')) => a */
   /* search557_0_0 -> 11 in the cache */
   /* search557_0 -> 1712 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1712 },
      -1,
   } },

   /* replace557 -> 11 in the cache */

   /* ('~f2u16', ('u2f', 'a@16')) => a */
   /* search558_0_0 -> 11 in the cache */
   /* search558_0 -> 1714 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1714 },
      -1,
   } },

   /* replace558 -> 11 in the cache */

   /* ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a') */
   /* search559_0_0_0 -> 115 in the cache */
   /* search559_0_0_1 -> 11 in the cache */
   /* search559_0_0 -> 1672 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1672 },
      -1,
   } },
   /* search559_1_0_0_0 -> 11 in the cache */
   /* search559_1_0_0_1 -> 115 in the cache */
   /* search559_1_0_0 -> 1691 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1691 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1718, 1720 },
      -1,
   } },

   /* replace559_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a')) */
   /* search560_0_0_0 -> 804 in the cache */
   /* search560_0_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 804, 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1723 },
      -1,
   } },
   /* search560_1_0_0_0 -> 11 in the cache */
   /* search560_1_0_0_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 804 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1725 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1724, 1727 },
      -1,
   } },

   /* replace560_0_0 -> 11 in the cache */
   /* replace560_0 -> 1722 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1722 },
      -1,
   } },

   /* ('f2f16', ('f2f32', 'a@16')) => a */
   /* search561_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1730 },
      -1,
   } },

   /* replace561 -> 11 in the cache */

   /* ('i2i16', ('i2i32', 'a@16')) => a */
   /* search562_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1732 },
      -1,
   } },

   /* replace562 -> 11 in the cache */

   /* ('u2u16', ('u2u32', 'a@16')) => a */
   /* search563_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1734 },
      -1,
   } },

   /* replace563 -> 11 in the cache */

   /* ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search564_0_0 -> 706 in the cache */
   /* search564_0 -> 1337 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1337 },
      -1,
   } },

   /* replace564_0 -> 706 in the cache */
   /* replace564 -> 1333 in the cache */

   /* ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search565_0_0 -> 706 in the cache */
   /* search565_0 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1325 },
      -1,
   } },

   /* replace565_0 -> 706 in the cache */
   /* replace565 -> 1321 in the cache */

   /* ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search566_0_0 -> 706 in the cache */
   /* search566_0 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1325 },
      -1,
   } },

   /* replace566_0 -> 706 in the cache */
   /* replace566 -> 1321 in the cache */

   /* ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a') */
   /* search567_0_0 -> 11 in the cache */
   /* search567_0 -> 1730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1730 },
      -1,
   } },

   /* replace567_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a') */
   /* search568_0_0 -> 11 in the cache */
   /* search568_0 -> 1730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1730 },
      -1,
   } },

   /* replace568_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a') */
   /* search569_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1743 },
      -1,
   } },

   /* replace569_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a') */
   /* search570_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1746 },
      -1,
   } },

   /* replace570_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a') */
   /* search571_0_0 -> 11 in the cache */
   /* search571_0 -> 1734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 1734 },
      -1,
   } },

   /* replace571_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a') */
   /* search572_0_0 -> 11 in the cache */
   /* search572_0 -> 1732 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1732 },
      -1,
   } },

   /* replace572_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('f2f64', 'a@16')) => a */
   /* search573_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1753 },
      -1,
   } },

   /* replace573 -> 11 in the cache */

   /* ('i2i16', ('i2i64', 'a@16')) => a */
   /* search574_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1755 },
      -1,
   } },

   /* replace574 -> 11 in the cache */

   /* ('u2u16', ('u2u64', 'a@16')) => a */
   /* search575_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1757 },
      -1,
   } },

   /* replace575 -> 11 in the cache */

   /* ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a') */
   /* search576_0_0 -> 706 in the cache */
   /* search576_0 -> 1341 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1341 },
      -1,
   } },

   /* replace576_0 -> 706 in the cache */
   /* replace576 -> 1333 in the cache */

   /* ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search577_0_0 -> 706 in the cache */
   /* search577_0 -> 1329 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1329 },
      -1,
   } },

   /* replace577_0 -> 706 in the cache */
   /* replace577 -> 1321 in the cache */

   /* ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search578_0_0 -> 706 in the cache */
   /* search578_0 -> 1329 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1329 },
      -1,
   } },

   /* replace578_0 -> 706 in the cache */
   /* replace578 -> 1321 in the cache */

   /* ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a') */
   /* search579_0_0 -> 11 in the cache */
   /* search579_0 -> 1753 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1753 },
      -1,
   } },

   /* replace579_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a') */
   /* search580_0_0 -> 11 in the cache */
   /* search580_0 -> 1753 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1753 },
      -1,
   } },

   /* replace580_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a') */
   /* search581_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1766 },
      -1,
   } },

   /* replace581_0 -> 32 in the cache */
   /* replace581 -> 1745 in the cache */

   /* ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a') */
   /* search582_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1768 },
      -1,
   } },

   /* replace582_0 -> 32 in the cache */
   /* replace582 -> 1748 in the cache */

   /* ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a') */
   /* search583_0_0 -> 11 in the cache */
   /* search583_0 -> 1757 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1757 },
      -1,
   } },

   /* replace583_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a') */
   /* search584_0_0 -> 11 in the cache */
   /* search584_0 -> 1755 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1755 },
      -1,
   } },

   /* replace584_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search585_0_0 -> 117 in the cache */
   /* search585_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search585_1_0 -> 36 in the cache */
   /* search585_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1774, 1775 },
      -1,
   } },

   /* replace585_0 -> 117 in the cache */
   /* replace585_1_0 -> 16 in the cache */
   /* replace585_1_1_0 -> 36 in the cache */
   /* replace585_1_1 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 16, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1777 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search586_0_0 -> 117 in the cache */
   /* search586_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search586_1_0 -> 36 in the cache */
   /* search586_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1779, 1780 },
      -1,
   } },

   /* replace586_0 -> 117 in the cache */
   /* replace586_1_0 -> 16 in the cache */
   /* replace586_1_1_0 -> 36 in the cache */
   /* replace586_1_1 -> 581 in the cache */
   /* replace586_1 -> 1777 in the cache */
   /* replace586 -> 1778 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search587_0_0 -> 117 in the cache */
   /* search587_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search587_1_0 -> 36 in the cache */
   /* search587_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1782, 1783 },
      -1,
   } },

   /* replace587_0 -> 117 in the cache */
   /* replace587_1_0 -> 16 in the cache */
   /* replace587_1_1_0 -> 36 in the cache */
   /* replace587_1_1 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 16, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1785 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search588_0_0 -> 117 in the cache */
   /* search588_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search588_1_0 -> 36 in the cache */
   /* search588_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1787, 1788 },
      -1,
   } },

   /* replace588_0 -> 117 in the cache */
   /* replace588_1_0 -> 16 in the cache */
   /* replace588_1_1_0 -> 36 in the cache */
   /* replace588_1_1 -> 581 in the cache */
   /* replace588_1 -> 1785 in the cache */
   /* replace588 -> 1786 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search589_0_0 -> 117 in the cache */
   /* search589_0_1 -> 16 in the cache */
   /* search589_0 -> 1774 in the cache */
   /* search589_1_0 -> 36 in the cache */
   /* search589_1_1 -> 117 in the cache */
   /* search589_1 -> 1775 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1774, 1775 },
      -1,
   } },

   /* replace589_0 -> 117 in the cache */
   /* replace589_1_0 -> 16 in the cache */
   /* replace589_1_1_0 -> 36 in the cache */
   /* replace589_1_1 -> 581 in the cache */
   /* replace589_1 -> 1785 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1785 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search590_0_0 -> 117 in the cache */
   /* search590_0_1 -> 16 in the cache */
   /* search590_0 -> 1779 in the cache */
   /* search590_1_0 -> 36 in the cache */
   /* search590_1_1 -> 117 in the cache */
   /* search590_1 -> 1780 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1779, 1780 },
      -1,
   } },

   /* replace590_0 -> 117 in the cache */
   /* replace590_1_0 -> 16 in the cache */
   /* replace590_1_1_0 -> 36 in the cache */
   /* replace590_1_1 -> 581 in the cache */
   /* replace590_1 -> 1785 in the cache */
   /* replace590 -> 1791 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search591_0_0 -> 117 in the cache */
   /* search591_0_1 -> 16 in the cache */
   /* search591_0 -> 1782 in the cache */
   /* search591_1_0 -> 36 in the cache */
   /* search591_1_1 -> 117 in the cache */
   /* search591_1 -> 1783 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1782, 1783 },
      -1,
   } },

   /* replace591_0 -> 117 in the cache */
   /* replace591_1_0 -> 16 in the cache */
   /* replace591_1_1_0 -> 36 in the cache */
   /* replace591_1_1 -> 581 in the cache */
   /* replace591_1 -> 1777 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1777 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search592_0_0 -> 117 in the cache */
   /* search592_0_1 -> 16 in the cache */
   /* search592_0 -> 1787 in the cache */
   /* search592_1_0 -> 36 in the cache */
   /* search592_1_1 -> 117 in the cache */
   /* search592_1 -> 1788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1787, 1788 },
      -1,
   } },

   /* replace592_0 -> 117 in the cache */
   /* replace592_1_0 -> 16 in the cache */
   /* replace592_1_1_0 -> 36 in the cache */
   /* replace592_1_1 -> 581 in the cache */
   /* replace592_1 -> 1777 in the cache */
   /* replace592 -> 1794 in the cache */

   /* ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search593_0_0 -> 16 in the cache */
   /* search593_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 117 },
      -1,
   } },
   /* search593_1 -> 228 in the cache */
   /* search593_2_0_0_0_0 -> 117 in the cache */
   /* search593_2_0_0_0_1 -> 16 in the cache */
   /* search593_2_0_0_0 -> 1779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1779 },
      -1,
   } },
   /* search593_2_0_1_0_0_0 -> 16 in the cache */
   /* search593_2_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1798 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1799 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1797, 1800 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1801 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1796, 228, 1802 },
      -1,
   } },

   /* replace593_0_0_0_0 -> 16 in the cache */
   /* replace593_0_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1804 },
      -1,
   } },
   /* replace593_0_1_0_0_0 -> 16 in the cache */
   /* replace593_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1806 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1805, 1808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1809 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search594_0 -> 706 in the cache */
   /* search594_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 36 },
      0,
   } },
   /* search594_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1811, 1812 },
      -1,
   } },

   /* replace594_0_0 -> 706 in the cache */
   /* replace594_0_1 -> 36 in the cache */
   /* replace594_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1814 },
      -1,
   } },

   /* ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a') */
   /* search595_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1816 },
      -1,
   } },

   /* replace595_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~f2i32', ('i2f', 'a@32')) => a */
   /* search596_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1819 },
      -1,
   } },

   /* replace596 -> 16 in the cache */

   /* ('~f2i32', ('u2f', 'a@32')) => a */
   /* search597_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1821 },
      -1,
   } },

   /* replace597 -> 16 in the cache */

   /* ('~f2u32', ('i2f', 'a@32')) => a */
   /* search598_0_0 -> 16 in the cache */
   /* search598_0 -> 1819 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1819 },
      -1,
   } },

   /* replace598 -> 16 in the cache */

   /* ('~f2u32', ('u2f', 'a@32')) => a */
   /* search599_0_0 -> 16 in the cache */
   /* search599_0 -> 1821 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1821 },
      -1,
   } },

   /* replace599 -> 16 in the cache */

   /* ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a') */
   /* search600_0_0_0 -> 117 in the cache */
   /* search600_0_0_1 -> 16 in the cache */
   /* search600_0_0 -> 1779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1779 },
      -1,
   } },
   /* search600_1_0_0_0 -> 16 in the cache */
   /* search600_1_0_0_1 -> 117 in the cache */
   /* search600_1_0_0 -> 1798 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1798 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1826 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1825, 1827 },
      -1,
   } },

   /* replace600_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a')) */
   /* search601_0_0_0 -> 120 in the cache */
   /* search601_0_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1830 },
      -1,
   } },
   /* search601_1_0_0_0 -> 16 in the cache */
   /* search601_1_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1833 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1831, 1834 },
      -1,
   } },

   /* replace601_0_0 -> 16 in the cache */
   /* replace601_0 -> 1829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1829 },
      -1,
   } },

   /* ('f2f32', ('f2f64', 'a@32')) => a */
   /* search602_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1837 },
      -1,
   } },

   /* replace602 -> 16 in the cache */

   /* ('i2i32', ('i2i64', 'a@32')) => a */
   /* search603_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1839 },
      -1,
   } },

   /* replace603 -> 16 in the cache */

   /* ('u2u32', ('u2u64', 'a@32')) => a */
   /* search604_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1841 },
      -1,
   } },

   /* replace604 -> 16 in the cache */

   /* ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a') */
   /* search605_0_0 -> 706 in the cache */
   /* search605_0 -> 1341 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1341 },
      -1,
   } },

   /* replace605_0 -> 706 in the cache */
   /* replace605 -> 1337 in the cache */

   /* ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search606_0_0 -> 706 in the cache */
   /* search606_0 -> 1329 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1329 },
      -1,
   } },

   /* replace606_0 -> 706 in the cache */
   /* replace606 -> 1325 in the cache */

   /* ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search607_0_0 -> 706 in the cache */
   /* search607_0 -> 1329 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1329 },
      -1,
   } },

   /* replace607_0 -> 706 in the cache */
   /* replace607 -> 1325 in the cache */

   /* ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a') */
   /* search608_0_0 -> 16 in the cache */
   /* search608_0 -> 1837 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1837 },
      -1,
   } },

   /* replace608_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a') */
   /* search609_0_0 -> 16 in the cache */
   /* search609_0 -> 1837 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1837 },
      -1,
   } },

   /* replace609_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a') */
   /* search610_0_0 -> 32 in the cache */
   /* search610_0 -> 1766 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1766 },
      -1,
   } },

   /* replace610_0 -> 32 in the cache */
   /* replace610 -> 1743 in the cache */

   /* ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a') */
   /* search611_0_0 -> 32 in the cache */
   /* search611_0 -> 1768 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1768 },
      -1,
   } },

   /* replace611_0 -> 32 in the cache */
   /* replace611 -> 1746 in the cache */

   /* ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a') */
   /* search612_0_0 -> 16 in the cache */
   /* search612_0 -> 1841 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1841 },
      -1,
   } },

   /* replace612_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a') */
   /* search613_0_0 -> 16 in the cache */
   /* search613_0 -> 1839 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1839 },
      -1,
   } },

   /* replace613_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search614_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1856, 21 },
      0,
   } },
   /* search614_1_0 -> 41 in the cache */
   /* search614_1_1 -> 1856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 1856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1857, 1858 },
      -1,
   } },

   /* replace614_0 -> 1856 in the cache */
   /* replace614_1_0 -> 21 in the cache */
   /* replace614_1_1_0 -> 41 in the cache */
   /* replace614_1_1 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 21, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1856, 1860 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search615_0_0 -> 1856 in the cache */
   /* search615_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1856, 21 },
      -1,
   } },
   /* search615_1_0 -> 41 in the cache */
   /* search615_1_1 -> 1856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 1856 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1862, 1863 },
      -1,
   } },

   /* replace615_0 -> 1856 in the cache */
   /* replace615_1_0 -> 21 in the cache */
   /* replace615_1_1_0 -> 41 in the cache */
   /* replace615_1_1 -> 654 in the cache */
   /* replace615_1 -> 1860 in the cache */
   /* replace615 -> 1861 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search616_0_0 -> 1856 in the cache */
   /* search616_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1856, 21 },
      0,
   } },
   /* search616_1_0 -> 41 in the cache */
   /* search616_1_1 -> 1856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 1856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1865, 1866 },
      -1,
   } },

   /* replace616_0 -> 1856 in the cache */
   /* replace616_1_0 -> 21 in the cache */
   /* replace616_1_1_0 -> 41 in the cache */
   /* replace616_1_1 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 21, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1856, 1868 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search617_0_0 -> 1856 in the cache */
   /* search617_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1856, 21 },
      -1,
   } },
   /* search617_1_0 -> 41 in the cache */
   /* search617_1_1 -> 1856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 1856 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1870, 1871 },
      -1,
   } },

   /* replace617_0 -> 1856 in the cache */
   /* replace617_1_0 -> 21 in the cache */
   /* replace617_1_1_0 -> 41 in the cache */
   /* replace617_1_1 -> 654 in the cache */
   /* replace617_1 -> 1868 in the cache */
   /* replace617 -> 1869 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search618_0_0 -> 1856 in the cache */
   /* search618_0_1 -> 21 in the cache */
   /* search618_0 -> 1857 in the cache */
   /* search618_1_0 -> 41 in the cache */
   /* search618_1_1 -> 1856 in the cache */
   /* search618_1 -> 1858 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1857, 1858 },
      -1,
   } },

   /* replace618_0 -> 1856 in the cache */
   /* replace618_1_0 -> 21 in the cache */
   /* replace618_1_1_0 -> 41 in the cache */
   /* replace618_1_1 -> 654 in the cache */
   /* replace618_1 -> 1868 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1856, 1868 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search619_0_0 -> 1856 in the cache */
   /* search619_0_1 -> 21 in the cache */
   /* search619_0 -> 1862 in the cache */
   /* search619_1_0 -> 41 in the cache */
   /* search619_1_1 -> 1856 in the cache */
   /* search619_1 -> 1863 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1862, 1863 },
      -1,
   } },

   /* replace619_0 -> 1856 in the cache */
   /* replace619_1_0 -> 21 in the cache */
   /* replace619_1_1_0 -> 41 in the cache */
   /* replace619_1_1 -> 654 in the cache */
   /* replace619_1 -> 1868 in the cache */
   /* replace619 -> 1874 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search620_0_0 -> 1856 in the cache */
   /* search620_0_1 -> 21 in the cache */
   /* search620_0 -> 1865 in the cache */
   /* search620_1_0 -> 41 in the cache */
   /* search620_1_1 -> 1856 in the cache */
   /* search620_1 -> 1866 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1865, 1866 },
      -1,
   } },

   /* replace620_0 -> 1856 in the cache */
   /* replace620_1_0 -> 21 in the cache */
   /* replace620_1_1_0 -> 41 in the cache */
   /* replace620_1_1 -> 654 in the cache */
   /* replace620_1 -> 1860 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1856, 1860 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search621_0_0 -> 1856 in the cache */
   /* search621_0_1 -> 21 in the cache */
   /* search621_0 -> 1870 in the cache */
   /* search621_1_0 -> 41 in the cache */
   /* search621_1_1 -> 1856 in the cache */
   /* search621_1 -> 1871 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1870, 1871 },
      -1,
   } },

   /* replace621_0 -> 1856 in the cache */
   /* replace621_1_0 -> 21 in the cache */
   /* replace621_1_1_0 -> 41 in the cache */
   /* replace621_1_1 -> 654 in the cache */
   /* replace621_1 -> 1860 in the cache */
   /* replace621 -> 1877 in the cache */

   /* ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search622_0_0 -> 21 in the cache */
   /* search622_0_1 -> 1856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 21, 1856 },
      -1,
   } },
   /* search622_1 -> 603 in the cache */
   /* search622_2_0_0_0_0 -> 1856 in the cache */
   /* search622_2_0_0_0_1 -> 21 in the cache */
   /* search622_2_0_0_0 -> 1862 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1862 },
      -1,
   } },
   /* search622_2_0_1_0_0_0 -> 21 in the cache */
   /* search622_2_0_1_0_0_1 -> 1856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 1856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1881 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1882 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1880, 1883 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1884 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1879, 603, 1885 },
      -1,
   } },

   /* replace622_0_0_0_0 -> 21 in the cache */
   /* replace622_0_0_0_1 -> 1856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 21, 1856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1887 },
      -1,
   } },
   /* replace622_0_1_0_0_0 -> 21 in the cache */
   /* replace622_0_1_0_0_1 -> 1856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 1856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1888, 1891 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1892 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search623_0 -> 706 in the cache */
   /* search623_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 41 },
      0,
   } },
   /* search623_2_0 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1894, 1895 },
      -1,
   } },

   /* replace623_0_0 -> 706 in the cache */
   /* replace623_0_1 -> 41 in the cache */
   /* replace623_0_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 41, 591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1897 },
      -1,
   } },

   /* ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a') */
   /* search624_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1899 },
      -1,
   } },

   /* replace624_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('~f2i64', ('i2f', 'a@64')) => a */
   /* search625_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1902 },
      -1,
   } },

   /* replace625 -> 21 in the cache */

   /* ('~f2i64', ('u2f', 'a@64')) => a */
   /* search626_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1904 },
      -1,
   } },

   /* replace626 -> 21 in the cache */

   /* ('~f2u64', ('i2f', 'a@64')) => a */
   /* search627_0_0 -> 21 in the cache */
   /* search627_0 -> 1902 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1902 },
      -1,
   } },

   /* replace627 -> 21 in the cache */

   /* ('~f2u64', ('u2f', 'a@64')) => a */
   /* search628_0_0 -> 21 in the cache */
   /* search628_0 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1904 },
      -1,
   } },

   /* replace628 -> 21 in the cache */

   /* ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a') */
   /* search629_0_0_0 -> 1856 in the cache */
   /* search629_0_0_1 -> 21 in the cache */
   /* search629_0_0 -> 1862 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1862 },
      -1,
   } },
   /* search629_1_0_0_0 -> 21 in the cache */
   /* search629_1_0_0_1 -> 1856 in the cache */
   /* search629_1_0_0 -> 1881 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1881 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1909 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1908, 1910 },
      -1,
   } },

   /* replace629_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a')) */
   /* search630_0_0_0 -> 847 in the cache */
   /* search630_0_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 847, 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1913 },
      -1,
   } },
   /* search630_1_0_0_0 -> 21 in the cache */
   /* search630_1_0_0_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1915 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1916 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1914, 1917 },
      -1,
   } },

   /* replace630_0_0 -> 21 in the cache */
   /* replace630_0 -> 1912 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1912 },
      -1,
   } },

   /* ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a') */
   /* search631_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1920 },
      -1,
   } },

   /* replace631_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a') */
   /* search632_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1923 },
      -1,
   } },

   /* replace632_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a') */
   /* search633_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1926 },
      -1,
   } },

   /* replace633_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a') */
   /* search634_0_0 -> 16 in the cache */
   /* search634_0 -> 1926 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1926 },
      -1,
   } },

   /* replace634_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a') */
   /* search635_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1931 },
      -1,
   } },

   /* replace635_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a') */
   /* search636_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1934 },
      -1,
   } },

   /* replace636_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a') */
   /* search637_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 1937 },
      -1,
   } },

   /* replace637_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a') */
   /* search638_0_0 -> 16 in the cache */
   /* search638_0 -> 1937 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1937 },
      -1,
   } },

   /* replace638_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255)) */
   /* search639_0_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1942 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1943, 1944 },
      -1,
   } },

   /* replace639_0 -> 11 in the cache */
   /* replace639_1_0 -> 243 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 243, 1946 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 11, 1947 },
      -1,
   } },

   /* ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255)) */
   /* search640_0_0_0 -> 11 in the cache */
   /* search640_0_0_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1944 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1949 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 1,
      { 1950 },
      -1,
   } },

   /* replace640_0 -> 11 in the cache */
   /* replace640_1_0 -> 243 in the cache */
   /* replace640_1_1 -> 1946 in the cache */
   /* replace640_1 -> 1947 in the cache */
   /* replace640 -> 1948 in the cache */

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search641_0_0_0_0 -> 11 in the cache */
   /* search641_0_0_0 -> 1942 in the cache */
   /* search641_0_0 -> 1943 in the cache */
   /* search641_0_1_0_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1943, 1953 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1954 },
      -1,
   } },

   /* replace641_0_0 -> 11 in the cache */
   /* replace641_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1956 },
      -1,
   } },

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search642_0_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1958 },
      -1,
   } },
   /* search642_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1959, 1961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1962 },
      -1,
   } },

   /* replace642_0_0 -> 16 in the cache */
   /* replace642_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1964 },
      -1,
   } },

   /* ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b') */
   /* search643_0_0 -> 0 in the cache */
   /* search643_0_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 767 },
      -1,
   } },
   /* search643_1_0 -> 138 in the cache */
   /* search643_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1966, 1967 },
      -1,
   } },

   /* replace643_0_0 -> 0 in the cache */
   /* replace643_0_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 138 },
      -1,
   } },
   /* replace643_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 1969, 3 },
      -1,
   } },

   /* ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b') */
   /* search644_0_0 -> 0 in the cache */
   /* search644_0_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 767 },
      -1,
   } },
   /* search644_1_0 -> 138 in the cache */
   /* search644_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1971, 1972 },
      -1,
   } },

   /* replace644_0_0 -> 0 in the cache */
   /* replace644_0_1 -> 138 in the cache */
   /* replace644_0 -> 1969 in the cache */
   /* replace644_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 1969, 3 },
      -1,
   } },

   /* ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b') */
   /* search645_0_0 -> 0 in the cache */
   /* search645_0_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 767 },
      -1,
   } },
   /* search645_1_0 -> 138 in the cache */
   /* search645_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1975, 1976 },
      -1,
   } },

   /* replace645_0_0 -> 0 in the cache */
   /* replace645_0_1 -> 138 in the cache */
   /* replace645_0 -> 1969 in the cache */
   /* replace645_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 1969, 3 },
      -1,
   } },

   /* ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b') */
   /* search646_0_0 -> 0 in the cache */
   /* search646_0_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 767 },
      -1,
   } },
   /* search646_1_0 -> 138 in the cache */
   /* search646_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1979, 1980 },
      -1,
   } },

   /* replace646_0_0 -> 0 in the cache */
   /* replace646_0_1 -> 138 in the cache */
   /* replace646_0 -> 1969 in the cache */
   /* replace646_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 1969, 3 },
      -1,
   } },

   /* ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b') */
   /* search647_0_0 -> 124 in the cache */
   /* search647_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search647_1_0 -> 127 in the cache */
   /* search647_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1983, 1984 },
      -1,
   } },

   /* replace647_0_0 -> 124 in the cache */
   /* replace647_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace647_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 1986, 36 },
      -1,
   } },

   /* ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b') */
   /* search648_0_0 -> 124 in the cache */
   /* search648_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search648_1_0 -> 127 in the cache */
   /* search648_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1988, 1989 },
      -1,
   } },

   /* replace648_0_0 -> 124 in the cache */
   /* replace648_0_1 -> 127 in the cache */
   /* replace648_0 -> 1986 in the cache */
   /* replace648_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 1986, 36 },
      -1,
   } },

   /* ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b') */
   /* search649_0_0 -> 124 in the cache */
   /* search649_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search649_1_0 -> 127 in the cache */
   /* search649_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1992, 1993 },
      -1,
   } },

   /* replace649_0_0 -> 124 in the cache */
   /* replace649_0_1 -> 127 in the cache */
   /* replace649_0 -> 1986 in the cache */
   /* replace649_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1986, 36 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search650_0_0_0_0 -> 11 in the cache */
   /* search650_0_0_0 -> 1942 in the cache */
   /* search650_0_0 -> 1943 in the cache */
   /* search650_0_1_0_0 -> 243 in the cache */
   /* search650_0_1_0 -> 1952 in the cache */
   /* search650_0_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1943, 1953 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1996 },
      -1,
   } },

   /* replace650_0_0 -> 11 in the cache */
   /* replace650_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1998 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search651_0_0_0_0 -> 16 in the cache */
   /* search651_0_0_0 -> 1958 in the cache */
   /* search651_0_0 -> 1959 in the cache */
   /* search651_0_1_0_0 -> 36 in the cache */
   /* search651_0_1_0 -> 1960 in the cache */
   /* search651_0_1 -> 1961 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1959, 1961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2000 },
      -1,
   } },

   /* replace651_0_0 -> 16 in the cache */
   /* replace651_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2002 },
      -1,
   } },

   /* ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b') */
   /* search652_0_0 -> 0 in the cache */
   /* search652_0_1 -> 767 in the cache */
   /* search652_0 -> 1966 in the cache */
   /* search652_1_0 -> 138 in the cache */
   /* search652_1_1 -> 3 in the cache */
   /* search652_1 -> 1967 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1966, 1967 },
      -1,
   } },

   /* replace652_0_0 -> 0 in the cache */
   /* replace652_0_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 138 },
      -1,
   } },
   /* replace652_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2005, 3 },
      -1,
   } },

   /* ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b') */
   /* search653_0_0 -> 0 in the cache */
   /* search653_0_1 -> 767 in the cache */
   /* search653_0 -> 1971 in the cache */
   /* search653_1_0 -> 138 in the cache */
   /* search653_1_1 -> 3 in the cache */
   /* search653_1 -> 1972 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1971, 1972 },
      -1,
   } },

   /* replace653_0_0 -> 0 in the cache */
   /* replace653_0_1 -> 138 in the cache */
   /* replace653_0 -> 2005 in the cache */
   /* replace653_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2005, 3 },
      -1,
   } },

   /* ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b') */
   /* search654_0_0 -> 0 in the cache */
   /* search654_0_1 -> 767 in the cache */
   /* search654_0 -> 1975 in the cache */
   /* search654_1_0 -> 138 in the cache */
   /* search654_1_1 -> 3 in the cache */
   /* search654_1 -> 1976 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1975, 1976 },
      -1,
   } },

   /* replace654_0_0 -> 0 in the cache */
   /* replace654_0_1 -> 138 in the cache */
   /* replace654_0 -> 2005 in the cache */
   /* replace654_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2005, 3 },
      -1,
   } },

   /* ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b') */
   /* search655_0_0 -> 0 in the cache */
   /* search655_0_1 -> 767 in the cache */
   /* search655_0 -> 1979 in the cache */
   /* search655_1_0 -> 138 in the cache */
   /* search655_1_1 -> 3 in the cache */
   /* search655_1 -> 1980 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1979, 1980 },
      -1,
   } },

   /* replace655_0_0 -> 0 in the cache */
   /* replace655_0_1 -> 138 in the cache */
   /* replace655_0 -> 2005 in the cache */
   /* replace655_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2005, 3 },
      -1,
   } },

   /* ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b') */
   /* search656_0_0 -> 124 in the cache */
   /* search656_0_1 -> 33 in the cache */
   /* search656_0 -> 1983 in the cache */
   /* search656_1_0 -> 127 in the cache */
   /* search656_1_1 -> 36 in the cache */
   /* search656_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1983, 1984 },
      -1,
   } },

   /* replace656_0_0 -> 124 in the cache */
   /* replace656_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace656_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2014, 36 },
      -1,
   } },

   /* ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b') */
   /* search657_0_0 -> 124 in the cache */
   /* search657_0_1 -> 33 in the cache */
   /* search657_0 -> 1988 in the cache */
   /* search657_1_0 -> 127 in the cache */
   /* search657_1_1 -> 36 in the cache */
   /* search657_1 -> 1989 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1988, 1989 },
      -1,
   } },

   /* replace657_0_0 -> 124 in the cache */
   /* replace657_0_1 -> 127 in the cache */
   /* replace657_0 -> 2014 in the cache */
   /* replace657_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2014, 36 },
      -1,
   } },

   /* ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b') */
   /* search658_0_0 -> 124 in the cache */
   /* search658_0_1 -> 33 in the cache */
   /* search658_0 -> 1992 in the cache */
   /* search658_1_0 -> 127 in the cache */
   /* search658_1_1 -> 36 in the cache */
   /* search658_1 -> 1993 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1992, 1993 },
      -1,
   } },

   /* replace658_0_0 -> 124 in the cache */
   /* replace658_0_1 -> 127 in the cache */
   /* replace658_0 -> 2014 in the cache */
   /* replace658_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2014, 36 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search659_0_0_0_0 -> 11 in the cache */
   /* search659_0_0_0 -> 1942 in the cache */
   /* search659_0_0 -> 1943 in the cache */
   /* search659_0_1_0_0 -> 243 in the cache */
   /* search659_0_1_0 -> 1952 in the cache */
   /* search659_0_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1943, 1953 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2020 },
      -1,
   } },

   /* replace659_0_0 -> 11 in the cache */
   /* replace659_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2022 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search660_0_0_0_0 -> 16 in the cache */
   /* search660_0_0_0 -> 1958 in the cache */
   /* search660_0_0 -> 1959 in the cache */
   /* search660_0_1_0_0 -> 36 in the cache */
   /* search660_0_1_0 -> 1960 in the cache */
   /* search660_0_1 -> 1961 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1959, 1961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2024 },
      -1,
   } },

   /* replace660_0_0 -> 16 in the cache */
   /* replace660_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2026 },
      -1,
   } },

   /* ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b') */
   /* search661_0_0 -> 0 in the cache */
   /* search661_0_1 -> 767 in the cache */
   /* search661_0 -> 1966 in the cache */
   /* search661_1_0 -> 138 in the cache */
   /* search661_1_1 -> 3 in the cache */
   /* search661_1 -> 1967 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1966, 1967 },
      -1,
   } },

   /* replace661_0_0 -> 0 in the cache */
   /* replace661_0_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 0, 138 },
      -1,
   } },
   /* replace661_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2029, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b') */
   /* search662_0_0 -> 0 in the cache */
   /* search662_0_1 -> 767 in the cache */
   /* search662_0 -> 1971 in the cache */
   /* search662_1_0 -> 138 in the cache */
   /* search662_1_1 -> 3 in the cache */
   /* search662_1 -> 1972 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1971, 1972 },
      -1,
   } },

   /* replace662_0_0 -> 0 in the cache */
   /* replace662_0_1 -> 138 in the cache */
   /* replace662_0 -> 2029 in the cache */
   /* replace662_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2029, 3 },
      -1,
   } },

   /* ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b') */
   /* search663_0_0 -> 0 in the cache */
   /* search663_0_1 -> 767 in the cache */
   /* search663_0 -> 1975 in the cache */
   /* search663_1_0 -> 138 in the cache */
   /* search663_1_1 -> 3 in the cache */
   /* search663_1 -> 1976 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1975, 1976 },
      -1,
   } },

   /* replace663_0_0 -> 0 in the cache */
   /* replace663_0_1 -> 138 in the cache */
   /* replace663_0 -> 2029 in the cache */
   /* replace663_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2029, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b') */
   /* search664_0_0 -> 0 in the cache */
   /* search664_0_1 -> 767 in the cache */
   /* search664_0 -> 1979 in the cache */
   /* search664_1_0 -> 138 in the cache */
   /* search664_1_1 -> 3 in the cache */
   /* search664_1 -> 1980 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1979, 1980 },
      -1,
   } },

   /* replace664_0_0 -> 0 in the cache */
   /* replace664_0_1 -> 138 in the cache */
   /* replace664_0 -> 2029 in the cache */
   /* replace664_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2029, 3 },
      -1,
   } },

   /* ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b') */
   /* search665_0_0 -> 124 in the cache */
   /* search665_0_1 -> 33 in the cache */
   /* search665_0 -> 1983 in the cache */
   /* search665_1_0 -> 127 in the cache */
   /* search665_1_1 -> 36 in the cache */
   /* search665_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1983, 1984 },
      -1,
   } },

   /* replace665_0_0 -> 124 in the cache */
   /* replace665_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace665_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2038, 36 },
      -1,
   } },

   /* ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b') */
   /* search666_0_0 -> 124 in the cache */
   /* search666_0_1 -> 33 in the cache */
   /* search666_0 -> 1988 in the cache */
   /* search666_1_0 -> 127 in the cache */
   /* search666_1_1 -> 36 in the cache */
   /* search666_1 -> 1989 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1988, 1989 },
      -1,
   } },

   /* replace666_0_0 -> 124 in the cache */
   /* replace666_0_1 -> 127 in the cache */
   /* replace666_0 -> 2038 in the cache */
   /* replace666_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2038, 36 },
      -1,
   } },

   /* ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b') */
   /* search667_0_0 -> 124 in the cache */
   /* search667_0_1 -> 33 in the cache */
   /* search667_0 -> 1992 in the cache */
   /* search667_1_0 -> 127 in the cache */
   /* search667_1_1 -> 36 in the cache */
   /* search667_1 -> 1993 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1992, 1993 },
      -1,
   } },

   /* replace667_0_0 -> 124 in the cache */
   /* replace667_0_1 -> 127 in the cache */
   /* replace667_0 -> 2038 in the cache */
   /* replace667_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2038, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search668_0_0 -> 6 in the cache */
   /* search668_0_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 782 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search668_1_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2045, 782 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2044, 2046 },
      -1,
   } },

   /* replace668_0_0 -> 6 in the cache */
   /* replace668_0_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 6, 2045 },
      -1,
   } },
   /* replace668_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2048, 782 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search669_0_0 -> 6 in the cache */
   /* search669_0_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 782 },
      -1,
   } },
   /* search669_1_0 -> 2045 in the cache */
   /* search669_1_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2045, 782 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2050, 2051 },
      -1,
   } },

   /* replace669_0_0 -> 6 in the cache */
   /* replace669_0_1 -> 2045 in the cache */
   /* replace669_0 -> 2048 in the cache */
   /* replace669_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2048, 782 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search670_0_0 -> 6 in the cache */
   /* search670_0_1 -> 782 in the cache */
   /* search670_0 -> 2044 in the cache */
   /* search670_1_0 -> 2045 in the cache */
   /* search670_1_1 -> 782 in the cache */
   /* search670_1 -> 2046 in the cache */
   /* search670 -> 2047 in the cache */

   /* replace670_0_0 -> 6 in the cache */
   /* replace670_0_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 6, 2045 },
      -1,
   } },
   /* replace670_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2054, 782 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search671_0_0 -> 6 in the cache */
   /* search671_0_1 -> 782 in the cache */
   /* search671_0 -> 2044 in the cache */
   /* search671_1_0 -> 2045 in the cache */
   /* search671_1_1 -> 782 in the cache */
   /* search671_1 -> 2046 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2044, 2046 },
      -1,
   } },

   /* replace671_0_0 -> 6 in the cache */
   /* replace671_0_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 6, 2045 },
      -1,
   } },
   /* replace671_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2057, 782 },
      -1,
   } },

   /* ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search672_0_0 -> 6 in the cache */
   /* search672_0_1 -> 782 in the cache */
   /* search672_0 -> 2050 in the cache */
   /* search672_1_0 -> 2045 in the cache */
   /* search672_1_1 -> 782 in the cache */
   /* search672_1 -> 2051 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2050, 2051 },
      -1,
   } },

   /* replace672_0_0 -> 6 in the cache */
   /* replace672_0_1 -> 2045 in the cache */
   /* replace672_0 -> 2057 in the cache */
   /* replace672_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2057, 782 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search673_0_0 -> 6 in the cache */
   /* search673_0_1 -> 782 in the cache */
   /* search673_0 -> 2050 in the cache */
   /* search673_1_0 -> 2045 in the cache */
   /* search673_1_1 -> 782 in the cache */
   /* search673_1 -> 2051 in the cache */
   /* search673 -> 2052 in the cache */

   /* replace673_0_0 -> 6 in the cache */
   /* replace673_0_1 -> 2045 in the cache */
   /* replace673_0 -> 2054 in the cache */
   /* replace673_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2054, 782 },
      -1,
   } },

   /* ('ineg', ('b2i8', 'a@8')) => a */
   /* search674_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2062 },
      -1,
   } },

   /* replace674 -> 6 in the cache */

   /* ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b') */
   /* search675_0 -> 6 in the cache */
   /* search675_1_0 -> 9 in the cache */
   /* search675_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 2064 },
      -1,
   } },

   /* replace675_0 -> 6 in the cache */
   /* replace675_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b') */
   /* search676_0 -> 6 in the cache */
   /* search676_1_0 -> 9 in the cache */
   /* search676_1_1 -> 36 in the cache */
   /* search676_1 -> 2064 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 6, 2064 },
      -1,
   } },

   /* replace676_0 -> 6 in the cache */
   /* replace676_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b') */
   /* search677_0 -> 6 in the cache */
   /* search677_1_0 -> 9 in the cache */
   /* search677_1_1 -> 36 in the cache */
   /* search677_1 -> 2064 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 2064 },
      -1,
   } },

   /* replace677_0 -> 6 in the cache */
   /* replace677_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search678_0_0 -> 11 in the cache */
   /* search678_0_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 804 },
      -1,
   } },
   /* search678_1_0 -> 243 in the cache */
   /* search678_1_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 243, 804 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2071, 2072 },
      -1,
   } },

   /* replace678_0_0 -> 11 in the cache */
   /* replace678_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace678_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2074, 804 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search679_0_0 -> 11 in the cache */
   /* search679_0_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 804 },
      -1,
   } },
   /* search679_1_0 -> 243 in the cache */
   /* search679_1_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 243, 804 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2076, 2077 },
      -1,
   } },

   /* replace679_0_0 -> 11 in the cache */
   /* replace679_0_1 -> 243 in the cache */
   /* replace679_0 -> 2074 in the cache */
   /* replace679_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2074, 804 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search680_0_0 -> 11 in the cache */
   /* search680_0_1 -> 804 in the cache */
   /* search680_0 -> 2071 in the cache */
   /* search680_1_0 -> 243 in the cache */
   /* search680_1_1 -> 804 in the cache */
   /* search680_1 -> 2072 in the cache */
   /* search680 -> 2073 in the cache */

   /* replace680_0_0 -> 11 in the cache */
   /* replace680_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace680_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2080, 804 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search681_0_0 -> 11 in the cache */
   /* search681_0_1 -> 804 in the cache */
   /* search681_0 -> 2071 in the cache */
   /* search681_1_0 -> 243 in the cache */
   /* search681_1_1 -> 804 in the cache */
   /* search681_1 -> 2072 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2071, 2072 },
      -1,
   } },

   /* replace681_0_0 -> 11 in the cache */
   /* replace681_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace681_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2083, 804 },
      -1,
   } },

   /* ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search682_0_0 -> 11 in the cache */
   /* search682_0_1 -> 804 in the cache */
   /* search682_0 -> 2076 in the cache */
   /* search682_1_0 -> 243 in the cache */
   /* search682_1_1 -> 804 in the cache */
   /* search682_1 -> 2077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2076, 2077 },
      -1,
   } },

   /* replace682_0_0 -> 11 in the cache */
   /* replace682_0_1 -> 243 in the cache */
   /* replace682_0 -> 2083 in the cache */
   /* replace682_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2083, 804 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search683_0_0 -> 11 in the cache */
   /* search683_0_1 -> 804 in the cache */
   /* search683_0 -> 2076 in the cache */
   /* search683_1_0 -> 243 in the cache */
   /* search683_1_1 -> 804 in the cache */
   /* search683_1 -> 2077 in the cache */
   /* search683 -> 2078 in the cache */

   /* replace683_0_0 -> 11 in the cache */
   /* replace683_0_1 -> 243 in the cache */
   /* replace683_0 -> 2080 in the cache */
   /* replace683_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2080, 804 },
      -1,
   } },

   /* ('ineg', ('b2i16', 'a@16')) => a */
   /* search684_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2088 },
      -1,
   } },

   /* replace684 -> 11 in the cache */

   /* ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b') */
   /* search685_0 -> 11 in the cache */
   /* search685_1_0 -> 14 in the cache */
   /* search685_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 14, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2090 },
      -1,
   } },

   /* replace685_0 -> 11 in the cache */
   /* replace685_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b') */
   /* search686_0 -> 11 in the cache */
   /* search686_1_0 -> 14 in the cache */
   /* search686_1_1 -> 36 in the cache */
   /* search686_1 -> 2090 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 11, 2090 },
      -1,
   } },

   /* replace686_0 -> 11 in the cache */
   /* replace686_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b') */
   /* search687_0 -> 11 in the cache */
   /* search687_1_0 -> 14 in the cache */
   /* search687_1_1 -> 36 in the cache */
   /* search687_1 -> 2090 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2090 },
      -1,
   } },

   /* replace687_0 -> 11 in the cache */
   /* replace687_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search688_0_0 -> 16 in the cache */
   /* search688_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 120 },
      -1,
   } },
   /* search688_1_0 -> 36 in the cache */
   /* search688_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2097, 2098 },
      -1,
   } },

   /* replace688_0_0 -> 16 in the cache */
   /* replace688_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace688_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2100, 120 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search689_0_0 -> 16 in the cache */
   /* search689_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 120 },
      -1,
   } },
   /* search689_1_0 -> 36 in the cache */
   /* search689_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2102, 2103 },
      -1,
   } },

   /* replace689_0_0 -> 16 in the cache */
   /* replace689_0_1 -> 36 in the cache */
   /* replace689_0 -> 2100 in the cache */
   /* replace689_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2100, 120 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search690_0_0 -> 16 in the cache */
   /* search690_0_1 -> 120 in the cache */
   /* search690_0 -> 2097 in the cache */
   /* search690_1_0 -> 36 in the cache */
   /* search690_1_1 -> 120 in the cache */
   /* search690_1 -> 2098 in the cache */
   /* search690 -> 2099 in the cache */

   /* replace690_0_0 -> 16 in the cache */
   /* replace690_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace690_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2106, 120 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search691_0_0 -> 16 in the cache */
   /* search691_0_1 -> 120 in the cache */
   /* search691_0 -> 2097 in the cache */
   /* search691_1_0 -> 36 in the cache */
   /* search691_1_1 -> 120 in the cache */
   /* search691_1 -> 2098 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2097, 2098 },
      -1,
   } },

   /* replace691_0_0 -> 16 in the cache */
   /* replace691_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace691_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2109, 120 },
      -1,
   } },

   /* ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search692_0_0 -> 16 in the cache */
   /* search692_0_1 -> 120 in the cache */
   /* search692_0 -> 2102 in the cache */
   /* search692_1_0 -> 36 in the cache */
   /* search692_1_1 -> 120 in the cache */
   /* search692_1 -> 2103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2102, 2103 },
      -1,
   } },

   /* replace692_0_0 -> 16 in the cache */
   /* replace692_0_1 -> 36 in the cache */
   /* replace692_0 -> 2109 in the cache */
   /* replace692_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2109, 120 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search693_0_0 -> 16 in the cache */
   /* search693_0_1 -> 120 in the cache */
   /* search693_0 -> 2102 in the cache */
   /* search693_1_0 -> 36 in the cache */
   /* search693_1_1 -> 120 in the cache */
   /* search693_1 -> 2103 in the cache */
   /* search693 -> 2104 in the cache */

   /* replace693_0_0 -> 16 in the cache */
   /* replace693_0_1 -> 36 in the cache */
   /* replace693_0 -> 2106 in the cache */
   /* replace693_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2106, 120 },
      -1,
   } },

   /* ('ineg', ('b2i32', 'a@32')) => a */
   /* search694_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2114 },
      -1,
   } },

   /* replace694 -> 16 in the cache */

   /* ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b') */
   /* search695_0 -> 16 in the cache */
   /* search695_1_0 -> 19 in the cache */
   /* search695_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2116 },
      -1,
   } },

   /* replace695_0 -> 16 in the cache */
   /* replace695_1 -> 36 in the cache */
   /* replace695 -> 895 in the cache */

   /* ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b') */
   /* search696_0 -> 16 in the cache */
   /* search696_1_0 -> 19 in the cache */
   /* search696_1_1 -> 36 in the cache */
   /* search696_1 -> 2116 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 16, 2116 },
      -1,
   } },

   /* replace696_0 -> 16 in the cache */
   /* replace696_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b') */
   /* search697_0 -> 16 in the cache */
   /* search697_1_0 -> 19 in the cache */
   /* search697_1_1 -> 36 in the cache */
   /* search697_1 -> 2116 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2116 },
      -1,
   } },

   /* replace697_0 -> 16 in the cache */
   /* replace697_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search698_0_0 -> 21 in the cache */
   /* search698_0_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 21, 847 },
      -1,
   } },
   /* search698_1_0 -> 41 in the cache */
   /* search698_1_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 41, 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2122, 2123 },
      -1,
   } },

   /* replace698_0_0 -> 21 in the cache */
   /* replace698_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace698_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2125, 847 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search699_0_0 -> 21 in the cache */
   /* search699_0_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 21, 847 },
      -1,
   } },
   /* search699_1_0 -> 41 in the cache */
   /* search699_1_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 41, 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2127, 2128 },
      -1,
   } },

   /* replace699_0_0 -> 21 in the cache */
   /* replace699_0_1 -> 41 in the cache */
   /* replace699_0 -> 2125 in the cache */
   /* replace699_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2125, 847 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search700_0_0 -> 21 in the cache */
   /* search700_0_1 -> 847 in the cache */
   /* search700_0 -> 2122 in the cache */
   /* search700_1_0 -> 41 in the cache */
   /* search700_1_1 -> 847 in the cache */
   /* search700_1 -> 2123 in the cache */
   /* search700 -> 2124 in the cache */

   /* replace700_0_0 -> 21 in the cache */
   /* replace700_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace700_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2131, 847 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search701_0_0 -> 21 in the cache */
   /* search701_0_1 -> 847 in the cache */
   /* search701_0 -> 2122 in the cache */
   /* search701_1_0 -> 41 in the cache */
   /* search701_1_1 -> 847 in the cache */
   /* search701_1 -> 2123 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2122, 2123 },
      -1,
   } },

   /* replace701_0_0 -> 21 in the cache */
   /* replace701_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace701_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2134, 847 },
      -1,
   } },

   /* ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search702_0_0 -> 21 in the cache */
   /* search702_0_1 -> 847 in the cache */
   /* search702_0 -> 2127 in the cache */
   /* search702_1_0 -> 41 in the cache */
   /* search702_1_1 -> 847 in the cache */
   /* search702_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2127, 2128 },
      -1,
   } },

   /* replace702_0_0 -> 21 in the cache */
   /* replace702_0_1 -> 41 in the cache */
   /* replace702_0 -> 2134 in the cache */
   /* replace702_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2134, 847 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search703_0_0 -> 21 in the cache */
   /* search703_0_1 -> 847 in the cache */
   /* search703_0 -> 2127 in the cache */
   /* search703_1_0 -> 41 in the cache */
   /* search703_1_1 -> 847 in the cache */
   /* search703_1 -> 2128 in the cache */
   /* search703 -> 2129 in the cache */

   /* replace703_0_0 -> 21 in the cache */
   /* replace703_0_1 -> 41 in the cache */
   /* replace703_0 -> 2131 in the cache */
   /* replace703_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2131, 847 },
      -1,
   } },

   /* ('ineg', ('b2i64', 'a@64')) => a */
   /* search704_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2139 },
      -1,
   } },

   /* replace704 -> 21 in the cache */

   /* ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b') */
   /* search705_0 -> 21 in the cache */
   /* search705_1_0 -> 24 in the cache */
   /* search705_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 2141 },
      -1,
   } },

   /* replace705_0 -> 21 in the cache */
   /* replace705_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b') */
   /* search706_0 -> 21 in the cache */
   /* search706_1_0 -> 24 in the cache */
   /* search706_1_1 -> 36 in the cache */
   /* search706_1 -> 2141 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 21, 2141 },
      -1,
   } },

   /* replace706_0 -> 21 in the cache */
   /* replace706_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b') */
   /* search707_0 -> 21 in the cache */
   /* search707_1_0 -> 24 in the cache */
   /* search707_1_1 -> 36 in the cache */
   /* search707_1 -> 2141 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 2141 },
      -1,
   } },

   /* replace707_0 -> 21 in the cache */
   /* replace707_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a') */
   /* search708_0_0 -> 32 in the cache */
   /* search708_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 61 },
      -1,
   } },
   /* search708_1_0 -> 32 in the cache */
   /* search708_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2148, 2149 },
      -1,
   } },

   /* replace708_0 -> 35 in the cache */
   /* replace708_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 35, 32 },
      -1,
   } },

   /* ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a') */
   /* search709_0_0 -> 35 in the cache */
   /* search709_0_1 -> 32 in the cache */
   /* search709_0 -> 2151 in the cache */
   /* search709_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2152 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2151, 2153 },
      -1,
   } },

   /* replace709_0 -> 2152 in the cache */
   /* replace709_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2152, 32 },
      -1,
   } },

   /* ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a') */
   /* search710_0_0 -> 2152 in the cache */
   /* search710_0_1 -> 32 in the cache */
   /* search710_0 -> 2155 in the cache */
   /* search710_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2156 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2155, 2157 },
      -1,
   } },

   /* replace710_0 -> 2156 in the cache */
   /* replace710_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2156, 32 },
      -1,
   } },

   /* ('ior', 'a', ('ieq', 'a', False)) => True */
   /* search711_0 -> 706 in the cache */
   /* search711_1_0 -> 706 in the cache */
   /* search711_1_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 706, 1024 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 706, 2160 },
      -1,
   } },

   /* replace711 -> 1177 in the cache */

   /* ('ior', 'a', ('inot', 'a')) => -1 */
   /* search712_0 -> 32 in the cache */
   /* search712_1_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 2162 },
      -1,
   } },

   /* replace712 -> 63 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b') */
   /* search713_0_0_0 -> 706 in the cache */
   /* search713_0_0 -> 1168 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1168 },
      -1,
   } },
   /* search713_1_0_0 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1075 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2164, 2166 },
      -1,
   } },

   /* replace713_0 -> 706 in the cache */
   /* replace713_1 -> 1075 in the cache */
   /* replace713 -> 1320 in the cache */

   /* ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b')) */
   /* search714_0_0 -> 706 in the cache */
   /* search714_0_1 -> 1075 in the cache */
   /* search714_0 -> 1320 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1320 },
      -1,
   } },

   /* replace714_0_0 -> 706 in the cache */
   /* replace714_0_1 -> 1075 in the cache */
   /* replace714_0 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1092 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0)) */
   /* search715_0_0_0_0_0 -> 32 in the cache */
   /* search715_0_0_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 32, 61 },
      -1,
   } },
   /* search715_0_0_0_1 -> 1075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 2170, 1075 },
      -1,
   } },
   /* search715_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2171, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2172 },
      -1,
   } },
   /* search715_1_0 -> 32 in the cache */
   /* search715_1_1 -> 61 in the cache */
   /* search715_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2173, 1191 },
      -1,
   } },

   /* replace715_0_0_0 -> 1075 in the cache */
   /* replace715_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1075, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2175 },
      -1,
   } },
   /* replace715_1_0 -> 32 in the cache */
   /* replace715_1_1 -> 61 in the cache */
   /* replace715_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2176, 1191 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0)) */
   /* search716_0_0_0_0_0 -> 0 in the cache */
   /* search716_0_0_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      3, 1,
      { 0, 3 },
      -1,
   } },
   /* search716_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 2178, 86 },
      -1,
   } },
   /* search716_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2179, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2180 },
      -1,
   } },
   /* search716_1_0 -> 0 in the cache */
   /* search716_1_1 -> 86 in the cache */
   /* search716_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2181, 90 },
      -1,
   } },

   /* replace716_0_0_0_0 -> 3 in the cache */
   /* replace716_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3, 86 },
      -1,
   } },
   /* replace716_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 2,
      { 2183, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 2,
      { 2184 },
      -1,
   } },
   /* replace716_1_0 -> 0 in the cache */
   /* replace716_1_1 -> 86 in the cache */
   /* replace716_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2185, 90 },
      -1,
   } },

   /* ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b') */
   /* search717_0 -> 32 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search717_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2188 },
      -1,
   } },

   /* replace717_0 -> 32 in the cache */
   /* replace717_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 2187 },
      -1,
   } },

   /* ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a') */
   /* search718_0_0 -> 0 in the cache */
   /* search718_0_1 -> 3 in the cache */
   /* search718_0 -> 1225 in the cache */
   /* search718_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1225, 0 },
      -1,
   } },

   /* replace718_0 -> 3 in the cache */
   /* replace718_1 -> 0 in the cache */
   /* replace718 -> 1025 in the cache */

   /* ('~fge', 'a', ('fmin', 'b', 'a')) => True */
   /* search719_0 -> 32 in the cache */
   /* search719_1_0 -> 2187 in the cache */
   /* search719_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2192 },
      -1,
   } },

   /* replace719 -> 1177 in the cache */

   /* ('~fge', ('fmax', 'a', 'b'), 'a') => True */
   /* search720_0_0 -> 0 in the cache */
   /* search720_0_1 -> 3 in the cache */
   /* search720_0 -> 1223 in the cache */
   /* search720_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1223, 0 },
      -1,
   } },

   /* replace720 -> 1177 in the cache */

   /* ('flt', 'a', ('fmin', 'b', 'a')) => False */
   /* search721_0 -> 32 in the cache */
   /* search721_1_0 -> 2187 in the cache */
   /* search721_1_1 -> 32 in the cache */
   /* search721_1 -> 2192 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2192 },
      -1,
   } },

   /* replace721 -> 1024 in the cache */

   /* ('flt', ('fmax', 'a', 'b'), 'a') => False */
   /* search722_0_0 -> 0 in the cache */
   /* search722_0_1 -> 3 in the cache */
   /* search722_0 -> 1223 in the cache */
   /* search722_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1223, 0 },
      -1,
   } },

   /* replace722 -> 1024 in the cache */

   /* ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b') */
   /* search723_0 -> 32 in the cache */
   /* search723_1_0 -> 2187 in the cache */
   /* search723_1_1 -> 32 in the cache */
   /* search723_1 -> 2188 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2188 },
      -1,
   } },

   /* replace723_0 -> 32 in the cache */
   /* replace723_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 2187 },
      -1,
   } },

   /* ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a') */
   /* search724_0_0 -> 0 in the cache */
   /* search724_0_1 -> 3 in the cache */
   /* search724_0 -> 1225 in the cache */
   /* search724_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1225, 0 },
      -1,
   } },

   /* replace724_0 -> 3 in the cache */
   /* replace724_1 -> 0 in the cache */
   /* replace724 -> 1037 in the cache */

   /* ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b') */
   /* search725_0 -> 32 in the cache */
   /* search725_1_0 -> 2187 in the cache */
   /* search725_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2200 },
      -1,
   } },

   /* replace725_0 -> 32 in the cache */
   /* replace725_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 2187 },
      -1,
   } },

   /* ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a') */
   /* search726_0_0 -> 0 in the cache */
   /* search726_0_1 -> 3 in the cache */
   /* search726_0 -> 1285 in the cache */
   /* search726_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1285, 0 },
      -1,
   } },

   /* replace726_0 -> 3 in the cache */
   /* replace726_1 -> 0 in the cache */
   /* replace726 -> 1030 in the cache */

   /* ('ige', 'a', ('imin', 'b', 'a')) => True */
   /* search727_0 -> 32 in the cache */
   /* search727_1_0 -> 2187 in the cache */
   /* search727_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2204 },
      -1,
   } },

   /* replace727 -> 1177 in the cache */

   /* ('ige', ('imax', 'a', 'b'), 'a') => True */
   /* search728_0_0 -> 0 in the cache */
   /* search728_0_1 -> 3 in the cache */
   /* search728_0 -> 1277 in the cache */
   /* search728_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1277, 0 },
      -1,
   } },

   /* replace728 -> 1177 in the cache */

   /* ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b') */
   /* search729_0 -> 32 in the cache */
   /* search729_1_0 -> 2187 in the cache */
   /* search729_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2207 },
      -1,
   } },

   /* replace729_0 -> 32 in the cache */
   /* replace729_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 2187 },
      -1,
   } },

   /* ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a') */
   /* search730_0_0 -> 0 in the cache */
   /* search730_0_1 -> 3 in the cache */
   /* search730_0 -> 1282 in the cache */
   /* search730_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1282, 0 },
      -1,
   } },

   /* replace730_0 -> 3 in the cache */
   /* replace730_1 -> 0 in the cache */
   /* replace730 -> 1032 in the cache */

   /* ('uge', 'a', ('umin', 'b', 'a')) => True */
   /* search731_0 -> 32 in the cache */
   /* search731_1_0 -> 2187 in the cache */
   /* search731_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2211 },
      -1,
   } },

   /* replace731 -> 1177 in the cache */

   /* ('uge', ('umax', 'a', 'b'), 'a') => True */
   /* search732_0_0 -> 0 in the cache */
   /* search732_0_1 -> 3 in the cache */
   /* search732_0 -> 1274 in the cache */
   /* search732_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1274, 0 },
      -1,
   } },

   /* replace732 -> 1177 in the cache */

   /* ('ilt', 'a', ('imin', 'b', 'a')) => False */
   /* search733_0 -> 32 in the cache */
   /* search733_1_0 -> 2187 in the cache */
   /* search733_1_1 -> 32 in the cache */
   /* search733_1 -> 2204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2204 },
      -1,
   } },

   /* replace733 -> 1024 in the cache */

   /* ('ilt', ('imax', 'a', 'b'), 'a') => False */
   /* search734_0_0 -> 0 in the cache */
   /* search734_0_1 -> 3 in the cache */
   /* search734_0 -> 1277 in the cache */
   /* search734_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1277, 0 },
      -1,
   } },

   /* replace734 -> 1024 in the cache */

   /* ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b') */
   /* search735_0 -> 32 in the cache */
   /* search735_1_0 -> 2187 in the cache */
   /* search735_1_1 -> 32 in the cache */
   /* search735_1 -> 2200 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2200 },
      -1,
   } },

   /* replace735_0 -> 32 in the cache */
   /* replace735_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 2187 },
      -1,
   } },

   /* ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a') */
   /* search736_0_0 -> 0 in the cache */
   /* search736_0_1 -> 3 in the cache */
   /* search736_0 -> 1285 in the cache */
   /* search736_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1285, 0 },
      -1,
   } },

   /* replace736_0 -> 3 in the cache */
   /* replace736_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('umin', 'b', 'a')) => False */
   /* search737_0 -> 32 in the cache */
   /* search737_1_0 -> 2187 in the cache */
   /* search737_1_1 -> 32 in the cache */
   /* search737_1 -> 2211 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2211 },
      -1,
   } },

   /* replace737 -> 1024 in the cache */

   /* ('ult', ('umax', 'a', 'b'), 'a') => False */
   /* search738_0_0 -> 0 in the cache */
   /* search738_0_1 -> 3 in the cache */
   /* search738_0 -> 1274 in the cache */
   /* search738_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1274, 0 },
      -1,
   } },

   /* replace738 -> 1024 in the cache */

   /* ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b') */
   /* search739_0 -> 32 in the cache */
   /* search739_1_0 -> 2187 in the cache */
   /* search739_1_1 -> 32 in the cache */
   /* search739_1 -> 2207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2207 },
      -1,
   } },

   /* replace739_0 -> 32 in the cache */
   /* replace739_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 2187 },
      -1,
   } },

   /* ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a') */
   /* search740_0_0 -> 0 in the cache */
   /* search740_0_1 -> 3 in the cache */
   /* search740_0 -> 1282 in the cache */
   /* search740_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1282, 0 },
      -1,
   } },

   /* replace740_0 -> 3 in the cache */
   /* replace740_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('iand', 'b', 'a')) => False */
   /* search741_0 -> 32 in the cache */
   /* search741_1_0 -> 2187 in the cache */
   /* search741_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2226 },
      -1,
   } },

   /* replace741 -> 1024 in the cache */

   /* ('ult', ('ior', 'a', 'b'), 'a') => False */
   /* search742_0_0 -> 0 in the cache */
   /* search742_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* search742_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2228, 0 },
      -1,
   } },

   /* replace742 -> 1024 in the cache */

   /* ('uge', 'a', ('iand', 'b', 'a')) => True */
   /* search743_0 -> 32 in the cache */
   /* search743_1_0 -> 2187 in the cache */
   /* search743_1_1 -> 32 in the cache */
   /* search743_1 -> 2226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2226 },
      -1,
   } },

   /* replace743 -> 1177 in the cache */

   /* ('uge', ('ior', 'a', 'b'), 'a') => True */
   /* search744_0_0 -> 0 in the cache */
   /* search744_0_1 -> 3 in the cache */
   /* search744_0 -> 2228 in the cache */
   /* search744_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2228, 0 },
      -1,
   } },

   /* replace744 -> 1177 in the cache */

   /* ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search745_0 -> 267 in the cache */
   /* search745_1_0 -> 268 in the cache */
   /* search745_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 267, 2232 },
      -1,
   } },

   /* replace745_0_0 -> 124 in the cache */
   /* replace745_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace745_1_0 -> 124 in the cache */
   /* replace745_1_1 -> 127 in the cache */
   /* replace745_1 -> 1586 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2234, 1586 },
      -1,
   } },

   /* ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search746_0_0 -> 267 in the cache */
   /* search746_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search746_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2236, 760 },
      -1,
   } },

   /* replace746_0_0 -> 124 in the cache */
   /* replace746_0_1 -> 127 in the cache */
   /* replace746_0 -> 1586 in the cache */
   /* replace746_1_0 -> 125 in the cache */
   /* replace746_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1586, 2238 },
      -1,
   } },

   /* ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search747_0 -> 267 in the cache */
   /* search747_1_0 -> 268 in the cache */
   /* search747_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 267, 2240 },
      -1,
   } },

   /* replace747_0_0 -> 124 in the cache */
   /* replace747_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace747_1_0 -> 124 in the cache */
   /* replace747_1_1 -> 127 in the cache */
   /* replace747_1 -> 1596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2242, 1596 },
      -1,
   } },

   /* ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search748_0_0 -> 267 in the cache */
   /* search748_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search748_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2244, 760 },
      -1,
   } },

   /* replace748_0_0 -> 124 in the cache */
   /* replace748_0_1 -> 127 in the cache */
   /* replace748_0 -> 1596 in the cache */
   /* replace748_1_0 -> 125 in the cache */
   /* replace748_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1596, 2246 },
      -1,
   } },

   /* ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search749_0 -> 267 in the cache */
   /* search749_1_0 -> 268 in the cache */
   /* search749_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 267, 2248 },
      -1,
   } },

   /* replace749_0_0 -> 124 in the cache */
   /* replace749_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace749_1_0 -> 124 in the cache */
   /* replace749_1_1 -> 127 in the cache */
   /* replace749_1 -> 1606 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2250, 1606 },
      -1,
   } },

   /* ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search750_0_0 -> 267 in the cache */
   /* search750_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search750_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2252, 760 },
      -1,
   } },

   /* replace750_0_0 -> 124 in the cache */
   /* replace750_0_1 -> 127 in the cache */
   /* replace750_0 -> 1606 in the cache */
   /* replace750_1_0 -> 125 in the cache */
   /* replace750_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1606, 2254 },
      -1,
   } },

   /* ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search751_0 -> 267 in the cache */
   /* search751_1_0 -> 268 in the cache */
   /* search751_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 267, 2256 },
      -1,
   } },

   /* replace751_0_0 -> 124 in the cache */
   /* replace751_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace751_1_0 -> 124 in the cache */
   /* replace751_1_1 -> 127 in the cache */
   /* replace751_1 -> 1616 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2258, 1616 },
      -1,
   } },

   /* ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search752_0_0 -> 267 in the cache */
   /* search752_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search752_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2260, 760 },
      -1,
   } },

   /* replace752_0_0 -> 124 in the cache */
   /* replace752_0_1 -> 127 in the cache */
   /* replace752_0 -> 1616 in the cache */
   /* replace752_1_0 -> 125 in the cache */
   /* replace752_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1616, 2262 },
      -1,
   } },

   /* ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search753_0 -> 267 in the cache */
   /* search753_1_0 -> 268 in the cache */
   /* search753_1_1 -> 127 in the cache */
   /* search753_1 -> 2240 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 267, 2240 },
      -1,
   } },

   /* replace753_0_0 -> 124 in the cache */
   /* replace753_0_1 -> 125 in the cache */
   /* replace753_0 -> 2234 in the cache */
   /* replace753_1_0 -> 124 in the cache */
   /* replace753_1_1 -> 127 in the cache */
   /* replace753_1 -> 1586 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2234, 1586 },
      -1,
   } },

   /* ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search754_0_0 -> 267 in the cache */
   /* search754_0_1 -> 125 in the cache */
   /* search754_0 -> 2244 in the cache */
   /* search754_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2244, 760 },
      -1,
   } },

   /* replace754_0_0 -> 124 in the cache */
   /* replace754_0_1 -> 127 in the cache */
   /* replace754_0 -> 1586 in the cache */
   /* replace754_1_0 -> 125 in the cache */
   /* replace754_1_1 -> 127 in the cache */
   /* replace754_1 -> 2238 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1586, 2238 },
      -1,
   } },

   /* ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search755_0 -> 267 in the cache */
   /* search755_1_0 -> 268 in the cache */
   /* search755_1_1 -> 127 in the cache */
   /* search755_1 -> 2232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 267, 2232 },
      -1,
   } },

   /* replace755_0_0 -> 124 in the cache */
   /* replace755_0_1 -> 125 in the cache */
   /* replace755_0 -> 2242 in the cache */
   /* replace755_1_0 -> 124 in the cache */
   /* replace755_1_1 -> 127 in the cache */
   /* replace755_1 -> 1596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2242, 1596 },
      -1,
   } },

   /* ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search756_0_0 -> 267 in the cache */
   /* search756_0_1 -> 125 in the cache */
   /* search756_0 -> 2236 in the cache */
   /* search756_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2236, 760 },
      -1,
   } },

   /* replace756_0_0 -> 124 in the cache */
   /* replace756_0_1 -> 127 in the cache */
   /* replace756_0 -> 1596 in the cache */
   /* replace756_1_0 -> 125 in the cache */
   /* replace756_1_1 -> 127 in the cache */
   /* replace756_1 -> 2246 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1596, 2246 },
      -1,
   } },

   /* ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search757_0 -> 267 in the cache */
   /* search757_1_0 -> 268 in the cache */
   /* search757_1_1 -> 127 in the cache */
   /* search757_1 -> 2256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 267, 2256 },
      -1,
   } },

   /* replace757_0_0 -> 124 in the cache */
   /* replace757_0_1 -> 125 in the cache */
   /* replace757_0 -> 2250 in the cache */
   /* replace757_1_0 -> 124 in the cache */
   /* replace757_1_1 -> 127 in the cache */
   /* replace757_1 -> 1606 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2250, 1606 },
      -1,
   } },

   /* ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search758_0_0 -> 267 in the cache */
   /* search758_0_1 -> 125 in the cache */
   /* search758_0 -> 2260 in the cache */
   /* search758_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2260, 760 },
      -1,
   } },

   /* replace758_0_0 -> 124 in the cache */
   /* replace758_0_1 -> 127 in the cache */
   /* replace758_0 -> 1606 in the cache */
   /* replace758_1_0 -> 125 in the cache */
   /* replace758_1_1 -> 127 in the cache */
   /* replace758_1 -> 2254 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1606, 2254 },
      -1,
   } },

   /* ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search759_0 -> 267 in the cache */
   /* search759_1_0 -> 268 in the cache */
   /* search759_1_1 -> 127 in the cache */
   /* search759_1 -> 2248 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 267, 2248 },
      -1,
   } },

   /* replace759_0_0 -> 124 in the cache */
   /* replace759_0_1 -> 125 in the cache */
   /* replace759_0 -> 2258 in the cache */
   /* replace759_1_0 -> 124 in the cache */
   /* replace759_1_1 -> 127 in the cache */
   /* replace759_1 -> 1616 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2258, 1616 },
      -1,
   } },

   /* ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search760_0_0 -> 267 in the cache */
   /* search760_0_1 -> 125 in the cache */
   /* search760_0 -> 2252 in the cache */
   /* search760_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2252, 760 },
      -1,
   } },

   /* replace760_0_0 -> 124 in the cache */
   /* replace760_0_1 -> 127 in the cache */
   /* replace760_0 -> 1616 in the cache */
   /* replace760_1_0 -> 125 in the cache */
   /* replace760_1_1 -> 127 in the cache */
   /* replace760_1 -> 2262 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1616, 2262 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b')) */
   /* search761_0_0 -> 32 in the cache */
   /* search761_0_1 -> 61 in the cache */
   /* search761_0 -> 1191 in the cache */
   /* search761_1_0_0 -> 32 in the cache */
   /* search761_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2280 },
      -1,
   } },
   /* search761_2_0 -> 32 in the cache */
   /* search761_2_1 -> 36 in the cache */
   /* search761_2 -> 2280 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1191, 2281, 2280 },
      -1,
   } },

   /* replace761_0_0 -> 32 in the cache */
   /* replace761_0_1 -> 36 in the cache */
   /* replace761_0 -> 2280 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2280 },
      -1,
   } },

   /* ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b') */
   /* search762_0_0_0 -> 32 in the cache */
   /* search762_0_0 -> 106 in the cache */
   /* search762_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 106, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2284 },
      -1,
   } },

   /* replace762_0_0 -> 32 in the cache */
   /* replace762_0 -> 106 in the cache */
   /* replace762_1 -> 36 in the cache */
   /* replace762 -> 2284 in the cache */

   /* ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b') */
   /* search763_0_0 -> 0 in the cache */
   /* search763_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2286 },
      -1,
   } },

   /* replace763_0 -> 0 in the cache */
   /* replace763_1 -> 3 in the cache */
   /* replace763 -> 2286 in the cache */

   /* ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b') */
   /* search764_0_0 -> 0 in the cache */
   /* search764_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2288 },
      -1,
   } },

   /* replace764_0 -> 0 in the cache */
   /* replace764_1 -> 3 in the cache */
   /* replace764 -> 2288 in the cache */

   /* ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b') */
   /* search765_0_0 -> 0 in the cache */
   /* search765_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2290 },
      -1,
   } },

   /* replace765_0 -> 0 in the cache */
   /* replace765_1 -> 3 in the cache */
   /* replace765 -> 2290 in the cache */

   /* ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b') */
   /* search766_0_0 -> 0 in the cache */
   /* search766_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2292 },
      -1,
   } },

   /* replace766_0 -> 0 in the cache */
   /* replace766_1 -> 3 in the cache */
   /* replace766 -> 2292 in the cache */

   /* ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b')) */
   /* search767_0 -> 0 in the cache */
   /* search767_1 -> 3 in the cache */
   /* search767 -> 2286 in the cache */

   /* replace767_0_0 -> 0 in the cache */
   /* replace767_0_1 -> 3 in the cache */
   /* replace767_0 -> 996 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 996 },
      -1,
   } },

   /* ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b')) */
   /* search768_0 -> 0 in the cache */
   /* search768_1 -> 3 in the cache */
   /* search768 -> 2288 in the cache */

   /* replace768_0_0 -> 0 in the cache */
   /* replace768_0_1 -> 3 in the cache */
   /* replace768_0 -> 993 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 993 },
      -1,
   } },

   /* ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b')) */
   /* search769_0 -> 0 in the cache */
   /* search769_1 -> 3 in the cache */
   /* search769 -> 2290 in the cache */

   /* replace769_0_0 -> 0 in the cache */
   /* replace769_0_1 -> 3 in the cache */
   /* replace769_0 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1002 },
      -1,
   } },

   /* ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b')) */
   /* search770_0 -> 0 in the cache */
   /* search770_1 -> 3 in the cache */
   /* search770 -> 2292 in the cache */

   /* replace770_0_0 -> 0 in the cache */
   /* replace770_0_1 -> 3 in the cache */
   /* replace770_0 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 999 },
      -1,
   } },

   /* ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search771_0_0 -> 0 in the cache */
   /* search771_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search771_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2298, 255 },
      -1,
   } },

   /* replace771_0 -> 0 in the cache */
   /* replace771_1 -> 3 in the cache */
   /* replace771 -> 2290 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search772_0_0 -> 0 in the cache */
   /* search772_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search772_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2300, 255 },
      -1,
   } },

   /* replace772_0 -> 0 in the cache */
   /* replace772_1 -> 3 in the cache */
   /* replace772 -> 2292 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search773_0_0 -> 0 in the cache */
   /* search773_0_1 -> 3 in the cache */
   /* search773_0 -> 2286 in the cache */
   /* search773_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2286, 255 },
      -1,
   } },

   /* replace773_0 -> 0 in the cache */
   /* replace773_1 -> 3 in the cache */
   /* replace773 -> 2286 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search774_0_0 -> 0 in the cache */
   /* search774_0_1 -> 3 in the cache */
   /* search774_0 -> 2288 in the cache */
   /* search774_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2288, 255 },
      -1,
   } },

   /* replace774_0 -> 0 in the cache */
   /* replace774_1 -> 3 in the cache */
   /* replace774 -> 2288 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search775_0_0 -> 0 in the cache */
   /* search775_0_1 -> 3 in the cache */
   /* search775_0 -> 2298 in the cache */
   /* search775_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2298, 241 },
      -1,
   } },

   /* replace775_0 -> 0 in the cache */
   /* replace775_1 -> 3 in the cache */
   /* replace775 -> 2290 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search776_0_0 -> 0 in the cache */
   /* search776_0_1 -> 3 in the cache */
   /* search776_0 -> 2300 in the cache */
   /* search776_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2300, 241 },
      -1,
   } },

   /* replace776_0 -> 0 in the cache */
   /* replace776_1 -> 3 in the cache */
   /* replace776 -> 2292 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search777_0_0 -> 0 in the cache */
   /* search777_0_1 -> 3 in the cache */
   /* search777_0 -> 2286 in the cache */
   /* search777_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2286, 241 },
      -1,
   } },

   /* replace777_0 -> 0 in the cache */
   /* replace777_1 -> 3 in the cache */
   /* replace777 -> 2286 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search778_0_0 -> 0 in the cache */
   /* search778_0_1 -> 3 in the cache */
   /* search778_0 -> 2288 in the cache */
   /* search778_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2288, 241 },
      -1,
   } },

   /* replace778_0 -> 0 in the cache */
   /* replace778_1 -> 3 in the cache */
   /* replace778 -> 2288 in the cache */

   /* ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search779_0_0 -> 0 in the cache */
   /* search779_0_1 -> 3 in the cache */
   /* search779_0 -> 2298 in the cache */
   /* search779_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2298, 241 },
      -1,
   } },

   /* replace779_0 -> 0 in the cache */
   /* replace779_1 -> 3 in the cache */
   /* replace779 -> 2292 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search780_0_0 -> 0 in the cache */
   /* search780_0_1 -> 3 in the cache */
   /* search780_0 -> 2300 in the cache */
   /* search780_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2300, 241 },
      -1,
   } },

   /* replace780_0 -> 0 in the cache */
   /* replace780_1 -> 3 in the cache */
   /* replace780 -> 2290 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search781_0_0 -> 0 in the cache */
   /* search781_0_1 -> 3 in the cache */
   /* search781_0 -> 2286 in the cache */
   /* search781_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2286, 241 },
      -1,
   } },

   /* replace781_0 -> 0 in the cache */
   /* replace781_1 -> 3 in the cache */
   /* replace781 -> 2288 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search782_0_0 -> 0 in the cache */
   /* search782_0_1 -> 3 in the cache */
   /* search782_0 -> 2288 in the cache */
   /* search782_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2288, 241 },
      -1,
   } },

   /* replace782_0 -> 0 in the cache */
   /* replace782_1 -> 3 in the cache */
   /* replace782 -> 2286 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search783_0_0 -> 0 in the cache */
   /* search783_0_1 -> 3 in the cache */
   /* search783_0 -> 2298 in the cache */
   /* search783_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2298, 255 },
      -1,
   } },

   /* replace783_0 -> 0 in the cache */
   /* replace783_1 -> 3 in the cache */
   /* replace783 -> 2292 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search784_0_0 -> 0 in the cache */
   /* search784_0_1 -> 3 in the cache */
   /* search784_0 -> 2300 in the cache */
   /* search784_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2300, 255 },
      -1,
   } },

   /* replace784_0 -> 0 in the cache */
   /* replace784_1 -> 3 in the cache */
   /* replace784 -> 2290 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search785_0_0 -> 0 in the cache */
   /* search785_0_1 -> 3 in the cache */
   /* search785_0 -> 2286 in the cache */
   /* search785_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2286, 255 },
      -1,
   } },

   /* replace785_0 -> 0 in the cache */
   /* replace785_1 -> 3 in the cache */
   /* replace785 -> 2288 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search786_0_0 -> 0 in the cache */
   /* search786_0_1 -> 3 in the cache */
   /* search786_0 -> 2288 in the cache */
   /* search786_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2288, 255 },
      -1,
   } },

   /* replace786_0 -> 0 in the cache */
   /* replace786_1 -> 3 in the cache */
   /* replace786 -> 2286 in the cache */

   /* ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y')) */
   /* search787_0 -> 16 in the cache */
   /* search787_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2317, 2318 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 2320, 2321 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      -1, 2,
      { 2319, 2322 },
      -1,
   } },

   /* ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0) */
   /* search788_0 -> 16 in the cache */
   /* search788_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace788_0_0 -> 16 in the cache */
   /* replace788_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace788_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2325, 117 },
      -1,
   } },

   /* ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0) */
   /* search789_0 -> 16 in the cache */
   /* search789_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace789_0_0 -> 16 in the cache */
   /* replace789_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace789_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2328, 117 },
      -1,
   } },

   /* ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y')) */
   /* search790_0 -> 16 in the cache */
   /* search790_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace790_0_0 -> 2317 in the cache */
   /* replace790_0_1 -> 2318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2317, 2318 },
      -1,
   } },
   /* replace790_1_0 -> 2320 in the cache */
   /* replace790_1_1 -> 2321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 2320, 2321 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      -1, 2,
      { 2331, 2332 },
      -1,
   } },

   /* ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search791_0 -> 16 in the cache */
   /* search791_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace791_0_0_0 -> 16 in the cache */
   /* replace791_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace791_0_1_0 -> 16 in the cache */
   /* replace791_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot3,
      -1, 2,
      { 2335, 2336 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2337 },
      -1,
   } },

   /* ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search792_0 -> 16 in the cache */
   /* search792_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace792_0_0_0 -> 16 in the cache */
   /* replace792_0_0_1 -> 36 in the cache */
   /* replace792_0_0 -> 2335 in the cache */
   /* replace792_0_1_0 -> 16 in the cache */
   /* replace792_0_1_1 -> 36 in the cache */
   /* replace792_0_1 -> 2336 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot4,
      -1, 2,
      { 2335, 2336 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2340 },
      -1,
   } },

   /* ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')) */
   /* search793_0 -> 0 in the cache */
   /* search793_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace793_0_0 -> 715 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 715, 2343 },
      -1,
   } },
   /* replace793_1_0 -> 716 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 716, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2344, 2346 },
      -1,
   } },

   /* ('ball_iequal3', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('ieq', 'a.z', 'b.z')) */
   /* search794_0 -> 0 in the cache */
   /* search794_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace794_0_0_0 -> 715 in the cache */
   /* replace794_0_0_1 -> 2343 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 715, 2343 },
      -1,
   } },
   /* replace794_0_1_0 -> 716 in the cache */
   /* replace794_0_1_1 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 716, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2349, 2350 },
      -1,
   } },
   /* replace794_1_0 -> 717 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 717, 2352 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2351, 2353 },
      -1,
   } },

   /* ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w'))) */
   /* search795_0 -> 0 in the cache */
   /* search795_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace795_0_0_0 -> 715 in the cache */
   /* replace795_0_0_1 -> 2343 in the cache */
   /* replace795_0_0 -> 2344 in the cache */
   /* replace795_0_1_0 -> 716 in the cache */
   /* replace795_0_1_1 -> 2345 in the cache */
   /* replace795_0_1 -> 2346 in the cache */
   /* replace795_0 -> 2347 in the cache */
   /* replace795_1_0_0 -> 717 in the cache */
   /* replace795_1_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 717, 2352 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 2357, 2358 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2356, 2359 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2347, 2360 },
      -1,
   } },

   /* ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')) */
   /* search796_0 -> 0 in the cache */
   /* search796_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace796_0_0 -> 715 in the cache */
   /* replace796_0_1 -> 2343 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 715, 2343 },
      -1,
   } },
   /* replace796_1_0 -> 716 in the cache */
   /* replace796_1_1 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 716, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2363, 2364 },
      -1,
   } },

   /* ('bany_inequal3', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ine', 'a.z', 'b.z')) */
   /* search797_0 -> 0 in the cache */
   /* search797_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace797_0_0_0 -> 715 in the cache */
   /* replace797_0_0_1 -> 2343 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 715, 2343 },
      -1,
   } },
   /* replace797_0_1_0 -> 716 in the cache */
   /* replace797_0_1_1 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 716, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2367, 2368 },
      -1,
   } },
   /* replace797_1_0 -> 717 in the cache */
   /* replace797_1_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 717, 2352 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2369, 2370 },
      -1,
   } },

   /* ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w'))) */
   /* search798_0 -> 0 in the cache */
   /* search798_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace798_0_0_0 -> 715 in the cache */
   /* replace798_0_0_1 -> 2343 in the cache */
   /* replace798_0_0 -> 2363 in the cache */
   /* replace798_0_1_0 -> 716 in the cache */
   /* replace798_0_1_1 -> 2345 in the cache */
   /* replace798_0_1 -> 2364 in the cache */
   /* replace798_0 -> 2365 in the cache */
   /* replace798_1_0_0 -> 717 in the cache */
   /* replace798_1_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 717, 2352 },
      -1,
   } },
   /* replace798_1_1_0 -> 2357 in the cache */
   /* replace798_1_1_1 -> 2358 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 2357, 2358 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2373, 2374 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2365, 2375 },
      -1,
   } },

   /* ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')) */
   /* search799_0 -> 0 in the cache */
   /* search799_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace799_0_0 -> 715 in the cache */
   /* replace799_0_1 -> 2343 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 715, 2343 },
      -1,
   } },
   /* replace799_1_0 -> 716 in the cache */
   /* replace799_1_1 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 716, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2378, 2379 },
      -1,
   } },

   /* ('ball_fequal3', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('feq', 'a.z', 'b.z')) */
   /* search800_0 -> 0 in the cache */
   /* search800_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace800_0_0_0 -> 715 in the cache */
   /* replace800_0_0_1 -> 2343 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 715, 2343 },
      -1,
   } },
   /* replace800_0_1_0 -> 716 in the cache */
   /* replace800_0_1_1 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 716, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2382, 2383 },
      -1,
   } },
   /* replace800_1_0 -> 717 in the cache */
   /* replace800_1_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 717, 2352 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2384, 2385 },
      -1,
   } },

   /* ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w'))) */
   /* search801_0 -> 0 in the cache */
   /* search801_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace801_0_0_0 -> 715 in the cache */
   /* replace801_0_0_1 -> 2343 in the cache */
   /* replace801_0_0 -> 2378 in the cache */
   /* replace801_0_1_0 -> 716 in the cache */
   /* replace801_0_1_1 -> 2345 in the cache */
   /* replace801_0_1 -> 2379 in the cache */
   /* replace801_0 -> 2380 in the cache */
   /* replace801_1_0_0 -> 717 in the cache */
   /* replace801_1_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 717, 2352 },
      -1,
   } },
   /* replace801_1_1_0 -> 2357 in the cache */
   /* replace801_1_1_1 -> 2358 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 2357, 2358 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2388, 2389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2380, 2390 },
      -1,
   } },

   /* ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')) */
   /* search802_0 -> 0 in the cache */
   /* search802_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace802_0_0 -> 715 in the cache */
   /* replace802_0_1 -> 2343 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 715, 2343 },
      -1,
   } },
   /* replace802_1_0 -> 716 in the cache */
   /* replace802_1_1 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 716, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2393, 2394 },
      -1,
   } },

   /* ('bany_fnequal3', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('fneu', 'a.z', 'b.z')) */
   /* search803_0 -> 0 in the cache */
   /* search803_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace803_0_0_0 -> 715 in the cache */
   /* replace803_0_0_1 -> 2343 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 715, 2343 },
      -1,
   } },
   /* replace803_0_1_0 -> 716 in the cache */
   /* replace803_0_1_1 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 716, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2397, 2398 },
      -1,
   } },
   /* replace803_1_0 -> 717 in the cache */
   /* replace803_1_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 717, 2352 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2399, 2400 },
      -1,
   } },

   /* ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w'))) */
   /* search804_0 -> 0 in the cache */
   /* search804_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace804_0_0_0 -> 715 in the cache */
   /* replace804_0_0_1 -> 2343 in the cache */
   /* replace804_0_0 -> 2393 in the cache */
   /* replace804_0_1_0 -> 716 in the cache */
   /* replace804_0_1_1 -> 2345 in the cache */
   /* replace804_0_1 -> 2394 in the cache */
   /* replace804_0 -> 2395 in the cache */
   /* replace804_1_0_0 -> 717 in the cache */
   /* replace804_1_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 717, 2352 },
      -1,
   } },
   /* replace804_1_1_0 -> 2357 in the cache */
   /* replace804_1_1_1 -> 2358 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 2357, 2358 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2403, 2404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2395, 2405 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0) */
   /* search805_0_0 -> 32 in the cache */
   /* search805_0 -> 98 in the cache */
   /* search805_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace805_0 -> 32 in the cache */
   /* replace805_1 -> 113 in the cache */
   /* replace805 -> 1195 in the cache */

   /* ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0) */
   /* search806_0_0 -> 32 in the cache */
   /* search806_0 -> 98 in the cache */
   /* search806_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace806_0 -> 32 in the cache */
   /* replace806_1 -> 113 in the cache */
   /* replace806 -> 1199 in the cache */

   /* ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search807_0_0 -> 706 in the cache */
   /* search807_0 -> 1168 in the cache */
   /* search807_1_0 -> 1075 in the cache */
   /* search807_1 -> 2165 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1168, 2165 },
      -1,
   } },

   /* replace807_0_0 -> 706 in the cache */
   /* replace807_0_1 -> 1075 in the cache */
   /* replace807_0 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1087 },
      -1,
   } },

   /* ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search808_0_0 -> 706 in the cache */
   /* search808_0 -> 1168 in the cache */
   /* search808_1_0 -> 1075 in the cache */
   /* search808_1 -> 2165 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1168, 2165 },
      -1,
   } },

   /* replace808_0_0 -> 706 in the cache */
   /* replace808_0_1 -> 1075 in the cache */
   /* replace808_0 -> 1087 in the cache */
   /* replace808 -> 2410 in the cache */

   /* ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search809_0_0 -> 706 in the cache */
   /* search809_0 -> 1168 in the cache */
   /* search809_1_0 -> 1075 in the cache */
   /* search809_1 -> 2165 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1168, 2165 },
      -1,
   } },

   /* replace809_0_0 -> 706 in the cache */
   /* replace809_0_1 -> 1075 in the cache */
   /* replace809_0 -> 1079 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1079 },
      -1,
   } },

   /* ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search810_0_0 -> 706 in the cache */
   /* search810_0 -> 1070 in the cache */
   /* search810_1_0 -> 1075 in the cache */
   /* search810_1 -> 1076 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1070, 1076 },
      -1,
   } },

   /* replace810_0_0 -> 706 in the cache */
   /* replace810_0_1 -> 1075 in the cache */
   /* replace810_0 -> 1087 in the cache */
   /* replace810 -> 1208 in the cache */

   /* ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b')) */
   /* search811_0_0_0 -> 706 in the cache */
   /* search811_0_0 -> 1070 in the cache */
   /* search811_0_1_0 -> 1075 in the cache */
   /* search811_0_1 -> 1076 in the cache */
   /* search811_0 -> 1106 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1106 },
      -1,
   } },

   /* replace811_0_0 -> 706 in the cache */
   /* replace811_0_1 -> 1075 in the cache */
   /* replace811_0 -> 1079 in the cache */
   /* replace811 -> 1205 in the cache */

   /* ('iand', 'a@bool16', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search812_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2416, 462 },
      -1,
   } },

   /* replace812_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iand', 'a@bool32', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search813_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2419, 228 },
      -1,
   } },

   /* replace813_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('flt', ('fneg', ('b2f', 'a@1')), 0) => a */
   /* search814_0_0_0 -> 706 in the cache */
   /* search814_0_0 -> 1070 in the cache */
   /* search814_0 -> 1073 in the cache */
   /* search814_1 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1073, 1169 },
      -1,
   } },

   /* replace814 -> 706 in the cache */

   /* ('ilt', 'a', 'a') => False */
   /* search815_0 -> 32 in the cache */
   /* search815_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace815 -> 1024 in the cache */

   /* ('ige', 'a', 'a') => True */
   /* search816_0 -> 32 in the cache */
   /* search816_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace816 -> 1177 in the cache */

   /* ('ieq', 'a', 'a') => True */
   /* search817_0 -> 32 in the cache */
   /* search817_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace817 -> 1177 in the cache */

   /* ('ine', 'a', 'a') => False */
   /* search818_0 -> 32 in the cache */
   /* search818_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace818 -> 1024 in the cache */

   /* ('ult', 'a', 'a') => False */
   /* search819_0 -> 32 in the cache */
   /* search819_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace819 -> 1024 in the cache */

   /* ('uge', 'a', 'a') => True */
   /* search820_0 -> 32 in the cache */
   /* search820_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace820 -> 1177 in the cache */

   /* ('flt', 'a', 'a') => False */
   /* search821_0 -> 32 in the cache */
   /* search821_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace821 -> 1024 in the cache */

   /* ('fge', 'a(is_a_number)', 'a') => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search822_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2430, 32 },
      -1,
   } },

   /* replace822 -> 1177 in the cache */

   /* ('feq', 'a(is_a_number)', 'a') => True */
   /* search823_0 -> 2430 in the cache */
   /* search823_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 2430, 32 },
      -1,
   } },

   /* replace823 -> 1177 in the cache */

   /* ('fneu', 'a(is_a_number)', 'a') => False */
   /* search824_0 -> 2430 in the cache */
   /* search824_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 2430, 32 },
      -1,
   } },

   /* replace824 -> 1024 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search825_0 -> 32 in the cache */
   /* search825_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace825 -> 32 in the cache */

   /* ('iand', 'a', -1) => a */
   /* search826_0 -> 32 in the cache */
   /* search826_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace826 -> 32 in the cache */

   /* ('iand', 'a', 0) => 0 */
   /* search827_0 -> 32 in the cache */
   /* search827_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace827 -> 61 in the cache */

   /* ('ior', 'a', 'a') => a */
   /* search828_0 -> 32 in the cache */
   /* search828_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace828 -> 32 in the cache */

   /* ('ior', 'a', 0) => a */
   /* search829_0 -> 32 in the cache */
   /* search829_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace829 -> 32 in the cache */

   /* ('ior', 'a', True) => True */
   /* search830_0 -> 706 in the cache */
   /* search830_1 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 706, 1177 },
      -1,
   } },

   /* replace830 -> 1177 in the cache */

   /* ('ixor', 'a', 'a') => 0 */
   /* search831_0 -> 32 in the cache */
   /* search831_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace831 -> 61 in the cache */

   /* ('ixor', 'a', 0) => a */
   /* search832_0 -> 32 in the cache */
   /* search832_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace832 -> 32 in the cache */

   /* ('inot', ('inot', 'a')) => a */
   /* search833_0_0 -> 32 in the cache */
   /* search833_0 -> 2162 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 2162 },
      -1,
   } },

   /* replace833 -> 32 in the cache */

   /* ('ior', ('iand', 'a', 'b'), 'b') => b */
   /* search834_0_0 -> 0 in the cache */
   /* search834_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search834_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2443, 3 },
      -1,
   } },

   /* replace834 -> 3 in the cache */

   /* ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b') */
   /* search835_0_0 -> 0 in the cache */
   /* search835_0_1 -> 3 in the cache */
   /* search835_0 -> 84 in the cache */
   /* search835_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace835_0 -> 0 in the cache */
   /* replace835_1 -> 3 in the cache */
   /* replace835 -> 2228 in the cache */

   /* ('iand', ('ior', 'a', 'b'), 'b') => b */
   /* search836_0_0 -> 0 in the cache */
   /* search836_0_1 -> 3 in the cache */
   /* search836_0 -> 84 in the cache */
   /* search836_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace836 -> 3 in the cache */

   /* ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b') */
   /* search837_0_0 -> 0 in the cache */
   /* search837_0_1 -> 3 in the cache */
   /* search837_0 -> 2443 in the cache */
   /* search837_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2443, 3 },
      -1,
   } },

   /* replace837_0 -> 0 in the cache */
   /* replace837_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b')) */
   /* search838_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search838_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2449, 2450 },
      -1,
   } },

   /* replace838_0_0 -> 0 in the cache */
   /* replace838_0_1 -> 3 in the cache */
   /* replace838_0 -> 2228 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2228 },
      -1,
   } },

   /* ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b')) */
   /* search839_0_0 -> 0 in the cache */
   /* search839_0 -> 2449 in the cache */
   /* search839_1_0 -> 3 in the cache */
   /* search839_1 -> 2450 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2449, 2450 },
      -1,
   } },

   /* replace839_0_0 -> 0 in the cache */
   /* replace839_0_1 -> 3 in the cache */
   /* replace839_0 -> 2448 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2448 },
      -1,
   } },

   /* ('ishl', 0, 'a') => 0 */
   /* search840_0 -> 1169 in the cache */
   /* search840_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1169, 16 },
      -1,
   } },

   /* replace840 -> 1169 in the cache */

   /* ('ishl', 'a', 0) => a */
   /* search841_0 -> 32 in the cache */
   /* search841_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace841 -> 32 in the cache */

   /* ('ishr', 0, 'a') => 0 */
   /* search842_0 -> 1169 in the cache */
   /* search842_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 1169, 16 },
      -1,
   } },

   /* replace842 -> 1169 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search843_0 -> 32 in the cache */
   /* search843_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace843 -> 32 in the cache */

   /* ('ushr', 0, 'a') => 0 */
   /* search844_0 -> 1169 in the cache */
   /* search844_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1169, 16 },
      -1,
   } },

   /* replace844 -> 1169 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search845_0 -> 32 in the cache */
   /* search845_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace845 -> 32 in the cache */

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search846_0_0 -> 11 in the cache */
   /* search846_0_1 -> 36 in the cache */
   /* search846_0 -> 2092 in the cache */
   /* search846_1_0 -> 11 in the cache */
   /* search846_1_1_0 -> 801 in the cache */
   /* search846_1_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 801, 2461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2462 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2092, 2463 },
      -1,
   } },

   /* replace846_0 -> 11 in the cache */
   /* replace846_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b') */
   /* search847_0_0 -> 11 in the cache */
   /* search847_0_1 -> 36 in the cache */
   /* search847_0 -> 2092 in the cache */
   /* search847_1_0 -> 11 in the cache */
   /* search847_1_1_0 -> 801 in the cache */
   /* search847_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 801, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 2466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2092, 2467 },
      -1,
   } },

   /* replace847_0 -> 11 in the cache */
   /* replace847_1 -> 36 in the cache */
   /* replace847 -> 2465 in the cache */

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search848_0_0 -> 16 in the cache */
   /* search848_0_1 -> 36 in the cache */
   /* search848_0 -> 895 in the cache */
   /* search848_1_0 -> 16 in the cache */
   /* search848_1_1_0 -> 823 in the cache */
   /* search848_1_1_1_0 -> 36 in the cache */
   /* search848_1_1_1 -> 2461 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 823, 2461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 895, 2470 },
      -1,
   } },

   /* replace848_0 -> 16 in the cache */
   /* replace848_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b') */
   /* search849_0_0 -> 16 in the cache */
   /* search849_0_1 -> 36 in the cache */
   /* search849_0 -> 895 in the cache */
   /* search849_1_0 -> 16 in the cache */
   /* search849_1_1_0 -> 823 in the cache */
   /* search849_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 823, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 2473 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 895, 2474 },
      -1,
   } },

   /* replace849_0 -> 16 in the cache */
   /* replace849_1 -> 36 in the cache */
   /* replace849 -> 2472 in the cache */

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search850_0_0 -> 11 in the cache */
   /* search850_0_1 -> 36 in the cache */
   /* search850_0 -> 2096 in the cache */
   /* search850_1_0 -> 11 in the cache */
   /* search850_1_1_0 -> 801 in the cache */
   /* search850_1_1_1_0 -> 36 in the cache */
   /* search850_1_1_1 -> 2461 in the cache */
   /* search850_1_1 -> 2462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2462 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2096, 2476 },
      -1,
   } },

   /* replace850_0 -> 11 in the cache */
   /* replace850_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b') */
   /* search851_0_0 -> 11 in the cache */
   /* search851_0_1 -> 36 in the cache */
   /* search851_0 -> 2096 in the cache */
   /* search851_1_0 -> 11 in the cache */
   /* search851_1_1_0 -> 801 in the cache */
   /* search851_1_1_1 -> 36 in the cache */
   /* search851_1_1 -> 2466 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 2466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2096, 2479 },
      -1,
   } },

   /* replace851_0 -> 11 in the cache */
   /* replace851_1 -> 36 in the cache */
   /* replace851 -> 2478 in the cache */

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search852_0_0 -> 16 in the cache */
   /* search852_0_1 -> 36 in the cache */
   /* search852_0 -> 2121 in the cache */
   /* search852_1_0 -> 16 in the cache */
   /* search852_1_1_0 -> 823 in the cache */
   /* search852_1_1_1_0 -> 36 in the cache */
   /* search852_1_1_1 -> 2461 in the cache */
   /* search852_1_1 -> 2469 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2121, 2481 },
      -1,
   } },

   /* replace852_0 -> 16 in the cache */
   /* replace852_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b') */
   /* search853_0_0 -> 16 in the cache */
   /* search853_0_1 -> 36 in the cache */
   /* search853_0 -> 2121 in the cache */
   /* search853_1_0 -> 16 in the cache */
   /* search853_1_1_0 -> 823 in the cache */
   /* search853_1_1_1 -> 36 in the cache */
   /* search853_1_1 -> 2473 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 2473 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2121, 2484 },
      -1,
   } },

   /* replace853_0 -> 16 in the cache */
   /* replace853_1 -> 36 in the cache */
   /* replace853 -> 2483 in the cache */

   /* ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b'))) */
   /* search854_0 -> 11 in the cache */
   /* search854_1 -> 36 in the cache */
   /* search854 -> 2465 in the cache */

   /* replace854_0_0 -> 11 in the cache */
   /* replace854_0_1 -> 36 in the cache */
   /* replace854_0 -> 2092 in the cache */
   /* replace854_1_0 -> 11 in the cache */
   /* replace854_1_1_0 -> 801 in the cache */
   /* replace854_1_1_1 -> 36 in the cache */
   /* replace854_1_1 -> 2466 in the cache */
   /* replace854_1 -> 2467 in the cache */
   /* replace854 -> 2468 in the cache */

   /* ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b'))) */
   /* search855_0 -> 16 in the cache */
   /* search855_1 -> 36 in the cache */
   /* search855 -> 2472 in the cache */

   /* replace855_0_0 -> 16 in the cache */
   /* replace855_0_1 -> 36 in the cache */
   /* replace855_0 -> 895 in the cache */
   /* replace855_1_0 -> 16 in the cache */
   /* replace855_1_1_0 -> 823 in the cache */
   /* replace855_1_1_1 -> 36 in the cache */
   /* replace855_1_1 -> 2473 in the cache */
   /* replace855_1 -> 2474 in the cache */
   /* replace855 -> 2475 in the cache */

   /* ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b'))) */
   /* search856_0 -> 11 in the cache */
   /* search856_1 -> 36 in the cache */
   /* search856 -> 2478 in the cache */

   /* replace856_0_0 -> 11 in the cache */
   /* replace856_0_1 -> 36 in the cache */
   /* replace856_0 -> 2096 in the cache */
   /* replace856_1_0 -> 11 in the cache */
   /* replace856_1_1_0 -> 801 in the cache */
   /* replace856_1_1_1 -> 36 in the cache */
   /* replace856_1_1 -> 2466 in the cache */
   /* replace856_1 -> 2479 in the cache */
   /* replace856 -> 2480 in the cache */

   /* ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b'))) */
   /* search857_0 -> 16 in the cache */
   /* search857_1 -> 36 in the cache */
   /* search857 -> 2483 in the cache */

   /* replace857_0_0 -> 16 in the cache */
   /* replace857_0_1 -> 36 in the cache */
   /* replace857_0 -> 2121 in the cache */
   /* replace857_1_0 -> 16 in the cache */
   /* replace857_1_1_0 -> 823 in the cache */
   /* replace857_1_1_1 -> 36 in the cache */
   /* replace857_1_1 -> 2473 in the cache */
   /* replace857_1 -> 2484 in the cache */
   /* replace857 -> 2485 in the cache */

   /* ('~fexp2', ('flog2', 'a')) => a */
   /* search858_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 2486 },
      -1,
   } },

   /* replace858 -> 32 in the cache */

   /* ('~flog2', ('fexp2', 'a')) => a */
   /* search859_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2488 },
      -1,
   } },

   /* replace859 -> 32 in the cache */

   /* ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b')) */
   /* search860_0 -> 0 in the cache */
   /* search860_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace860_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace860_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2491, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2492 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b') */
   /* search861_0_0_0 -> 0 in the cache */
   /* search861_0_0 -> 2491 in the cache */
   /* search861_0_1 -> 3 in the cache */
   /* search861_0 -> 2492 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2492 },
      -1,
   } },

   /* replace861_0 -> 0 in the cache */
   /* replace861_1 -> 3 in the cache */
   /* replace861 -> 2490 in the cache */

   /* ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd')) */
   /* search862_0_0_0_0 -> 147 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 147 },
      -1,
   } },
   /* search862_0_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 2495, 148 },
      -1,
   } },
   /* search862_0_1_0_0 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 150 },
      -1,
   } },
   /* search862_0_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 2497, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 2496, 2498 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 3,
      { 2499 },
      -1,
   } },

   /* replace862_0_0 -> 147 in the cache */
   /* replace862_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 147, 148 },
      -1,
   } },
   /* replace862_1_0 -> 150 in the cache */
   /* replace862_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2501, 2502 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a') */
   /* search863_0_0_0 -> 32 in the cache */
   /* search863_0_0 -> 2486 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2486, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2505 },
      -1,
   } },

   /* replace863_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a') */
   /* search864_0_0_0 -> 32 in the cache */
   /* search864_0_0 -> 2486 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2486, 2508 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2509 },
      -1,
   } },

   /* replace864_0 -> 32 in the cache */
   /* replace864_1 -> 32 in the cache */
   /* replace864 -> 236 in the cache */

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search865_0_0_0 -> 32 in the cache */
   /* search865_0_0 -> 2486 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4010000000000000 /* 4.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2486, 2511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2512 },
      -1,
   } },

   /* replace865_0_0 -> 32 in the cache */
   /* replace865_0_1 -> 32 in the cache */
   /* replace865_0 -> 236 in the cache */
   /* replace865_1_0 -> 32 in the cache */
   /* replace865_1_1 -> 32 in the cache */
   /* replace865_1 -> 236 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 236, 236 },
      -1,
   } },

   /* ('~fpow', 'a', 1.0) => a */
   /* search866_0 -> 32 in the cache */
   /* search866_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 226 },
      -1,
   } },

   /* replace866 -> 32 in the cache */

   /* ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a') */
   /* search867_0 -> 32 in the cache */
   /* search867_1 -> 2508 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2508 },
      -1,
   } },

   /* replace867_0 -> 32 in the cache */
   /* replace867_1 -> 32 in the cache */
   /* replace867 -> 236 in the cache */

   /* ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search868_0 -> 32 in the cache */
   /* search868_1 -> 2511 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2511 },
      -1,
   } },

   /* replace868_0_0 -> 32 in the cache */
   /* replace868_0_1 -> 32 in the cache */
   /* replace868_0 -> 236 in the cache */
   /* replace868_1_0 -> 32 in the cache */
   /* replace868_1_1 -> 32 in the cache */
   /* replace868_1 -> 236 in the cache */
   /* replace868 -> 2514 in the cache */

   /* ('~fpow', 2.0, 'a') => ('fexp2', 'a') */
   /* search869_0 -> 2508 in the cache */
   /* search869_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2508, 32 },
      -1,
   } },

   /* replace869_0 -> 32 in the cache */
   /* replace869 -> 2488 in the cache */

   /* ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a */
   /* search870_0_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x400199999999999a /* 2.2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2519 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fdd1743e963dc48 /* 0.454545 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2520, 2521 },
      -1,
   } },

   /* replace870 -> 32 in the cache */

   /* ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a') */
   /* search871_0_0_0 -> 32 in the cache */
   /* search871_0_0_1 -> 2519 in the cache */
   /* search871_0_0 -> 2520 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2520 },
      -1,
   } },
   /* search871_1 -> 2521 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2523, 2521 },
      -1,
   } },

   /* replace871_0 -> 32 in the cache */
   /* replace871 -> 103 in the cache */

   /* ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a')) */
   /* search872_0_0 -> 32 in the cache */
   /* search872_0 -> 2488 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 2488 },
      -1,
   } },

   /* replace872_0_0 -> 2504 in the cache */
   /* replace872_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2504, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2526 },
      -1,
   } },

   /* ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a')) */
   /* search873_0_0 -> 32 in the cache */
   /* search873_0 -> 2488 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2488 },
      -1,
   } },

   /* replace873_0_0 -> 32 in the cache */
   /* replace873_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 98 },
      -1,
   } },

   /* ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a')) */
   /* search874_0_0 -> 32 in the cache */
   /* search874_0 -> 2488 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 2488 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbfe0000000000000 /* -0.5 */ },
   } },
   /* replace874_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2531, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2532 },
      -1,
   } },

   /* ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a')) */
   /* search875_0_0 -> 32 in the cache */
   /* search875_0 -> 2507 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2507 },
      -1,
   } },

   /* replace875_0 -> 2504 in the cache */
   /* replace875_1_0 -> 32 in the cache */
   /* replace875_1 -> 2486 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2504, 2486 },
      -1,
   } },

   /* ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a')) */
   /* search876_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2536 },
      -1,
   } },

   /* replace876_0_0 -> 32 in the cache */
   /* replace876_0 -> 2486 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2486 },
      -1,
   } },

   /* ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a')) */
   /* search877_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2539 },
      -1,
   } },

   /* replace877_0 -> 2531 in the cache */
   /* replace877_1_0 -> 32 in the cache */
   /* replace877_1 -> 2486 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2531, 2486 },
      -1,
   } },

   /* ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a')) */
   /* search878_0_0 -> 0 in the cache */
   /* search878_0_1 -> 3 in the cache */
   /* search878_0 -> 2490 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2490 },
      -1,
   } },

   /* replace878_0 -> 3 in the cache */
   /* replace878_1_0 -> 0 in the cache */
   /* replace878_1 -> 2491 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 2491 },
      -1,
   } },

   /* ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b')) */
   /* search879_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 0 },
      0,
   } },
   /* search879_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2544, 2545 },
      -1,
   } },

   /* replace879_0_0 -> 0 in the cache */
   /* replace879_0_1 -> 3 in the cache */
   /* replace879_0 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 257 },
      -1,
   } },

   /* ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0)) */
   /* search880_0_0 -> 32 in the cache */
   /* search880_0_1 -> 113 in the cache */
   /* search880_0 -> 670 in the cache */
   /* search880_1 -> 113 in the cache */
   /* search880_2_0 -> 32 in the cache */
   /* search880_2 -> 2507 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 670, 113, 2507 },
      -1,
   } },

   /* replace880_0_0 -> 32 in the cache */
   /* replace880_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 1,
      { 2549 },
      -1,
   } },

   /* ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search881_0_0 -> 32 in the cache */
   /* search881_0 -> 2507 in the cache */
   /* search881_1_0 -> 32 in the cache */
   /* search881_1 -> 2507 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 2507, 2507 },
      -1,
   } },

   /* replace881_0 -> 32 in the cache */
   /* replace881 -> 103 in the cache */

   /* ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search882_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search882_1_0 -> 16 in the cache */
   /* search882_1 -> 2552 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 2552, 2552 },
      -1,
   } },

   /* replace882_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~fdiv', 1.0, 'a') => ('frcp', 'a') */
   /* search883_0 -> 226 in the cache */
   /* search883_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 226, 32 },
      -1,
   } },

   /* replace883_0 -> 32 in the cache */
   /* replace883 -> 2536 in the cache */

   /* ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b')) */
   /* search884_0 -> 0 in the cache */
   /* search884_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace884_0 -> 0 in the cache */
   /* replace884_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2557 },
      -1,
   } },

   /* ('~frcp', ('frcp', 'a')) => a */
   /* search885_0_0 -> 32 in the cache */
   /* search885_0 -> 2536 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2536 },
      -1,
   } },

   /* replace885 -> 32 in the cache */

   /* ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a') */
   /* search886_0_0 -> 32 in the cache */
   /* search886_0 -> 2507 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2507 },
      -1,
   } },

   /* replace886_0 -> 32 in the cache */
   /* replace886 -> 2539 in the cache */

   /* ('fsqrt', 'a') => ('frcp', ('frsq', 'a')) */
   /* search887_0 -> 32 in the cache */
   /* search887 -> 2507 in the cache */

   /* replace887_0_0 -> 32 in the cache */
   /* replace887_0 -> 2539 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2539 },
      -1,
   } },

   /* ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a') */
   /* search888_0_0 -> 32 in the cache */
   /* search888_0 -> 2539 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2539 },
      -1,
   } },

   /* replace888_0 -> 32 in the cache */
   /* replace888 -> 2507 in the cache */

   /* ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)) */
   /* search889_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace889_0_0_0_0_0_0 -> 2508 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fc45f306dc9c883 /* 0.15915494309189535 */ },
   } },
   /* replace889_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      5, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_0_0_0_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2565, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2566 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2508, 2567 },
      -1,
   } },
   /* replace889_0_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2568, 226 },
      -1,
   } },
   /* replace889_0_0_0_1_0_0_0 -> 2508 in the cache */
   /* replace889_0_0_0_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      9, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_0_0_0_1_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2570, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2508, 2572 },
      -1,
   } },
   /* replace889_0_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2573, 226 },
      -1,
   } },
   /* replace889_0_0_0_1_1_0_0_0 -> 2508 in the cache */
   /* replace889_0_0_0_1_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      12, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_0_0_0_1_1_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2575, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2508, 2577 },
      -1,
   } },
   /* replace889_0_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2578, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2579 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2574, 2580 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2569, 2581 },
      -1,
   } },
   /* replace889_0_0_1 -> 2511 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2582, 2511 },
      -1,
   } },
   /* replace889_0_1_0_0_0_0_0 -> 2508 in the cache */
   /* replace889_0_1_0_0_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      16, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_0_1_0_0_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2584, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2508, 2586 },
      -1,
   } },
   /* replace889_0_1_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2587, 226 },
      -1,
   } },
   /* replace889_0_1_0_0_1_0_0_0 -> 2508 in the cache */
   /* replace889_0_1_0_0_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      20, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_0_1_0_0_1_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2589, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2590 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2508, 2591 },
      -1,
   } },
   /* replace889_0_1_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2592, 226 },
      -1,
   } },
   /* replace889_0_1_0_0_1_1_0_0_0 -> 2508 in the cache */
   /* replace889_0_1_0_0_1_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      23, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_0_1_0_0_1_1_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2594, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2595 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2508, 2596 },
      -1,
   } },
   /* replace889_0_1_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2597, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2598 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2593, 2599 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2588, 2600 },
      -1,
   } },
   /* replace889_0_1_0_1 -> 2511 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2601, 2511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2602 },
      -1,
   } },
   /* replace889_0_2_0_0_0_0_0 -> 2508 in the cache */
   /* replace889_0_2_0_0_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      27, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_0_2_0_0_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2604, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2605 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2508, 2606 },
      -1,
   } },
   /* replace889_0_2_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2607, 226 },
      -1,
   } },
   /* replace889_0_2_0_0_1_0_0_0 -> 2508 in the cache */
   /* replace889_0_2_0_0_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      31, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_0_2_0_0_1_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2609, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2508, 2611 },
      -1,
   } },
   /* replace889_0_2_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2612, 226 },
      -1,
   } },
   /* replace889_0_2_0_0_1_1_0_0_0 -> 2508 in the cache */
   /* replace889_0_2_0_0_1_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      34, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_0_2_0_0_1_1_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2614, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2615 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2508, 2616 },
      -1,
   } },
   /* replace889_0_2_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2617, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2618 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2613, 2619 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2608, 2620 },
      -1,
   } },
   /* replace889_0_2_0_1 -> 2511 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2621, 2511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2622 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2583, 2603, 2623 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fcccccccccccccd /* 0.225 */ },
   } },
   /* replace889_2_0_0_0_0 -> 2508 in the cache */
   /* replace889_2_0_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_2_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      38, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_2_0_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2626, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2508, 2628 },
      -1,
   } },
   /* replace889_2_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2629, 226 },
      -1,
   } },
   /* replace889_2_0_1_0_0_0 -> 2508 in the cache */
   /* replace889_2_0_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      42, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_2_0_1_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2631, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2632 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2508, 2633 },
      -1,
   } },
   /* replace889_2_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2634, 226 },
      -1,
   } },
   /* replace889_2_0_1_1_0_0_0 -> 2508 in the cache */
   /* replace889_2_0_1_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace889_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      45, 1,
      { 2564, 32 },
      -1,
   } },
   /* replace889_2_0_1_1_0_0_1_0_1 -> 2504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2636, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2637 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2508, 2638 },
      -1,
   } },
   /* replace889_2_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2639, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2640 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2635, 2641 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2630, 2642 },
      -1,
   } },
   /* replace889_2_1 -> 2511 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2643, 2511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2624, 2625, 2644 },
      -1,
   } },

   /* ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)) */
   /* search890_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace890_0_0_0_0_0_0 -> 2508 in the cache */
   /* replace890_0_0_0_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_0_0_0_0_0_1_0_0 -> 2565 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe8000000000000 /* 0.75 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2565, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2648 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2508, 2649 },
      -1,
   } },
   /* replace890_0_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2650, 226 },
      -1,
   } },
   /* replace890_0_0_0_1_0_0_0 -> 2508 in the cache */
   /* replace890_0_0_0_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_0_0_0_1_0_0_1_0_0 -> 2570 in the cache */
   /* replace890_0_0_0_1_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2570, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2652 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2508, 2653 },
      -1,
   } },
   /* replace890_0_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2654, 226 },
      -1,
   } },
   /* replace890_0_0_0_1_1_0_0_0 -> 2508 in the cache */
   /* replace890_0_0_0_1_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_0_0_0_1_1_0_0_1_0_0 -> 2575 in the cache */
   /* replace890_0_0_0_1_1_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2575, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2656 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2508, 2657 },
      -1,
   } },
   /* replace890_0_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2658, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2659 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2655, 2660 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2651, 2661 },
      -1,
   } },
   /* replace890_0_0_1 -> 2511 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2662, 2511 },
      -1,
   } },
   /* replace890_0_1_0_0_0_0_0 -> 2508 in the cache */
   /* replace890_0_1_0_0_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_0_1_0_0_0_0_1_0_0 -> 2584 in the cache */
   /* replace890_0_1_0_0_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2584, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2508, 2665 },
      -1,
   } },
   /* replace890_0_1_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2666, 226 },
      -1,
   } },
   /* replace890_0_1_0_0_1_0_0_0 -> 2508 in the cache */
   /* replace890_0_1_0_0_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_0_1_0_0_1_0_0_1_0_0 -> 2589 in the cache */
   /* replace890_0_1_0_0_1_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2589, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2668 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2508, 2669 },
      -1,
   } },
   /* replace890_0_1_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2670, 226 },
      -1,
   } },
   /* replace890_0_1_0_0_1_1_0_0_0 -> 2508 in the cache */
   /* replace890_0_1_0_0_1_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_0_1_0_0_1_1_0_0_1_0_0 -> 2594 in the cache */
   /* replace890_0_1_0_0_1_1_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2594, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2672 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2508, 2673 },
      -1,
   } },
   /* replace890_0_1_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2674, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2671, 2676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2667, 2677 },
      -1,
   } },
   /* replace890_0_1_0_1 -> 2511 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2678, 2511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2679 },
      -1,
   } },
   /* replace890_0_2_0_0_0_0_0 -> 2508 in the cache */
   /* replace890_0_2_0_0_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_0_2_0_0_0_0_1_0_0 -> 2604 in the cache */
   /* replace890_0_2_0_0_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2604, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2681 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2508, 2682 },
      -1,
   } },
   /* replace890_0_2_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2683, 226 },
      -1,
   } },
   /* replace890_0_2_0_0_1_0_0_0 -> 2508 in the cache */
   /* replace890_0_2_0_0_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_0_2_0_0_1_0_0_1_0_0 -> 2609 in the cache */
   /* replace890_0_2_0_0_1_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2609, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2685 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2508, 2686 },
      -1,
   } },
   /* replace890_0_2_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2687, 226 },
      -1,
   } },
   /* replace890_0_2_0_0_1_1_0_0_0 -> 2508 in the cache */
   /* replace890_0_2_0_0_1_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_0_2_0_0_1_1_0_0_1_0_0 -> 2614 in the cache */
   /* replace890_0_2_0_0_1_1_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2614, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2689 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2508, 2690 },
      -1,
   } },
   /* replace890_0_2_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2691, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2692 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2688, 2693 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2684, 2694 },
      -1,
   } },
   /* replace890_0_2_0_1 -> 2511 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2695, 2511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2696 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2663, 2680, 2697 },
      -1,
   } },
   /* replace890_1 -> 2625 in the cache */
   /* replace890_2_0_0_0_0 -> 2508 in the cache */
   /* replace890_2_0_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_2_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_2_0_0_0_1_0_0 -> 2626 in the cache */
   /* replace890_2_0_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2626, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2699 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2508, 2700 },
      -1,
   } },
   /* replace890_2_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2701, 226 },
      -1,
   } },
   /* replace890_2_0_1_0_0_0 -> 2508 in the cache */
   /* replace890_2_0_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_2_0_1_0_0_1_0_0 -> 2631 in the cache */
   /* replace890_2_0_1_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2631, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2508, 2704 },
      -1,
   } },
   /* replace890_2_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2705, 226 },
      -1,
   } },
   /* replace890_2_0_1_1_0_0_0 -> 2508 in the cache */
   /* replace890_2_0_1_1_0_0_1_0_0_0 -> 2564 in the cache */
   /* replace890_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace890_2_0_1_1_0_0_1_0_0 -> 2636 in the cache */
   /* replace890_2_0_1_1_0_0_1_0_1 -> 2647 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2636, 2647 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2707 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2508, 2708 },
      -1,
   } },
   /* replace890_2_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2709, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2706, 2711 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2702, 2712 },
      -1,
   } },
   /* replace890_2_1 -> 2511 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2713, 2511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2698, 2625, 2714 },
      -1,
   } },

   /* ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0) */
   /* search891_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace891_0 -> 32 in the cache */
   /* replace891_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ine16,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0) */
   /* search892_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace892_0 -> 32 in the cache */
   /* replace892_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ine32,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0) */
   /* search893_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace893_0 -> 32 in the cache */
   /* replace893_1 -> 61 in the cache */
   /* replace893 -> 1173 in the cache */

   /* ('ieq', 'a', True) => a */
   /* search894_0 -> 706 in the cache */
   /* search894_1 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 706, 1177 },
      -1,
   } },

   /* replace894 -> 706 in the cache */

   /* ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a') */
   /* search895_0 -> 706 in the cache */
   /* search895_1 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 706, 1177 },
      3,
   } },

   /* replace895_0 -> 706 in the cache */
   /* replace895 -> 1072 in the cache */

   /* ('ine', 'a', False) => a */
   /* search896_0 -> 706 in the cache */
   /* search896_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 706, 1024 },
      -1,
   } },

   /* replace896 -> 706 in the cache */

   /* ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a') */
   /* search897_0 -> 706 in the cache */
   /* search897_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 706, 1024 },
      3,
   } },

   /* replace897_0 -> 706 in the cache */
   /* replace897 -> 1072 in the cache */

   /* ('bcsel', 'a', True, False) => a */
   /* search898_0 -> 706 in the cache */
   /* search898_1 -> 1177 in the cache */
   /* search898_2 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1177, 1024 },
      -1,
   } },

   /* replace898 -> 706 in the cache */

   /* ('bcsel', 'a', False, True) => ('inot', 'a') */
   /* search899_0 -> 706 in the cache */
   /* search899_1 -> 1024 in the cache */
   /* search899_2 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1024, 1177 },
      -1,
   } },

   /* replace899_0 -> 706 in the cache */
   /* replace899 -> 1072 in the cache */

   /* ('bcsel', True, 'b', 'c') => b */
   /* search900_0 -> 1177 in the cache */
   /* search900_1 -> 1058 in the cache */
   /* search900_2 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1177, 1058, 665 },
      -1,
   } },

   /* replace900 -> 1058 in the cache */

   /* ('bcsel', False, 'b', 'c') => c */
   /* search901_0 -> 1024 in the cache */
   /* search901_1 -> 1058 in the cache */
   /* search901_2 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1024, 1058, 665 },
      -1,
   } },

   /* replace901 -> 665 in the cache */

   /* ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search902_0 -> 706 in the cache */
   /* search902_1 -> 462 in the cache */
   /* search902_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 462, 115 },
      -1,
   } },

   /* replace902_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search903_0 -> 706 in the cache */
   /* search903_1 -> 115 in the cache */
   /* search903_2 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 115, 462 },
      -1,
   } },

   /* replace903_0_0 -> 706 in the cache */
   /* replace903_0 -> 1072 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1072 },
      -1,
   } },

   /* ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search904_0 -> 706 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 2733, 2734 },
      -1,
   } },

   /* replace904_0_0 -> 706 in the cache */
   /* replace904_0 -> 2730 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2730 },
      -1,
   } },

   /* ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search905_0 -> 706 in the cache */
   /* search905_1 -> 2734 in the cache */
   /* search905_2 -> 2733 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 2734, 2733 },
      -1,
   } },

   /* replace905_0_0_0 -> 706 in the cache */
   /* replace905_0_0 -> 1072 in the cache */
   /* replace905_0 -> 2732 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2732 },
      -1,
   } },

   /* ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search906_0 -> 706 in the cache */
   /* search906_1 -> 228 in the cache */
   /* search906_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 228, 117 },
      -1,
   } },

   /* replace906_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search907_0 -> 706 in the cache */
   /* search907_1 -> 117 in the cache */
   /* search907_2 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 117, 228 },
      -1,
   } },

   /* replace907_0_0 -> 706 in the cache */
   /* replace907_0 -> 1072 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1072 },
      -1,
   } },

   /* ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search908_0 -> 706 in the cache */
   /* search908_1 -> 263 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 263, 2743 },
      -1,
   } },

   /* replace908_0_0 -> 706 in the cache */
   /* replace908_0 -> 2740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2740 },
      -1,
   } },

   /* ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search909_0 -> 706 in the cache */
   /* search909_1 -> 2743 in the cache */
   /* search909_2 -> 263 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 2743, 263 },
      -1,
   } },

   /* replace909_0_0_0 -> 706 in the cache */
   /* replace909_0_0 -> 1072 in the cache */
   /* replace909_0 -> 2742 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2742 },
      -1,
   } },

   /* ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search910_0 -> 706 in the cache */
   /* search910_1 -> 603 in the cache */
   /* search910_2 -> 1856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 603, 1856 },
      -1,
   } },

   /* replace910_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search911_0 -> 706 in the cache */
   /* search911_1 -> 1856 in the cache */
   /* search911_2 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1856, 603 },
      -1,
   } },

   /* replace911_0_0 -> 706 in the cache */
   /* replace911_0 -> 1072 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1072 },
      -1,
   } },

   /* ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search912_0 -> 706 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 2752, 2753 },
      -1,
   } },

   /* replace912_0_0 -> 706 in the cache */
   /* replace912_0 -> 2749 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2749 },
      -1,
   } },

   /* ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search913_0 -> 706 in the cache */
   /* search913_1 -> 2753 in the cache */
   /* search913_2 -> 2752 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 2753, 2752 },
      -1,
   } },

   /* replace913_0_0_0 -> 706 in the cache */
   /* replace913_0_0 -> 1072 in the cache */
   /* replace913_0 -> 2751 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2751 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', 'b') => b */
   /* search914_0 -> 706 in the cache */
   /* search914_1 -> 3 in the cache */
   /* search914_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 3, 3 },
      -1,
   } },

   /* replace914 -> 3 in the cache */

   /* ('~fcsel', 'a', 'b', 'b') => b */
   /* search915_0 -> 16 in the cache */
   /* search915_1 -> 36 in the cache */
   /* search915_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 16, 36, 36 },
      -1,
   } },

   /* replace915 -> 36 in the cache */

   /* ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1')) */
   /* search916_0 -> 706 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* search916_2 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 2760, 1169 },
      -1,
   } },

   /* replace916_0_0 -> 706 in the cache */
   /* replace916_0 -> 1168 in the cache */
   /* replace916 -> 2164 in the cache */

   /* ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a'))) */
   /* search917_0 -> 706 in the cache */
   /* search917_1 -> 1169 in the cache */
   /* search917_2 -> 2760 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1169, 2760 },
      -1,
   } },

   /* replace917_0_0_0 -> 706 in the cache */
   /* replace917_0_0 -> 1072 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1072 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2763 },
      -1,
   } },

   /* ('bcsel', 'a', 1, 0) => ('b2i', 'a@1') */
   /* search918_0 -> 706 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   /* search918_2 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 2765, 1169 },
      -1,
   } },

   /* replace918_0 -> 706 in the cache */
   /* replace918 -> 1168 in the cache */

   /* ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a')) */
   /* search919_0 -> 706 in the cache */
   /* search919_1 -> 1169 in the cache */
   /* search919_2 -> 2765 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1169, 2765 },
      -1,
   } },

   /* replace919_0_0 -> 706 in the cache */
   /* replace919_0 -> 1072 in the cache */
   /* replace919 -> 2763 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search920_0_0_0 -> 706 in the cache */
   /* search920_0_0 -> 1168 in the cache */
   /* search920_0 -> 2164 in the cache */
   /* search920_1_0_0 -> 1075 in the cache */
   /* search920_1_0 -> 2165 in the cache */
   /* search920_1 -> 2166 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2164, 2166 },
      -1,
   } },

   /* replace920_0_0_0 -> 706 in the cache */
   /* replace920_0_0_1 -> 1075 in the cache */
   /* replace920_0_0 -> 1087 in the cache */
   /* replace920_0 -> 2410 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2410 },
      -1,
   } },

   /* ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search921_0_0_0 -> 706 in the cache */
   /* search921_0_0 -> 1168 in the cache */
   /* search921_0 -> 2164 in the cache */
   /* search921_1_0_0 -> 1075 in the cache */
   /* search921_1_0 -> 2165 in the cache */
   /* search921_1 -> 2166 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2164, 2166 },
      -1,
   } },

   /* replace921_0_0_0 -> 706 in the cache */
   /* replace921_0_0_1 -> 1075 in the cache */
   /* replace921_0_0 -> 1079 in the cache */
   /* replace921_0 -> 2413 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2413 },
      -1,
   } },

   /* ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search922_0_0_0 -> 706 in the cache */
   /* search922_0_0 -> 1168 in the cache */
   /* search922_0 -> 2164 in the cache */
   /* search922_1 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2164, 1169 },
      -1,
   } },

   /* replace922_0 -> 706 in the cache */
   /* replace922 -> 1072 in the cache */

   /* ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a */
   /* search923_0_0_0 -> 706 in the cache */
   /* search923_0_0 -> 1168 in the cache */
   /* search923_0 -> 2164 in the cache */
   /* search923_1 -> 2760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2164, 2760 },
      -1,
   } },

   /* replace923 -> 706 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search924_0_0_0 -> 706 in the cache */
   /* search924_0_0 -> 1168 in the cache */
   /* search924_0 -> 2164 in the cache */
   /* search924_1 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2164, 1169 },
      -1,
   } },

   /* replace924 -> 706 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a') */
   /* search925_0_0_0 -> 706 in the cache */
   /* search925_0_0 -> 1168 in the cache */
   /* search925_0 -> 2164 in the cache */
   /* search925_1 -> 2760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2164, 2760 },
      -1,
   } },

   /* replace925_0 -> 706 in the cache */
   /* replace925 -> 1072 in the cache */

   /* ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search926_0_0_0 -> 706 in the cache */
   /* search926_0_0 -> 1168 in the cache */
   /* search926_0 -> 2164 in the cache */
   /* search926_1 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2164, 1169 },
      -1,
   } },

   /* replace926_0 -> 706 in the cache */
   /* replace926 -> 1072 in the cache */

   /* ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search927_0_0_0 -> 706 in the cache */
   /* search927_0_0 -> 1168 in the cache */
   /* search927_0 -> 2164 in the cache */
   /* search927_1 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2164, 1169 },
      -1,
   } },

   /* replace927 -> 706 in the cache */

   /* ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a */
   /* search928_0 -> 1169 in the cache */
   /* search928_1_0_0 -> 706 in the cache */
   /* search928_1_0 -> 1168 in the cache */
   /* search928_1 -> 2164 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1169, 2164 },
      -1,
   } },

   /* replace928 -> 706 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a') */
   /* search929_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2779 },
      -1,
   } },
   /* search929_1 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2780, 1080 },
      -1,
   } },

   /* replace929_0 -> 32 in the cache */
   /* replace929 -> 1457 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a') */
   /* search930_0_0_0 -> 32 in the cache */
   /* search930_0_0 -> 2779 in the cache */
   /* search930_0 -> 2780 in the cache */
   /* search930_1 -> 2765 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2780, 2765 },
      -1,
   } },

   /* replace930_0 -> 32 in the cache */
   /* replace930 -> 2779 in the cache */

   /* ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search931_0_0_0 -> 706 in the cache */
   /* search931_0_0 -> 1168 in the cache */
   /* search931_0 -> 2164 in the cache */
   /* search931_1_0_0 -> 1075 in the cache */
   /* search931_1_0 -> 2165 in the cache */
   /* search931_1 -> 2166 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2164, 2166 },
      -1,
   } },

   /* replace931_0_0_0 -> 706 in the cache */
   /* replace931_0_0_1 -> 1075 in the cache */
   /* replace931_0_0 -> 1087 in the cache */
   /* replace931_0 -> 2410 in the cache */
   /* replace931 -> 2769 in the cache */

   /* ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search932_0_0_0 -> 706 in the cache */
   /* search932_0_0 -> 1168 in the cache */
   /* search932_0 -> 2164 in the cache */
   /* search932_1_0_0 -> 1075 in the cache */
   /* search932_1_0 -> 2165 in the cache */
   /* search932_1 -> 2166 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2164, 2166 },
      -1,
   } },

   /* replace932_0_0_0 -> 706 in the cache */
   /* replace932_0_0_1 -> 1075 in the cache */
   /* replace932_0_0 -> 1079 in the cache */
   /* replace932_0 -> 2413 in the cache */
   /* replace932 -> 2771 in the cache */

   /* ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search933_0_0_0 -> 706 in the cache */
   /* search933_0_0 -> 1168 in the cache */
   /* search933_0 -> 2164 in the cache */
   /* search933_1_0_0 -> 1075 in the cache */
   /* search933_1_0 -> 2165 in the cache */
   /* search933_1 -> 2166 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2164, 2166 },
      -1,
   } },

   /* replace933_0_0_0 -> 706 in the cache */
   /* replace933_0_0_1 -> 1075 in the cache */
   /* replace933_0_0 -> 1079 in the cache */
   /* replace933_0 -> 2413 in the cache */
   /* replace933 -> 2771 in the cache */

   /* ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search934_0_0_0 -> 706 in the cache */
   /* search934_0_0 -> 1168 in the cache */
   /* search934_0 -> 2164 in the cache */
   /* search934_1_0_0 -> 1075 in the cache */
   /* search934_1_0 -> 2165 in the cache */
   /* search934_1 -> 2166 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2164, 2166 },
      -1,
   } },

   /* replace934_0_0_0 -> 706 in the cache */
   /* replace934_0_0_1 -> 1075 in the cache */
   /* replace934_0_0 -> 1087 in the cache */
   /* replace934_0 -> 2410 in the cache */
   /* replace934 -> 2769 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search935_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 2787 },
      -1,
   } },

   /* replace935 -> 11 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search936_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 2789 },
      -1,
   } },

   /* replace936 -> 16 in the cache */

   /* ('f2i', ('ftrunc', 'a')) => ('f2i', 'a') */
   /* search937_0_0 -> 32 in the cache */
   /* search937_0 -> 669 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 669 },
      -1,
   } },

   /* replace937_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2u', ('ftrunc', 'a')) => ('f2u', 'a') */
   /* search938_0_0 -> 32 in the cache */
   /* search938_0 -> 669 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 669 },
      -1,
   } },

   /* replace938_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search939_0_0 -> 32 in the cache */
   /* search939_0 -> 100 in the cache */
   /* search939 -> 111 in the cache */

   /* replace939_0 -> 32 in the cache */
   /* replace939 -> 112 in the cache */

   /* ('i2b', ('iabs', 'a')) => ('i2b', 'a') */
   /* search940_0_0 -> 32 in the cache */
   /* search940_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace940_0 -> 32 in the cache */
   /* replace940 -> 112 in the cache */

   /* ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0) */
   /* search941_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 2796 },
      -1,
   } },

   /* replace941_0 -> 32 in the cache */
   /* replace941_1 -> 113 in the cache */
   /* replace941 -> 1199 in the cache */

   /* ('f2fmp', ('f2f32', 'a@16')) => a */
   /* search942_0_0 -> 11 in the cache */
   /* search942_0 -> 1730 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1730 },
      -1,
   } },

   /* replace942 -> 11 in the cache */

   /* ('i2imp', ('i2i32', 'a@16')) => a */
   /* search943_0_0 -> 11 in the cache */
   /* search943_0 -> 1732 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1732 },
      -1,
   } },

   /* replace943 -> 11 in the cache */

   /* ('i2imp', ('u2u32', 'a@16')) => a */
   /* search944_0_0 -> 11 in the cache */
   /* search944_0 -> 1734 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1734 },
      -1,
   } },

   /* replace944 -> 11 in the cache */

   /* ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a') */
   /* search945_0_0 -> 11 in the cache */
   /* search945_0 -> 1730 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1730 },
      -1,
   } },

   /* replace945_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a') */
   /* search946_0_0 -> 11 in the cache */
   /* search946_0 -> 1730 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1730 },
      -1,
   } },

   /* replace946_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a') */
   /* search947_0_0 -> 11 in the cache */
   /* search947_0 -> 1732 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1732 },
      -1,
   } },

   /* replace947_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a') */
   /* search948_0_0 -> 11 in the cache */
   /* search948_0 -> 1734 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1734 },
      -1,
   } },

   /* replace948_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search949_0_0 -> 706 in the cache */
   /* search949_0 -> 1337 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1337 },
      -1,
   } },

   /* replace949_0 -> 706 in the cache */
   /* replace949 -> 1333 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search950_0_0 -> 706 in the cache */
   /* search950_0 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1325 },
      -1,
   } },

   /* replace950_0 -> 706 in the cache */
   /* replace950 -> 1321 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search951_0_0 -> 706 in the cache */
   /* search951_0 -> 1325 in the cache */
   /* search951 -> 2810 in the cache */

   /* replace951_0 -> 706 in the cache */
   /* replace951 -> 1321 in the cache */

   /* ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search952_0_0 -> 706 in the cache */
   /* search952_0 -> 1337 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1337 },
      -1,
   } },

   /* replace952_0 -> 706 in the cache */
   /* replace952 -> 1321 in the cache */

   /* ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search953_0_0 -> 706 in the cache */
   /* search953_0 -> 1337 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1337 },
      -1,
   } },

   /* replace953_0 -> 706 in the cache */
   /* replace953 -> 1321 in the cache */

   /* ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search954_0_0 -> 706 in the cache */
   /* search954_0 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1325 },
      -1,
   } },

   /* replace954_0 -> 706 in the cache */
   /* replace954 -> 1333 in the cache */

   /* ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search955_0_0 -> 706 in the cache */
   /* search955_0 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1325 },
      -1,
   } },

   /* replace955_0 -> 706 in the cache */
   /* replace955 -> 1333 in the cache */

   /* ('f2f32', ('f2fmp', 'a@32')) => a */
   /* search956_0_0 -> 16 in the cache */
   /* search956_0 -> 1926 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1926 },
      -1,
   } },

   /* replace956 -> 16 in the cache */

   /* ('i2i32', ('i2imp', 'a@32')) => a */
   /* search957_0_0 -> 16 in the cache */
   /* search957_0 -> 1937 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1937 },
      -1,
   } },

   /* replace957 -> 16 in the cache */

   /* ('u2u32', ('i2imp', 'a@32')) => a */
   /* search958_0_0 -> 16 in the cache */
   /* search958_0 -> 1937 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1937 },
      -1,
   } },

   /* replace958 -> 16 in the cache */

   /* ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a') */
   /* search959_0_0 -> 16 in the cache */
   /* search959_0 -> 1936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1936 },
      -1,
   } },

   /* replace959_0 -> 16 in the cache */
   /* replace959 -> 1934 in the cache */

   /* ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a') */
   /* search960_0_0 -> 16 in the cache */
   /* search960_0 -> 1933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1933 },
      -1,
   } },

   /* replace960_0 -> 16 in the cache */
   /* replace960 -> 1931 in the cache */

   /* ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a') */
   /* search961_0_0 -> 16 in the cache */
   /* search961_0 -> 1925 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1925 },
      -1,
   } },

   /* replace961_0 -> 16 in the cache */
   /* replace961 -> 1923 in the cache */

   /* ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a') */
   /* search962_0_0 -> 16 in the cache */
   /* search962_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace962_0 -> 16 in the cache */
   /* replace962 -> 1920 in the cache */

   /* ('~f2f32', ('f2f64', 'a@32')) => a */
   /* search963_0_0 -> 16 in the cache */
   /* search963_0 -> 1837 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1837 },
      -1,
   } },

   /* replace963 -> 16 in the cache */

   /* ('ffloor', 'a(is_integral)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 2823 },
      -1,
   } },

   /* replace964 -> 32 in the cache */

   /* ('fceil', 'a(is_integral)') => a */
   /* search965_0 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 2823 },
      -1,
   } },

   /* replace965 -> 32 in the cache */

   /* ('ftrunc', 'a(is_integral)') => a */
   /* search966_0 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 2823 },
      -1,
   } },

   /* replace966 -> 32 in the cache */

   /* ('~ffract', 'a(is_integral)') => 0.0 */
   /* search967_0 -> 2823 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 2823 },
      -1,
   } },

   /* replace967 -> 113 in the cache */

   /* ('fabs', 'a(is_not_negative)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2828 },
      -1,
   } },

   /* replace968 -> 32 in the cache */

   /* ('iabs', 'a(is_not_negative)') => a */
   /* search969_0 -> 2828 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2828 },
      -1,
   } },

   /* replace969 -> 32 in the cache */

   /* ('fsat', 'a(is_not_positive)') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 2831 },
      -1,
   } },

   /* replace970 -> 113 in the cache */

   /* ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a') */
   /* search971_0 -> 2828 in the cache */
   /* search971_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2828, 226 },
      -1,
   } },

   /* replace971_0 -> 32 in the cache */
   /* replace971 -> 202 in the cache */

   /* ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search972_0_0_0_0 -> 32 in the cache */
   /* search972_0_0_0 -> 202 in the cache */
   /* search972_0_0_1_0_0 -> 32 in the cache */
   /* search972_0_0_1_0 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 202, 2834 },
      -1,
   } },
   /* search972_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 2835, 226 },
      -1,
   } },
   /* search972_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 2836, 113 },
      -1,
   } },

   /* replace972 -> 1024 in the cache */

   /* ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search973_0_0_0_0_0 -> 32 in the cache */
   /* search973_0_0_0_0 -> 202 in the cache */
   /* search973_0_0_0_1_0 -> 32 in the cache */
   /* search973_0_0_0_1 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 202, 202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2838 },
      -1,
   } },
   /* search973_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 2839, 226 },
      -1,
   } },
   /* search973_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2840, 113 },
      -1,
   } },

   /* replace973 -> 1024 in the cache */

   /* ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0) */
   /* search974_0_0_0_0 -> 32 in the cache */
   /* search974_0_0_0 -> 202 in the cache */
   /* search974_0_0_1_0_0 -> 32 in the cache */
   /* search974_0_0_1_0 -> 202 in the cache */
   /* search974_0_0_1 -> 2834 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 202, 2834 },
      -1,
   } },
   /* search974_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 2842, 226 },
      -1,
   } },
   /* search974_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 2843, 113 },
      -1,
   } },

   /* replace974_0_0_0 -> 32 in the cache */
   /* replace974_0_0 -> 202 in the cache */
   /* replace974_0_1_0_0 -> 32 in the cache */
   /* replace974_0_1_0 -> 202 in the cache */
   /* replace974_0_1 -> 2834 in the cache */
   /* replace974_0 -> 2835 in the cache */
   /* replace974_1 -> 226 in the cache */
   /* replace974 -> 2836 in the cache */

   /* ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0) */
   /* search975_0_0_0_0_0 -> 32 in the cache */
   /* search975_0_0_0_0 -> 202 in the cache */
   /* search975_0_0_0_1_0 -> 32 in the cache */
   /* search975_0_0_0_1 -> 202 in the cache */
   /* search975_0_0_0 -> 2838 in the cache */
   /* search975_0_0 -> 2839 in the cache */
   /* search975_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 2839, 226 },
      -1,
   } },
   /* search975_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 2845, 113 },
      -1,
   } },

   /* replace975_0_0_0_0 -> 32 in the cache */
   /* replace975_0_0_0 -> 202 in the cache */
   /* replace975_0_0_1_0 -> 32 in the cache */
   /* replace975_0_0_1 -> 202 in the cache */
   /* replace975_0_0 -> 2838 in the cache */
   /* replace975_0 -> 2839 in the cache */
   /* replace975_1 -> 226 in the cache */
   /* replace975 -> 2840 in the cache */

   /* ('fneu', 'a(is_not_zero)', 0.0) => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search976_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2847, 113 },
      -1,
   } },

   /* replace976 -> 1177 in the cache */

   /* ('feq', 'a(is_not_zero)', 0.0) => False */
   /* search977_0 -> 2847 in the cache */
   /* search977_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2847, 113 },
      -1,
   } },

   /* replace977 -> 1024 in the cache */

   /* ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2850, 2851 },
      -1,
   } },

   /* replace978 -> 1177 in the cache */

   /* ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2853, 2854 },
      -1,
   } },

   /* replace979 -> 1024 in the cache */

   /* ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      26,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2856, 2857 },
      -1,
   } },

   /* replace980 -> 1024 in the cache */

   /* ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search981_0 -> 1513 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1513, 2859 },
      -1,
   } },

   /* replace981 -> 1024 in the cache */

   /* ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2861, 2862 },
      -1,
   } },

   /* replace982 -> 1177 in the cache */

   /* ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      28,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2864, 2865 },
      -1,
   } },

   /* replace983 -> 1177 in the cache */

   /* ('ine', 'a(is_not_zero)', 0) => True */
   /* search984_0 -> 2847 in the cache */
   /* search984_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2847, 61 },
      -1,
   } },

   /* replace984 -> 1177 in the cache */

   /* ('ieq', 'a(is_not_zero)', 0) => False */
   /* search985_0 -> 2847 in the cache */
   /* search985_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2847, 61 },
      -1,
   } },

   /* replace985 -> 1024 in the cache */

   /* ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True */
   /* search986_0 -> 1513 in the cache */
   /* search986_1 -> 2859 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1513, 2859 },
      -1,
   } },

   /* replace986 -> 1177 in the cache */

   /* ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   /* search987_0 -> 2853 in the cache */
   /* search987_1 -> 2854 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2853, 2854 },
      -1,
   } },

   /* replace987 -> 1024 in the cache */

   /* ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   /* search988_0 -> 2856 in the cache */
   /* search988_1 -> 2857 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2856, 2857 },
      -1,
   } },

   /* replace988 -> 1024 in the cache */

   /* ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search989_0 -> 1513 in the cache */
   /* search989_1 -> 2859 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1513, 2859 },
      -1,
   } },

   /* replace989 -> 1024 in the cache */

   /* ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True */
   /* search990_0 -> 2853 in the cache */
   /* search990_1 -> 2854 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2853, 2854 },
      -1,
   } },

   /* replace990 -> 1177 in the cache */

   /* ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True */
   /* search991_0 -> 2856 in the cache */
   /* search991_1 -> 2857 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2856, 2857 },
      -1,
   } },

   /* replace991 -> 1177 in the cache */

   /* ('ult', 0, 'a(is_gt_zero)') => True */
   /* search992_0 -> 61 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 2875 },
      -1,
   } },

   /* replace992 -> 1177 in the cache */

   /* ('ult', 'a', 0) => False */
   /* search993_0 -> 32 in the cache */
   /* search993_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace993 -> 1024 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a */
   /* search994_0_0 -> 16 in the cache */
   /* search994_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 2878 },
      -1,
   } },

   /* replace994 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b */
   /* search995_0_0 -> 16 in the cache */
   /* search995_0_1 -> 36 in the cache */
   /* search995_0 -> 2878 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 2878 },
      -1,
   } },

   /* replace995 -> 36 in the cache */

   /* ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b') */
   /* search996_0_0 -> 16 in the cache */
   /* search996_0_1 -> 36 in the cache */
   /* search996_0 -> 2878 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 2878 },
      -1,
   } },

   /* replace996_0 -> 16 in the cache */
   /* replace996_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a */
   /* search997_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 2883 },
      -1,
   } },

   /* replace997 -> 16 in the cache */

   /* ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a */
   /* search998_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 2885 },
      -1,
   } },

   /* replace998 -> 16 in the cache */

   /* ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a */
   /* search999_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 21 },
      -1,
   } },
   /* search999_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 2887, 2888 },
      -1,
   } },

   /* replace999 -> 21 in the cache */

   /* ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a */
   /* search1000_0_0_0 -> 21 in the cache */
   /* search1000_0_0 -> 2887 in the cache */
   /* search1000_0_1_0 -> 21 in the cache */
   /* search1000_0_1 -> 2888 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2887, 2888 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 2890 },
      -1,
   } },

   /* replace1000 -> 21 in the cache */

   /* ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a */
   /* search1001_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 2892 },
      -1,
   } },

   /* replace1001 -> 21 in the cache */

   /* ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a */
   /* search1002_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 2894 },
      -1,
   } },

   /* replace1002 -> 21 in the cache */

   /* ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c')) */
   /* search1003_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1003_0_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 2896, 1944 },
      -1,
   } },
   /* search1003_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2898, 2899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2897, 2900 },
      -1,
   } },

   /* replace1003_0 -> 16 in the cache */
   /* replace1003_1_0 -> 243 in the cache */
   /* replace1003_1_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 243, 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 2902 },
      -1,
   } },

   /* ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1) */
   /* search1004_0 -> 11 in the cache */
   /* search1004_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 778 },
      -1,
   } },

   /* replace1004_0 -> 11 in the cache */
   /* replace1004_1 -> 1381 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 1381 },
      -1,
   } },

   /* ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3) */
   /* search1005_0 -> 16 in the cache */
   /* search1005_1 -> 959 in the cache */
   /* search1005 -> 964 in the cache */

   /* replace1005_0 -> 16 in the cache */
   /* replace1005_1 -> 386 in the cache */
   /* replace1005 -> 403 in the cache */

   /* ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7) */
   /* search1006_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x38 /* 56 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 2906 },
      -1,
   } },

   /* replace1006_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 2908 },
      -1,
   } },

   /* ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1) */
   /* search1007_0 -> 11 in the cache */
   /* search1007_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 778 },
      -1,
   } },

   /* replace1007_0 -> 11 in the cache */
   /* replace1007_1 -> 1381 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 1381 },
      -1,
   } },

   /* ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3) */
   /* search1008_0 -> 16 in the cache */
   /* search1008_1 -> 959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 959 },
      -1,
   } },

   /* replace1008_0 -> 16 in the cache */
   /* replace1008_1 -> 386 in the cache */
   /* replace1008 -> 387 in the cache */

   /* ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7) */
   /* search1009_0 -> 21 in the cache */
   /* search1009_1 -> 2906 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 2906 },
      -1,
   } },

   /* replace1009_0 -> 21 in the cache */
   /* replace1009_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 2908 },
      -1,
   } },

   /* ('iand', 255, 'a') => ('extract_u8', 'a', 0) */
   /* search1010_0 -> 1519 in the cache */
   /* search1010_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1519, 32 },
      -1,
   } },

   /* replace1010_0 -> 32 in the cache */
   /* replace1010_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2)) */
   /* search1011_0_0 -> 32 in the cache */
   /* search1011_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2917 },
      -1,
   } },

   /* replace1011_0_0 -> 32 in the cache */
   /* replace1011_0_1 -> 2152 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 2152 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2919 },
      -1,
   } },

   /* ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1)) */
   /* search1012_0_0 -> 32 in the cache */
   /* search1012_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2921 },
      -1,
   } },

   /* replace1012_0_0 -> 32 in the cache */
   /* replace1012_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2923 },
      -1,
   } },

   /* ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b')) */
   /* search1013_0_0_0 -> 0 in the cache */
   /* search1013_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2925 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2926 },
      -1,
   } },

   /* replace1013_0_0 -> 0 in the cache */
   /* replace1013_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2928 },
      -1,
   } },

   /* ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b')) */
   /* search1014_0_0_0 -> 0 in the cache */
   /* search1014_0_0_1 -> 3 in the cache */
   /* search1014_0_0 -> 2925 in the cache */
   /* search1014_0 -> 2926 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2926 },
      -1,
   } },

   /* replace1014_0_0 -> 0 in the cache */
   /* replace1014_0_1 -> 3 in the cache */
   /* replace1014_0 -> 2925 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2925 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0) */
   /* search1015_0 -> 16 in the cache */
   /* search1015_1 -> 120 in the cache */
   /* search1015_2 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 778 },
      -1,
   } },

   /* replace1015_0 -> 16 in the cache */
   /* replace1015_1 -> 120 in the cache */
   /* replace1015 -> 393 in the cache */

   /* ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1) */
   /* search1016_0 -> 16 in the cache */
   /* search1016_1 -> 778 in the cache */
   /* search1016_2 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 778, 778 },
      -1,
   } },

   /* replace1016_0 -> 16 in the cache */
   /* replace1016_1 -> 377 in the cache */
   /* replace1016 -> 396 in the cache */

   /* ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2) */
   /* search1017_0 -> 16 in the cache */
   /* search1017_1 -> 801 in the cache */
   /* search1017_2 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 801, 778 },
      -1,
   } },

   /* replace1017_0 -> 16 in the cache */
   /* replace1017_1 -> 382 in the cache */
   /* replace1017 -> 400 in the cache */

   /* ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3) */
   /* search1018_0 -> 16 in the cache */
   /* search1018_1 -> 959 in the cache */
   /* search1018_2 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 959, 778 },
      -1,
   } },

   /* replace1018_0 -> 16 in the cache */
   /* replace1018_1 -> 386 in the cache */
   /* replace1018 -> 403 in the cache */

   /* ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0) */
   /* search1019_0 -> 16 in the cache */
   /* search1019_1 -> 120 in the cache */
   /* search1019_2 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 120, 778 },
      -1,
   } },

   /* replace1019_0 -> 16 in the cache */
   /* replace1019_1 -> 120 in the cache */
   /* replace1019 -> 374 in the cache */

   /* ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1) */
   /* search1020_0 -> 16 in the cache */
   /* search1020_1 -> 778 in the cache */
   /* search1020_2 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 778, 778 },
      -1,
   } },

   /* replace1020_0 -> 16 in the cache */
   /* replace1020_1 -> 377 in the cache */
   /* replace1020 -> 378 in the cache */

   /* ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2) */
   /* search1021_0 -> 16 in the cache */
   /* search1021_1 -> 801 in the cache */
   /* search1021_2 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 801, 778 },
      -1,
   } },

   /* replace1021_0 -> 16 in the cache */
   /* replace1021_1 -> 382 in the cache */
   /* replace1021 -> 383 in the cache */

   /* ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3) */
   /* search1022_0 -> 16 in the cache */
   /* search1022_1 -> 959 in the cache */
   /* search1022_2 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 959, 778 },
      -1,
   } },

   /* replace1022_0 -> 16 in the cache */
   /* replace1022_1 -> 386 in the cache */
   /* replace1022 -> 387 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1023_0_0 -> 0 in the cache */
   /* search1023_0_1 -> 3 in the cache */
   /* search1023_0 -> 2928 in the cache */
   /* search1023_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2928, 86 },
      -1,
   } },

   /* replace1023_0 -> 0 in the cache */
   /* replace1023_1 -> 3 in the cache */
   /* replace1023 -> 2925 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1024_0_0 -> 0 in the cache */
   /* search1024_0_1 -> 3 in the cache */
   /* search1024_0 -> 2925 in the cache */
   /* search1024_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2925, 86 },
      -1,
   } },

   /* replace1024_0 -> 0 in the cache */
   /* replace1024_1 -> 3 in the cache */
   /* replace1024 -> 2925 in the cache */

   /* ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0) */
   /* search1025_0_0 -> 16 in the cache */
   /* search1025_0_1 -> 801 in the cache */
   /* search1025_0 -> 953 in the cache */
   /* search1025_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 953, 801 },
      -1,
   } },

   /* replace1025_0 -> 16 in the cache */
   /* replace1025_1 -> 120 in the cache */
   /* replace1025 -> 425 in the cache */

   /* ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1) */
   /* search1026_0 -> 16 in the cache */
   /* search1026_1 -> 801 in the cache */
   /* search1026 -> 956 in the cache */

   /* replace1026_0 -> 16 in the cache */
   /* replace1026_1 -> 377 in the cache */
   /* replace1026 -> 428 in the cache */

   /* ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0) */
   /* search1027_0_0 -> 16 in the cache */
   /* search1027_0_1 -> 801 in the cache */
   /* search1027_0 -> 953 in the cache */
   /* search1027_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 953, 801 },
      -1,
   } },

   /* replace1027_0 -> 16 in the cache */
   /* replace1027_1 -> 120 in the cache */
   /* replace1027 -> 417 in the cache */

   /* ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1) */
   /* search1028_0 -> 16 in the cache */
   /* search1028_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 801 },
      -1,
   } },

   /* replace1028_0 -> 16 in the cache */
   /* replace1028_1 -> 377 in the cache */
   /* replace1028 -> 420 in the cache */

   /* ('iand', 65535, 'a') => ('extract_u16', 'a', 0) */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* search1029_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2945, 32 },
      -1,
   } },

   /* replace1029_0 -> 32 in the cache */
   /* replace1029_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0) */
   /* search1030_0 -> 16 in the cache */
   /* search1030_1 -> 120 in the cache */
   /* search1030_2 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 801 },
      -1,
   } },

   /* replace1030_0 -> 16 in the cache */
   /* replace1030_1 -> 120 in the cache */
   /* replace1030 -> 425 in the cache */

   /* ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1) */
   /* search1031_0 -> 16 in the cache */
   /* search1031_1 -> 801 in the cache */
   /* search1031_2 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 801, 801 },
      -1,
   } },

   /* replace1031_0 -> 16 in the cache */
   /* replace1031_1 -> 377 in the cache */
   /* replace1031 -> 428 in the cache */

   /* ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0) */
   /* search1032_0 -> 16 in the cache */
   /* search1032_1 -> 120 in the cache */
   /* search1032_2 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 120, 801 },
      -1,
   } },

   /* replace1032_0 -> 16 in the cache */
   /* replace1032_1 -> 120 in the cache */
   /* replace1032 -> 417 in the cache */

   /* ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1) */
   /* search1033_0 -> 16 in the cache */
   /* search1033_1 -> 801 in the cache */
   /* search1033_2 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 801, 801 },
      -1,
   } },

   /* replace1033_0 -> 16 in the cache */
   /* replace1033_1 -> 377 in the cache */
   /* replace1033 -> 420 in the cache */

   /* ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a')) */
   /* search1034_0_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 6 },
      -1,
   } },
   /* search1034_0_1 -> 959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2952, 959 },
      -1,
   } },
   /* search1034_1_0_0_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2045 },
      -1,
   } },
   /* search1034_1_0_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2954, 801 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2956 },
      -1,
   } },
   /* search1034_1_1_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2957, 778 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2959 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 2958, 2960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 2,
      { 2955, 2961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2953, 2962 },
      -1,
   } },

   /* replace1034_0_0 -> 2959 in the cache */
   /* replace1034_0_1 -> 2956 in the cache */
   /* replace1034_0_2 -> 2045 in the cache */
   /* replace1034_0_3 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 2959, 2956, 2045, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 2964 },
      -1,
   } },

   /* ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1035_0_0 -> 0 in the cache */
   /* search1035_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   /* search1035_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 2966, 86 },
      -1,
   } },

   /* replace1035_0 -> 0 in the cache */
   /* replace1035_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1036_0_0 -> 0 in the cache */
   /* search1036_0_1 -> 3 in the cache */
   /* search1036_0 -> 2968 in the cache */
   /* search1036_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 2968, 86 },
      -1,
   } },

   /* replace1036_0 -> 0 in the cache */
   /* replace1036_1 -> 3 in the cache */
   /* replace1036 -> 2968 in the cache */

   /* ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32)) */
   /* search1037_0 -> 16 in the cache */
   /* search1037_1 -> 36 in the cache */
   /* search1037 -> 2878 in the cache */

   /* replace1037_0_0 -> 16 in the cache */
   /* replace1037_0 -> 1841 in the cache */
   /* replace1037_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 36 },
      -1,
   } },
   /* replace1037_1_1 -> 823 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2970, 823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1841, 2971 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16)) */
   /* search1038_0 -> 11 in the cache */
   /* search1038_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 11, 243 },
      -1,
   } },

   /* replace1038_0_0 -> 11 in the cache */
   /* replace1038_0 -> 1734 in the cache */
   /* replace1038_1_0_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 243 },
      -1,
   } },
   /* replace1038_1_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2974, 801 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1734, 2975 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a') */
   /* search1039_0 -> 21 in the cache */
   /* search1039 -> 2887 in the cache */

   /* replace1039_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32)) */
   /* search1040_0 -> 21 in the cache */
   /* search1040 -> 2888 in the cache */

   /* replace1040_0_0 -> 21 in the cache */
   /* replace1040_0_1 -> 823 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2978 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a') */
   /* search1041_0 -> 16 in the cache */
   /* search1041 -> 2896 in the cache */

   /* replace1041_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1042_0 -> 16 in the cache */
   /* search1042 -> 2898 in the cache */

   /* replace1042_0_0 -> 16 in the cache */
   /* replace1042_0_1 -> 801 in the cache */
   /* replace1042_0 -> 956 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 956 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1043_0_0 -> 16 in the cache */
   /* search1043_0_1 -> 797 in the cache */
   /* search1043_0 -> 951 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 1,
      { 951 },
      -1,
   } },

   /* replace1043_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1044_0_0 -> 16 in the cache */
   /* search1044_0_1 -> 797 in the cache */
   /* search1044_0 -> 951 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 1,
      { 951 },
      -1,
   } },

   /* replace1044_0 -> 16 in the cache */
   /* replace1044 -> 2896 in the cache */

   /* ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a') */
   /* search1045_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 2985 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 2986 },
      -1,
   } },

   /* replace1045_0 -> 21 in the cache */
   /* replace1045 -> 2887 in the cache */

   /* ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1046_0_0 -> 16 in the cache */
   /* search1046_0_1 -> 954 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 954 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 1,
      { 2988 },
      -1,
   } },

   /* replace1046_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1047_0_0 -> 16 in the cache */
   /* search1047_0_1 -> 954 in the cache */
   /* search1047_0 -> 2988 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 1,
      { 2988 },
      -1,
   } },

   /* replace1047_0 -> 16 in the cache */
   /* replace1047 -> 2898 in the cache */

   /* ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1048_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff00000000 /* 18446744069414584320 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 2992 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 1,
      { 2993 },
      -1,
   } },

   /* replace1048_0 -> 21 in the cache */
   /* replace1048 -> 2888 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1049_0_0 -> 16 in the cache */
   /* search1049_0_1 -> 120 in the cache */
   /* search1049_0 -> 425 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 425 },
      -1,
   } },

   /* replace1049_0 -> 16 in the cache */
   /* replace1049 -> 2983 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1050_0_0 -> 16 in the cache */
   /* search1050_0_1 -> 377 in the cache */
   /* search1050_0 -> 428 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace1050_0 -> 16 in the cache */
   /* replace1050 -> 2990 in the cache */

   /* ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1051_0_0 -> 16 in the cache */
   /* search1051_0_1 -> 801 in the cache */
   /* search1051_0 -> 956 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 956 },
      -1,
   } },

   /* replace1051_0 -> 16 in the cache */
   /* replace1051 -> 2990 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1052_0_0 -> 16 in the cache */
   /* search1052_0_1 -> 120 in the cache */
   /* search1052_0 -> 425 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 425 },
      -1,
   } },

   /* replace1052_0 -> 16 in the cache */
   /* replace1052 -> 2896 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1053_0_0 -> 16 in the cache */
   /* search1053_0_1 -> 377 in the cache */
   /* search1053_0 -> 428 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace1053_0 -> 16 in the cache */
   /* replace1053 -> 2898 in the cache */

   /* ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a')) */
   /* search1054_0_0_0 -> 16 in the cache */
   /* search1054_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3000 },
      -1,
   } },
   /* search1054_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3001, 801 },
      -1,
   } },

   /* replace1054_0_0 -> 120 in the cache */
   /* replace1054_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3003 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0)) */
   /* search1055_0_0_0 -> 120 in the cache */
   /* search1055_0_0_1 -> 16 in the cache */
   /* search1055_0_0 -> 3003 in the cache */
   /* search1055_0 -> 3004 in the cache */
   /* search1055_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3004, 801 },
      -1,
   } },

   /* replace1055_0_0 -> 16 in the cache */
   /* replace1055_0_1 -> 120 in the cache */
   /* replace1055_0 -> 3000 in the cache */
   /* replace1055 -> 3001 in the cache */

   /* ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1056_0_0_0 -> 16 in the cache */
   /* search1056_0_0_1 -> 120 in the cache */
   /* search1056_0_0 -> 3000 in the cache */
   /* search1056_0 -> 3001 in the cache */
   /* search1056_1_0_0 -> 120 in the cache */
   /* search1056_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3001, 3007 },
      -1,
   } },

   /* replace1056_0_0 -> 16 in the cache */
   /* replace1056_0_1 -> 36 in the cache */
   /* replace1056_0 -> 2882 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 2882 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1057_0_0_0 -> 16 in the cache */
   /* search1057_0_0_1 -> 120 in the cache */
   /* search1057_0_0 -> 3000 in the cache */
   /* search1057_0 -> 3001 in the cache */
   /* search1057_1_0_0 -> 120 in the cache */
   /* search1057_1_0_1 -> 36 in the cache */
   /* search1057_1_0 -> 3006 in the cache */
   /* search1057_1 -> 3007 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3001, 3007 },
      -1,
   } },

   /* replace1057_0_0 -> 16 in the cache */
   /* replace1057_0_1 -> 36 in the cache */
   /* replace1057_0 -> 2882 in the cache */
   /* replace1057 -> 3009 in the cache */

   /* ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a') */
   /* search1058_0_0 -> 16 in the cache */
   /* search1058_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1058_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3011, 801 },
      -1,
   } },

   /* replace1058_0 -> 120 in the cache */
   /* replace1058_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 120, 16 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0) */
   /* search1059_0_0 -> 120 in the cache */
   /* search1059_0_1 -> 16 in the cache */
   /* search1059_0 -> 3013 in the cache */
   /* search1059_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3013, 801 },
      -1,
   } },

   /* replace1059_0 -> 16 in the cache */
   /* replace1059_1 -> 120 in the cache */
   /* replace1059 -> 3011 in the cache */

   /* ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0) */
   /* search1060_0_0 -> 120 in the cache */
   /* search1060_0_1 -> 16 in the cache */
   /* search1060_0 -> 3013 in the cache */
   /* search1060_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3013, 377 },
      -1,
   } },

   /* replace1060_0 -> 16 in the cache */
   /* replace1060_1 -> 120 in the cache */
   /* replace1060 -> 3011 in the cache */

   /* ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1061_0_0 -> 16 in the cache */
   /* search1061_0_1 -> 120 in the cache */
   /* search1061_0 -> 3011 in the cache */
   /* search1061_1_0 -> 120 in the cache */
   /* search1061_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3011, 3016 },
      -1,
   } },

   /* replace1061_0 -> 16 in the cache */
   /* replace1061_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1062_0_0 -> 16 in the cache */
   /* search1062_0_1 -> 120 in the cache */
   /* search1062_0 -> 3011 in the cache */
   /* search1062_1_0 -> 120 in the cache */
   /* search1062_1_1 -> 36 in the cache */
   /* search1062_1 -> 3016 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3011, 3016 },
      -1,
   } },

   /* replace1062_0 -> 16 in the cache */
   /* replace1062_1 -> 36 in the cache */
   /* replace1062 -> 3018 in the cache */

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a') */
   /* search1063_0_0 -> 6 in the cache */
   /* search1063_0_1 -> 2045 in the cache */
   /* search1063_0_2 -> 2956 in the cache */
   /* search1063_0_3 -> 2959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8_split,
      -1, 0,
      { 6, 2045, 2956, 2959 },
      -1,
   } },
   /* search1063_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3020, 120 },
      -1,
   } },

   /* replace1063_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b') */
   /* search1064_0_0 -> 6 in the cache */
   /* search1064_0_1 -> 2045 in the cache */
   /* search1064_0_2 -> 2956 in the cache */
   /* search1064_0_3 -> 2959 in the cache */
   /* search1064_0 -> 3020 in the cache */
   /* search1064_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3020, 377 },
      -1,
   } },

   /* replace1064_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2045 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c') */
   /* search1065_0_0 -> 6 in the cache */
   /* search1065_0_1 -> 2045 in the cache */
   /* search1065_0_2 -> 2956 in the cache */
   /* search1065_0_3 -> 2959 in the cache */
   /* search1065_0 -> 3020 in the cache */
   /* search1065_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3020, 382 },
      -1,
   } },

   /* replace1065_0 -> 2956 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2956 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd') */
   /* search1066_0_0 -> 6 in the cache */
   /* search1066_0_1 -> 2045 in the cache */
   /* search1066_0_2 -> 2956 in the cache */
   /* search1066_0_3 -> 2959 in the cache */
   /* search1066_0 -> 3020 in the cache */
   /* search1066_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3020, 386 },
      -1,
   } },

   /* replace1066_0 -> 2959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2959 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a') */
   /* search1067_0_0 -> 6 in the cache */
   /* search1067_0_1 -> 2045 in the cache */
   /* search1067_0_2 -> 2956 in the cache */
   /* search1067_0_3 -> 2959 in the cache */
   /* search1067_0 -> 3020 in the cache */
   /* search1067_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3020, 120 },
      -1,
   } },

   /* replace1067_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b') */
   /* search1068_0_0 -> 6 in the cache */
   /* search1068_0_1 -> 2045 in the cache */
   /* search1068_0_2 -> 2956 in the cache */
   /* search1068_0_3 -> 2959 in the cache */
   /* search1068_0 -> 3020 in the cache */
   /* search1068_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3020, 377 },
      -1,
   } },

   /* replace1068_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2045 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c') */
   /* search1069_0_0 -> 6 in the cache */
   /* search1069_0_1 -> 2045 in the cache */
   /* search1069_0_2 -> 2956 in the cache */
   /* search1069_0_3 -> 2959 in the cache */
   /* search1069_0 -> 3020 in the cache */
   /* search1069_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3020, 382 },
      -1,
   } },

   /* replace1069_0 -> 2956 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2956 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd') */
   /* search1070_0_0 -> 6 in the cache */
   /* search1070_0_1 -> 2045 in the cache */
   /* search1070_0_2 -> 2956 in the cache */
   /* search1070_0_3 -> 2959 in the cache */
   /* search1070_0 -> 3020 in the cache */
   /* search1070_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3020, 386 },
      -1,
   } },

   /* replace1070_0 -> 2959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2959 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1071_0_0 -> 11 in the cache */
   /* search1071_0_1 -> 778 in the cache */
   /* search1071_0 -> 2904 in the cache */
   /* search1071_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2904, 804 },
      -1,
   } },

   /* replace1071_0 -> 11 in the cache */
   /* replace1071_1 -> 1381 in the cache */
   /* replace1071 -> 2905 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1072_0_0 -> 16 in the cache */
   /* search1072_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 778 },
      -1,
   } },
   /* search1072_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3038, 120 },
      -1,
   } },

   /* replace1072_0 -> 16 in the cache */
   /* replace1072_1 -> 377 in the cache */
   /* replace1072 -> 396 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1073_0_0 -> 16 in the cache */
   /* search1073_0_1 -> 801 in the cache */
   /* search1073_0 -> 956 in the cache */
   /* search1073_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 956, 120 },
      -1,
   } },

   /* replace1073_0 -> 16 in the cache */
   /* replace1073_1 -> 382 in the cache */
   /* replace1073 -> 400 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1074_0_0 -> 16 in the cache */
   /* search1074_0_1 -> 959 in the cache */
   /* search1074_0 -> 964 in the cache */
   /* search1074_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 964, 120 },
      -1,
   } },

   /* replace1074_0 -> 16 in the cache */
   /* replace1074_1 -> 386 in the cache */
   /* replace1074 -> 403 in the cache */

   /* ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1075_0_0 -> 21 in the cache */
   /* search1075_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 778 },
      -1,
   } },
   /* search1075_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3042, 847 },
      -1,
   } },

   /* replace1075_0 -> 21 in the cache */
   /* replace1075_1 -> 1423 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 1423 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1076_0_0 -> 21 in the cache */
   /* search1076_0_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 801 },
      -1,
   } },
   /* search1076_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3045, 847 },
      -1,
   } },

   /* replace1076_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3047 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1077_0_0 -> 21 in the cache */
   /* search1077_0_1 -> 959 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 959 },
      -1,
   } },
   /* search1077_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3049, 847 },
      -1,
   } },

   /* replace1077_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3051 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1078_0_0 -> 21 in the cache */
   /* search1078_0_1 -> 823 in the cache */
   /* search1078_0 -> 2978 in the cache */
   /* search1078_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2978, 847 },
      -1,
   } },

   /* replace1078_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3054 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1079_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x28 /* 40 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3056 },
      -1,
   } },
   /* search1079_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3057, 847 },
      -1,
   } },

   /* replace1079_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3059 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1080_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x30 /* 48 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3061 },
      -1,
   } },
   /* search1080_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3062, 847 },
      -1,
   } },

   /* replace1080_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x6 /* 6 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3064 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1081_0_0 -> 21 in the cache */
   /* search1081_0_1 -> 2906 in the cache */
   /* search1081_0 -> 2907 in the cache */
   /* search1081_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2907, 847 },
      -1,
   } },

   /* replace1081_0 -> 21 in the cache */
   /* replace1081_1 -> 2908 in the cache */
   /* replace1081 -> 2909 in the cache */

   /* ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1082_0_0 -> 11 in the cache */
   /* search1082_0_1 -> 778 in the cache */
   /* search1082_0 -> 2910 in the cache */
   /* search1082_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2910, 804 },
      -1,
   } },

   /* replace1082_0 -> 11 in the cache */
   /* replace1082_1 -> 1381 in the cache */
   /* replace1082 -> 2905 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1083_0_0 -> 16 in the cache */
   /* search1083_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 778 },
      -1,
   } },
   /* search1083_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3068, 120 },
      -1,
   } },

   /* replace1083_0 -> 16 in the cache */
   /* replace1083_1 -> 377 in the cache */
   /* replace1083 -> 396 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1084_0_0 -> 16 in the cache */
   /* search1084_0_1 -> 801 in the cache */
   /* search1084_0 -> 2944 in the cache */
   /* search1084_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2944, 120 },
      -1,
   } },

   /* replace1084_0 -> 16 in the cache */
   /* replace1084_1 -> 382 in the cache */
   /* replace1084 -> 400 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1085_0_0 -> 16 in the cache */
   /* search1085_0_1 -> 959 in the cache */
   /* search1085_0 -> 2912 in the cache */
   /* search1085_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2912, 120 },
      -1,
   } },

   /* replace1085_0 -> 16 in the cache */
   /* replace1085_1 -> 386 in the cache */
   /* replace1085 -> 403 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1086_0_0 -> 21 in the cache */
   /* search1086_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 778 },
      -1,
   } },
   /* search1086_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3072, 847 },
      -1,
   } },

   /* replace1086_0 -> 21 in the cache */
   /* replace1086_1 -> 1423 in the cache */
   /* replace1086 -> 3044 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1087_0_0 -> 21 in the cache */
   /* search1087_0_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 801 },
      -1,
   } },
   /* search1087_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3074, 847 },
      -1,
   } },

   /* replace1087_0 -> 21 in the cache */
   /* replace1087_1 -> 3047 in the cache */
   /* replace1087 -> 3048 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1088_0_0 -> 21 in the cache */
   /* search1088_0_1 -> 959 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 959 },
      -1,
   } },
   /* search1088_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3076, 847 },
      -1,
   } },

   /* replace1088_0 -> 21 in the cache */
   /* replace1088_1 -> 3051 in the cache */
   /* replace1088 -> 3052 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1089_0_0 -> 21 in the cache */
   /* search1089_0_1 -> 823 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 823 },
      -1,
   } },
   /* search1089_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3078, 847 },
      -1,
   } },

   /* replace1089_0 -> 21 in the cache */
   /* replace1089_1 -> 3054 in the cache */
   /* replace1089 -> 3055 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1090_0_0 -> 21 in the cache */
   /* search1090_0_1 -> 3056 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3056 },
      -1,
   } },
   /* search1090_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3080, 847 },
      -1,
   } },

   /* replace1090_0 -> 21 in the cache */
   /* replace1090_1 -> 3059 in the cache */
   /* replace1090 -> 3060 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1091_0_0 -> 21 in the cache */
   /* search1091_0_1 -> 3061 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3061 },
      -1,
   } },
   /* search1091_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3082, 847 },
      -1,
   } },

   /* replace1091_0 -> 21 in the cache */
   /* replace1091_1 -> 3064 in the cache */
   /* replace1091 -> 3065 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1092_0_0 -> 21 in the cache */
   /* search1092_0_1 -> 2906 in the cache */
   /* search1092_0 -> 2913 in the cache */
   /* search1092_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2913, 847 },
      -1,
   } },

   /* replace1092_0 -> 21 in the cache */
   /* replace1092_1 -> 2908 in the cache */
   /* replace1092 -> 2909 in the cache */

   /* ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2) */
   /* search1093_0_0 -> 32 in the cache */
   /* search1093_0_1 -> 35 in the cache */
   /* search1093_0 -> 2917 in the cache */
   /* search1093_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2917, 61 },
      -1,
   } },

   /* replace1093_0 -> 32 in the cache */
   /* replace1093_1 -> 2152 in the cache */
   /* replace1093 -> 2919 in the cache */

   /* ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0) */
   /* search1094_0_0 -> 11 in the cache */
   /* search1094_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 778 },
      -1,
   } },
   /* search1094_1 -> 1381 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3086, 1381 },
      -1,
   } },

   /* replace1094_0 -> 11 in the cache */
   /* replace1094_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 804 },
      -1,
   } },

   /* ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2) */
   /* search1095_0_0 -> 16 in the cache */
   /* search1095_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 778 },
      -1,
   } },
   /* search1095_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3089, 386 },
      -1,
   } },

   /* replace1095_0 -> 16 in the cache */
   /* replace1095_1 -> 382 in the cache */
   /* replace1095 -> 400 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1) */
   /* search1096_0_0 -> 16 in the cache */
   /* search1096_0_1 -> 801 in the cache */
   /* search1096_0 -> 953 in the cache */
   /* search1096_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 953, 386 },
      -1,
   } },

   /* replace1096_0 -> 16 in the cache */
   /* replace1096_1 -> 377 in the cache */
   /* replace1096 -> 396 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0) */
   /* search1097_0_0 -> 16 in the cache */
   /* search1097_0_1 -> 959 in the cache */
   /* search1097_0 -> 961 in the cache */
   /* search1097_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 961, 386 },
      -1,
   } },

   /* replace1097_0 -> 16 in the cache */
   /* replace1097_1 -> 120 in the cache */
   /* replace1097 -> 393 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6) */
   /* search1098_0_0 -> 21 in the cache */
   /* search1098_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 778 },
      -1,
   } },
   /* search1098_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3093, 2908 },
      -1,
   } },

   /* replace1098_0 -> 21 in the cache */
   /* replace1098_1 -> 3064 in the cache */
   /* replace1098 -> 3065 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5) */
   /* search1099_0_0 -> 21 in the cache */
   /* search1099_0_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 801 },
      -1,
   } },
   /* search1099_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3095, 2908 },
      -1,
   } },

   /* replace1099_0 -> 21 in the cache */
   /* replace1099_1 -> 3059 in the cache */
   /* replace1099 -> 3060 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4) */
   /* search1100_0_0 -> 21 in the cache */
   /* search1100_0_1 -> 959 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 959 },
      -1,
   } },
   /* search1100_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3097, 2908 },
      -1,
   } },

   /* replace1100_0 -> 21 in the cache */
   /* replace1100_1 -> 3054 in the cache */
   /* replace1100 -> 3055 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3) */
   /* search1101_0_0 -> 21 in the cache */
   /* search1101_0_1 -> 823 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 823 },
      -1,
   } },
   /* search1101_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3099, 2908 },
      -1,
   } },

   /* replace1101_0 -> 21 in the cache */
   /* replace1101_1 -> 3051 in the cache */
   /* replace1101 -> 3052 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2) */
   /* search1102_0_0 -> 21 in the cache */
   /* search1102_0_1 -> 3056 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3056 },
      -1,
   } },
   /* search1102_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3101, 2908 },
      -1,
   } },

   /* replace1102_0 -> 21 in the cache */
   /* replace1102_1 -> 3047 in the cache */
   /* replace1102 -> 3048 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1) */
   /* search1103_0_0 -> 21 in the cache */
   /* search1103_0_1 -> 3061 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3061 },
      -1,
   } },
   /* search1103_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3103, 2908 },
      -1,
   } },

   /* replace1103_0 -> 21 in the cache */
   /* replace1103_1 -> 1423 in the cache */
   /* replace1103 -> 3044 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0) */
   /* search1104_0_0 -> 21 in the cache */
   /* search1104_0_1 -> 2906 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 2906 },
      -1,
   } },
   /* search1104_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3105, 2908 },
      -1,
   } },

   /* replace1104_0 -> 21 in the cache */
   /* replace1104_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 847 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0) */
   /* search1105_0_0 -> 11 in the cache */
   /* search1105_0_1 -> 778 in the cache */
   /* search1105_0 -> 3086 in the cache */
   /* search1105_1 -> 1381 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3086, 1381 },
      -1,
   } },

   /* replace1105_0 -> 11 in the cache */
   /* replace1105_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 804 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2) */
   /* search1106_0_0 -> 16 in the cache */
   /* search1106_0_1 -> 778 in the cache */
   /* search1106_0 -> 3089 in the cache */
   /* search1106_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3089, 386 },
      -1,
   } },

   /* replace1106_0 -> 16 in the cache */
   /* replace1106_1 -> 382 in the cache */
   /* replace1106 -> 383 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1) */
   /* search1107_0_0 -> 16 in the cache */
   /* search1107_0_1 -> 801 in the cache */
   /* search1107_0 -> 953 in the cache */
   /* search1107_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 953, 386 },
      -1,
   } },

   /* replace1107_0 -> 16 in the cache */
   /* replace1107_1 -> 377 in the cache */
   /* replace1107 -> 378 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0) */
   /* search1108_0_0 -> 16 in the cache */
   /* search1108_0_1 -> 959 in the cache */
   /* search1108_0 -> 961 in the cache */
   /* search1108_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 961, 386 },
      -1,
   } },

   /* replace1108_0 -> 16 in the cache */
   /* replace1108_1 -> 120 in the cache */
   /* replace1108 -> 374 in the cache */

   /* ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6) */
   /* search1109_0_0 -> 21 in the cache */
   /* search1109_0_1 -> 778 in the cache */
   /* search1109_0 -> 3093 in the cache */
   /* search1109_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3093, 2908 },
      -1,
   } },

   /* replace1109_0 -> 21 in the cache */
   /* replace1109_1 -> 3064 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3064 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5) */
   /* search1110_0_0 -> 21 in the cache */
   /* search1110_0_1 -> 801 in the cache */
   /* search1110_0 -> 3095 in the cache */
   /* search1110_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3095, 2908 },
      -1,
   } },

   /* replace1110_0 -> 21 in the cache */
   /* replace1110_1 -> 3059 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3059 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4) */
   /* search1111_0_0 -> 21 in the cache */
   /* search1111_0_1 -> 959 in the cache */
   /* search1111_0 -> 3097 in the cache */
   /* search1111_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3097, 2908 },
      -1,
   } },

   /* replace1111_0 -> 21 in the cache */
   /* replace1111_1 -> 3054 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3054 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3) */
   /* search1112_0_0 -> 21 in the cache */
   /* search1112_0_1 -> 823 in the cache */
   /* search1112_0 -> 3099 in the cache */
   /* search1112_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3099, 2908 },
      -1,
   } },

   /* replace1112_0 -> 21 in the cache */
   /* replace1112_1 -> 3051 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3051 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2) */
   /* search1113_0_0 -> 21 in the cache */
   /* search1113_0_1 -> 3056 in the cache */
   /* search1113_0 -> 3101 in the cache */
   /* search1113_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3101, 2908 },
      -1,
   } },

   /* replace1113_0 -> 21 in the cache */
   /* replace1113_1 -> 3047 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3047 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1) */
   /* search1114_0_0 -> 21 in the cache */
   /* search1114_0_1 -> 3061 in the cache */
   /* search1114_0 -> 3103 in the cache */
   /* search1114_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3103, 2908 },
      -1,
   } },

   /* replace1114_0 -> 21 in the cache */
   /* replace1114_1 -> 1423 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 1423 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0) */
   /* search1115_0_0 -> 21 in the cache */
   /* search1115_0_1 -> 2906 in the cache */
   /* search1115_0 -> 3105 in the cache */
   /* search1115_1 -> 2908 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3105, 2908 },
      -1,
   } },

   /* replace1115_0 -> 21 in the cache */
   /* replace1115_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 847 },
      -1,
   } },

   /* ('ussub_4x8_vc4', 'a', 0) => a */
   /* search1116_0 -> 16 in the cache */
   /* search1116_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* replace1116 -> 16 in the cache */

   /* ('ussub_4x8_vc4', 'a', -1) => 0 */
   /* search1117_0 -> 16 in the cache */
   /* search1117_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 122 },
      -1,
   } },

   /* replace1117 -> 120 in the cache */

   /* ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b')) */
   /* search1118_0 -> 0 in the cache */
   /* search1118_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1118_0 -> 0 in the cache */
   /* replace1118_1_0 -> 3 in the cache */
   /* replace1118_1 -> 1034 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1034 },
      -1,
   } },

   /* ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b')) */
   /* search1119_0 -> 0 in the cache */
   /* search1119_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1119_0 -> 0 in the cache */
   /* replace1119_1_0 -> 3 in the cache */
   /* replace1119_1 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 93 },
      -1,
   } },

   /* ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1120_0 -> 0 in the cache */
   /* search1120_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_usub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1120_0_0 -> 0 in the cache */
   /* replace1120_0_1 -> 3 in the cache */
   /* replace1120_0 -> 1014 in the cache */
   /* replace1120_1_0_0 -> 0 in the cache */
   /* replace1120_1_0_1 -> 3 in the cache */
   /* replace1120_1_0 -> 3131 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3131 },
      -1,
   } },
   /* replace1120_2_0 -> 0 in the cache */
   /* replace1120_2_1 -> 3 in the cache */
   /* replace1120_2 -> 3131 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1014, 3134, 3131 },
      -1,
   } },

   /* ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1121_0 -> 0 in the cache */
   /* search1121_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1121_0_0 -> 0 in the cache */
   /* replace1121_0_1 -> 3 in the cache */
   /* replace1121_0 -> 1011 in the cache */
   /* replace1121_1_0_0 -> 0 in the cache */
   /* replace1121_1_0_1 -> 3 in the cache */
   /* replace1121_1_0 -> 3131 in the cache */
   /* replace1121_1 -> 3134 in the cache */
   /* replace1121_2_0 -> 0 in the cache */
   /* replace1121_2_1 -> 3 in the cache */
   /* replace1121_2 -> 3131 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1011, 3134, 3131 },
      -1,
   } },

   /* ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b')) */
   /* search1122_0_0 -> 0 in the cache */
   /* search1122_0 -> 197 in the cache */
   /* search1122_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 197, 3 },
      4,
   } },

   /* replace1122_0_0 -> 0 in the cache */
   /* replace1122_0_1 -> 3 in the cache */
   /* replace1122_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b')) */
   /* search1123_0_0 -> 16 in the cache */
   /* search1123_0 -> 265 in the cache */
   /* search1123_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 265, 36 },
      4,
   } },

   /* replace1123_0_0 -> 16 in the cache */
   /* replace1123_0_1 -> 36 in the cache */
   /* replace1123_0 -> 254 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 254 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search1124_0_0 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 124 },
      -1,
   } },
   /* search1124_1_0 -> 125 in the cache */
   /* search1124_1 -> 1137 in the cache */
   /* search1124_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 3142, 1137, 127 },
      -1,
   } },

   /* replace1124_0 -> 124 in the cache */
   /* replace1124_1 -> 125 in the cache */
   /* replace1124_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 124, 125, 127 },
      -1,
   } },

   /* ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1125_0_0 -> 16 in the cache */
   /* search1125_0 -> 265 in the cache */
   /* search1125_1_0 -> 36 in the cache */
   /* search1125_1 -> 581 in the cache */
   /* search1125_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 265, 581, 133 },
      -1,
   } },

   /* replace1125_0 -> 16 in the cache */
   /* replace1125_1 -> 36 in the cache */
   /* replace1125_2 -> 133 in the cache */
   /* replace1125 -> 373 in the cache */

   /* ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b')) */
   /* search1126_0_0 -> 0 in the cache */
   /* search1126_0 -> 192 in the cache */
   /* search1126_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 192, 3 },
      -1,
   } },

   /* replace1126_0_0 -> 0 in the cache */
   /* replace1126_0_1 -> 3 in the cache */
   /* replace1126_0 -> 900 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 900 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3148, 3149 },
      0,
   } },
   /* search1127_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3150, 760 },
      0,
   } },

   /* replace1127_0_0 -> 124 in the cache */
   /* replace1127_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1127_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3152, 125 },
      -1,
   } },

   /* ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1128_0_0 -> 313 in the cache */
   /* search1128_0_1 -> 323 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 313, 323 },
      0,
   } },
   /* search1128_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3154, 294 },
      0,
   } },

   /* replace1128_0_0 -> 16 in the cache */
   /* replace1128_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 133 },
      -1,
   } },
   /* replace1128_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3156, 36 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   /* search1129_0_0 -> 313 in the cache */
   /* search1129_0_1 -> 323 in the cache */
   /* search1129_0 -> 3154 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3154, 3158 },
      0,
   } },

   /* replace1129_0_0 -> 16 in the cache */
   /* replace1129_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 133 },
      -1,
   } },
   /* replace1129_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3160, 36 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1130_0_0 -> 3148 in the cache */
   /* search1130_0_1 -> 3149 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3148, 3149 },
      0,
   } },
   /* search1130_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 3162, 760 },
      0,
   } },

   /* replace1130_0_0 -> 124 in the cache */
   /* replace1130_0_1 -> 127 in the cache */
   /* replace1130_0 -> 972 in the cache */
   /* replace1130_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 972, 125 },
      -1,
   } },

   /* ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3165, 3166 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1131_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3167, 3168, 151 },
      -1,
   } },

   /* replace1131_0_0 -> 147 in the cache */
   /* replace1131_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 147, 150 },
      -1,
   } },
   /* replace1131_1 -> 148 in the cache */
   /* replace1131_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3170, 148, 151 },
      -1,
   } },

   /* ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1132_0_0 -> 313 in the cache */
   /* search1132_0_1 -> 323 in the cache */
   /* search1132_0 -> 3154 in the cache */
   /* search1132_1 -> 294 in the cache */
   /* search1132_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3154, 294, 161 },
      -1,
   } },

   /* replace1132_0_0 -> 16 in the cache */
   /* replace1132_0_1 -> 133 in the cache */
   /* replace1132_0 -> 3156 in the cache */
   /* replace1132_1 -> 36 in the cache */
   /* replace1132_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3156, 36, 161 },
      -1,
   } },

   /* ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1133_0_0 -> 313 in the cache */
   /* search1133_0_1 -> 323 in the cache */
   /* search1133_0 -> 3154 in the cache */
   /* search1133_1 -> 3158 in the cache */
   /* search1133_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3154, 3158, 161 },
      -1,
   } },

   /* replace1133_0_0 -> 16 in the cache */
   /* replace1133_0_1 -> 133 in the cache */
   /* replace1133_0 -> 3160 in the cache */
   /* replace1133_1 -> 36 in the cache */
   /* replace1133_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3160, 36, 161 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1134_0_0 -> 3148 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3148, 3176 },
      0,
   } },
   /* search1134_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3177, 760 },
      0,
   } },

   /* replace1134_0_0 -> 124 in the cache */
   /* replace1134_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1134_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3179, 125 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1135_0_0 -> 3148 in the cache */
   /* search1135_0_1 -> 3149 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3148, 3149 },
      0,
   } },
   /* search1135_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3181, 760 },
      0,
   } },

   /* replace1135_0_0 -> 124 in the cache */
   /* replace1135_0_1 -> 127 in the cache */
   /* replace1135_0 -> 3179 in the cache */
   /* replace1135_1 -> 125 in the cache */
   /* replace1135 -> 3180 in the cache */

   /* ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c') */
   /* search1136_0_0 -> 3165 in the cache */
   /* search1136_0_1 -> 148 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3165, 148, 3183 },
      0,
   } },
   /* search1136_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3184, 978 },
      0,
   } },

   /* replace1136_0_0 -> 147 in the cache */
   /* replace1136_0_1 -> 148 in the cache */
   /* replace1136_0_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 147, 148, 151 },
      -1,
   } },
   /* replace1136_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3186, 150 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c') */
   /* search1137_0_0 -> 313 in the cache */
   /* search1137_0_1 -> 36 in the cache */
   /* search1137_0_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 313, 36, 332 },
      0,
   } },
   /* search1137_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3188, 296 },
      0,
   } },

   /* replace1137_0_0 -> 16 in the cache */
   /* replace1137_0_1 -> 36 in the cache */
   /* replace1137_0_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 36, 161 },
      -1,
   } },
   /* replace1137_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3190, 133 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1138_0_0 -> 3148 in the cache */
   /* search1138_0_1 -> 3149 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3148, 3149 },
      0,
   } },
   /* search1138_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3192, 760 },
      0,
   } },

   /* replace1138_0_0 -> 124 in the cache */
   /* replace1138_0_1 -> 127 in the cache */
   /* replace1138_0 -> 986 in the cache */
   /* replace1138_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 986, 125 },
      -1,
   } },

   /* ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b') */
   /* search1139_0 -> 267 in the cache */
   /* search1139_1_0 -> 3149 in the cache */
   /* search1139_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3149, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 267, 3195 },
      -1,
   } },

   /* replace1139_0_0 -> 124 in the cache */
   /* replace1139_0_1 -> 127 in the cache */
   /* replace1139_0 -> 3152 in the cache */
   /* replace1139_1 -> 125 in the cache */
   /* replace1139 -> 3153 in the cache */

   /* ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1140_0 -> 271 in the cache */
   /* search1140_1_0 -> 323 in the cache */
   /* search1140_1_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 323, 294 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 271, 3197 },
      -1,
   } },

   /* replace1140_0_0 -> 16 in the cache */
   /* replace1140_0_1 -> 133 in the cache */
   /* replace1140_0 -> 3156 in the cache */
   /* replace1140_1 -> 36 in the cache */
   /* replace1140 -> 3157 in the cache */

   /* ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1141_1_0 -> 323 in the cache */
   /* search1141_1_1 -> 294 in the cache */
   /* search1141_1 -> 3197 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3199, 3197 },
      -1,
   } },

   /* replace1141_0_0 -> 16 in the cache */
   /* replace1141_0_1 -> 133 in the cache */
   /* replace1141_0 -> 3160 in the cache */
   /* replace1141_1 -> 36 in the cache */
   /* replace1141 -> 3161 in the cache */

   /* ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1142_1_0 -> 3166 in the cache */
   /* search1142_1_1 -> 3168 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3166, 3168 },
      -1,
   } },
   /* search1142_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3201, 3202, 151 },
      -1,
   } },

   /* replace1142_0_0 -> 147 in the cache */
   /* replace1142_0_1 -> 150 in the cache */
   /* replace1142_0 -> 3170 in the cache */
   /* replace1142_1 -> 148 in the cache */
   /* replace1142_2 -> 151 in the cache */
   /* replace1142 -> 3171 in the cache */

   /* ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1143_0 -> 271 in the cache */
   /* search1143_1_0 -> 323 in the cache */
   /* search1143_1_1 -> 294 in the cache */
   /* search1143_1 -> 3197 in the cache */
   /* search1143_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 271, 3197, 161 },
      -1,
   } },

   /* replace1143_0_0 -> 16 in the cache */
   /* replace1143_0_1 -> 133 in the cache */
   /* replace1143_0 -> 3156 in the cache */
   /* replace1143_1 -> 36 in the cache */
   /* replace1143_2 -> 161 in the cache */
   /* replace1143 -> 3173 in the cache */

   /* ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1144_0 -> 3199 in the cache */
   /* search1144_1_0 -> 323 in the cache */
   /* search1144_1_1 -> 294 in the cache */
   /* search1144_1 -> 3197 in the cache */
   /* search1144_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3199, 3197, 161 },
      -1,
   } },

   /* replace1144_0_0 -> 16 in the cache */
   /* replace1144_0_1 -> 133 in the cache */
   /* replace1144_0 -> 3160 in the cache */
   /* replace1144_1 -> 36 in the cache */
   /* replace1144_2 -> 161 in the cache */
   /* replace1144 -> 3175 in the cache */

   /* ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1145_0 -> 267 in the cache */
   /* search1145_1_0 -> 3149 in the cache */
   /* search1145_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3149, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 267, 3206 },
      -1,
   } },

   /* replace1145_0_0 -> 124 in the cache */
   /* replace1145_0_1 -> 127 in the cache */
   /* replace1145_0 -> 972 in the cache */
   /* replace1145_1 -> 125 in the cache */
   /* replace1145 -> 3164 in the cache */

   /* ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1146_0 -> 267 in the cache */
   /* search1146_1_0 -> 3149 in the cache */
   /* search1146_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3149, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 267, 3208 },
      -1,
   } },

   /* replace1146_0_0 -> 124 in the cache */
   /* replace1146_0_1 -> 127 in the cache */
   /* replace1146_0 -> 3179 in the cache */
   /* replace1146_1 -> 125 in the cache */
   /* replace1146 -> 3180 in the cache */

   /* ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b')) */
   /* search1147_0 -> 267 in the cache */
   /* search1147_1_0_0 -> 3149 in the cache */
   /* search1147_1_0_1 -> 760 in the cache */
   /* search1147_1_0 -> 3208 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3208 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 267, 3210 },
      -1,
   } },

   /* replace1147_0_0 -> 124 in the cache */
   /* replace1147_0_1_0 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 124, 3212 },
      -1,
   } },
   /* replace1147_1_0 -> 125 in the cache */
   /* replace1147_1 -> 1137 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3213, 1137 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1148_0 -> 3201 in the cache */
   /* search1148_1_0 -> 3166 in the cache */
   /* search1148_1_1 -> 3183 in the cache */
   /* search1148_1_2 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3166, 3183, 978 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3201, 3215 },
      -1,
   } },

   /* replace1148_0 -> 148 in the cache */
   /* replace1148_1 -> 150 in the cache */
   /* replace1148_2_0 -> 147 in the cache */
   /* replace1148_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 147, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 148, 150, 3217 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1149_0 -> 3201 in the cache */
   /* search1149_1_0_0 -> 3166 in the cache */
   /* search1149_1_0_1 -> 3183 in the cache */
   /* search1149_1_0_2 -> 978 in the cache */
   /* search1149_1_0 -> 3215 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3215 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3201, 3219 },
      -1,
   } },

   /* replace1149_0_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 148 },
      -1,
   } },
   /* replace1149_1 -> 150 in the cache */
   /* replace1149_2_0 -> 147 in the cache */
   /* replace1149_2_1_0 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 147, 3222 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3221, 150, 3223 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1150_0 -> 271 in the cache */
   /* search1150_1_0 -> 323 in the cache */
   /* search1150_1_1 -> 332 in the cache */
   /* search1150_1_2 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 323, 332, 296 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 271, 3225 },
      -1,
   } },

   /* replace1150_0 -> 36 in the cache */
   /* replace1150_1 -> 133 in the cache */
   /* replace1150_2_0 -> 16 in the cache */
   /* replace1150_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 36, 133, 3227 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1151_0 -> 271 in the cache */
   /* search1151_1_0_0 -> 323 in the cache */
   /* search1151_1_0_1 -> 332 in the cache */
   /* search1151_1_0_2 -> 296 in the cache */
   /* search1151_1_0 -> 3225 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3225 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 271, 3229 },
      -1,
   } },

   /* replace1151_0_0 -> 36 in the cache */
   /* replace1151_0 -> 581 in the cache */
   /* replace1151_1 -> 133 in the cache */
   /* replace1151_2_0 -> 16 in the cache */
   /* replace1151_2_1_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 3231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 581, 133, 3232 },
      -1,
   } },

   /* ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1152_0 -> 267 in the cache */
   /* search1152_1_0 -> 3149 in the cache */
   /* search1152_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3149, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 267, 3234 },
      -1,
   } },

   /* replace1152_0_0 -> 124 in the cache */
   /* replace1152_0_1 -> 127 in the cache */
   /* replace1152_0 -> 986 in the cache */
   /* replace1152_1 -> 125 in the cache */
   /* replace1152 -> 3194 in the cache */

   /* ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b') */
   /* search1153_0 -> 267 in the cache */
   /* search1153_1_0 -> 3149 in the cache */
   /* search1153_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3149, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 267, 3236 },
      -1,
   } },

   /* replace1153_0_0 -> 124 in the cache */
   /* replace1153_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1153_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3238, 125 },
      -1,
   } },

   /* ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b') */
   /* search1154_0 -> 267 in the cache */
   /* search1154_1_0 -> 3149 in the cache */
   /* search1154_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3149, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 267, 3240 },
      -1,
   } },

   /* replace1154_0_0 -> 124 in the cache */
   /* replace1154_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1154_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 3242, 125 },
      -1,
   } },

   /* ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b') */
   /* search1155_0 -> 267 in the cache */
   /* search1155_1_0 -> 3149 in the cache */
   /* search1155_1_1 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 3149, 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 267, 3244 },
      -1,
   } },

   /* replace1155_0_0 -> 124 in the cache */
   /* replace1155_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1155_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 3246, 125 },
      -1,
   } },

   /* ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1156_0_1 -> 3176 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3248, 3176 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3249, 3250 },
      -1,
   } },

   /* replace1156_0_0 -> 124 in the cache */
   /* replace1156_0_1 -> 127 in the cache */
   /* replace1156_0 -> 3179 in the cache */
   /* replace1156_1 -> 125 in the cache */
   /* replace1156 -> 3180 in the cache */

   /* ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a */
   /* search1157_0_0 -> 0 in the cache */
   /* search1157_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      5,
   } },
   /* search1157_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 1,
      { 3252, 3 },
      -1,
   } },

   /* replace1157 -> 0 in the cache */

   /* ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1158_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1158_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3254, 120 },
      -1,
   } },
   /* search1158_1_0 -> 32 in the cache */
   /* search1158_1 -> 3254 in the cache */
   /* search1158_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3255, 3254, 122 },
      -1,
   } },

   /* replace1158_0 -> 32 in the cache */
   /* replace1158 -> 3254 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1159_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1159_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3257, 120 },
      -1,
   } },
   /* search1159_1_0 -> 16 in the cache */
   /* search1159_1 -> 3257 in the cache */
   /* search1159_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3258, 3257, 122 },
      -1,
   } },

   /* replace1159_0 -> 16 in the cache */
   /* replace1159 -> 3257 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1160_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1160_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3260, 120 },
      -1,
   } },
   /* search1160_1_0 -> 32 in the cache */
   /* search1160_1 -> 3260 in the cache */
   /* search1160_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3261, 3260, 122 },
      -1,
   } },

   /* replace1160_0 -> 32 in the cache */
   /* replace1160 -> 3260 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1161_0_0 -> 32 in the cache */
   /* search1161_0_1 -> 61 in the cache */
   /* search1161_0 -> 1173 in the cache */
   /* search1161_1_0 -> 32 in the cache */
   /* search1161_1 -> 3254 in the cache */
   /* search1161_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1173, 3254, 122 },
      -1,
   } },

   /* replace1161_0 -> 32 in the cache */
   /* replace1161 -> 3254 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1162_0_0 -> 16 in the cache */
   /* search1162_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 120 },
      -1,
   } },
   /* search1162_1_0 -> 16 in the cache */
   /* search1162_1 -> 3257 in the cache */
   /* search1162_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3264, 3257, 122 },
      -1,
   } },

   /* replace1162_0 -> 16 in the cache */
   /* replace1162 -> 3257 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1163_0_0 -> 32 in the cache */
   /* search1163_0_1 -> 61 in the cache */
   /* search1163_0 -> 1173 in the cache */
   /* search1163_1_0 -> 32 in the cache */
   /* search1163_1 -> 3260 in the cache */
   /* search1163_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1173, 3260, 122 },
      -1,
   } },

   /* replace1163_0 -> 32 in the cache */
   /* replace1163 -> 3260 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1164_0_0 -> 16 in the cache */
   /* search1164_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 122 },
      -1,
   } },
   /* search1164_1_0 -> 16 in the cache */
   /* search1164_1 -> 3257 in the cache */
   /* search1164_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3267, 3257, 122 },
      -1,
   } },

   /* replace1164_0 -> 16 in the cache */
   /* replace1164 -> 3257 in the cache */

   /* ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1165_0_0 -> 502 in the cache */
   /* search1165_0_1 -> 260 in the cache */
   /* search1165_0_2 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 260, 255 },
      0,
   } },
   /* search1165_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3269, 3 },
      -1,
   } },

   /* replace1165_0 -> 502 in the cache */
   /* replace1165_1_0 -> 3 in the cache */
   /* replace1165_1 -> 1034 in the cache */
   /* replace1165_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 1034, 3 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1166_0_0 -> 502 in the cache */
   /* search1166_0_1 -> 255 in the cache */
   /* search1166_0_2 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 255, 260 },
      0,
   } },
   /* search1166_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3272, 3 },
      -1,
   } },

   /* replace1166_0 -> 502 in the cache */
   /* replace1166_1 -> 3 in the cache */
   /* replace1166_2_0 -> 3 in the cache */
   /* replace1166_2 -> 1034 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 3, 1034 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1167_0_0 -> 502 in the cache */
   /* search1167_0_1 -> 263 in the cache */
   /* search1167_0_2 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 263, 228 },
      0,
   } },
   /* search1167_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3275, 36 },
      -1,
   } },

   /* replace1167_0 -> 502 in the cache */
   /* replace1167_1_0 -> 36 in the cache */
   /* replace1167_1 -> 581 in the cache */
   /* replace1167_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 581, 36 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1168_0_0 -> 502 in the cache */
   /* search1168_0_1 -> 228 in the cache */
   /* search1168_0_2 -> 263 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 228, 263 },
      0,
   } },
   /* search1168_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3278, 36 },
      -1,
   } },

   /* replace1168_0 -> 502 in the cache */
   /* replace1168_1 -> 36 in the cache */
   /* replace1168_2_0 -> 36 in the cache */
   /* replace1168_2 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 36, 581 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a') */
   /* search1169_0_0 -> 32 in the cache */
   /* search1169_0_1 -> 113 in the cache */
   /* search1169_0 -> 670 in the cache */
   /* search1169_1_0 -> 32 in the cache */
   /* search1169_1 -> 98 in the cache */
   /* search1169_2 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 670, 98, 32 },
      -1,
   } },

   /* replace1169_0 -> 32 in the cache */
   /* replace1169 -> 103 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd') */
   /* search1170_0 -> 706 in the cache */
   /* search1170_1_0 -> 1075 in the cache */
   /* search1170_1_1 -> 150 in the cache */
   /* search1170_1_2 -> 151 in the cache */
   /* search1170_1 -> 1247 in the cache */
   /* search1170_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 1247, 151 },
      -1,
   } },

   /* replace1170_0_0 -> 706 in the cache */
   /* replace1170_0_1 -> 1075 in the cache */
   /* replace1170_0 -> 1087 in the cache */
   /* replace1170_1 -> 150 in the cache */
   /* replace1170_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1087, 150, 151 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd') */
   /* search1171_0 -> 706 in the cache */
   /* search1171_1 -> 148 in the cache */
   /* search1171_2_0 -> 445 in the cache */
   /* search1171_2_1 -> 148 in the cache */
   /* search1171_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 148, 3284 },
      -1,
   } },

   /* replace1171_0_0 -> 706 in the cache */
   /* replace1171_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 706, 445 },
      -1,
   } },
   /* replace1171_1 -> 148 in the cache */
   /* replace1171_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3286, 148, 151 },
      -1,
   } },

   /* ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b')))) */
   /* search1172_0 -> 0 in the cache */
   /* search1172_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1172_0 -> 0 in the cache */
   /* replace1172_1_0 -> 3 in the cache */
   /* replace1172_1_1_0_0 -> 0 in the cache */
   /* replace1172_1_1_0_1 -> 3 in the cache */
   /* replace1172_1_1_0 -> 2556 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 2556 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3289 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3290 },
      -1,
   } },

   /* ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b')))) */
   /* search1173_0 -> 0 in the cache */
   /* search1173_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1173_0 -> 0 in the cache */
   /* replace1173_1_0 -> 3 in the cache */
   /* replace1173_1_1_0_0 -> 0 in the cache */
   /* replace1173_1_1_0_1 -> 3 in the cache */
   /* replace1173_1_1_0 -> 2556 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 2556 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3294 },
      -1,
   } },

   /* ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a')) */
   /* search1174_0 -> 0 in the cache */
   /* search1174_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1174_0_0_0 -> 0 in the cache */
   /* replace1174_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1174_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3297, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 3298 },
      -1,
   } },

   /* ('usub_borrow@32', 'a', 'b') => ('b2i', ('ult', 'a', 'b')) */
   /* search1175_0 -> 16 in the cache */
   /* search1175_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1175_0_0 -> 16 in the cache */
   /* replace1175_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 3301 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* base */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* insert */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_insert,
      -1, 0,
      { 3303, 3304, 3305, 3306 },
      -1,
   } },

   /* replace1176_0_0 -> 19 in the cache */
   /* replace1176_0_1 -> 3306 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3306 },
      -1,
   } },
   /* replace1176_1 -> 3304 in the cache */
   /* replace1176_2_0_0 -> 3306 in the cache */
   /* replace1176_2_0_1 -> 3305 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3306, 3305 },
      -1,
   } },
   /* replace1176_2_1 -> 3304 in the cache */
   /* replace1176_2_2 -> 3303 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3309, 3304, 3303 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3308, 3304, 3310 },
      -1,
   } },

   /* ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1177_0 -> 0 in the cache */
   /* search1177_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1177_0_0 -> 0 in the cache */
   /* replace1177_0_1 -> 3 in the cache */
   /* replace1177_0 -> 2443 in the cache */
   /* replace1177_1_0_0 -> 0 in the cache */
   /* replace1177_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1177_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3313, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 2443, 3314 },
      -1,
   } },

   /* ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1178_0 -> 0 in the cache */
   /* search1178_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1178_0_0 -> 0 in the cache */
   /* replace1178_0_1 -> 3 in the cache */
   /* replace1178_0 -> 2443 in the cache */
   /* replace1178_1_0_0 -> 0 in the cache */
   /* replace1178_1_0_1 -> 3 in the cache */
   /* replace1178_1_0 -> 3313 in the cache */
   /* replace1178_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3313, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 2443, 3317 },
      -1,
   } },

   /* ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1179_0 -> 0 in the cache */
   /* search1179_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1179_0_0 -> 0 in the cache */
   /* replace1179_0_1 -> 3 in the cache */
   /* replace1179_0 -> 2228 in the cache */
   /* replace1179_1_0_0 -> 0 in the cache */
   /* replace1179_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1179_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3320, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2228, 3321 },
      -1,
   } },

   /* ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1180_0 -> 0 in the cache */
   /* search1180_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1180_0_0 -> 0 in the cache */
   /* replace1180_0_1 -> 3 in the cache */
   /* replace1180_0 -> 2228 in the cache */
   /* replace1180_1_0_0 -> 0 in the cache */
   /* replace1180_1_0_1 -> 3 in the cache */
   /* replace1180_1_0 -> 3320 in the cache */
   /* replace1180_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3320, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2228, 3324 },
      -1,
   } },

   /* ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1181_0 -> 21 in the cache */
   /* search1181_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1181_0_0 -> 21 in the cache */
   /* replace1181_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1181_1_0_0 -> 21 in the cache */
   /* replace1181_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1181_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3328, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3327, 3329 },
      -1,
   } },

   /* ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1182_0 -> 21 in the cache */
   /* search1182_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1182_0_0 -> 21 in the cache */
   /* replace1182_0_1 -> 41 in the cache */
   /* replace1182_0 -> 3327 in the cache */
   /* replace1182_1_0_0 -> 21 in the cache */
   /* replace1182_1_0_1 -> 41 in the cache */
   /* replace1182_1_0 -> 3328 in the cache */
   /* replace1182_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3328, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3327, 3332 },
      -1,
   } },

   /* ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1183_0 -> 21 in the cache */
   /* search1183_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1183_0_0 -> 21 in the cache */
   /* replace1183_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1183_1_0_0 -> 21 in the cache */
   /* replace1183_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1183_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3336, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3335, 3337 },
      -1,
   } },

   /* ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1184_0 -> 21 in the cache */
   /* search1184_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1184_0_0 -> 21 in the cache */
   /* replace1184_0_1 -> 41 in the cache */
   /* replace1184_0 -> 3335 in the cache */
   /* replace1184_1_0_0 -> 21 in the cache */
   /* replace1184_1_0_1 -> 41 in the cache */
   /* replace1184_1_0 -> 3336 in the cache */
   /* replace1184_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3336, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3335, 3340 },
      -1,
   } },

   /* ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1185_0 -> 21 in the cache */
   /* search1185_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1185_0_0_0 -> 21 in the cache */
   /* replace1185_0_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1185_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3343, 21 },
      -1,
   } },
   /* replace1185_1 -> 1428 in the cache */
   /* replace1185_2_0 -> 21 in the cache */
   /* replace1185_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3344, 1428, 3345 },
      -1,
   } },

   /* ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1186_0 -> 0 in the cache */
   /* search1186_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1186_0_0_0 -> 0 in the cache */
   /* replace1186_0_0_1 -> 3 in the cache */
   /* replace1186_0_0 -> 3297 in the cache */
   /* replace1186_0_1 -> 0 in the cache */
   /* replace1186_0 -> 3298 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* replace1186_2_0 -> 0 in the cache */
   /* replace1186_2_1 -> 3 in the cache */
   /* replace1186_2 -> 193 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3298, 3348, 193 },
      -1,
   } },

   /* ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1187_0 -> 0 in the cache */
   /* search1187_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1187_0_0 -> 0 in the cache */
   /* replace1187_0_1 -> 3 in the cache */
   /* replace1187_0 -> 1014 in the cache */
   /* replace1187_1 -> 86 in the cache */
   /* replace1187_2_0 -> 0 in the cache */
   /* replace1187_2_1 -> 3 in the cache */
   /* replace1187_2 -> 3131 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1014, 86, 3131 },
      -1,
   } },

   /* ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1188_0 -> 21 in the cache */
   /* search1188_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1188_0_0 -> 21 in the cache */
   /* replace1188_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   /* replace1188_1 -> 847 in the cache */
   /* replace1188_2_0 -> 21 in the cache */
   /* replace1188_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3353, 847, 3354 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807)) */
   /* search1189_0 -> 21 in the cache */
   /* search1189_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1189_0_0_0_0 -> 21 in the cache */
   /* replace1189_0_0_0_1 -> 847 in the cache */
   /* replace1189_0_0_0 -> 1418 in the cache */
   /* replace1189_0_0_1_0 -> 41 in the cache */
   /* replace1189_0_0_1_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 41, 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1418, 3357 },
      -1,
   } },
   /* replace1189_0_1_0_0 -> 21 in the cache */
   /* replace1189_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1189_0_1_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3359, 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3358, 3360 },
      -1,
   } },
   /* replace1189_1 -> 22 in the cache */
   /* replace1189_2_0_0_0_0 -> 21 in the cache */
   /* replace1189_2_0_0_0_1 -> 847 in the cache */
   /* replace1189_2_0_0_0 -> 1418 in the cache */
   /* replace1189_2_0_0_1_0 -> 41 in the cache */
   /* replace1189_2_0_0_1_1 -> 847 in the cache */
   /* replace1189_2_0_0_1 -> 3357 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      4, 1,
      { 1418, 3357 },
      -1,
   } },
   /* replace1189_2_0_1_0_0 -> 21 in the cache */
   /* replace1189_2_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1189_2_0_1_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3363, 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 3,
      { 3362, 3364 },
      -1,
   } },
   /* replace1189_2_1_0 -> 21 in the cache */
   /* replace1189_2_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      6, 1,
      { 21, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffffffffffff /* 9223372036854775807 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3365, 3366, 3367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 7,
      { 3361, 22, 3368 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807)) */
   /* search1190_0 -> 21 in the cache */
   /* search1190_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1190_0_0_0_0 -> 21 in the cache */
   /* replace1190_0_0_0_1 -> 847 in the cache */
   /* replace1190_0_0_0 -> 1418 in the cache */
   /* replace1190_0_0_1_0 -> 41 in the cache */
   /* replace1190_0_0_1_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1418, 3371 },
      -1,
   } },
   /* replace1190_0_1_0_0 -> 21 in the cache */
   /* replace1190_0_1_0_1 -> 41 in the cache */
   /* replace1190_0_1_0 -> 3354 in the cache */
   /* replace1190_0_1_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3354, 847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3372, 3373 },
      -1,
   } },
   /* replace1190_1 -> 22 in the cache */
   /* replace1190_2_0_0_0_0 -> 21 in the cache */
   /* replace1190_2_0_0_0_1 -> 847 in the cache */
   /* replace1190_2_0_0_0 -> 1418 in the cache */
   /* replace1190_2_0_0_1_0 -> 41 in the cache */
   /* replace1190_2_0_0_1_1 -> 847 in the cache */
   /* replace1190_2_0_0_1 -> 3371 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 1,
      { 1418, 3371 },
      -1,
   } },
   /* replace1190_2_0_1_0_0 -> 21 in the cache */
   /* replace1190_2_0_1_0_1 -> 41 in the cache */
   /* replace1190_2_0_1_0 -> 3354 in the cache */
   /* replace1190_2_0_1_1 -> 847 in the cache */
   /* replace1190_2_0_1 -> 3373 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 3375, 3373 },
      -1,
   } },
   /* replace1190_2_1_0 -> 21 in the cache */
   /* replace1190_2_1_1 -> 41 in the cache */
   /* replace1190_2_1 -> 3354 in the cache */
   /* replace1190_2_2 -> 3367 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3376, 3354, 3367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3374, 22, 3377 },
      -1,
   } },

   /* ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1191_0_0 -> 21 in the cache */
   /* search1191_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1191_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3379, 847 },
      -1,
   } },

   /* replace1191_0_0_0 -> 21 in the cache */
   /* replace1191_0_0 -> 2888 in the cache */
   /* replace1191_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2888, 3381 },
      -1,
   } },
   /* replace1191_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3382, 120 },
      -1,
   } },

   /* ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1192_0_0 -> 21 in the cache */
   /* search1192_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1192_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3384, 847 },
      -1,
   } },

   /* replace1192_0_0_0 -> 21 in the cache */
   /* replace1192_0_0 -> 2888 in the cache */
   /* replace1192_0_1_0 -> 41 in the cache */
   /* replace1192_0_1 -> 3381 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2888, 3381 },
      -1,
   } },
   /* replace1192_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3386, 120 },
      -1,
   } },

   /* ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1193_0_0 -> 21 in the cache */
   /* search1193_0_1 -> 41 in the cache */
   /* search1193_0 -> 3379 in the cache */
   /* search1193_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3379, 847 },
      -1,
   } },

   /* replace1193_0_0_0 -> 21 in the cache */
   /* replace1193_0_0 -> 2888 in the cache */
   /* replace1193_0_1_0 -> 41 in the cache */
   /* replace1193_0_1 -> 3381 in the cache */
   /* replace1193_0 -> 3382 in the cache */
   /* replace1193_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3382, 120 },
      -1,
   } },

   /* ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1194_0_0 -> 21 in the cache */
   /* search1194_0_1 -> 41 in the cache */
   /* search1194_0 -> 3384 in the cache */
   /* search1194_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3384, 847 },
      -1,
   } },

   /* replace1194_0_0_0 -> 21 in the cache */
   /* replace1194_0_0 -> 2888 in the cache */
   /* replace1194_0_1_0 -> 41 in the cache */
   /* replace1194_0_1 -> 3381 in the cache */
   /* replace1194_0 -> 3386 in the cache */
   /* replace1194_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3386, 120 },
      -1,
   } },

   /* ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1195_0 -> 21 in the cache */
   /* search1195_1 -> 847 in the cache */
   /* search1195 -> 1418 in the cache */

   /* replace1195_0_0 -> 21 in the cache */
   /* replace1195_0 -> 2888 in the cache */
   /* replace1195_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2888, 120 },
      -1,
   } },

   /* ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1196_0 -> 21 in the cache */
   /* search1196_1 -> 847 in the cache */
   /* search1196 -> 1415 in the cache */

   /* replace1196_0_0 -> 21 in the cache */
   /* replace1196_0 -> 2888 in the cache */
   /* replace1196_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2888, 120 },
      -1,
   } },

   /* ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1197_0 -> 21 in the cache */
   /* search1197_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 21, 847 },
      -1,
   } },

   /* replace1197_0_0_0 -> 21 in the cache */
   /* replace1197_0_0 -> 2887 in the cache */
   /* replace1197_0_1_0 -> 21 in the cache */
   /* replace1197_0_1 -> 2888 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 2887, 2888 },
      -1,
   } },
   /* replace1197_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3395, 120 },
      -1,
   } },

   /* ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1198_0 -> 21 in the cache */
   /* search1198_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 21, 847 },
      -1,
   } },

   /* replace1198_0_0_0 -> 21 in the cache */
   /* replace1198_0_0 -> 2887 in the cache */
   /* replace1198_0_1_0 -> 21 in the cache */
   /* replace1198_0_1 -> 2888 in the cache */
   /* replace1198_0 -> 3395 in the cache */
   /* replace1198_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3395, 120 },
      -1,
   } },

   /* ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1199_0 -> 847 in the cache */
   /* search1199_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 847, 21 },
      -1,
   } },

   /* replace1199_0_0_0 -> 21 in the cache */
   /* replace1199_0_0 -> 2887 in the cache */
   /* replace1199_0_1_0 -> 21 in the cache */
   /* replace1199_0_1 -> 2888 in the cache */
   /* replace1199_0 -> 3395 in the cache */
   /* replace1199_1 -> 120 in the cache */
   /* replace1199 -> 3396 in the cache */

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset')))) */
   /* search1200_0 -> 3303 in the cache */
   /* search1200_1 -> 3304 in the cache */
   /* search1200_2 -> 3305 in the cache */
   /* search1200_3 -> 3306 in the cache */
   /* search1200 -> 3307 in the cache */

   /* replace1200_0_0 -> 19 in the cache */
   /* replace1200_0_1 -> 3306 in the cache */
   /* replace1200_0 -> 3308 in the cache */
   /* replace1200_1 -> 3304 in the cache */
   /* replace1200_2_0_0 -> 3303 in the cache */
   /* replace1200_2_0_1_0_0_0_0 -> 377 in the cache */
   /* replace1200_2_0_1_0_0_0_1 -> 3306 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 377, 3306 },
      -1,
   } },
   /* replace1200_2_0_1_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3400, 377 },
      -1,
   } },
   /* replace1200_2_0_1_0_1 -> 3305 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3401, 3305 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3402 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3303, 3403 },
      -1,
   } },
   /* replace1200_2_1_0_0 -> 3304 in the cache */
   /* replace1200_2_1_0_1 -> 3305 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3304, 3305 },
      -1,
   } },
   /* replace1200_2_1_1_0_0_0 -> 377 in the cache */
   /* replace1200_2_1_1_0_0_1 -> 3306 in the cache */
   /* replace1200_2_1_1_0_0 -> 3400 in the cache */
   /* replace1200_2_1_1_0_1 -> 377 in the cache */
   /* replace1200_2_1_1_0 -> 3401 in the cache */
   /* replace1200_2_1_1_1 -> 3305 in the cache */
   /* replace1200_2_1_1 -> 3402 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 3405, 3402 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3404, 3406 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 3308, 3304, 3407 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base')) */
   /* search1201_0 -> 3303 in the cache */
   /* search1201_1 -> 3304 in the cache */
   /* search1201_2 -> 3305 in the cache */
   /* search1201_3 -> 3306 in the cache */
   /* search1201 -> 3307 in the cache */

   /* replace1201_0_0 -> 19 in the cache */
   /* replace1201_0_1 -> 3306 in the cache */
   /* replace1201_0 -> 3308 in the cache */
   /* replace1201_1 -> 3304 in the cache */
   /* replace1201_2_0_0 -> 3306 in the cache */
   /* replace1201_2_0_1 -> 3305 in the cache */
   /* replace1201_2_0 -> 3309 in the cache */
   /* replace1201_2_1_0 -> 3304 in the cache */
   /* replace1201_2_1_1 -> 3305 in the cache */
   /* replace1201_2_1 -> 3405 in the cache */
   /* replace1201_2_2 -> 3303 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 3309, 3405, 3303 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3308, 3304, 3409 },
      -1,
   } },

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibitfield_extract,
      -1, 0,
      { 3411, 3412, 3413 },
      -1,
   } },

   /* replace1202_0_0 -> 19 in the cache */
   /* replace1202_0_1 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3413 },
      -1,
   } },
   /* replace1202_1 -> 3411 in the cache */
   /* replace1202_2_0 -> 3411 in the cache */
   /* replace1202_2_1 -> 3412 in the cache */
   /* replace1202_2_2 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 3411, 3412, 3413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3415, 3411, 3416 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits')) */
   /* search1203_0 -> 3411 in the cache */
   /* search1203_1 -> 3412 in the cache */
   /* search1203_2 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubitfield_extract,
      -1, 0,
      { 3411, 3412, 3413 },
      -1,
   } },

   /* replace1203_0_0 -> 19 in the cache */
   /* replace1203_0_1 -> 3413 in the cache */
   /* replace1203_0 -> 3415 in the cache */
   /* replace1203_1 -> 3411 in the cache */
   /* replace1203_2_0 -> 3411 in the cache */
   /* replace1203_2_1 -> 3412 in the cache */
   /* replace1203_2_2 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 3411, 3412, 3413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3415, 3411, 3419 },
      -1,
   } },

   /* ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b') */
   /* search1204_0 -> 0 in the cache */
   /* search1204_1 -> 3 in the cache */
   /* search1204_2 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 0, 3, 86 },
      -1,
   } },

   /* replace1204_0 -> 0 in the cache */
   /* replace1204_1 -> 3 in the cache */
   /* replace1204 -> 2448 in the cache */

   /* ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c') */
   /* search1205_0 -> 124 in the cache */
   /* search1205_1_0 -> 124 in the cache */
   /* search1205_1_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 124, 125 },
      -1,
   } },
   /* search1205_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 1,
      { 124, 3422, 127 },
      -1,
   } },

   /* replace1205_0 -> 124 in the cache */
   /* replace1205_1 -> 125 in the cache */
   /* replace1205_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 124, 125, 127 },
      -1,
   } },

   /* ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits') */
   /* search1206_0 -> 3411 in the cache */
   /* search1206_1 -> 3412 in the cache */
   /* search1206_2_0 -> 19 in the cache */
   /* search1206_2_1 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3411, 3412, 3425 },
      -1,
   } },

   /* replace1206_0 -> 3411 in the cache */
   /* replace1206_1 -> 3412 in the cache */
   /* replace1206_2 -> 3413 in the cache */
   /* replace1206 -> 3419 in the cache */

   /* ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits') */
   /* search1207_0 -> 3411 in the cache */
   /* search1207_1_0 -> 19 in the cache */
   /* search1207_1_1 -> 3412 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3412 },
      -1,
   } },
   /* search1207_2 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3411, 3427, 3413 },
      -1,
   } },

   /* replace1207_0 -> 3411 in the cache */
   /* replace1207_1 -> 3412 in the cache */
   /* replace1207_2 -> 3413 in the cache */
   /* replace1207 -> 3419 in the cache */

   /* ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits') */
   /* search1208_0 -> 3411 in the cache */
   /* search1208_1 -> 3412 in the cache */
   /* search1208_2_0 -> 19 in the cache */
   /* search1208_2_1 -> 3413 in the cache */
   /* search1208_2 -> 3425 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3411, 3412, 3425 },
      -1,
   } },

   /* replace1208_0 -> 3411 in the cache */
   /* replace1208_1 -> 3412 in the cache */
   /* replace1208_2 -> 3413 in the cache */
   /* replace1208 -> 3416 in the cache */

   /* ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits') */
   /* search1209_0 -> 3411 in the cache */
   /* search1209_1_0 -> 19 in the cache */
   /* search1209_1_1 -> 3412 in the cache */
   /* search1209_1 -> 3427 in the cache */
   /* search1209_2 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3411, 3427, 3413 },
      -1,
   } },

   /* replace1209_0 -> 3411 in the cache */
   /* replace1209_1 -> 3412 in the cache */
   /* replace1209_2 -> 3413 in the cache */
   /* replace1209 -> 3416 in the cache */

   /* ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1210_1_0 -> 19 in the cache */
   /* search1210_1_1 -> 3412 in the cache */
   /* search1210_1 -> 3427 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3431, 3427 },
      -1,
   } },

   /* replace1210_0 -> 3431 in the cache */
   /* replace1210_1 -> 3412 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3431, 3412 },
      -1,
   } },

   /* ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset') */
   /* search1211_0_0 -> 19 in the cache */
   /* search1211_0_1 -> 3431 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3431 },
      -1,
   } },
   /* search1211_1 -> 3412 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3434, 3412 },
      -1,
   } },

   /* replace1211_0 -> 3431 in the cache */
   /* replace1211_1 -> 3412 in the cache */
   /* replace1211 -> 3433 in the cache */

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search1212_0 -> 16 in the cache */
   /* search1212_1 -> 36 in the cache */
   /* search1212_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1212 -> 120 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search1213_0 -> 16 in the cache */
   /* search1213_1 -> 36 in the cache */
   /* search1213_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1213 -> 120 in the cache */

   /* ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b'))) */
   /* search1214_0 -> 16 in the cache */
   /* search1214_1 -> 120 in the cache */
   /* search1214_2 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 33 },
      -1,
   } },

   /* replace1214_0 -> 16 in the cache */
   /* replace1214_1_0 -> 819 in the cache */
   /* replace1214_1_1_0 -> 36 in the cache */
   /* replace1214_1_1 -> 2461 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 819, 2461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 3439 },
      -1,
   } },

   /* ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1215_0_0_0 -> 16 in the cache */
   /* search1215_0_0_1 -> 36 in the cache */
   /* search1215_0_0_2 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3441 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3442 },
      -1,
   } },

   /* replace1215_0 -> 16 in the cache */
   /* replace1215_1 -> 36 in the cache */
   /* replace1215_2 -> 377 in the cache */
   /* replace1215 -> 3441 in the cache */

   /* ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1216_0_0_0 -> 16 in the cache */
   /* search1216_0_0_1 -> 36 in the cache */
   /* search1216_0_0_2 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3444 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3445 },
      -1,
   } },

   /* replace1216_0 -> 16 in the cache */
   /* replace1216_1 -> 36 in the cache */
   /* replace1216_2 -> 377 in the cache */
   /* replace1216 -> 3441 in the cache */

   /* ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1217_0_0 -> 16 in the cache */
   /* search1217_0_1 -> 33 in the cache */
   /* search1217_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 33, 294 },
      0,
   } },
   /* search1217_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3447, 120 },
      -1,
   } },

   /* replace1217_0_0 -> 16 in the cache */
   /* replace1217_0_1_0_0 -> 819 in the cache */
   /* replace1217_0_1_0_1_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 819, 3449 },
      -1,
   } },
   /* replace1217_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3450, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3451 },
      -1,
   } },
   /* replace1217_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3452, 120 },
      -1,
   } },

   /* ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1218_0_0 -> 16 in the cache */
   /* search1218_0_1 -> 33 in the cache */
   /* search1218_0_2 -> 294 in the cache */
   /* search1218_0 -> 3447 in the cache */
   /* search1218_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3447, 120 },
      -1,
   } },

   /* replace1218_0_0 -> 16 in the cache */
   /* replace1218_0_1_0_0 -> 819 in the cache */
   /* replace1218_0_1_0_1_0 -> 133 in the cache */
   /* replace1218_0_1_0_1 -> 3449 in the cache */
   /* replace1218_0_1_0 -> 3450 in the cache */
   /* replace1218_0_1_1 -> 36 in the cache */
   /* replace1218_0_1 -> 3451 in the cache */
   /* replace1218_0 -> 3452 in the cache */
   /* replace1218_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3452, 120 },
      -1,
   } },

   /* ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1219_0_0 -> 16 in the cache */
   /* search1219_0_1 -> 33 in the cache */
   /* search1219_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 33, 294 },
      0,
   } },
   /* search1219_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3456, 120 },
      -1,
   } },

   /* replace1219_0_0 -> 16 in the cache */
   /* replace1219_0_1_0_0 -> 819 in the cache */
   /* replace1219_0_1_0_1_0 -> 133 in the cache */
   /* replace1219_0_1_0_1 -> 3449 in the cache */
   /* replace1219_0_1_0 -> 3450 in the cache */
   /* replace1219_0_1_1 -> 36 in the cache */
   /* replace1219_0_1 -> 3451 in the cache */
   /* replace1219_0 -> 3452 in the cache */
   /* replace1219_1 -> 120 in the cache */
   /* replace1219 -> 3453 in the cache */

   /* ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1220_0_0 -> 16 in the cache */
   /* search1220_0_1 -> 33 in the cache */
   /* search1220_0_2 -> 294 in the cache */
   /* search1220_0 -> 3456 in the cache */
   /* search1220_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3456, 120 },
      -1,
   } },

   /* replace1220_0_0 -> 16 in the cache */
   /* replace1220_0_1_0_0 -> 819 in the cache */
   /* replace1220_0_1_0_1_0 -> 133 in the cache */
   /* replace1220_0_1_0_1 -> 3449 in the cache */
   /* replace1220_0_1_0 -> 3450 in the cache */
   /* replace1220_0_1_1 -> 36 in the cache */
   /* replace1220_0_1 -> 3451 in the cache */
   /* replace1220_0 -> 3452 in the cache */
   /* replace1220_1 -> 120 in the cache */
   /* replace1220 -> 3455 in the cache */

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits'))) */
   /* search1221_0 -> 3411 in the cache */
   /* search1221_1 -> 3412 in the cache */
   /* search1221_2 -> 3413 in the cache */
   /* search1221 -> 3414 in the cache */

   /* replace1221_0_0 -> 120 in the cache */
   /* replace1221_0_1 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 120, 3413 },
      -1,
   } },
   /* replace1221_1 -> 120 in the cache */
   /* replace1221_2_0_0 -> 3411 in the cache */
   /* replace1221_2_0_1_0_0 -> 823 in the cache */
   /* replace1221_2_0_1_0_1 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 823, 3413 },
      -1,
   } },
   /* replace1221_2_0_1_1 -> 3412 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3460, 3412 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3411, 3461 },
      -1,
   } },
   /* replace1221_2_1_0 -> 823 in the cache */
   /* replace1221_2_1_1 -> 3413 in the cache */
   /* replace1221_2_1 -> 3460 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 3462, 3460 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3459, 120, 3463 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1))) */
   /* search1222_0 -> 3411 in the cache */
   /* search1222_1 -> 3412 in the cache */
   /* search1222_2 -> 3413 in the cache */
   /* search1222 -> 3418 in the cache */

   /* replace1222_0_0 -> 3411 in the cache */
   /* replace1222_0_1 -> 3412 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3411, 3412 },
      -1,
   } },
   /* replace1222_1_0_0 -> 3413 in the cache */
   /* replace1222_1_0_1 -> 823 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3413, 823 },
      -1,
   } },
   /* replace1222_1_1 -> 819 in the cache */
   /* replace1222_1_2_0_0 -> 377 in the cache */
   /* replace1222_1_2_0_1 -> 3413 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 377, 3413 },
      -1,
   } },
   /* replace1222_1_2_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3467, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3466, 819, 3468 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3465, 3469 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value')) */
   /* search1223_0 -> 3411 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 3411 },
      -1,
   } },

   /* replace1223_0_0_0 -> 3411 in the cache */
   /* replace1223_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3411, 120 },
      -1,
   } },
   /* replace1223_0_1_0 -> 3411 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3411 },
      -1,
   } },
   /* replace1223_0_2 -> 3411 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3472, 3473, 3411 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3474 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value')) */
   /* search1224_0 -> 3411 in the cache */
   /* search1224 -> 3471 in the cache */

   /* replace1224_0_0_0 -> 3411 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 3411 },
      -1,
   } },
   /* replace1224_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3476, 120 },
      -1,
   } },
   /* replace1224_1_0 -> 19 in the cache */
   /* replace1224_1_1_0 -> 3411 in the cache */
   /* replace1224_1_1 -> 3476 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3476 },
      -1,
   } },
   /* replace1224_2_0 -> 3411 in the cache */
   /* replace1224_2 -> 3476 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3477, 3478, 3476 },
      -1,
   } },

   /* ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3480 },
      -1,
   } },

   /* replace1225_0_0_0 -> 3480 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3480 },
      -1,
   } },
   /* replace1225_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3482, 120 },
      -1,
   } },
   /* replace1225_1_0 -> 19 in the cache */
   /* replace1225_1_1_0 -> 3480 in the cache */
   /* replace1225_1_1 -> 3482 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3482 },
      -1,
   } },
   /* replace1225_2_0 -> 3480 in the cache */
   /* replace1225_2 -> 3482 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3483, 3484, 3482 },
      -1,
   } },

   /* ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value'))) */
   /* search1226_0 -> 3480 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3480 },
      -1,
   } },

   /* replace1226_0_0 -> 3480 in the cache */
   /* replace1226_0_1_0 -> 3480 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3480, 3487 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 1,
      { 3488 },
      -1,
   } },

   /* ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24) */
   /* search1227_0 -> 16 in the cache */
   /* search1227_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1227_0_0 -> 16 in the cache */
   /* replace1227_0_1_0_0 -> 386 in the cache */
   /* replace1227_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 386, 36 },
      -1,
   } },
   /* replace1227_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3491, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3492 },
      -1,
   } },
   /* replace1227_1 -> 959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3493, 959 },
      -1,
   } },

   /* ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255) */
   /* search1228_0 -> 16 in the cache */
   /* search1228_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1228_0_0 -> 16 in the cache */
   /* replace1228_0_1_0 -> 36 in the cache */
   /* replace1228_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3496 },
      -1,
   } },
   /* replace1228_1 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3497, 774 },
      -1,
   } },

   /* ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16) */
   /* search1229_0 -> 16 in the cache */
   /* search1229_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1229_0_0 -> 16 in the cache */
   /* replace1229_0_1_0_0 -> 377 in the cache */
   /* replace1229_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 377, 36 },
      -1,
   } },
   /* replace1229_0_1_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3500, 801 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3501 },
      -1,
   } },
   /* replace1229_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3502, 801 },
      -1,
   } },

   /* ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535) */
   /* search1230_0 -> 16 in the cache */
   /* search1230_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1230_0_0 -> 16 in the cache */
   /* replace1230_0_1_0 -> 36 in the cache */
   /* replace1230_0_1_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 801 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3505 },
      -1,
   } },
   /* replace1230_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3506, 797 },
      -1,
   } },

   /* ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0)))) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* v */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_2x16,
      -1, 0,
      { 3508 },
      -1,
   } },

   /* replace1231_0_0_0_0_0 -> 3508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3508 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3510, 3511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3512 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 1,
      { 3514 },
      -1,
   } },

   /* ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0)))) */
   /* search1232_0 -> 3508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_4x8,
      -1, 0,
      { 3508 },
      -1,
   } },

   /* replace1232_0_0_0_0_0 -> 3508 in the cache */
   /* replace1232_0_0_0_0 -> 3510 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3510, 3517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 1,
      { 3520 },
      -1,
   } },

   /* ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0)))) */
   /* search1233_0 -> 3508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_2x16,
      -1, 0,
      { 3508 },
      -1,
   } },

   /* replace1233_0_0_0_0_0 -> 228 in the cache */
   /* replace1233_0_0_0_0_1_0 -> 263 in the cache */
   /* replace1233_0_0_0_0_1_1 -> 3508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 263, 3508 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 228, 3523 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3524, 3525 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3527 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 3,
      { 3528 },
      -1,
   } },

   /* ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0)))) */
   /* search1234_0 -> 3508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_4x8,
      -1, 0,
      { 3508 },
      -1,
   } },

   /* replace1234_0_0_0_0_0 -> 228 in the cache */
   /* replace1234_0_0_0_0_1_0 -> 263 in the cache */
   /* replace1234_0_0_0_0_1_1 -> 3508 in the cache */
   /* replace1234_0_0_0_0_1 -> 3523 in the cache */
   /* replace1234_0_0_0_0 -> 3524 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3524, 3531 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3532 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 3,
      { 3534 },
      -1,
   } },

   /* ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0) */
   /* search1235_0 -> 3508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_2x16,
      -1, 0,
      { 3508 },
      -1,
   } },

   /* replace1235_0_0_0_0 -> 3508 in the cache */
   /* replace1235_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3508, 120 },
      -1,
   } },
   /* replace1235_0_0_1_0 -> 3508 in the cache */
   /* replace1235_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3508, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3537, 3538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3539 },
      -1,
   } },
   /* replace1235_1 -> 3511 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3540, 3511 },
      -1,
   } },

   /* ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0) */
   /* search1236_0 -> 3508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_4x8,
      -1, 0,
      { 3508 },
      -1,
   } },

   /* replace1236_0_0_0_0 -> 3508 in the cache */
   /* replace1236_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3508, 120 },
      -1,
   } },
   /* replace1236_0_0_1_0 -> 3508 in the cache */
   /* replace1236_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3508, 377 },
      -1,
   } },
   /* replace1236_0_0_2_0 -> 3508 in the cache */
   /* replace1236_0_0_2_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3508, 382 },
      -1,
   } },
   /* replace1236_0_0_3_0 -> 3508 in the cache */
   /* replace1236_0_0_3_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3508, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3543, 3544, 3545, 3546 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3547 },
      -1,
   } },
   /* replace1236_1 -> 3517 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3548, 3517 },
      -1,
   } },

   /* ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0))) */
   /* search1237_0 -> 3508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_2x16,
      -1, 0,
      { 3508 },
      -1,
   } },

   /* replace1237_0 -> 228 in the cache */
   /* replace1237_1_0 -> 263 in the cache */
   /* replace1237_1_1_0_0_0_0 -> 3508 in the cache */
   /* replace1237_1_1_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3508, 120 },
      -1,
   } },
   /* replace1237_1_1_0_0_1_0 -> 3508 in the cache */
   /* replace1237_1_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3508, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3551, 3552 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3553 },
      -1,
   } },
   /* replace1237_1_1_1 -> 3525 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3554, 3525 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 263, 3555 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 228, 3556 },
      -1,
   } },

   /* ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0))) */
   /* search1238_0 -> 3508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_4x8,
      -1, 0,
      { 3508 },
      -1,
   } },

   /* replace1238_0 -> 228 in the cache */
   /* replace1238_1_0 -> 263 in the cache */
   /* replace1238_1_1_0_0_0_0 -> 3508 in the cache */
   /* replace1238_1_1_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3508, 120 },
      -1,
   } },
   /* replace1238_1_1_0_0_1_0 -> 3508 in the cache */
   /* replace1238_1_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3508, 377 },
      -1,
   } },
   /* replace1238_1_1_0_0_2_0 -> 3508 in the cache */
   /* replace1238_1_1_0_0_2_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3508, 382 },
      -1,
   } },
   /* replace1238_1_1_0_0_3_0 -> 3508 in the cache */
   /* replace1238_1_1_0_0_3_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3508, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3559, 3560, 3561, 3562 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3563 },
      -1,
   } },
   /* replace1238_1_1_1 -> 3531 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3564, 3531 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 263, 3565 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 228, 3566 },
      -1,
   } },

   /* ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a'))) */
   /* search1239_0 -> 16 in the cache */
   /* search1239_1 -> 36 in the cache */
   /* search1239 -> 3018 in the cache */

   /* replace1239_0_0_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3568 },
      -1,
   } },
   /* replace1239_0_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3569, 801 },
      -1,
   } },
   /* replace1239_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3570, 3572 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a')) */
   /* search1240_0 -> 16 in the cache */
   /* search1240 -> 2983 in the cache */

   /* replace1240_0_0 -> 16 in the cache */
   /* replace1240_0 -> 2980 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2980 },
      -1,
   } },

   /* ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16))) */
   /* search1241_0 -> 16 in the cache */
   /* search1241 -> 2990 in the cache */

   /* replace1241_0_0_0 -> 16 in the cache */
   /* replace1241_0_0_1 -> 801 in the cache */
   /* replace1241_0_0 -> 956 in the cache */
   /* replace1241_0 -> 2981 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2981 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a')) */
   /* search1242_0 -> 11 in the cache */
   /* search1242_1 -> 243 in the cache */
   /* search1242 -> 2973 in the cache */

   /* replace1242_0_0_0 -> 243 in the cache */
   /* replace1242_0_0 -> 2974 in the cache */
   /* replace1242_0_1 -> 801 in the cache */
   /* replace1242_0 -> 2975 in the cache */
   /* replace1242_1_0 -> 11 in the cache */
   /* replace1242_1 -> 1734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2975, 1734 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a') */
   /* search1243_0 -> 16 in the cache */
   /* search1243 -> 2896 in the cache */

   /* replace1243_0 -> 16 in the cache */
   /* replace1243 -> 2980 in the cache */

   /* ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1244_0 -> 16 in the cache */
   /* search1244 -> 2898 in the cache */

   /* replace1244_0_0 -> 16 in the cache */
   /* replace1244_0_1 -> 801 in the cache */
   /* replace1244_0 -> 956 in the cache */
   /* replace1244 -> 2981 in the cache */

   /* ('isign', 'a') => ('imin', ('imax', 'a', -1), 1) */
   /* search1245_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1245_0_0 -> 32 in the cache */
   /* replace1245_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 63 },
      -1,
   } },
   /* replace1245_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 3578, 35 },
      -1,
   } },

   /* ('imin', ('imax', 'a', -1), 1) => ('isign', 'a') */
   /* search1246_0_0 -> 32 in the cache */
   /* search1246_0_1 -> 63 in the cache */
   /* search1246_0 -> 3578 in the cache */
   /* search1246_1 -> 35 in the cache */
   /* search1246 -> 3579 in the cache */

   /* replace1246_0 -> 32 in the cache */
   /* replace1246 -> 3577 in the cache */

   /* ('imax', ('imin', 'a', 1), -1) => ('isign', 'a') */
   /* search1247_0_0 -> 32 in the cache */
   /* search1247_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 32, 35 },
      -1,
   } },
   /* search1247_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 3580, 63 },
      -1,
   } },

   /* replace1247_0 -> 32 in the cache */
   /* replace1247 -> 3577 in the cache */

   /* ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0))) */
   /* search1248_0 -> 32 in the cache */
   /* search1248 -> 235 in the cache */

   /* replace1248_0_0_0 -> 113 in the cache */
   /* replace1248_0_0_1 -> 32 in the cache */
   /* replace1248_0_0 -> 1455 in the cache */
   /* replace1248_0 -> 1456 in the cache */
   /* replace1248_1_0_0 -> 32 in the cache */
   /* replace1248_1_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 3582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 1456, 3583 },
      -1,
   } },

   /* ('amul', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1249_0 -> 0 in the cache */
   /* search1249_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_amul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1249_0 -> 0 in the cache */
   /* replace1249_1 -> 3 in the cache */
   /* replace1249 -> 900 in the cache */

   /* ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)) */
   /* search1250_0 -> 16 in the cache */
   /* search1250_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1250_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff /* 16777215 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3587 },
      -1,
   } },
   /* replace1250_1_0 -> 36 in the cache */
   /* replace1250_1_1 -> 3587 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 3587 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 3588, 3589 },
      -1,
   } },

   /* ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c') */
   /* search1251_0 -> 16 in the cache */
   /* search1251_1 -> 36 in the cache */
   /* search1251_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace1251_0_0_0 -> 16 in the cache */
   /* replace1251_0_0_1 -> 3587 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 16, 3587 },
      -1,
   } },
   /* replace1251_0_1_0 -> 36 in the cache */
   /* replace1251_0_1_1 -> 3587 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 36, 3587 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 3,
      { 3592, 3593 },
      -1,
   } },
   /* replace1251_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 3594, 133 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b') */
   /* search1252_0 -> 16 in the cache */
   /* search1252_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1252_0 -> 16 in the cache */
   /* replace1252_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1253_0 -> 16 in the cache */
   /* search1253_1 -> 36 in the cache */
   /* search1253 -> 3596 in the cache */

   /* replace1253_0 -> 16 in the cache */
   /* replace1253_1 -> 36 in the cache */
   /* replace1253 -> 49 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c') */
   /* search1254_0 -> 16 in the cache */
   /* search1254_1 -> 36 in the cache */
   /* search1254_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24_relaxed,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace1254_0 -> 16 in the cache */
   /* replace1254_1 -> 36 in the cache */
   /* replace1254_2 -> 133 in the cache */
   /* replace1254 -> 3591 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c') */
   /* search1255_0 -> 16 in the cache */
   /* search1255_1 -> 36 in the cache */
   /* search1255_2 -> 133 in the cache */
   /* search1255 -> 3598 in the cache */

   /* replace1255_0_0 -> 16 in the cache */
   /* replace1255_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1255_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3599, 133 },
      -1,
   } },

   /* ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b') */
   /* search1256_0 -> 16 in the cache */
   /* search1256_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1256_0 -> 16 in the cache */
   /* replace1256_1 -> 36 in the cache */
   /* replace1256 -> 3586 in the cache */

   /* ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1257_0 -> 16 in the cache */
   /* search1257_1 -> 36 in the cache */
   /* search1257 -> 3601 in the cache */

   /* replace1257_0 -> 16 in the cache */
   /* replace1257_1 -> 36 in the cache */
   /* replace1257 -> 49 in the cache */

   /* ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b') */
   /* search1258_0 -> 16 in the cache */
   /* search1258_1 -> 36 in the cache */
   /* search1258_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1258_0 -> 16 in the cache */
   /* replace1258_1 -> 36 in the cache */
   /* replace1258 -> 3597 in the cache */

   /* ('imad24_ir3', 'a', 0, 'c') => c */
   /* search1259_0 -> 16 in the cache */
   /* search1259_1 -> 120 in the cache */
   /* search1259_2 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 120, 536 },
      -1,
   } },

   /* replace1259 -> 536 in the cache */

   /* ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c') */
   /* search1260_0 -> 16 in the cache */
   /* search1260_1 -> 377 in the cache */
   /* search1260_2 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 377, 536 },
      -1,
   } },

   /* replace1260_0 -> 16 in the cache */
   /* replace1260_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 536 },
      -1,
   } },

   /* ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c') */
   /* search1261_0 -> 271 in the cache */
   /* search1261_1 -> 33 in the cache */
   /* search1261_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 271, 33, 133 },
      -1,
   } },

   /* replace1261_0_0 -> 16 in the cache */
   /* replace1261_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1261_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3607, 133 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   /* search1262_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3609 },
      -1,
   } },

   /* replace1262_0 -> 16 in the cache */
   /* replace1262_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3611 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search1263_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3613 },
      -1,
   } },

   /* replace1263_0_0 -> 16 in the cache */
   /* replace1263_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3615 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3616 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3617 },
      -1,
   } },

   /* ('imul24', 'a', 0) => 0 */
   /* search1264_0 -> 16 in the cache */
   /* search1264_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace1264 -> 120 in the cache */

   /* ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search1265_0_0 -> 120 in the cache */
   /* search1265_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1265_1 -> 36 in the cache */
   /* search1265_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3620, 36, 133 },
      -1,
   } },

   /* replace1265_0 -> 16 in the cache */
   /* replace1265_1 -> 36 in the cache */
   /* replace1265_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'c', 'b') */
   /* search1266_0_0 -> 16 in the cache */
   /* search1266_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1266_1 -> 36 in the cache */
   /* search1266_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3623, 36, 133 },
      -1,
   } },

   /* replace1266_0 -> 16 in the cache */
   /* replace1266_1 -> 133 in the cache */
   /* replace1266_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search1267_0_0 -> 16 in the cache */
   /* search1267_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1267_1 -> 36 in the cache */
   /* search1267_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3626, 36, 133 },
      -1,
   } },

   /* replace1267_0 -> 16 in the cache */
   /* replace1267_1 -> 36 in the cache */
   /* replace1267_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'c', 'b') */
   /* search1268_0_0 -> 120 in the cache */
   /* search1268_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1268_1 -> 36 in the cache */
   /* search1268_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3629, 36, 133 },
      -1,
   } },

   /* replace1268_0 -> 16 in the cache */
   /* replace1268_1 -> 133 in the cache */
   /* replace1268_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c') */
   /* search1269_0_0 -> 120 in the cache */
   /* search1269_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1269_1 -> 36 in the cache */
   /* search1269_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3632, 36, 133 },
      -1,
   } },

   /* replace1269_0 -> 16 in the cache */
   /* replace1269_1 -> 36 in the cache */
   /* replace1269_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b') */
   /* search1270_0_0 -> 16 in the cache */
   /* search1270_0_1 -> 120 in the cache */
   /* search1270_0 -> 1398 in the cache */
   /* search1270_1 -> 36 in the cache */
   /* search1270_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1398, 36, 133 },
      -1,
   } },

   /* replace1270_0 -> 16 in the cache */
   /* replace1270_1 -> 133 in the cache */
   /* replace1270_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c') */
   /* search1271_0_0 -> 16 in the cache */
   /* search1271_0_1 -> 120 in the cache */
   /* search1271_0 -> 1395 in the cache */
   /* search1271_1 -> 36 in the cache */
   /* search1271_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1395, 36, 133 },
      -1,
   } },

   /* replace1271_0 -> 16 in the cache */
   /* replace1271_1 -> 36 in the cache */
   /* replace1271_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b') */
   /* search1272_0_0 -> 120 in the cache */
   /* search1272_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1272_1 -> 36 in the cache */
   /* search1272_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3639, 36, 133 },
      -1,
   } },

   /* replace1272_0 -> 16 in the cache */
   /* replace1272_1 -> 133 in the cache */
   /* replace1272_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search1273_0_0 -> 120 in the cache */
   /* search1273_0_1 -> 16 in the cache */
   /* search1273_0 -> 1830 in the cache */
   /* search1273_1 -> 36 in the cache */
   /* search1273_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1830, 36, 133 },
      -1,
   } },

   /* replace1273_0 -> 16 in the cache */
   /* replace1273_1 -> 36 in the cache */
   /* replace1273_2 -> 133 in the cache */
   /* replace1273 -> 3622 in the cache */

   /* ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'c', 'b') */
   /* search1274_0_0 -> 16 in the cache */
   /* search1274_0_1 -> 120 in the cache */
   /* search1274_0 -> 1832 in the cache */
   /* search1274_1 -> 36 in the cache */
   /* search1274_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1832, 36, 133 },
      -1,
   } },

   /* replace1274_0 -> 16 in the cache */
   /* replace1274_1 -> 133 in the cache */
   /* replace1274_2 -> 36 in the cache */
   /* replace1274 -> 3625 in the cache */

   /* ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search1275_0_0 -> 16 in the cache */
   /* search1275_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1275_1 -> 36 in the cache */
   /* search1275_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3644, 36, 133 },
      -1,
   } },

   /* replace1275_0 -> 16 in the cache */
   /* replace1275_1 -> 36 in the cache */
   /* replace1275_2 -> 133 in the cache */
   /* replace1275 -> 3628 in the cache */

   /* ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'c', 'b') */
   /* search1276_0_0 -> 120 in the cache */
   /* search1276_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1276_1 -> 36 in the cache */
   /* search1276_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3646, 36, 133 },
      -1,
   } },

   /* replace1276_0 -> 16 in the cache */
   /* replace1276_1 -> 133 in the cache */
   /* replace1276_2 -> 36 in the cache */
   /* replace1276 -> 3631 in the cache */

   /* ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b'))) */
   /* search1277_0 -> 6 in the cache */
   /* search1277_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 6, 2045 },
      -1,
   } },

   /* replace1277_0_0 -> 2045 in the cache */
   /* replace1277_0_1 -> 1359 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2045, 1359 },
      -1,
   } },
   /* replace1277_1_0_0_0 -> 6 in the cache */
   /* replace1277_1_0_0_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6, 2045 },
      -1,
   } },
   /* replace1277_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3650, 6 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1277_1_2_0 -> 6 in the cache */
   /* replace1277_1_2_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 6, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3651, 3652, 3653 },
      -1,
   } },
   /* replace1277_2_0_0 -> 6 in the cache */
   /* replace1277_2_0_1_0 -> 6 in the cache */
   /* replace1277_2_0_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 6, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 6, 3655 },
      -1,
   } },
   /* replace1277_2_1 -> 7 in the cache */
   /* replace1277_2_2_0 -> 6 in the cache */
   /* replace1277_2_2_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 6, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3656, 7, 3657 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3649, 3654, 3658 },
      -1,
   } },

   /* ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b'))) */
   /* search1278_0 -> 6 in the cache */
   /* search1278_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 6, 2045 },
      -1,
   } },

   /* replace1278_0_0 -> 2045 in the cache */
   /* replace1278_0_1 -> 782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2045, 782 },
      -1,
   } },
   /* replace1278_1_0_0_0 -> 6 in the cache */
   /* replace1278_1_0_0_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 6, 2045 },
      -1,
   } },
   /* replace1278_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3662, 6 },
      -1,
   } },
   /* replace1278_1_1 -> 3652 in the cache */
   /* replace1278_1_2_0 -> 6 in the cache */
   /* replace1278_1_2_1 -> 2045 in the cache */
   /* replace1278_1_2 -> 3662 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3663, 3652, 3662 },
      -1,
   } },
   /* replace1278_2_0_0 -> 6 in the cache */
   /* replace1278_2_0_1_0 -> 6 in the cache */
   /* replace1278_2_0_1_1 -> 2045 in the cache */
   /* replace1278_2_0_1 -> 3662 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3662 },
      -1,
   } },
   /* replace1278_2_1 -> 7 in the cache */
   /* replace1278_2_2_0 -> 6 in the cache */
   /* replace1278_2_2_1 -> 2045 in the cache */
   /* replace1278_2_2 -> 3662 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3665, 7, 3662 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3661, 3664, 3666 },
      -1,
   } },

   /* ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b'))) */
   /* search1279_0 -> 11 in the cache */
   /* search1279_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 11, 243 },
      -1,
   } },

   /* replace1279_0_0 -> 243 in the cache */
   /* replace1279_0_1 -> 1381 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 243, 1381 },
      -1,
   } },
   /* replace1279_1_0_0_0 -> 11 in the cache */
   /* replace1279_1_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 11, 243 },
      -1,
   } },
   /* replace1279_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3670, 11 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1279_1_2_0 -> 11 in the cache */
   /* replace1279_1_2_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3671, 3672, 3673 },
      -1,
   } },
   /* replace1279_2_0_0 -> 11 in the cache */
   /* replace1279_2_0_1_0 -> 11 in the cache */
   /* replace1279_2_0_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 11, 3675 },
      -1,
   } },
   /* replace1279_2_1 -> 12 in the cache */
   /* replace1279_2_2_0 -> 11 in the cache */
   /* replace1279_2_2_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3676, 12, 3677 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3669, 3674, 3678 },
      -1,
   } },

   /* ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b'))) */
   /* search1280_0 -> 11 in the cache */
   /* search1280_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 11, 243 },
      -1,
   } },

   /* replace1280_0_0 -> 243 in the cache */
   /* replace1280_0_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 243, 804 },
      -1,
   } },
   /* replace1280_1_0_0_0 -> 11 in the cache */
   /* replace1280_1_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 11, 243 },
      -1,
   } },
   /* replace1280_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3682, 11 },
      -1,
   } },
   /* replace1280_1_1 -> 3672 in the cache */
   /* replace1280_1_2_0 -> 11 in the cache */
   /* replace1280_1_2_1 -> 243 in the cache */
   /* replace1280_1_2 -> 3682 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3683, 3672, 3682 },
      -1,
   } },
   /* replace1280_2_0_0 -> 11 in the cache */
   /* replace1280_2_0_1_0 -> 11 in the cache */
   /* replace1280_2_0_1_1 -> 243 in the cache */
   /* replace1280_2_0_1 -> 3682 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3682 },
      -1,
   } },
   /* replace1280_2_1 -> 12 in the cache */
   /* replace1280_2_2_0 -> 11 in the cache */
   /* replace1280_2_2_1 -> 243 in the cache */
   /* replace1280_2_2 -> 3682 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3685, 12, 3682 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3681, 3684, 3686 },
      -1,
   } },

   /* ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b'))) */
   /* search1281_0 -> 16 in the cache */
   /* search1281_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1281_0_0 -> 36 in the cache */
   /* replace1281_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   /* replace1281_1_0_0_0 -> 16 in the cache */
   /* replace1281_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1281_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3690, 16 },
      -1,
   } },
   /* replace1281_1_1 -> 937 in the cache */
   /* replace1281_1_2_0 -> 16 in the cache */
   /* replace1281_1_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3691, 937, 3692 },
      -1,
   } },
   /* replace1281_2_0_0 -> 16 in the cache */
   /* replace1281_2_0_1_0 -> 16 in the cache */
   /* replace1281_2_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 16, 3694 },
      -1,
   } },
   /* replace1281_2_1 -> 17 in the cache */
   /* replace1281_2_2_0 -> 16 in the cache */
   /* replace1281_2_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3695, 17, 3696 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3689, 3693, 3697 },
      -1,
   } },

   /* ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b'))) */
   /* search1282_0 -> 16 in the cache */
   /* search1282_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1282_0_0 -> 36 in the cache */
   /* replace1282_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   /* replace1282_1_0_0_0 -> 16 in the cache */
   /* replace1282_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* replace1282_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3701, 16 },
      -1,
   } },
   /* replace1282_1_1 -> 937 in the cache */
   /* replace1282_1_2_0 -> 16 in the cache */
   /* replace1282_1_2_1 -> 36 in the cache */
   /* replace1282_1_2 -> 3701 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3702, 937, 3701 },
      -1,
   } },
   /* replace1282_2_0_0 -> 16 in the cache */
   /* replace1282_2_0_1_0 -> 16 in the cache */
   /* replace1282_2_0_1_1 -> 36 in the cache */
   /* replace1282_2_0_1 -> 3701 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3701 },
      -1,
   } },
   /* replace1282_2_1 -> 17 in the cache */
   /* replace1282_2_2_0 -> 16 in the cache */
   /* replace1282_2_2_1 -> 36 in the cache */
   /* replace1282_2_2 -> 3701 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3704, 17, 3701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3700, 3703, 3705 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b'))) */
   /* search1283_0 -> 21 in the cache */
   /* search1283_1 -> 41 in the cache */
   /* search1283 -> 3356 in the cache */

   /* replace1283_0_0 -> 41 in the cache */
   /* replace1283_0_1 -> 1423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 1423 },
      -1,
   } },
   /* replace1283_1_0_0_0 -> 21 in the cache */
   /* replace1283_1_0_0_1 -> 41 in the cache */
   /* replace1283_1_0_0 -> 3343 in the cache */
   /* replace1283_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3343, 21 },
      -1,
   } },
   /* replace1283_1_1 -> 3367 in the cache */
   /* replace1283_1_2_0 -> 21 in the cache */
   /* replace1283_1_2_1 -> 41 in the cache */
   /* replace1283_1_2 -> 3345 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3708, 3367, 3345 },
      -1,
   } },
   /* replace1283_2_0_0 -> 21 in the cache */
   /* replace1283_2_0_1_0 -> 21 in the cache */
   /* replace1283_2_0_1_1 -> 41 in the cache */
   /* replace1283_2_0_1 -> 3359 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 21, 3359 },
      -1,
   } },
   /* replace1283_2_1 -> 22 in the cache */
   /* replace1283_2_2_0 -> 21 in the cache */
   /* replace1283_2_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3710, 22, 3711 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3707, 3709, 3712 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b'))) */
   /* search1284_0 -> 21 in the cache */
   /* search1284_1 -> 41 in the cache */
   /* search1284 -> 3370 in the cache */

   /* replace1284_0_0 -> 41 in the cache */
   /* replace1284_0_1 -> 847 in the cache */
   /* replace1284_0 -> 3357 in the cache */
   /* replace1284_1_0_0_0 -> 21 in the cache */
   /* replace1284_1_0_0_1 -> 41 in the cache */
   /* replace1284_1_0_0 -> 3354 in the cache */
   /* replace1284_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3354, 21 },
      -1,
   } },
   /* replace1284_1_1 -> 3367 in the cache */
   /* replace1284_1_2_0 -> 21 in the cache */
   /* replace1284_1_2_1 -> 41 in the cache */
   /* replace1284_1_2 -> 3354 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3714, 3367, 3354 },
      -1,
   } },
   /* replace1284_2_0_0 -> 21 in the cache */
   /* replace1284_2_0_1_0 -> 21 in the cache */
   /* replace1284_2_0_1_1 -> 41 in the cache */
   /* replace1284_2_0_1 -> 3354 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 3354 },
      -1,
   } },
   /* replace1284_2_1 -> 22 in the cache */
   /* replace1284_2_2_0 -> 21 in the cache */
   /* replace1284_2_2_1 -> 41 in the cache */
   /* replace1284_2_2 -> 3354 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3716, 22, 3354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3357, 3715, 3717 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1285_0_0_0 -> 0 in the cache */
   /* search1285_0_0_1 -> 3 in the cache */
   /* search1285_0_0 -> 1021 in the cache */
   /* search1285_0_1_0 -> 150 in the cache */
   /* search1285_0_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1021, 3719 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3720 },
      -1,
   } },

   /* replace1285_0_0 -> 0 in the cache */
   /* replace1285_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1285_1_0 -> 150 in the cache */
   /* replace1285_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3722, 3723 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1286_0_0_0 -> 0 in the cache */
   /* search1286_0_0_1 -> 3 in the cache */
   /* search1286_0_0 -> 1021 in the cache */
   /* search1286_0_1_0 -> 150 in the cache */
   /* search1286_0_1_1 -> 151 in the cache */
   /* search1286_0_1 -> 3719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1021, 3719 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3725 },
      -1,
   } },

   /* replace1286_0_0 -> 0 in the cache */
   /* replace1286_0_1 -> 3 in the cache */
   /* replace1286_0 -> 3722 in the cache */
   /* replace1286_1_0 -> 150 in the cache */
   /* replace1286_1_1 -> 151 in the cache */
   /* replace1286_1 -> 3723 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3722, 3723 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1287_0_0_0 -> 0 in the cache */
   /* search1287_0_0_1 -> 3 in the cache */
   /* search1287_0_0 -> 1021 in the cache */
   /* search1287_0_1_0 -> 150 in the cache */
   /* search1287_0_1_1 -> 151 in the cache */
   /* search1287_0_1 -> 3723 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1021, 3723 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3728 },
      -1,
   } },

   /* replace1287_0_0 -> 0 in the cache */
   /* replace1287_0_1 -> 3 in the cache */
   /* replace1287_0 -> 3722 in the cache */
   /* replace1287_1_0 -> 150 in the cache */
   /* replace1287_1_1 -> 151 in the cache */
   /* replace1287_1 -> 3719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3722, 3719 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1288_0_0_0 -> 0 in the cache */
   /* search1288_0_0_1 -> 3 in the cache */
   /* search1288_0_0 -> 1021 in the cache */
   /* search1288_0_1_0 -> 150 in the cache */
   /* search1288_0_1_1 -> 151 in the cache */
   /* search1288_0_1 -> 3723 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1021, 3723 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3731 },
      -1,
   } },

   /* replace1288_0_0 -> 0 in the cache */
   /* replace1288_0_1 -> 3 in the cache */
   /* replace1288_0 -> 3722 in the cache */
   /* replace1288_1_0 -> 150 in the cache */
   /* replace1288_1_1 -> 151 in the cache */
   /* replace1288_1 -> 3719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3722, 3719 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1289_0_0_0 -> 0 in the cache */
   /* search1289_0_0_1 -> 3 in the cache */
   /* search1289_0_0 -> 3722 in the cache */
   /* search1289_0_1_0 -> 150 in the cache */
   /* search1289_0_1_1 -> 151 in the cache */
   /* search1289_0_1 -> 3723 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3722, 3723 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3734 },
      -1,
   } },

   /* replace1289_0_0 -> 0 in the cache */
   /* replace1289_0_1 -> 3 in the cache */
   /* replace1289_0 -> 1021 in the cache */
   /* replace1289_1_0 -> 150 in the cache */
   /* replace1289_1_1 -> 151 in the cache */
   /* replace1289_1 -> 3719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1021, 3719 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1290_0_0_0 -> 0 in the cache */
   /* search1290_0_0_1 -> 3 in the cache */
   /* search1290_0_0 -> 3722 in the cache */
   /* search1290_0_1_0 -> 150 in the cache */
   /* search1290_0_1_1 -> 151 in the cache */
   /* search1290_0_1 -> 3723 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3722, 3723 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3737 },
      -1,
   } },

   /* replace1290_0_0 -> 0 in the cache */
   /* replace1290_0_1 -> 3 in the cache */
   /* replace1290_0 -> 1021 in the cache */
   /* replace1290_1_0 -> 150 in the cache */
   /* replace1290_1_1 -> 151 in the cache */
   /* replace1290_1 -> 3719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1021, 3719 },
      -1,
   } },

   /* ('f2b1', ('b2f', 'a@1')) => a */
   /* search1291_0_0 -> 706 in the cache */
   /* search1291_0 -> 1070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 1070 },
      -1,
   } },

   /* replace1291 -> 706 in the cache */

   /* ('i2b1', ('b2i', 'a@1')) => a */
   /* search1292_0_0 -> 706 in the cache */
   /* search1292_0 -> 1168 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 1168 },
      -1,
   } },

   /* replace1292 -> 706 in the cache */

   /* ('f2b8', ('b2f', 'a@8')) => a */
   /* search1293_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_f2b8,
      -1, 0,
      { 3742 },
      -1,
   } },

   /* replace1293 -> 6 in the cache */

   /* ('i2b8', ('b2i', 'a@8')) => a */
   /* search1294_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2b8,
      -1, 0,
      { 3744 },
      -1,
   } },

   /* replace1294 -> 6 in the cache */

   /* ('f2b16', ('b2f', 'a@16')) => a */
   /* search1295_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2b16,
      -1, 0,
      { 3746 },
      -1,
   } },

   /* replace1295 -> 11 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search1296_0_0 -> 11 in the cache */
   /* search1296_0 -> 2787 in the cache */
   /* search1296 -> 2788 in the cache */

   /* replace1296 -> 11 in the cache */

   /* ('f2b32', ('b2f', 'a@32')) => a */
   /* search1297_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2b32,
      -1, 0,
      { 3748 },
      -1,
   } },

   /* replace1297 -> 16 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search1298_0_0 -> 16 in the cache */
   /* search1298_0 -> 2789 in the cache */
   /* search1298 -> 2790 in the cache */

   /* replace1298 -> 16 in the cache */

   /* ('f2f', ('b2f', 'a')) => ('b2f', 'a') */
   /* search1299_0_0 -> 32 in the cache */
   /* search1299_0 -> 1457 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2f,
      -1, 0,
      { 1457 },
      -1,
   } },

   /* replace1299_0 -> 32 in the cache */
   /* replace1299 -> 1457 in the cache */

   /* ('f2u', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1300_0_0 -> 32 in the cache */
   /* search1300_0 -> 1457 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 1457 },
      -1,
   } },

   /* replace1300_0 -> 32 in the cache */
   /* replace1300 -> 2779 in the cache */

   /* ('f2i', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1301_0_0 -> 32 in the cache */
   /* search1301_0 -> 1457 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 1457 },
      -1,
   } },

   /* replace1301_0 -> 32 in the cache */
   /* replace1301 -> 2779 in the cache */

   /* ('u2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1302_0_0 -> 32 in the cache */
   /* search1302_0 -> 2779 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 2779 },
      -1,
   } },

   /* replace1302_0 -> 32 in the cache */
   /* replace1302 -> 1457 in the cache */

   /* ('u2u', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1303_0_0 -> 32 in the cache */
   /* search1303_0 -> 2779 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2779 },
      -1,
   } },

   /* replace1303_0 -> 32 in the cache */
   /* replace1303 -> 2779 in the cache */

   /* ('i2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1304_0_0 -> 32 in the cache */
   /* search1304_0 -> 2779 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 2779 },
      -1,
   } },

   /* replace1304_0 -> 32 in the cache */
   /* replace1304 -> 1457 in the cache */

   /* ('i2i', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1305_0_0 -> 32 in the cache */
   /* search1305_0 -> 2779 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2779 },
      -1,
   } },

   /* replace1305_0 -> 32 in the cache */
   /* replace1305 -> 2779 in the cache */

   /* ('i2i1', 'a@1') => a */
   /* search1306_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 706 },
      -1,
   } },

   /* replace1306 -> 706 in the cache */

   /* ('i2i8', 'a@8') => a */
   /* search1307_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1307 -> 6 in the cache */

   /* ('i2i16', 'a@16') => a */
   /* search1308_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1308 -> 11 in the cache */

   /* ('i2i32', 'a@32') => a */
   /* search1309_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1309 -> 16 in the cache */

   /* ('i2i64', 'a@64') => a */
   /* search1310_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1310 -> 21 in the cache */

   /* ('u2u1', 'a@1') => a */
   /* search1311_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 706 },
      -1,
   } },

   /* replace1311 -> 706 in the cache */

   /* ('u2u8', 'a@8') => a */
   /* search1312_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1312 -> 6 in the cache */

   /* ('u2u16', 'a@16') => a */
   /* search1313_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1313 -> 11 in the cache */

   /* ('u2u32', 'a@32') => a */
   /* search1314_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1314 -> 16 in the cache */

   /* ('u2u64', 'a@64') => a */
   /* search1315_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1315 -> 21 in the cache */

   /* ('f2f16', 'a@16') => a */
   /* search1316_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1316 -> 11 in the cache */

   /* ('f2f32', 'a@32') => a */
   /* search1317_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1317 -> 16 in the cache */

   /* ('f2f64', 'a@64') => a */
   /* search1318_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1318 -> 21 in the cache */

   /* ('b2b1', 'a@1') => a */
   /* search1319_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_b2b1,
      -1, 0,
      { 706 },
      -1,
   } },

   /* replace1319 -> 706 in the cache */

   /* ('b2b8', 'a@8') => a */
   /* search1320_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2b8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1320 -> 6 in the cache */

   /* ('b2b16', 'a@16') => a */
   /* search1321_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2b16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1321 -> 11 in the cache */

   /* ('b2b32', 'a@32') => a */
   /* search1322_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2b32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1322 -> 16 in the cache */

   /* ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1323_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3774 },
      -1,
   } },

   /* replace1323_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1324_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3777 },
      -1,
   } },

   /* replace1324_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1325_0_0 -> 32 in the cache */
   /* search1325_0 -> 3774 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3774 },
      -1,
   } },

   /* replace1325_0 -> 32 in the cache */
   /* replace1325 -> 3776 in the cache */

   /* ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1326_0_0 -> 32 in the cache */
   /* search1326_0 -> 3777 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3777 },
      -1,
   } },

   /* replace1326_0 -> 32 in the cache */
   /* replace1326 -> 3779 in the cache */

   /* ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1327_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3782 },
      -1,
   } },

   /* replace1327_0 -> 32 in the cache */
   /* replace1327 -> 3776 in the cache */

   /* ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1328_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1328_0 -> 32 in the cache */
   /* replace1328 -> 3779 in the cache */

   /* ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1329_0_0 -> 32 in the cache */
   /* search1329_0 -> 3782 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3782 },
      -1,
   } },

   /* replace1329_0 -> 32 in the cache */
   /* replace1329 -> 3776 in the cache */

   /* ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1330_0_0 -> 32 in the cache */
   /* search1330_0 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1330_0 -> 32 in the cache */
   /* replace1330 -> 3779 in the cache */

   /* ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1331_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3788 },
      -1,
   } },

   /* replace1331_0 -> 32 in the cache */
   /* replace1331 -> 3776 in the cache */

   /* ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1332_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3790 },
      -1,
   } },

   /* replace1332_0 -> 32 in the cache */
   /* replace1332 -> 3779 in the cache */

   /* ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1333_0_0 -> 32 in the cache */
   /* search1333_0 -> 3788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3788 },
      -1,
   } },

   /* replace1333_0 -> 32 in the cache */
   /* replace1333 -> 3776 in the cache */

   /* ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1334_0_0 -> 32 in the cache */
   /* search1334_0 -> 3790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3790 },
      -1,
   } },

   /* replace1334_0 -> 32 in the cache */
   /* replace1334 -> 3779 in the cache */

   /* ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1335_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3794 },
      -1,
   } },

   /* replace1335_0 -> 32 in the cache */
   /* replace1335 -> 3776 in the cache */

   /* ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1336_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1336_0 -> 32 in the cache */
   /* replace1336 -> 3779 in the cache */

   /* ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1337_0_0 -> 32 in the cache */
   /* search1337_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3794 },
      -1,
   } },

   /* replace1337_0 -> 32 in the cache */
   /* replace1337 -> 3776 in the cache */

   /* ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1338_0_0 -> 32 in the cache */
   /* search1338_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1338_0 -> 32 in the cache */
   /* replace1338 -> 3779 in the cache */

   /* ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a') */
   /* search1339_0_0 -> 706 in the cache */
   /* search1339_0 -> 3757 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3757 },
      -1,
   } },

   /* replace1339_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a') */
   /* search1340_0_0 -> 706 in the cache */
   /* search1340_0 -> 3762 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3762 },
      -1,
   } },

   /* replace1340_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1341_0_0 -> 32 in the cache */
   /* search1341_0 -> 3782 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3782 },
      -1,
   } },

   /* replace1341_0 -> 32 in the cache */
   /* replace1341 -> 3774 in the cache */

   /* ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1342_0_0 -> 32 in the cache */
   /* search1342_0 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1342_0 -> 32 in the cache */
   /* replace1342 -> 3777 in the cache */

   /* ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1343_0_0 -> 32 in the cache */
   /* search1343_0 -> 3782 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3782 },
      -1,
   } },

   /* replace1343_0 -> 32 in the cache */
   /* replace1343 -> 3774 in the cache */

   /* ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1344_0_0 -> 32 in the cache */
   /* search1344_0 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1344_0 -> 32 in the cache */
   /* replace1344 -> 3777 in the cache */

   /* ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1345_0_0 -> 32 in the cache */
   /* search1345_0 -> 3788 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3788 },
      -1,
   } },

   /* replace1345_0 -> 32 in the cache */
   /* replace1345 -> 3774 in the cache */

   /* ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1346_0_0 -> 32 in the cache */
   /* search1346_0 -> 3790 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3790 },
      -1,
   } },

   /* replace1346_0 -> 32 in the cache */
   /* replace1346 -> 3777 in the cache */

   /* ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1347_0_0 -> 32 in the cache */
   /* search1347_0 -> 3788 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3788 },
      -1,
   } },

   /* replace1347_0 -> 32 in the cache */
   /* replace1347 -> 3774 in the cache */

   /* ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1348_0_0 -> 32 in the cache */
   /* search1348_0 -> 3790 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3790 },
      -1,
   } },

   /* replace1348_0 -> 32 in the cache */
   /* replace1348 -> 3777 in the cache */

   /* ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1349_0_0 -> 32 in the cache */
   /* search1349_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3794 },
      -1,
   } },

   /* replace1349_0 -> 32 in the cache */
   /* replace1349 -> 3774 in the cache */

   /* ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1350_0_0 -> 32 in the cache */
   /* search1350_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1350_0 -> 32 in the cache */
   /* replace1350 -> 3777 in the cache */

   /* ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1351_0_0 -> 32 in the cache */
   /* search1351_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3794 },
      -1,
   } },

   /* replace1351_0 -> 32 in the cache */
   /* replace1351 -> 3774 in the cache */

   /* ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1352_0_0 -> 32 in the cache */
   /* search1352_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1352_0 -> 32 in the cache */
   /* replace1352 -> 3777 in the cache */

   /* ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a') */
   /* search1353_0_0 -> 706 in the cache */
   /* search1353_0 -> 3757 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3757 },
      -1,
   } },

   /* replace1353_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a') */
   /* search1354_0_0 -> 706 in the cache */
   /* search1354_0 -> 3762 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3762 },
      -1,
   } },

   /* replace1354_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a') */
   /* search1355_0_0 -> 706 in the cache */
   /* search1355_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1355_0 -> 706 in the cache */
   /* replace1355 -> 3817 in the cache */

   /* ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a') */
   /* search1356_0_0 -> 706 in the cache */
   /* search1356_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1356_0 -> 706 in the cache */
   /* replace1356 -> 3819 in the cache */

   /* ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a') */
   /* search1357_0_0 -> 6 in the cache */
   /* search1357_0 -> 3758 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3758 },
      -1,
   } },

   /* replace1357_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a') */
   /* search1358_0_0 -> 6 in the cache */
   /* search1358_0 -> 3763 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3763 },
      -1,
   } },

   /* replace1358_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1359_0_0 -> 32 in the cache */
   /* search1359_0 -> 3788 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3788 },
      -1,
   } },

   /* replace1359_0 -> 32 in the cache */
   /* replace1359 -> 3782 in the cache */

   /* ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1360_0_0 -> 32 in the cache */
   /* search1360_0 -> 3790 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3790 },
      -1,
   } },

   /* replace1360_0 -> 32 in the cache */
   /* replace1360 -> 3784 in the cache */

   /* ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1361_0_0 -> 32 in the cache */
   /* search1361_0 -> 3788 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3788 },
      -1,
   } },

   /* replace1361_0 -> 32 in the cache */
   /* replace1361 -> 3782 in the cache */

   /* ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1362_0_0 -> 32 in the cache */
   /* search1362_0 -> 3790 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3790 },
      -1,
   } },

   /* replace1362_0 -> 32 in the cache */
   /* replace1362 -> 3784 in the cache */

   /* ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1363_0_0 -> 32 in the cache */
   /* search1363_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3794 },
      -1,
   } },

   /* replace1363_0 -> 32 in the cache */
   /* replace1363 -> 3782 in the cache */

   /* ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1364_0_0 -> 32 in the cache */
   /* search1364_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1364_0 -> 32 in the cache */
   /* replace1364 -> 3784 in the cache */

   /* ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1365_0_0 -> 32 in the cache */
   /* search1365_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3794 },
      -1,
   } },

   /* replace1365_0 -> 32 in the cache */
   /* replace1365 -> 3782 in the cache */

   /* ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1366_0_0 -> 32 in the cache */
   /* search1366_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1366_0 -> 32 in the cache */
   /* replace1366 -> 3784 in the cache */

   /* ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a') */
   /* search1367_0_0 -> 706 in the cache */
   /* search1367_0 -> 3757 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3757 },
      -1,
   } },

   /* replace1367_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a') */
   /* search1368_0_0 -> 706 in the cache */
   /* search1368_0 -> 3762 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3762 },
      -1,
   } },

   /* replace1368_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a') */
   /* search1369_0_0 -> 706 in the cache */
   /* search1369_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1369_0 -> 706 in the cache */
   /* replace1369 -> 3835 in the cache */

   /* ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a') */
   /* search1370_0_0 -> 706 in the cache */
   /* search1370_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1370_0 -> 706 in the cache */
   /* replace1370 -> 3837 in the cache */

   /* ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a') */
   /* search1371_0_0 -> 6 in the cache */
   /* search1371_0 -> 3758 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3758 },
      -1,
   } },

   /* replace1371_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a') */
   /* search1372_0_0 -> 6 in the cache */
   /* search1372_0 -> 3763 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3763 },
      -1,
   } },

   /* replace1372_0 -> 6 in the cache */
   /* replace1372 -> 2952 in the cache */

   /* ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a') */
   /* search1373_0_0 -> 706 in the cache */
   /* search1373_0 -> 3817 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3817 },
      -1,
   } },

   /* replace1373_0 -> 706 in the cache */
   /* replace1373 -> 3835 in the cache */

   /* ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a') */
   /* search1374_0_0 -> 706 in the cache */
   /* search1374_0 -> 3819 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3819 },
      -1,
   } },

   /* replace1374_0 -> 706 in the cache */
   /* replace1374 -> 3837 in the cache */

   /* ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a') */
   /* search1375_0_0 -> 6 in the cache */
   /* search1375_0 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3823 },
      -1,
   } },

   /* replace1375_0 -> 6 in the cache */
   /* replace1375 -> 3841 in the cache */

   /* ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a') */
   /* search1376_0_0 -> 6 in the cache */
   /* search1376_0 -> 3825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3825 },
      -1,
   } },

   /* replace1376_0 -> 6 in the cache */
   /* replace1376 -> 2952 in the cache */

   /* ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a') */
   /* search1377_0_0 -> 11 in the cache */
   /* search1377_0 -> 3759 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3759 },
      -1,
   } },

   /* replace1377_0 -> 11 in the cache */
   /* replace1377 -> 1732 in the cache */

   /* ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a') */
   /* search1378_0_0 -> 11 in the cache */
   /* search1378_0 -> 3764 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3764 },
      -1,
   } },

   /* replace1378_0 -> 11 in the cache */
   /* replace1378 -> 1734 in the cache */

   /* ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1379_0_0 -> 32 in the cache */
   /* search1379_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3794 },
      -1,
   } },

   /* replace1379_0 -> 32 in the cache */
   /* replace1379 -> 3788 in the cache */

   /* ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1380_0_0 -> 32 in the cache */
   /* search1380_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1380_0 -> 32 in the cache */
   /* replace1380 -> 3790 in the cache */

   /* ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1381_0_0 -> 32 in the cache */
   /* search1381_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3794 },
      -1,
   } },

   /* replace1381_0 -> 32 in the cache */
   /* replace1381 -> 3788 in the cache */

   /* ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1382_0_0 -> 32 in the cache */
   /* search1382_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1382_0 -> 32 in the cache */
   /* replace1382 -> 3790 in the cache */

   /* ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a') */
   /* search1383_0_0 -> 706 in the cache */
   /* search1383_0 -> 3757 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3757 },
      -1,
   } },

   /* replace1383_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a') */
   /* search1384_0_0 -> 706 in the cache */
   /* search1384_0 -> 3762 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3762 },
      -1,
   } },

   /* replace1384_0 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 706 },
      -1,
   } },

   /* ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a') */
   /* search1385_0_0 -> 706 in the cache */
   /* search1385_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1385_0 -> 706 in the cache */
   /* replace1385 -> 3854 in the cache */

   /* ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a') */
   /* search1386_0_0 -> 706 in the cache */
   /* search1386_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1386_0 -> 706 in the cache */
   /* replace1386 -> 3856 in the cache */

   /* ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a') */
   /* search1387_0_0 -> 6 in the cache */
   /* search1387_0 -> 3758 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3758 },
      -1,
   } },

   /* replace1387_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a') */
   /* search1388_0_0 -> 6 in the cache */
   /* search1388_0 -> 3763 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3763 },
      -1,
   } },

   /* replace1388_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a') */
   /* search1389_0_0 -> 706 in the cache */
   /* search1389_0 -> 3817 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3817 },
      -1,
   } },

   /* replace1389_0 -> 706 in the cache */
   /* replace1389 -> 3854 in the cache */

   /* ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a') */
   /* search1390_0_0 -> 706 in the cache */
   /* search1390_0 -> 3819 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3819 },
      -1,
   } },

   /* replace1390_0 -> 706 in the cache */
   /* replace1390 -> 3856 in the cache */

   /* ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a') */
   /* search1391_0_0 -> 6 in the cache */
   /* search1391_0 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3823 },
      -1,
   } },

   /* replace1391_0 -> 6 in the cache */
   /* replace1391 -> 3860 in the cache */

   /* ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a') */
   /* search1392_0_0 -> 6 in the cache */
   /* search1392_0 -> 3825 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3825 },
      -1,
   } },

   /* replace1392_0 -> 6 in the cache */
   /* replace1392 -> 3862 in the cache */

   /* ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a') */
   /* search1393_0_0 -> 11 in the cache */
   /* search1393_0 -> 3759 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3759 },
      -1,
   } },

   /* replace1393_0 -> 11 in the cache */
   /* replace1393 -> 1755 in the cache */

   /* ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a') */
   /* search1394_0_0 -> 11 in the cache */
   /* search1394_0 -> 3764 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3764 },
      -1,
   } },

   /* replace1394_0 -> 11 in the cache */
   /* replace1394 -> 1757 in the cache */

   /* ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a') */
   /* search1395_0_0 -> 706 in the cache */
   /* search1395_0 -> 3835 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3835 },
      -1,
   } },

   /* replace1395_0 -> 706 in the cache */
   /* replace1395 -> 3854 in the cache */

   /* ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a') */
   /* search1396_0_0 -> 706 in the cache */
   /* search1396_0 -> 3837 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3837 },
      -1,
   } },

   /* replace1396_0 -> 706 in the cache */
   /* replace1396 -> 3856 in the cache */

   /* ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a') */
   /* search1397_0_0 -> 6 in the cache */
   /* search1397_0 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3841 },
      -1,
   } },

   /* replace1397_0 -> 6 in the cache */
   /* replace1397 -> 3860 in the cache */

   /* ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a') */
   /* search1398_0_0 -> 6 in the cache */
   /* search1398_0 -> 2952 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2952 },
      -1,
   } },

   /* replace1398_0 -> 6 in the cache */
   /* replace1398 -> 3862 in the cache */

   /* ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a') */
   /* search1399_0_0 -> 11 in the cache */
   /* search1399_0 -> 1732 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 1732 },
      -1,
   } },

   /* replace1399_0 -> 11 in the cache */
   /* replace1399 -> 1755 in the cache */

   /* ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a') */
   /* search1400_0_0 -> 11 in the cache */
   /* search1400_0 -> 1734 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 1734 },
      -1,
   } },

   /* replace1400_0 -> 11 in the cache */
   /* replace1400 -> 1757 in the cache */

   /* ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a') */
   /* search1401_0_0 -> 16 in the cache */
   /* search1401_0 -> 3760 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3760 },
      -1,
   } },

   /* replace1401_0 -> 16 in the cache */
   /* replace1401 -> 1839 in the cache */

   /* ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a') */
   /* search1402_0_0 -> 16 in the cache */
   /* search1402_0 -> 3765 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3765 },
      -1,
   } },

   /* replace1402_0 -> 16 in the cache */
   /* replace1402 -> 1841 in the cache */

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1403_0_0 -> 16 in the cache */
   /* search1403_0_1 -> 36 in the cache */
   /* search1403_0 -> 2878 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2878 },
      -1,
   } },

   /* replace1403_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1404_0_0 -> 16 in the cache */
   /* search1404_0_1 -> 36 in the cache */
   /* search1404_0 -> 2878 in the cache */
   /* search1404 -> 3877 in the cache */

   /* replace1404_0 -> 16 in the cache */
   /* replace1404 -> 3878 in the cache */

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1405_0_0 -> 16 in the cache */
   /* search1405_0_1 -> 36 in the cache */
   /* search1405_0 -> 2878 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2878 },
      -1,
   } },

   /* replace1405_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1406_0_0 -> 16 in the cache */
   /* search1406_0_1 -> 36 in the cache */
   /* search1406_0 -> 2878 in the cache */
   /* search1406 -> 3879 in the cache */

   /* replace1406_0 -> 16 in the cache */
   /* replace1406 -> 3880 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1407_0_0 -> 16 in the cache */
   /* search1407_0_1 -> 36 in the cache */
   /* search1407_0 -> 2878 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2878 },
      -1,
   } },

   /* replace1407_0 -> 16 in the cache */
   /* replace1407 -> 3760 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1408_0_0 -> 16 in the cache */
   /* search1408_0_1 -> 36 in the cache */
   /* search1408_0 -> 2878 in the cache */
   /* search1408 -> 3881 in the cache */

   /* replace1408_0 -> 16 in the cache */
   /* replace1408 -> 3760 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1409_0_0 -> 16 in the cache */
   /* search1409_0_1 -> 36 in the cache */
   /* search1409_0 -> 2878 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2878 },
      -1,
   } },

   /* replace1409_0 -> 16 in the cache */
   /* replace1409 -> 1958 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1410_0_0 -> 16 in the cache */
   /* search1410_0_1 -> 36 in the cache */
   /* search1410_0 -> 2878 in the cache */
   /* search1410 -> 3882 in the cache */

   /* replace1410_0 -> 16 in the cache */
   /* replace1410 -> 1958 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1411_0_0 -> 16 in the cache */
   /* search1411_0_1 -> 36 in the cache */
   /* search1411_0 -> 2878 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2878 },
      -1,
   } },

   /* replace1411_0 -> 16 in the cache */
   /* replace1411 -> 2980 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1412_0_0 -> 16 in the cache */
   /* search1412_0_1 -> 36 in the cache */
   /* search1412_0 -> 2878 in the cache */
   /* search1412 -> 3883 in the cache */

   /* replace1412_0 -> 16 in the cache */
   /* replace1412 -> 2980 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1413_0_0 -> 16 in the cache */
   /* search1413_0_1 -> 36 in the cache */
   /* search1413_0 -> 2878 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2878 },
      -1,
   } },

   /* replace1413_0 -> 16 in the cache */
   /* replace1413 -> 3765 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1414_0_0 -> 16 in the cache */
   /* search1414_0_1 -> 36 in the cache */
   /* search1414_0 -> 2878 in the cache */
   /* search1414 -> 3884 in the cache */

   /* replace1414_0 -> 16 in the cache */
   /* replace1414 -> 3765 in the cache */

   /* ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1415_0_0 -> 6 in the cache */
   /* search1415_0 -> 3823 in the cache */
   /* search1415_1_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3823, 3885 },
      -1,
   } },

   /* replace1415_0 -> 6 in the cache */
   /* replace1415_1_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 3887 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1416_0_0 -> 6 in the cache */
   /* search1416_0 -> 3823 in the cache */
   /* search1416_1_0 -> 2045 in the cache */
   /* search1416_1 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3823, 3885 },
      -1,
   } },

   /* replace1416_0 -> 6 in the cache */
   /* replace1416_1_0 -> 2045 in the cache */
   /* replace1416_1 -> 3887 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 3887 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1417_0_0 -> 6 in the cache */
   /* search1417_0 -> 3823 in the cache */
   /* search1417_1_0 -> 2045 in the cache */
   /* search1417_1 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3823, 3885 },
      -1,
   } },

   /* replace1417_0 -> 6 in the cache */
   /* replace1417_1_0 -> 2045 in the cache */
   /* replace1417_1 -> 3887 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3887 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1418_0_0 -> 6 in the cache */
   /* search1418_0 -> 3823 in the cache */
   /* search1418_1_0 -> 2045 in the cache */
   /* search1418_1 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3823, 3885 },
      -1,
   } },

   /* replace1418_0 -> 6 in the cache */
   /* replace1418_1_0 -> 2045 in the cache */
   /* replace1418_1 -> 3887 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3887 },
      -1,
   } },

   /* ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3895 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3896, 3898 },
      -1,
   } },

   /* replace1419_0_0 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3895 },
      -1,
   } },
   /* replace1419_1 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3900, 3897 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1420_0_0 -> 3895 in the cache */
   /* search1420_0 -> 3896 in the cache */
   /* search1420_1_0 -> 3897 in the cache */
   /* search1420_1 -> 3898 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3896, 3898 },
      -1,
   } },

   /* replace1420_0_0 -> 3895 in the cache */
   /* replace1420_0 -> 3900 in the cache */
   /* replace1420_1 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3900, 3897 },
      -1,
   } },

   /* ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1421_0_0 -> 6 in the cache */
   /* search1421_0 -> 3823 in the cache */
   /* search1421_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3823, 1944 },
      -1,
   } },

   /* replace1421_0_0 -> 6 in the cache */
   /* replace1421_0_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 3905 },
      -1,
   } },
   /* replace1421_1_0_0_0 -> 243 in the cache */
   /* replace1421_1_0_0 -> 3905 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3905 },
      -1,
   } },
   /* replace1421_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3907, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3906, 3908 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1422_0_0 -> 6 in the cache */
   /* search1422_0 -> 3823 in the cache */
   /* search1422_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3823, 1944 },
      -1,
   } },

   /* replace1422_0_0 -> 6 in the cache */
   /* replace1422_0_1_0 -> 243 in the cache */
   /* replace1422_0_1 -> 3905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 3905 },
      -1,
   } },
   /* replace1422_1_0_0_0 -> 243 in the cache */
   /* replace1422_1_0_0 -> 3905 in the cache */
   /* replace1422_1_0 -> 3907 in the cache */
   /* replace1422_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 3907, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3911, 3912 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1423_0_0 -> 6 in the cache */
   /* search1423_0 -> 3823 in the cache */
   /* search1423_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3823, 1944 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1423_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3915, 243 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1423_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3917, 243 },
      -1,
   } },
   /* replace1423_1_1_0 -> 6 in the cache */
   /* replace1423_1_1_1_0 -> 243 in the cache */
   /* replace1423_1_1_1 -> 3905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3905 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3918, 3919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3916, 3920 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1424_1_0 -> 2045 in the cache */
   /* search1424_1 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3922, 3885 },
      -1,
   } },

   /* replace1424_0_0 -> 11 in the cache */
   /* replace1424_0_1 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3917 },
      -1,
   } },
   /* replace1424_1_0_0 -> 11 in the cache */
   /* replace1424_1_0_1 -> 3915 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3915 },
      -1,
   } },
   /* replace1424_1_1_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 11 },
      -1,
   } },
   /* replace1424_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3926, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3925, 3927 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3924, 3928 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1425_0_0 -> 6 in the cache */
   /* search1425_0 -> 3823 in the cache */
   /* search1425_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3823, 1944 },
      -1,
   } },

   /* replace1425_0_0 -> 3917 in the cache */
   /* replace1425_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3917, 243 },
      -1,
   } },
   /* replace1425_1_0_0 -> 3915 in the cache */
   /* replace1425_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3915, 243 },
      -1,
   } },
   /* replace1425_1_1_0 -> 6 in the cache */
   /* replace1425_1_1_1_0 -> 243 in the cache */
   /* replace1425_1_1_1 -> 3905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3905 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3932, 3933 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3931, 3934 },
      -1,
   } },

   /* ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1426_0 -> 3922 in the cache */
   /* search1426_1_0 -> 2045 in the cache */
   /* search1426_1 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3922, 3885 },
      -1,
   } },

   /* replace1426_0_0 -> 11 in the cache */
   /* replace1426_0_1 -> 3915 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 3915 },
      -1,
   } },
   /* replace1426_1_0_0 -> 11 in the cache */
   /* replace1426_1_0_1 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 3917 },
      -1,
   } },
   /* replace1426_1_1_0_0 -> 11 in the cache */
   /* replace1426_1_1_0 -> 3926 in the cache */
   /* replace1426_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3926, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3938, 3939 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3937, 3940 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1427_0_0 -> 6 in the cache */
   /* search1427_0 -> 3841 in the cache */
   /* search1427_1_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3841, 3942 },
      -1,
   } },

   /* replace1427_0 -> 6 in the cache */
   /* replace1427_1_0 -> 2045 in the cache */
   /* replace1427_1 -> 3887 in the cache */
   /* replace1427 -> 3888 in the cache */

   /* ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1428_0_0 -> 6 in the cache */
   /* search1428_0 -> 3841 in the cache */
   /* search1428_1_0 -> 2045 in the cache */
   /* search1428_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3841, 3942 },
      -1,
   } },

   /* replace1428_0 -> 6 in the cache */
   /* replace1428_1_0 -> 2045 in the cache */
   /* replace1428_1 -> 3887 in the cache */
   /* replace1428 -> 3890 in the cache */

   /* ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1429_0_0 -> 6 in the cache */
   /* search1429_0 -> 3841 in the cache */
   /* search1429_1_0 -> 2045 in the cache */
   /* search1429_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3841, 3942 },
      -1,
   } },

   /* replace1429_0 -> 6 in the cache */
   /* replace1429_1_0 -> 2045 in the cache */
   /* replace1429_1 -> 3887 in the cache */
   /* replace1429 -> 3892 in the cache */

   /* ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1430_0_0 -> 6 in the cache */
   /* search1430_0 -> 3841 in the cache */
   /* search1430_1_0 -> 2045 in the cache */
   /* search1430_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3841, 3942 },
      -1,
   } },

   /* replace1430_0 -> 6 in the cache */
   /* replace1430_1_0 -> 2045 in the cache */
   /* replace1430_1 -> 3887 in the cache */
   /* replace1430 -> 3894 in the cache */

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1431_0_0 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3895 },
      -1,
   } },
   /* search1431_1_0 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3947, 3948 },
      -1,
   } },

   /* replace1431_0_0 -> 3895 in the cache */
   /* replace1431_0 -> 3900 in the cache */
   /* replace1431_1 -> 3897 in the cache */
   /* replace1431 -> 3901 in the cache */

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1432_0_0 -> 3895 in the cache */
   /* search1432_0 -> 3947 in the cache */
   /* search1432_1_0 -> 3897 in the cache */
   /* search1432_1 -> 3948 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3947, 3948 },
      -1,
   } },

   /* replace1432_0_0 -> 3895 in the cache */
   /* replace1432_0 -> 3900 in the cache */
   /* replace1432_1 -> 3897 in the cache */
   /* replace1432 -> 3903 in the cache */

   /* ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1433_0_0 -> 6 in the cache */
   /* search1433_0 -> 3841 in the cache */
   /* search1433_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3841, 33 },
      -1,
   } },

   /* replace1433_0_0 -> 6 in the cache */
   /* replace1433_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 3952 },
      -1,
   } },
   /* replace1433_1_0_0_0 -> 36 in the cache */
   /* replace1433_1_0_0 -> 3952 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3952 },
      -1,
   } },
   /* replace1433_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3954, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3953, 3955 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1434_0_0 -> 6 in the cache */
   /* search1434_0 -> 3841 in the cache */
   /* search1434_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3841, 33 },
      -1,
   } },

   /* replace1434_0_0 -> 6 in the cache */
   /* replace1434_0_1_0 -> 36 in the cache */
   /* replace1434_0_1 -> 3952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 3952 },
      -1,
   } },
   /* replace1434_1_0_0_0 -> 36 in the cache */
   /* replace1434_1_0_0 -> 3952 in the cache */
   /* replace1434_1_0 -> 3954 in the cache */
   /* replace1434_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 3954, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3958, 3959 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1435_0_0 -> 6 in the cache */
   /* search1435_0 -> 3841 in the cache */
   /* search1435_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3841, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1435_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3962, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1435_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3964, 36 },
      -1,
   } },
   /* replace1435_1_1_0 -> 6 in the cache */
   /* replace1435_1_1_1_0 -> 36 in the cache */
   /* replace1435_1_1_1 -> 3952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3965, 3966 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3963, 3967 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   /* search1436_0 -> 271 in the cache */
   /* search1436_1_0 -> 2045 in the cache */
   /* search1436_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 271, 3942 },
      -1,
   } },

   /* replace1436_0_0 -> 16 in the cache */
   /* replace1436_0_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3964 },
      -1,
   } },
   /* replace1436_1_0_0 -> 16 in the cache */
   /* replace1436_1_0_1 -> 3962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3962 },
      -1,
   } },
   /* replace1436_1_1_0_0 -> 16 in the cache */
   /* replace1436_1_1_0 -> 3878 in the cache */
   /* replace1436_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3878, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3971, 3972 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3970, 3973 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1437_0_0 -> 6 in the cache */
   /* search1437_0 -> 3841 in the cache */
   /* search1437_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3841, 33 },
      -1,
   } },

   /* replace1437_0_0 -> 3964 in the cache */
   /* replace1437_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3964, 36 },
      -1,
   } },
   /* replace1437_1_0_0 -> 3962 in the cache */
   /* replace1437_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3962, 36 },
      -1,
   } },
   /* replace1437_1_1_0 -> 6 in the cache */
   /* replace1437_1_1_1_0 -> 36 in the cache */
   /* replace1437_1_1_1 -> 3952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3977, 3978 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3976, 3979 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1438_0 -> 271 in the cache */
   /* search1438_1_0 -> 2045 in the cache */
   /* search1438_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 271, 3942 },
      -1,
   } },

   /* replace1438_0_0 -> 16 in the cache */
   /* replace1438_0_1 -> 3962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 3962 },
      -1,
   } },
   /* replace1438_1_0_0 -> 16 in the cache */
   /* replace1438_1_0_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 3964 },
      -1,
   } },
   /* replace1438_1_1_0_0 -> 16 in the cache */
   /* replace1438_1_1_0 -> 3878 in the cache */
   /* replace1438_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3878, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3983, 3984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3982, 3985 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1439_0_0 -> 6 in the cache */
   /* search1439_0 -> 3860 in the cache */
   /* search1439_1_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3860, 3987 },
      -1,
   } },

   /* replace1439_0 -> 6 in the cache */
   /* replace1439_1_0 -> 2045 in the cache */
   /* replace1439_1 -> 3887 in the cache */
   /* replace1439 -> 3888 in the cache */

   /* ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1440_0_0 -> 6 in the cache */
   /* search1440_0 -> 3860 in the cache */
   /* search1440_1_0 -> 2045 in the cache */
   /* search1440_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3860, 3987 },
      -1,
   } },

   /* replace1440_0 -> 6 in the cache */
   /* replace1440_1_0 -> 2045 in the cache */
   /* replace1440_1 -> 3887 in the cache */
   /* replace1440 -> 3890 in the cache */

   /* ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1441_0_0 -> 6 in the cache */
   /* search1441_0 -> 3860 in the cache */
   /* search1441_1_0 -> 2045 in the cache */
   /* search1441_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3860, 3987 },
      -1,
   } },

   /* replace1441_0 -> 6 in the cache */
   /* replace1441_1_0 -> 2045 in the cache */
   /* replace1441_1 -> 3887 in the cache */
   /* replace1441 -> 3892 in the cache */

   /* ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1442_0_0 -> 6 in the cache */
   /* search1442_0 -> 3860 in the cache */
   /* search1442_1_0 -> 2045 in the cache */
   /* search1442_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3860, 3987 },
      -1,
   } },

   /* replace1442_0 -> 6 in the cache */
   /* replace1442_1_0 -> 2045 in the cache */
   /* replace1442_1 -> 3887 in the cache */
   /* replace1442 -> 3894 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1443_0_0 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3895 },
      -1,
   } },
   /* search1443_1_0 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3992, 3993 },
      -1,
   } },

   /* replace1443_0_0 -> 3895 in the cache */
   /* replace1443_0 -> 3900 in the cache */
   /* replace1443_1 -> 3897 in the cache */
   /* replace1443 -> 3901 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1444_0_0 -> 3895 in the cache */
   /* search1444_0 -> 3992 in the cache */
   /* search1444_1_0 -> 3897 in the cache */
   /* search1444_1 -> 3993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3992, 3993 },
      -1,
   } },

   /* replace1444_0_0 -> 3895 in the cache */
   /* replace1444_0 -> 3900 in the cache */
   /* replace1444_1 -> 3897 in the cache */
   /* replace1444 -> 3903 in the cache */

   /* ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1445_0_0 -> 6 in the cache */
   /* search1445_0 -> 3860 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3860, 3996 },
      -1,
   } },

   /* replace1445_0_0 -> 6 in the cache */
   /* replace1445_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 3998 },
      -1,
   } },
   /* replace1445_1_0_0_0 -> 41 in the cache */
   /* replace1445_1_0_0 -> 3998 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3998 },
      -1,
   } },
   /* replace1445_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4000, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3999, 4001 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1446_0_0 -> 6 in the cache */
   /* search1446_0 -> 3860 in the cache */
   /* search1446_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3860, 3996 },
      -1,
   } },

   /* replace1446_0_0 -> 6 in the cache */
   /* replace1446_0_1_0 -> 41 in the cache */
   /* replace1446_0_1 -> 3998 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 3998 },
      -1,
   } },
   /* replace1446_1_0_0_0 -> 41 in the cache */
   /* replace1446_1_0_0 -> 3998 in the cache */
   /* replace1446_1_0 -> 4000 in the cache */
   /* replace1446_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4000, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4004, 4005 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1447_0_0 -> 6 in the cache */
   /* search1447_0 -> 3860 in the cache */
   /* search1447_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3860, 3996 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1447_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4008, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1447_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4010, 41 },
      -1,
   } },
   /* replace1447_1_1_0 -> 6 in the cache */
   /* replace1447_1_1_1_0 -> 41 in the cache */
   /* replace1447_1_1_1 -> 3998 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3998 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4011, 4012 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4009, 4013 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1448_1_0 -> 2045 in the cache */
   /* search1448_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4015, 3987 },
      -1,
   } },

   /* replace1448_0_0 -> 21 in the cache */
   /* replace1448_0_1 -> 4010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4010 },
      -1,
   } },
   /* replace1448_1_0_0 -> 21 in the cache */
   /* replace1448_1_0_1 -> 4008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4008 },
      -1,
   } },
   /* replace1448_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1448_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4019, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4018, 4020 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4017, 4021 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1449_0_0 -> 6 in the cache */
   /* search1449_0 -> 3860 in the cache */
   /* search1449_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3860, 3996 },
      -1,
   } },

   /* replace1449_0_0 -> 4010 in the cache */
   /* replace1449_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4010, 41 },
      -1,
   } },
   /* replace1449_1_0_0 -> 4008 in the cache */
   /* replace1449_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4008, 41 },
      -1,
   } },
   /* replace1449_1_1_0 -> 6 in the cache */
   /* replace1449_1_1_1_0 -> 41 in the cache */
   /* replace1449_1_1_1 -> 3998 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3998 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4025, 4026 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4024, 4027 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1450_0 -> 4015 in the cache */
   /* search1450_1_0 -> 2045 in the cache */
   /* search1450_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4015, 3987 },
      -1,
   } },

   /* replace1450_0_0 -> 21 in the cache */
   /* replace1450_0_1 -> 4008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4008 },
      -1,
   } },
   /* replace1450_1_0_0 -> 21 in the cache */
   /* replace1450_1_0_1 -> 4010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4010 },
      -1,
   } },
   /* replace1450_1_1_0_0 -> 21 in the cache */
   /* replace1450_1_1_0 -> 4019 in the cache */
   /* replace1450_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4019, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4031, 4032 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4030, 4033 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1451_0_0 -> 11 in the cache */
   /* search1451_0 -> 1732 in the cache */
   /* search1451_1_0 -> 2045 in the cache */
   /* search1451_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1732, 3942 },
      -1,
   } },

   /* replace1451_0 -> 11 in the cache */
   /* replace1451_1_0 -> 2045 in the cache */
   /* replace1451_1 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 3885 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1452_0_0 -> 11 in the cache */
   /* search1452_0 -> 1732 in the cache */
   /* search1452_1_0 -> 2045 in the cache */
   /* search1452_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1732, 3942 },
      -1,
   } },

   /* replace1452_0 -> 11 in the cache */
   /* replace1452_1_0 -> 2045 in the cache */
   /* replace1452_1 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 3885 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1453_0_0 -> 11 in the cache */
   /* search1453_0 -> 1732 in the cache */
   /* search1453_1_0 -> 2045 in the cache */
   /* search1453_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1732, 3942 },
      -1,
   } },

   /* replace1453_0 -> 11 in the cache */
   /* replace1453_1_0 -> 2045 in the cache */
   /* replace1453_1 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 3885 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1454_0_0 -> 11 in the cache */
   /* search1454_0 -> 1732 in the cache */
   /* search1454_1_0 -> 2045 in the cache */
   /* search1454_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1732, 3942 },
      -1,
   } },

   /* replace1454_0 -> 11 in the cache */
   /* replace1454_1_0 -> 2045 in the cache */
   /* replace1454_1 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3885 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1455_0_0 -> 3895 in the cache */
   /* search1455_0 -> 3947 in the cache */
   /* search1455_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3947, 4043 },
      -1,
   } },

   /* replace1455_0_0 -> 3895 in the cache */
   /* replace1455_0 -> 3896 in the cache */
   /* replace1455_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3896, 507 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1456_0_0 -> 3895 in the cache */
   /* search1456_0 -> 3947 in the cache */
   /* search1456_1_0 -> 507 in the cache */
   /* search1456_1 -> 4043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3947, 4043 },
      -1,
   } },

   /* replace1456_0_0 -> 3895 in the cache */
   /* replace1456_0 -> 3896 in the cache */
   /* replace1456_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3896, 507 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1457_0_0 -> 11 in the cache */
   /* search1457_0 -> 1732 in the cache */
   /* search1457_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1732, 4048 },
      -1,
   } },

   /* replace1457_0 -> 11 in the cache */
   /* replace1457_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4050 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1458_0_0 -> 11 in the cache */
   /* search1458_0 -> 1732 in the cache */
   /* search1458_1_0 -> 243 in the cache */
   /* search1458_1 -> 4048 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1732, 4048 },
      -1,
   } },

   /* replace1458_0 -> 11 in the cache */
   /* replace1458_1_0 -> 243 in the cache */
   /* replace1458_1 -> 4050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4050 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1459_0_0 -> 11 in the cache */
   /* search1459_0 -> 1732 in the cache */
   /* search1459_1_0 -> 243 in the cache */
   /* search1459_1 -> 4048 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1732, 4048 },
      -1,
   } },

   /* replace1459_0 -> 11 in the cache */
   /* replace1459_1_0 -> 243 in the cache */
   /* replace1459_1 -> 4050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4050 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1460_0_0 -> 11 in the cache */
   /* search1460_0 -> 1732 in the cache */
   /* search1460_1_0 -> 243 in the cache */
   /* search1460_1 -> 4048 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1732, 4048 },
      -1,
   } },

   /* replace1460_0 -> 11 in the cache */
   /* replace1460_1_0 -> 243 in the cache */
   /* replace1460_1 -> 4050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4050 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1461_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1461_1_0 -> 507 in the cache */
   /* search1461_1 -> 4043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4058, 4043 },
      -1,
   } },

   /* replace1461_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 496 },
      -1,
   } },
   /* replace1461_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4060, 507 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1462_0_0 -> 496 in the cache */
   /* search1462_0 -> 4058 in the cache */
   /* search1462_1_0 -> 507 in the cache */
   /* search1462_1 -> 4043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4058, 4043 },
      -1,
   } },

   /* replace1462_0_0 -> 496 in the cache */
   /* replace1462_0 -> 4060 in the cache */
   /* replace1462_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4060, 507 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1463_0_0 -> 11 in the cache */
   /* search1463_0 -> 1732 in the cache */
   /* search1463_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1732, 33 },
      -1,
   } },

   /* replace1463_0_0 -> 11 in the cache */
   /* replace1463_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4065 },
      -1,
   } },
   /* replace1463_1_0_0_0 -> 36 in the cache */
   /* replace1463_1_0_0 -> 4065 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4065 },
      -1,
   } },
   /* replace1463_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4067, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4066, 4068 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1464_0_0 -> 11 in the cache */
   /* search1464_0 -> 1732 in the cache */
   /* search1464_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1732, 33 },
      -1,
   } },

   /* replace1464_0_0 -> 11 in the cache */
   /* replace1464_0_1_0 -> 36 in the cache */
   /* replace1464_0_1 -> 4065 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4065 },
      -1,
   } },
   /* replace1464_1_0_0_0 -> 36 in the cache */
   /* replace1464_1_0_0 -> 4065 in the cache */
   /* replace1464_1_0 -> 4067 in the cache */
   /* replace1464_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4067, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4071, 4072 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1465_0_0 -> 11 in the cache */
   /* search1465_0 -> 1732 in the cache */
   /* search1465_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1732, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1465_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4075, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1465_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4077, 36 },
      -1,
   } },
   /* replace1465_1_1_0 -> 11 in the cache */
   /* replace1465_1_1_1_0 -> 36 in the cache */
   /* replace1465_1_1_1 -> 4065 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4065 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4078, 4079 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4076, 4080 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1466_0 -> 271 in the cache */
   /* search1466_1_0 -> 243 in the cache */
   /* search1466_1 -> 4048 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 271, 4048 },
      -1,
   } },

   /* replace1466_0_0 -> 16 in the cache */
   /* replace1466_0_1 -> 4077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4077 },
      -1,
   } },
   /* replace1466_1_0_0 -> 16 in the cache */
   /* replace1466_1_0_1 -> 4075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4075 },
      -1,
   } },
   /* replace1466_1_1_0_0 -> 16 in the cache */
   /* replace1466_1_1_0 -> 3880 in the cache */
   /* replace1466_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3880, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4084, 4085 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4083, 4086 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1467_0_0 -> 11 in the cache */
   /* search1467_0 -> 1732 in the cache */
   /* search1467_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1732, 33 },
      -1,
   } },

   /* replace1467_0_0 -> 4077 in the cache */
   /* replace1467_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4077, 36 },
      -1,
   } },
   /* replace1467_1_0_0 -> 4075 in the cache */
   /* replace1467_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4075, 36 },
      -1,
   } },
   /* replace1467_1_1_0 -> 11 in the cache */
   /* replace1467_1_1_1_0 -> 36 in the cache */
   /* replace1467_1_1_1 -> 4065 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4065 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4090, 4091 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4089, 4092 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1468_0 -> 271 in the cache */
   /* search1468_1_0 -> 243 in the cache */
   /* search1468_1 -> 4048 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 271, 4048 },
      -1,
   } },

   /* replace1468_0_0 -> 16 in the cache */
   /* replace1468_0_1 -> 4075 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4075 },
      -1,
   } },
   /* replace1468_1_0_0 -> 16 in the cache */
   /* replace1468_1_0_1 -> 4077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4077 },
      -1,
   } },
   /* replace1468_1_1_0_0 -> 16 in the cache */
   /* replace1468_1_1_0 -> 3880 in the cache */
   /* replace1468_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3880, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4096, 4097 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4095, 4098 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1469_0_0 -> 11 in the cache */
   /* search1469_0 -> 1755 in the cache */
   /* search1469_1_0 -> 2045 in the cache */
   /* search1469_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1755, 3987 },
      -1,
   } },

   /* replace1469_0 -> 11 in the cache */
   /* replace1469_1_0 -> 2045 in the cache */
   /* replace1469_1 -> 3885 in the cache */
   /* replace1469 -> 4036 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1470_0_0 -> 11 in the cache */
   /* search1470_0 -> 1755 in the cache */
   /* search1470_1_0 -> 2045 in the cache */
   /* search1470_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1755, 3987 },
      -1,
   } },

   /* replace1470_0 -> 11 in the cache */
   /* replace1470_1_0 -> 2045 in the cache */
   /* replace1470_1 -> 3885 in the cache */
   /* replace1470 -> 4038 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1471_0_0 -> 11 in the cache */
   /* search1471_0 -> 1755 in the cache */
   /* search1471_1_0 -> 2045 in the cache */
   /* search1471_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1755, 3987 },
      -1,
   } },

   /* replace1471_0 -> 11 in the cache */
   /* replace1471_1_0 -> 2045 in the cache */
   /* replace1471_1 -> 3885 in the cache */
   /* replace1471 -> 4040 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1472_0_0 -> 11 in the cache */
   /* search1472_0 -> 1755 in the cache */
   /* search1472_1_0 -> 2045 in the cache */
   /* search1472_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1755, 3987 },
      -1,
   } },

   /* replace1472_0 -> 11 in the cache */
   /* replace1472_1_0 -> 2045 in the cache */
   /* replace1472_1 -> 3885 in the cache */
   /* replace1472 -> 4042 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1473_0_0 -> 3895 in the cache */
   /* search1473_0 -> 3992 in the cache */
   /* search1473_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3992, 4104 },
      -1,
   } },

   /* replace1473_0_0 -> 3895 in the cache */
   /* replace1473_0 -> 3896 in the cache */
   /* replace1473_1 -> 507 in the cache */
   /* replace1473 -> 4045 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1474_0_0 -> 3895 in the cache */
   /* search1474_0 -> 3992 in the cache */
   /* search1474_1_0 -> 507 in the cache */
   /* search1474_1 -> 4104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3992, 4104 },
      -1,
   } },

   /* replace1474_0_0 -> 3895 in the cache */
   /* replace1474_0 -> 3896 in the cache */
   /* replace1474_1 -> 507 in the cache */
   /* replace1474 -> 4047 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1475_0_0 -> 11 in the cache */
   /* search1475_0 -> 1755 in the cache */
   /* search1475_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1755, 4107 },
      -1,
   } },

   /* replace1475_0 -> 11 in the cache */
   /* replace1475_1_0 -> 243 in the cache */
   /* replace1475_1 -> 4050 in the cache */
   /* replace1475 -> 4051 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1476_0_0 -> 11 in the cache */
   /* search1476_0 -> 1755 in the cache */
   /* search1476_1_0 -> 243 in the cache */
   /* search1476_1 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1755, 4107 },
      -1,
   } },

   /* replace1476_0 -> 11 in the cache */
   /* replace1476_1_0 -> 243 in the cache */
   /* replace1476_1 -> 4050 in the cache */
   /* replace1476 -> 4053 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1477_0_0 -> 11 in the cache */
   /* search1477_0 -> 1755 in the cache */
   /* search1477_1_0 -> 243 in the cache */
   /* search1477_1 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1755, 4107 },
      -1,
   } },

   /* replace1477_0 -> 11 in the cache */
   /* replace1477_1_0 -> 243 in the cache */
   /* replace1477_1 -> 4050 in the cache */
   /* replace1477 -> 4055 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1478_0_0 -> 11 in the cache */
   /* search1478_0 -> 1755 in the cache */
   /* search1478_1_0 -> 243 in the cache */
   /* search1478_1 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1755, 4107 },
      -1,
   } },

   /* replace1478_0 -> 11 in the cache */
   /* replace1478_1_0 -> 243 in the cache */
   /* replace1478_1 -> 4050 in the cache */
   /* replace1478 -> 4057 in the cache */

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1479_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1479_1_0 -> 507 in the cache */
   /* search1479_1 -> 4104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4112, 4104 },
      -1,
   } },

   /* replace1479_0_0 -> 496 in the cache */
   /* replace1479_0 -> 4060 in the cache */
   /* replace1479_1 -> 507 in the cache */
   /* replace1479 -> 4061 in the cache */

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1480_0_0 -> 496 in the cache */
   /* search1480_0 -> 4112 in the cache */
   /* search1480_1_0 -> 507 in the cache */
   /* search1480_1 -> 4104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4112, 4104 },
      -1,
   } },

   /* replace1480_0_0 -> 496 in the cache */
   /* replace1480_0 -> 4060 in the cache */
   /* replace1480_1 -> 507 in the cache */
   /* replace1480 -> 4063 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1481_0_0 -> 11 in the cache */
   /* search1481_0 -> 1755 in the cache */
   /* search1481_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1755, 3996 },
      -1,
   } },

   /* replace1481_0_0 -> 11 in the cache */
   /* replace1481_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4116 },
      -1,
   } },
   /* replace1481_1_0_0_0 -> 41 in the cache */
   /* replace1481_1_0_0 -> 4116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4116 },
      -1,
   } },
   /* replace1481_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4118, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4117, 4119 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1482_0_0 -> 11 in the cache */
   /* search1482_0 -> 1755 in the cache */
   /* search1482_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1755, 3996 },
      -1,
   } },

   /* replace1482_0_0 -> 11 in the cache */
   /* replace1482_0_1_0 -> 41 in the cache */
   /* replace1482_0_1 -> 4116 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4116 },
      -1,
   } },
   /* replace1482_1_0_0_0 -> 41 in the cache */
   /* replace1482_1_0_0 -> 4116 in the cache */
   /* replace1482_1_0 -> 4118 in the cache */
   /* replace1482_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4118, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4122, 4123 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1483_0_0 -> 11 in the cache */
   /* search1483_0 -> 1755 in the cache */
   /* search1483_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1755, 3996 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1483_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4126, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1483_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4128, 41 },
      -1,
   } },
   /* replace1483_1_1_0 -> 11 in the cache */
   /* replace1483_1_1_1_0 -> 41 in the cache */
   /* replace1483_1_1_1 -> 4116 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4116 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4129, 4130 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4127, 4131 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1484_0 -> 4015 in the cache */
   /* search1484_1_0 -> 243 in the cache */
   /* search1484_1 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4015, 4107 },
      -1,
   } },

   /* replace1484_0_0 -> 21 in the cache */
   /* replace1484_0_1 -> 4128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4128 },
      -1,
   } },
   /* replace1484_1_0_0 -> 21 in the cache */
   /* replace1484_1_0_1 -> 4126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4126 },
      -1,
   } },
   /* replace1484_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1484_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4136, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4135, 4137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4134, 4138 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1485_0_0 -> 11 in the cache */
   /* search1485_0 -> 1755 in the cache */
   /* search1485_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1755, 3996 },
      -1,
   } },

   /* replace1485_0_0 -> 4128 in the cache */
   /* replace1485_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4128, 41 },
      -1,
   } },
   /* replace1485_1_0_0 -> 4126 in the cache */
   /* replace1485_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4126, 41 },
      -1,
   } },
   /* replace1485_1_1_0 -> 11 in the cache */
   /* replace1485_1_1_1_0 -> 41 in the cache */
   /* replace1485_1_1_1 -> 4116 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4116 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4142, 4143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4141, 4144 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1486_0 -> 4015 in the cache */
   /* search1486_1_0 -> 243 in the cache */
   /* search1486_1 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4015, 4107 },
      -1,
   } },

   /* replace1486_0_0 -> 21 in the cache */
   /* replace1486_0_1 -> 4126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4126 },
      -1,
   } },
   /* replace1486_1_0_0 -> 21 in the cache */
   /* replace1486_1_0_1 -> 4128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4128 },
      -1,
   } },
   /* replace1486_1_1_0_0 -> 21 in the cache */
   /* replace1486_1_1_0 -> 4136 in the cache */
   /* replace1486_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4136, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4148, 4149 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4147, 4150 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1487_0_0 -> 16 in the cache */
   /* search1487_0 -> 1839 in the cache */
   /* search1487_1_0 -> 2045 in the cache */
   /* search1487_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1839, 3987 },
      -1,
   } },

   /* replace1487_0 -> 16 in the cache */
   /* replace1487_1_0 -> 2045 in the cache */
   /* replace1487_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3942 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1488_0_0 -> 16 in the cache */
   /* search1488_0 -> 1839 in the cache */
   /* search1488_1_0 -> 2045 in the cache */
   /* search1488_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1839, 3987 },
      -1,
   } },

   /* replace1488_0 -> 16 in the cache */
   /* replace1488_1_0 -> 2045 in the cache */
   /* replace1488_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 3942 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1489_0_0 -> 16 in the cache */
   /* search1489_0 -> 1839 in the cache */
   /* search1489_1_0 -> 2045 in the cache */
   /* search1489_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1839, 3987 },
      -1,
   } },

   /* replace1489_0 -> 16 in the cache */
   /* replace1489_1_0 -> 2045 in the cache */
   /* replace1489_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 3942 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1490_0_0 -> 16 in the cache */
   /* search1490_0 -> 1839 in the cache */
   /* search1490_1_0 -> 2045 in the cache */
   /* search1490_1 -> 3987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1839, 3987 },
      -1,
   } },

   /* replace1490_0 -> 16 in the cache */
   /* replace1490_1_0 -> 2045 in the cache */
   /* replace1490_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3942 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1491_0_0 -> 3895 in the cache */
   /* search1491_0 -> 3992 in the cache */
   /* search1491_1_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3992, 4160 },
      -1,
   } },

   /* replace1491_0_0 -> 3895 in the cache */
   /* replace1491_0 -> 3947 in the cache */
   /* replace1491_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3947, 360 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1492_0_0 -> 3895 in the cache */
   /* search1492_0 -> 3992 in the cache */
   /* search1492_1_0 -> 360 in the cache */
   /* search1492_1 -> 4160 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3992, 4160 },
      -1,
   } },

   /* replace1492_0_0 -> 3895 in the cache */
   /* replace1492_0 -> 3947 in the cache */
   /* replace1492_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3947, 360 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1493_0_0 -> 16 in the cache */
   /* search1493_0 -> 1839 in the cache */
   /* search1493_1_0 -> 243 in the cache */
   /* search1493_1 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1839, 4107 },
      -1,
   } },

   /* replace1493_0 -> 16 in the cache */
   /* replace1493_1_0 -> 243 in the cache */
   /* replace1493_1 -> 4048 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4048 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1494_0_0 -> 16 in the cache */
   /* search1494_0 -> 1839 in the cache */
   /* search1494_1_0 -> 243 in the cache */
   /* search1494_1 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1839, 4107 },
      -1,
   } },

   /* replace1494_0 -> 16 in the cache */
   /* replace1494_1_0 -> 243 in the cache */
   /* replace1494_1 -> 4048 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4048 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1495_0_0 -> 16 in the cache */
   /* search1495_0 -> 1839 in the cache */
   /* search1495_1_0 -> 243 in the cache */
   /* search1495_1 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1839, 4107 },
      -1,
   } },

   /* replace1495_0 -> 16 in the cache */
   /* replace1495_1_0 -> 243 in the cache */
   /* replace1495_1 -> 4048 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4048 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1496_0_0 -> 16 in the cache */
   /* search1496_0 -> 1839 in the cache */
   /* search1496_1_0 -> 243 in the cache */
   /* search1496_1 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1839, 4107 },
      -1,
   } },

   /* replace1496_0 -> 16 in the cache */
   /* replace1496_1_0 -> 243 in the cache */
   /* replace1496_1 -> 4048 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4048 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1497_0_0 -> 496 in the cache */
   /* search1497_0 -> 4112 in the cache */
   /* search1497_1_0 -> 360 in the cache */
   /* search1497_1 -> 4160 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4112, 4160 },
      -1,
   } },

   /* replace1497_0_0 -> 496 in the cache */
   /* replace1497_0 -> 4058 in the cache */
   /* replace1497_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4058, 360 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1498_0_0 -> 496 in the cache */
   /* search1498_0 -> 4112 in the cache */
   /* search1498_1_0 -> 360 in the cache */
   /* search1498_1 -> 4160 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4112, 4160 },
      -1,
   } },

   /* replace1498_0_0 -> 496 in the cache */
   /* replace1498_0 -> 4058 in the cache */
   /* replace1498_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4058, 360 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1499_0_0 -> 16 in the cache */
   /* search1499_0 -> 1839 in the cache */
   /* search1499_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1839, 4177 },
      -1,
   } },

   /* replace1499_0 -> 16 in the cache */
   /* replace1499_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4179 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1500_0_0 -> 16 in the cache */
   /* search1500_0 -> 1839 in the cache */
   /* search1500_1_0 -> 36 in the cache */
   /* search1500_1 -> 4177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1839, 4177 },
      -1,
   } },

   /* replace1500_0 -> 16 in the cache */
   /* replace1500_1_0 -> 36 in the cache */
   /* replace1500_1 -> 4179 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4179 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1501_0_0 -> 16 in the cache */
   /* search1501_0 -> 1839 in the cache */
   /* search1501_1_0 -> 36 in the cache */
   /* search1501_1 -> 4177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1839, 4177 },
      -1,
   } },

   /* replace1501_0 -> 16 in the cache */
   /* replace1501_1_0 -> 36 in the cache */
   /* replace1501_1 -> 4179 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4179 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1502_0_0 -> 16 in the cache */
   /* search1502_0 -> 1839 in the cache */
   /* search1502_1_0 -> 36 in the cache */
   /* search1502_1 -> 4177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1839, 4177 },
      -1,
   } },

   /* replace1502_0 -> 16 in the cache */
   /* replace1502_1_0 -> 36 in the cache */
   /* replace1502_1 -> 4179 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4179 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1503_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 358 },
      -1,
   } },
   /* search1503_1_0 -> 360 in the cache */
   /* search1503_1 -> 4160 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4187, 4160 },
      -1,
   } },

   /* replace1503_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 358 },
      -1,
   } },
   /* replace1503_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4189, 360 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1504_0_0 -> 358 in the cache */
   /* search1504_0 -> 4187 in the cache */
   /* search1504_1_0 -> 360 in the cache */
   /* search1504_1 -> 4160 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4187, 4160 },
      -1,
   } },

   /* replace1504_0_0 -> 358 in the cache */
   /* replace1504_0 -> 4189 in the cache */
   /* replace1504_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4189, 360 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1505_0_0 -> 16 in the cache */
   /* search1505_0 -> 1839 in the cache */
   /* search1505_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1839, 3996 },
      -1,
   } },

   /* replace1505_0_0 -> 16 in the cache */
   /* replace1505_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4194 },
      -1,
   } },
   /* replace1505_1_0_0_0 -> 41 in the cache */
   /* replace1505_1_0_0 -> 4194 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4194 },
      -1,
   } },
   /* replace1505_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4196, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4195, 4197 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1506_0_0 -> 16 in the cache */
   /* search1506_0 -> 1839 in the cache */
   /* search1506_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1839, 3996 },
      -1,
   } },

   /* replace1506_0_0 -> 16 in the cache */
   /* replace1506_0_1_0 -> 41 in the cache */
   /* replace1506_0_1 -> 4194 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4194 },
      -1,
   } },
   /* replace1506_1_0_0_0 -> 41 in the cache */
   /* replace1506_1_0_0 -> 4194 in the cache */
   /* replace1506_1_0 -> 4196 in the cache */
   /* replace1506_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4196, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4200, 4201 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b')))) */
   /* search1507_0_0 -> 16 in the cache */
   /* search1507_0 -> 1839 in the cache */
   /* search1507_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1839, 3996 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80000000 /* -2147483648 */ },
   } },
   /* replace1507_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4204, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   /* replace1507_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4206, 41 },
      -1,
   } },
   /* replace1507_1_1_0 -> 16 in the cache */
   /* replace1507_1_1_1_0 -> 41 in the cache */
   /* replace1507_1_1_1 -> 4194 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4207, 4208 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4205, 4209 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b'))) */
   /* search1508_0 -> 4015 in the cache */
   /* search1508_1_0 -> 36 in the cache */
   /* search1508_1 -> 4177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4015, 4177 },
      -1,
   } },

   /* replace1508_0_0 -> 21 in the cache */
   /* replace1508_0_1 -> 4206 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4206 },
      -1,
   } },
   /* replace1508_1_0_0 -> 21 in the cache */
   /* replace1508_1_0_1 -> 4204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4204 },
      -1,
   } },
   /* replace1508_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1508_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4214, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4213, 4215 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4212, 4216 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b')))) */
   /* search1509_0_0 -> 16 in the cache */
   /* search1509_0 -> 1839 in the cache */
   /* search1509_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1839, 3996 },
      -1,
   } },

   /* replace1509_0_0 -> 4206 in the cache */
   /* replace1509_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4206, 41 },
      -1,
   } },
   /* replace1509_1_0_0 -> 4204 in the cache */
   /* replace1509_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4204, 41 },
      -1,
   } },
   /* replace1509_1_1_0 -> 16 in the cache */
   /* replace1509_1_1_1_0 -> 41 in the cache */
   /* replace1509_1_1_1 -> 4194 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4220, 4221 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4219, 4222 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b'))) */
   /* search1510_0 -> 4015 in the cache */
   /* search1510_1_0 -> 36 in the cache */
   /* search1510_1 -> 4177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4015, 4177 },
      -1,
   } },

   /* replace1510_0_0 -> 21 in the cache */
   /* replace1510_0_1 -> 4204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4204 },
      -1,
   } },
   /* replace1510_1_0_0 -> 21 in the cache */
   /* replace1510_1_0_1 -> 4206 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4206 },
      -1,
   } },
   /* replace1510_1_1_0_0 -> 21 in the cache */
   /* replace1510_1_1_0 -> 4214 in the cache */
   /* replace1510_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4214, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4226, 4227 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4225, 4228 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1511_0_0 -> 6 in the cache */
   /* search1511_0 -> 3825 in the cache */
   /* search1511_1_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3825, 4230 },
      -1,
   } },

   /* replace1511_0 -> 6 in the cache */
   /* replace1511_1_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 4232 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1512_0_0 -> 6 in the cache */
   /* search1512_0 -> 3825 in the cache */
   /* search1512_1_0 -> 2045 in the cache */
   /* search1512_1 -> 4230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3825, 4230 },
      -1,
   } },

   /* replace1512_0 -> 6 in the cache */
   /* replace1512_1_0 -> 2045 in the cache */
   /* replace1512_1 -> 4232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 4232 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1513_0_0 -> 6 in the cache */
   /* search1513_0 -> 3825 in the cache */
   /* search1513_1_0 -> 2045 in the cache */
   /* search1513_1 -> 4230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3825, 4230 },
      -1,
   } },

   /* replace1513_0 -> 6 in the cache */
   /* replace1513_1_0 -> 2045 in the cache */
   /* replace1513_1 -> 4232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4232 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1514_0_0 -> 6 in the cache */
   /* search1514_0 -> 3825 in the cache */
   /* search1514_1_0 -> 2045 in the cache */
   /* search1514_1 -> 4230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3825, 4230 },
      -1,
   } },

   /* replace1514_0 -> 6 in the cache */
   /* replace1514_1_0 -> 2045 in the cache */
   /* replace1514_1 -> 4232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4232 },
      -1,
   } },

   /* ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1515_0_0 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3895 },
      -1,
   } },
   /* search1515_1_0 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4240, 4241 },
      -1,
   } },

   /* replace1515_0_0 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3895 },
      -1,
   } },
   /* replace1515_1 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4243, 3897 },
      -1,
   } },

   /* ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1516_0_0 -> 3895 in the cache */
   /* search1516_0 -> 4240 in the cache */
   /* search1516_1_0 -> 3897 in the cache */
   /* search1516_1 -> 4241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4240, 4241 },
      -1,
   } },

   /* replace1516_0_0 -> 3895 in the cache */
   /* replace1516_0 -> 4243 in the cache */
   /* replace1516_1 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4243, 3897 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1517_0_0 -> 6 in the cache */
   /* search1517_0 -> 3825 in the cache */
   /* search1517_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3825, 1944 },
      -1,
   } },

   /* replace1517_0_0 -> 6 in the cache */
   /* replace1517_0_1_0 -> 243 in the cache */
   /* replace1517_0_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 1952 },
      -1,
   } },
   /* replace1517_1_0_0_0 -> 243 in the cache */
   /* replace1517_1_0_0 -> 1952 in the cache */
   /* replace1517_1_0 -> 1953 in the cache */
   /* replace1517_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 1953, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4248, 4249 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1518_0_0 -> 6 in the cache */
   /* search1518_0 -> 3825 in the cache */
   /* search1518_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3825, 1944 },
      -1,
   } },

   /* replace1518_0_0 -> 6 in the cache */
   /* replace1518_0_1_0 -> 243 in the cache */
   /* replace1518_0_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 1952 },
      -1,
   } },
   /* replace1518_1_0_0_0 -> 243 in the cache */
   /* replace1518_1_0_0 -> 1952 in the cache */
   /* replace1518_1_0 -> 1953 in the cache */
   /* replace1518_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 1953, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4252, 4253 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1519_0_0 -> 6 in the cache */
   /* search1519_0 -> 3825 in the cache */
   /* search1519_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3825, 1944 },
      -1,
   } },

   /* replace1519_0_0 -> 804 in the cache */
   /* replace1519_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 804, 243 },
      -1,
   } },
   /* replace1519_1_0_0 -> 1946 in the cache */
   /* replace1519_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1946, 243 },
      -1,
   } },
   /* replace1519_1_1_0 -> 6 in the cache */
   /* replace1519_1_1_1_0 -> 243 in the cache */
   /* replace1519_1_1_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 1952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4257, 4258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4256, 4259 },
      -1,
   } },

   /* ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1520_0 -> 3922 in the cache */
   /* search1520_1_0 -> 2045 in the cache */
   /* search1520_1 -> 4230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3922, 4230 },
      -1,
   } },

   /* replace1520_0_0 -> 11 in the cache */
   /* replace1520_0_1 -> 1946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 1946 },
      -1,
   } },
   /* replace1520_1_0_0 -> 11 in the cache */
   /* replace1520_1_0_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 804 },
      -1,
   } },
   /* replace1520_1_1_0_0 -> 11 in the cache */
   /* replace1520_1_1_0 -> 1942 in the cache */
   /* replace1520_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1942, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4263, 4264 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4262, 4265 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1521_0_0 -> 6 in the cache */
   /* search1521_0 -> 3825 in the cache */
   /* search1521_1 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3825, 1944 },
      -1,
   } },

   /* replace1521_0_0 -> 1946 in the cache */
   /* replace1521_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1946, 243 },
      -1,
   } },
   /* replace1521_1_0_0 -> 804 in the cache */
   /* replace1521_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 804, 243 },
      -1,
   } },
   /* replace1521_1_1_0 -> 6 in the cache */
   /* replace1521_1_1_1_0 -> 243 in the cache */
   /* replace1521_1_1_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 1952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4269, 4270 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4268, 4271 },
      -1,
   } },

   /* ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1522_0 -> 3922 in the cache */
   /* search1522_1_0 -> 2045 in the cache */
   /* search1522_1 -> 4230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3922, 4230 },
      -1,
   } },

   /* replace1522_0_0 -> 11 in the cache */
   /* replace1522_0_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 804 },
      -1,
   } },
   /* replace1522_1_0_0 -> 11 in the cache */
   /* replace1522_1_0_1 -> 1946 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 1946 },
      -1,
   } },
   /* replace1522_1_1_0_0 -> 11 in the cache */
   /* replace1522_1_1_0 -> 1942 in the cache */
   /* replace1522_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1942, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4275, 4276 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4274, 4277 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1523_0_0 -> 6 in the cache */
   /* search1523_0 -> 2952 in the cache */
   /* search1523_1_0 -> 2045 in the cache */
   /* search1523_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2952, 2954 },
      -1,
   } },

   /* replace1523_0 -> 6 in the cache */
   /* replace1523_1_0 -> 2045 in the cache */
   /* replace1523_1 -> 4232 in the cache */
   /* replace1523 -> 4233 in the cache */

   /* ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1524_0_0 -> 6 in the cache */
   /* search1524_0 -> 2952 in the cache */
   /* search1524_1_0 -> 2045 in the cache */
   /* search1524_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2952, 2954 },
      -1,
   } },

   /* replace1524_0 -> 6 in the cache */
   /* replace1524_1_0 -> 2045 in the cache */
   /* replace1524_1 -> 4232 in the cache */
   /* replace1524 -> 4235 in the cache */

   /* ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1525_0_0 -> 6 in the cache */
   /* search1525_0 -> 2952 in the cache */
   /* search1525_1_0 -> 2045 in the cache */
   /* search1525_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2952, 2954 },
      -1,
   } },

   /* replace1525_0 -> 6 in the cache */
   /* replace1525_1_0 -> 2045 in the cache */
   /* replace1525_1 -> 4232 in the cache */
   /* replace1525 -> 4237 in the cache */

   /* ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1526_0_0 -> 6 in the cache */
   /* search1526_0 -> 2952 in the cache */
   /* search1526_1_0 -> 2045 in the cache */
   /* search1526_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2952, 2954 },
      -1,
   } },

   /* replace1526_0 -> 6 in the cache */
   /* replace1526_1_0 -> 2045 in the cache */
   /* replace1526_1 -> 4232 in the cache */
   /* replace1526 -> 4239 in the cache */

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1527_0_0 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3895 },
      -1,
   } },
   /* search1527_1_0 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4283, 4284 },
      -1,
   } },

   /* replace1527_0_0 -> 3895 in the cache */
   /* replace1527_0 -> 4243 in the cache */
   /* replace1527_1 -> 3897 in the cache */
   /* replace1527 -> 4244 in the cache */

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1528_0_0 -> 3895 in the cache */
   /* search1528_0 -> 4283 in the cache */
   /* search1528_1_0 -> 3897 in the cache */
   /* search1528_1 -> 4284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4283, 4284 },
      -1,
   } },

   /* replace1528_0_0 -> 3895 in the cache */
   /* replace1528_0 -> 4243 in the cache */
   /* replace1528_1 -> 3897 in the cache */
   /* replace1528 -> 4246 in the cache */

   /* ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1529_0_0 -> 6 in the cache */
   /* search1529_0 -> 2952 in the cache */
   /* search1529_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2952, 33 },
      -1,
   } },

   /* replace1529_0_0 -> 6 in the cache */
   /* replace1529_0_1_0 -> 36 in the cache */
   /* replace1529_0_1 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 1960 },
      -1,
   } },
   /* replace1529_1_0_0_0 -> 36 in the cache */
   /* replace1529_1_0_0 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1960 },
      -1,
   } },
   /* replace1529_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4289, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4288, 4290 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1530_0_0 -> 6 in the cache */
   /* search1530_0 -> 2952 in the cache */
   /* search1530_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2952, 33 },
      -1,
   } },

   /* replace1530_0_0 -> 6 in the cache */
   /* replace1530_0_1_0 -> 36 in the cache */
   /* replace1530_0_1 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 1960 },
      -1,
   } },
   /* replace1530_1_0_0_0 -> 36 in the cache */
   /* replace1530_1_0_0 -> 1960 in the cache */
   /* replace1530_1_0 -> 4289 in the cache */
   /* replace1530_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4289, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4293, 4294 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1531_0_0 -> 6 in the cache */
   /* search1531_0 -> 2952 in the cache */
   /* search1531_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2952, 33 },
      -1,
   } },

   /* replace1531_0_0 -> 120 in the cache */
   /* replace1531_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   /* replace1531_1_0_0 -> 774 in the cache */
   /* replace1531_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 774, 36 },
      -1,
   } },
   /* replace1531_1_1_0 -> 6 in the cache */
   /* replace1531_1_1_1_0 -> 36 in the cache */
   /* replace1531_1_1_1 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 1960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4298, 4299 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4297, 4300 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1532_0 -> 271 in the cache */
   /* search1532_1_0 -> 2045 in the cache */
   /* search1532_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 271, 2954 },
      -1,
   } },

   /* replace1532_0_0 -> 16 in the cache */
   /* replace1532_0_1 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 774 },
      -1,
   } },
   /* replace1532_1_0_0 -> 16 in the cache */
   /* replace1532_1_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace1532_1_1_0_0 -> 16 in the cache */
   /* replace1532_1_1_0 -> 1958 in the cache */
   /* replace1532_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1958, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4304, 4305 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4303, 4306 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1533_0_0 -> 6 in the cache */
   /* search1533_0 -> 2952 in the cache */
   /* search1533_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2952, 33 },
      -1,
   } },

   /* replace1533_0_0 -> 774 in the cache */
   /* replace1533_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 774, 36 },
      -1,
   } },
   /* replace1533_1_0_0 -> 120 in the cache */
   /* replace1533_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   /* replace1533_1_1_0 -> 6 in the cache */
   /* replace1533_1_1_1_0 -> 36 in the cache */
   /* replace1533_1_1_1 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 1960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4310, 4311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4309, 4312 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1534_0 -> 271 in the cache */
   /* search1534_1_0 -> 2045 in the cache */
   /* search1534_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 271, 2954 },
      -1,
   } },

   /* replace1534_0_0 -> 16 in the cache */
   /* replace1534_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace1534_1_0_0 -> 16 in the cache */
   /* replace1534_1_0_1 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 774 },
      -1,
   } },
   /* replace1534_1_1_0_0 -> 16 in the cache */
   /* replace1534_1_1_0 -> 1958 in the cache */
   /* replace1534_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1958, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4316, 4317 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4315, 4318 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1535_0_0 -> 6 in the cache */
   /* search1535_0 -> 3862 in the cache */
   /* search1535_1_0 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3862, 4320 },
      -1,
   } },

   /* replace1535_0 -> 6 in the cache */
   /* replace1535_1_0 -> 2045 in the cache */
   /* replace1535_1 -> 4232 in the cache */
   /* replace1535 -> 4233 in the cache */

   /* ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1536_0_0 -> 6 in the cache */
   /* search1536_0 -> 3862 in the cache */
   /* search1536_1_0 -> 2045 in the cache */
   /* search1536_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3862, 4320 },
      -1,
   } },

   /* replace1536_0 -> 6 in the cache */
   /* replace1536_1_0 -> 2045 in the cache */
   /* replace1536_1 -> 4232 in the cache */
   /* replace1536 -> 4235 in the cache */

   /* ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1537_0_0 -> 6 in the cache */
   /* search1537_0 -> 3862 in the cache */
   /* search1537_1_0 -> 2045 in the cache */
   /* search1537_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3862, 4320 },
      -1,
   } },

   /* replace1537_0 -> 6 in the cache */
   /* replace1537_1_0 -> 2045 in the cache */
   /* replace1537_1 -> 4232 in the cache */
   /* replace1537 -> 4237 in the cache */

   /* ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1538_0_0 -> 6 in the cache */
   /* search1538_0 -> 3862 in the cache */
   /* search1538_1_0 -> 2045 in the cache */
   /* search1538_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3862, 4320 },
      -1,
   } },

   /* replace1538_0 -> 6 in the cache */
   /* replace1538_1_0 -> 2045 in the cache */
   /* replace1538_1 -> 4232 in the cache */
   /* replace1538 -> 4239 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1539_0_0 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3895 },
      -1,
   } },
   /* search1539_1_0 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4325, 4326 },
      -1,
   } },

   /* replace1539_0_0 -> 3895 in the cache */
   /* replace1539_0 -> 4243 in the cache */
   /* replace1539_1 -> 3897 in the cache */
   /* replace1539 -> 4244 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1540_0_0 -> 3895 in the cache */
   /* search1540_0 -> 4325 in the cache */
   /* search1540_1_0 -> 3897 in the cache */
   /* search1540_1 -> 4326 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4325, 4326 },
      -1,
   } },

   /* replace1540_0_0 -> 3895 in the cache */
   /* replace1540_0 -> 4243 in the cache */
   /* replace1540_1 -> 3897 in the cache */
   /* replace1540 -> 4246 in the cache */

   /* ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1541_0_0 -> 6 in the cache */
   /* search1541_0 -> 3862 in the cache */
   /* search1541_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3862, 3996 },
      -1,
   } },

   /* replace1541_0_0 -> 6 in the cache */
   /* replace1541_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4330 },
      -1,
   } },
   /* replace1541_1_0_0_0 -> 41 in the cache */
   /* replace1541_1_0_0 -> 4330 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4330 },
      -1,
   } },
   /* replace1541_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4332, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4331, 4333 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1542_0_0 -> 6 in the cache */
   /* search1542_0 -> 3862 in the cache */
   /* search1542_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3862, 3996 },
      -1,
   } },

   /* replace1542_0_0 -> 6 in the cache */
   /* replace1542_0_1_0 -> 41 in the cache */
   /* replace1542_0_1 -> 4330 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4330 },
      -1,
   } },
   /* replace1542_1_0_0_0 -> 41 in the cache */
   /* replace1542_1_0_0 -> 4330 in the cache */
   /* replace1542_1_0 -> 4332 in the cache */
   /* replace1542_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4332, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4336, 4337 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1543_0_0 -> 6 in the cache */
   /* search1543_0 -> 3862 in the cache */
   /* search1543_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3862, 3996 },
      -1,
   } },

   /* replace1543_0_0 -> 847 in the cache */
   /* replace1543_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 847, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace1543_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4341, 41 },
      -1,
   } },
   /* replace1543_1_1_0 -> 6 in the cache */
   /* replace1543_1_1_1_0 -> 41 in the cache */
   /* replace1543_1_1_1 -> 4330 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4330 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4342, 4343 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4340, 4344 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1544_0 -> 4015 in the cache */
   /* search1544_1_0 -> 2045 in the cache */
   /* search1544_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4015, 4320 },
      -1,
   } },

   /* replace1544_0_0 -> 21 in the cache */
   /* replace1544_0_1 -> 4341 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4341 },
      -1,
   } },
   /* replace1544_1_0_0 -> 21 in the cache */
   /* replace1544_1_0_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 847 },
      -1,
   } },
   /* replace1544_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1544_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4349, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4348, 4350 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4347, 4351 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1545_0_0 -> 6 in the cache */
   /* search1545_0 -> 3862 in the cache */
   /* search1545_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3862, 3996 },
      -1,
   } },

   /* replace1545_0_0 -> 4341 in the cache */
   /* replace1545_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4341, 41 },
      -1,
   } },
   /* replace1545_1_0_0 -> 847 in the cache */
   /* replace1545_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 847, 41 },
      -1,
   } },
   /* replace1545_1_1_0 -> 6 in the cache */
   /* replace1545_1_1_1_0 -> 41 in the cache */
   /* replace1545_1_1_1 -> 4330 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4330 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4355, 4356 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4354, 4357 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1546_0 -> 4015 in the cache */
   /* search1546_1_0 -> 2045 in the cache */
   /* search1546_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4015, 4320 },
      -1,
   } },

   /* replace1546_0_0 -> 21 in the cache */
   /* replace1546_0_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 847 },
      -1,
   } },
   /* replace1546_1_0_0 -> 21 in the cache */
   /* replace1546_1_0_1 -> 4341 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4341 },
      -1,
   } },
   /* replace1546_1_1_0_0 -> 21 in the cache */
   /* replace1546_1_1_0 -> 4349 in the cache */
   /* replace1546_1_1_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4349, 2045 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4361, 4362 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4360, 4363 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1547_0_0 -> 11 in the cache */
   /* search1547_0 -> 1734 in the cache */
   /* search1547_1_0 -> 2045 in the cache */
   /* search1547_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1734, 2954 },
      -1,
   } },

   /* replace1547_0 -> 11 in the cache */
   /* replace1547_1_0 -> 2045 in the cache */
   /* replace1547_1 -> 4230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4230 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1548_0_0 -> 11 in the cache */
   /* search1548_0 -> 1734 in the cache */
   /* search1548_1_0 -> 2045 in the cache */
   /* search1548_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1734, 2954 },
      -1,
   } },

   /* replace1548_0 -> 11 in the cache */
   /* replace1548_1_0 -> 2045 in the cache */
   /* replace1548_1 -> 4230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4230 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1549_0_0 -> 11 in the cache */
   /* search1549_0 -> 1734 in the cache */
   /* search1549_1_0 -> 2045 in the cache */
   /* search1549_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1734, 2954 },
      -1,
   } },

   /* replace1549_0 -> 11 in the cache */
   /* replace1549_1_0 -> 2045 in the cache */
   /* replace1549_1 -> 4230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4230 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1550_0_0 -> 11 in the cache */
   /* search1550_0 -> 1734 in the cache */
   /* search1550_1_0 -> 2045 in the cache */
   /* search1550_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1734, 2954 },
      -1,
   } },

   /* replace1550_0 -> 11 in the cache */
   /* replace1550_1_0 -> 2045 in the cache */
   /* replace1550_1 -> 4230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4230 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1551_0_0 -> 3895 in the cache */
   /* search1551_0 -> 4283 in the cache */
   /* search1551_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4283, 4373 },
      -1,
   } },

   /* replace1551_0_0 -> 3895 in the cache */
   /* replace1551_0 -> 4240 in the cache */
   /* replace1551_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4240, 507 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1552_0_0 -> 3895 in the cache */
   /* search1552_0 -> 4283 in the cache */
   /* search1552_1_0 -> 507 in the cache */
   /* search1552_1 -> 4373 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4283, 4373 },
      -1,
   } },

   /* replace1552_0_0 -> 3895 in the cache */
   /* replace1552_0 -> 4240 in the cache */
   /* replace1552_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4240, 507 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1553_0_0 -> 11 in the cache */
   /* search1553_0 -> 1734 in the cache */
   /* search1553_1_0 -> 243 in the cache */
   /* search1553_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1734, 2974 },
      -1,
   } },

   /* replace1553_0 -> 11 in the cache */
   /* replace1553_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4379 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1554_0_0 -> 11 in the cache */
   /* search1554_0 -> 1734 in the cache */
   /* search1554_1_0 -> 243 in the cache */
   /* search1554_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1734, 2974 },
      -1,
   } },

   /* replace1554_0 -> 11 in the cache */
   /* replace1554_1_0 -> 243 in the cache */
   /* replace1554_1 -> 4379 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4379 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1555_0_0 -> 11 in the cache */
   /* search1555_0 -> 1734 in the cache */
   /* search1555_1_0 -> 243 in the cache */
   /* search1555_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1734, 2974 },
      -1,
   } },

   /* replace1555_0 -> 11 in the cache */
   /* replace1555_1_0 -> 243 in the cache */
   /* replace1555_1 -> 4379 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4379 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1556_0_0 -> 11 in the cache */
   /* search1556_0 -> 1734 in the cache */
   /* search1556_1_0 -> 243 in the cache */
   /* search1556_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1734, 2974 },
      -1,
   } },

   /* replace1556_0 -> 11 in the cache */
   /* replace1556_1_0 -> 243 in the cache */
   /* replace1556_1 -> 4379 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4379 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1557_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1557_1_0 -> 507 in the cache */
   /* search1557_1 -> 4373 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4387, 4373 },
      -1,
   } },

   /* replace1557_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 496 },
      -1,
   } },
   /* replace1557_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4389, 507 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1558_0_0 -> 496 in the cache */
   /* search1558_0 -> 4387 in the cache */
   /* search1558_1_0 -> 507 in the cache */
   /* search1558_1 -> 4373 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4387, 4373 },
      -1,
   } },

   /* replace1558_0_0 -> 496 in the cache */
   /* replace1558_0 -> 4389 in the cache */
   /* replace1558_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4389, 507 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1559_0_0 -> 11 in the cache */
   /* search1559_0 -> 1734 in the cache */
   /* search1559_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1734, 33 },
      -1,
   } },

   /* replace1559_0_0 -> 11 in the cache */
   /* replace1559_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4394 },
      -1,
   } },
   /* replace1559_1_0_0_0 -> 36 in the cache */
   /* replace1559_1_0_0 -> 4394 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4394 },
      -1,
   } },
   /* replace1559_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4396, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4395, 4397 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1560_0_0 -> 11 in the cache */
   /* search1560_0 -> 1734 in the cache */
   /* search1560_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1734, 33 },
      -1,
   } },

   /* replace1560_0_0 -> 11 in the cache */
   /* replace1560_0_1_0 -> 36 in the cache */
   /* replace1560_0_1 -> 4394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4394 },
      -1,
   } },
   /* replace1560_1_0_0_0 -> 36 in the cache */
   /* replace1560_1_0_0 -> 4394 in the cache */
   /* replace1560_1_0 -> 4396 in the cache */
   /* replace1560_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4396, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4400, 4401 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1561_0_0 -> 11 in the cache */
   /* search1561_0 -> 1734 in the cache */
   /* search1561_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1734, 33 },
      -1,
   } },

   /* replace1561_0_0 -> 120 in the cache */
   /* replace1561_0_1 -> 36 in the cache */
   /* replace1561_0 -> 4297 in the cache */
   /* replace1561_1_0_0 -> 797 in the cache */
   /* replace1561_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 797, 36 },
      -1,
   } },
   /* replace1561_1_1_0 -> 11 in the cache */
   /* replace1561_1_1_1_0 -> 36 in the cache */
   /* replace1561_1_1_1 -> 4394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4394 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4404, 4405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4297, 4406 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1562_0 -> 271 in the cache */
   /* search1562_1_0 -> 243 in the cache */
   /* search1562_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 271, 2974 },
      -1,
   } },

   /* replace1562_0_0 -> 16 in the cache */
   /* replace1562_0_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 797 },
      -1,
   } },
   /* replace1562_1_0_0 -> 16 in the cache */
   /* replace1562_1_0_1 -> 120 in the cache */
   /* replace1562_1_0 -> 4304 in the cache */
   /* replace1562_1_1_0_0 -> 16 in the cache */
   /* replace1562_1_1_0 -> 2980 in the cache */
   /* replace1562_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2980, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4304, 4410 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4409, 4411 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1563_0_0 -> 11 in the cache */
   /* search1563_0 -> 1734 in the cache */
   /* search1563_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1734, 33 },
      -1,
   } },

   /* replace1563_0_0 -> 797 in the cache */
   /* replace1563_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 797, 36 },
      -1,
   } },
   /* replace1563_1_0_0 -> 120 in the cache */
   /* replace1563_1_0_1 -> 36 in the cache */
   /* replace1563_1_0 -> 4310 in the cache */
   /* replace1563_1_1_0 -> 11 in the cache */
   /* replace1563_1_1_1_0 -> 36 in the cache */
   /* replace1563_1_1_1 -> 4394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4394 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4310, 4415 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4414, 4416 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1564_0 -> 271 in the cache */
   /* search1564_1_0 -> 243 in the cache */
   /* search1564_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 271, 2974 },
      -1,
   } },

   /* replace1564_0_0 -> 16 in the cache */
   /* replace1564_0_1 -> 120 in the cache */
   /* replace1564_0 -> 4315 in the cache */
   /* replace1564_1_0_0 -> 16 in the cache */
   /* replace1564_1_0_1 -> 797 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 797 },
      -1,
   } },
   /* replace1564_1_1_0_0 -> 16 in the cache */
   /* replace1564_1_1_0 -> 2980 in the cache */
   /* replace1564_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2980, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4419, 4420 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4315, 4421 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1565_0_0 -> 11 in the cache */
   /* search1565_0 -> 1757 in the cache */
   /* search1565_1_0 -> 2045 in the cache */
   /* search1565_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1757, 4320 },
      -1,
   } },

   /* replace1565_0 -> 11 in the cache */
   /* replace1565_1_0 -> 2045 in the cache */
   /* replace1565_1 -> 4230 in the cache */
   /* replace1565 -> 4366 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1566_0_0 -> 11 in the cache */
   /* search1566_0 -> 1757 in the cache */
   /* search1566_1_0 -> 2045 in the cache */
   /* search1566_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1757, 4320 },
      -1,
   } },

   /* replace1566_0 -> 11 in the cache */
   /* replace1566_1_0 -> 2045 in the cache */
   /* replace1566_1 -> 4230 in the cache */
   /* replace1566 -> 4368 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1567_0_0 -> 11 in the cache */
   /* search1567_0 -> 1757 in the cache */
   /* search1567_1_0 -> 2045 in the cache */
   /* search1567_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1757, 4320 },
      -1,
   } },

   /* replace1567_0 -> 11 in the cache */
   /* replace1567_1_0 -> 2045 in the cache */
   /* replace1567_1 -> 4230 in the cache */
   /* replace1567 -> 4370 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1568_0_0 -> 11 in the cache */
   /* search1568_0 -> 1757 in the cache */
   /* search1568_1_0 -> 2045 in the cache */
   /* search1568_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1757, 4320 },
      -1,
   } },

   /* replace1568_0 -> 11 in the cache */
   /* replace1568_1_0 -> 2045 in the cache */
   /* replace1568_1 -> 4230 in the cache */
   /* replace1568 -> 4372 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1569_0_0 -> 3895 in the cache */
   /* search1569_0 -> 4325 in the cache */
   /* search1569_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4325, 4427 },
      -1,
   } },

   /* replace1569_0_0 -> 3895 in the cache */
   /* replace1569_0 -> 4240 in the cache */
   /* replace1569_1 -> 507 in the cache */
   /* replace1569 -> 4375 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1570_0_0 -> 3895 in the cache */
   /* search1570_0 -> 4325 in the cache */
   /* search1570_1_0 -> 507 in the cache */
   /* search1570_1 -> 4427 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4325, 4427 },
      -1,
   } },

   /* replace1570_0_0 -> 3895 in the cache */
   /* replace1570_0 -> 4240 in the cache */
   /* replace1570_1 -> 507 in the cache */
   /* replace1570 -> 4377 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1571_0_0 -> 11 in the cache */
   /* search1571_0 -> 1757 in the cache */
   /* search1571_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1757, 4430 },
      -1,
   } },

   /* replace1571_0 -> 11 in the cache */
   /* replace1571_1_0 -> 243 in the cache */
   /* replace1571_1 -> 4379 in the cache */
   /* replace1571 -> 4380 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1572_0_0 -> 11 in the cache */
   /* search1572_0 -> 1757 in the cache */
   /* search1572_1_0 -> 243 in the cache */
   /* search1572_1 -> 4430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1757, 4430 },
      -1,
   } },

   /* replace1572_0 -> 11 in the cache */
   /* replace1572_1_0 -> 243 in the cache */
   /* replace1572_1 -> 4379 in the cache */
   /* replace1572 -> 4382 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1573_0_0 -> 11 in the cache */
   /* search1573_0 -> 1757 in the cache */
   /* search1573_1_0 -> 243 in the cache */
   /* search1573_1 -> 4430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1757, 4430 },
      -1,
   } },

   /* replace1573_0 -> 11 in the cache */
   /* replace1573_1_0 -> 243 in the cache */
   /* replace1573_1 -> 4379 in the cache */
   /* replace1573 -> 4384 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1574_0_0 -> 11 in the cache */
   /* search1574_0 -> 1757 in the cache */
   /* search1574_1_0 -> 243 in the cache */
   /* search1574_1 -> 4430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1757, 4430 },
      -1,
   } },

   /* replace1574_0 -> 11 in the cache */
   /* replace1574_1_0 -> 243 in the cache */
   /* replace1574_1 -> 4379 in the cache */
   /* replace1574 -> 4386 in the cache */

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1575_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1575_1_0 -> 507 in the cache */
   /* search1575_1 -> 4427 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4435, 4427 },
      -1,
   } },

   /* replace1575_0_0 -> 496 in the cache */
   /* replace1575_0 -> 4389 in the cache */
   /* replace1575_1 -> 507 in the cache */
   /* replace1575 -> 4390 in the cache */

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1576_0_0 -> 496 in the cache */
   /* search1576_0 -> 4435 in the cache */
   /* search1576_1_0 -> 507 in the cache */
   /* search1576_1 -> 4427 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4435, 4427 },
      -1,
   } },

   /* replace1576_0_0 -> 496 in the cache */
   /* replace1576_0 -> 4389 in the cache */
   /* replace1576_1 -> 507 in the cache */
   /* replace1576 -> 4392 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1577_0_0 -> 11 in the cache */
   /* search1577_0 -> 1757 in the cache */
   /* search1577_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1757, 3996 },
      -1,
   } },

   /* replace1577_0_0 -> 11 in the cache */
   /* replace1577_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4439 },
      -1,
   } },
   /* replace1577_1_0_0_0 -> 41 in the cache */
   /* replace1577_1_0_0 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4439 },
      -1,
   } },
   /* replace1577_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4441, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4440, 4442 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1578_0_0 -> 11 in the cache */
   /* search1578_0 -> 1757 in the cache */
   /* search1578_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1757, 3996 },
      -1,
   } },

   /* replace1578_0_0 -> 11 in the cache */
   /* replace1578_0_1_0 -> 41 in the cache */
   /* replace1578_0_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4439 },
      -1,
   } },
   /* replace1578_1_0_0_0 -> 41 in the cache */
   /* replace1578_1_0_0 -> 4439 in the cache */
   /* replace1578_1_0 -> 4441 in the cache */
   /* replace1578_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4441, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4445, 4446 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1579_0_0 -> 11 in the cache */
   /* search1579_0 -> 1757 in the cache */
   /* search1579_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1757, 3996 },
      -1,
   } },

   /* replace1579_0_0 -> 847 in the cache */
   /* replace1579_0_1 -> 41 in the cache */
   /* replace1579_0 -> 4340 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace1579_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4449, 41 },
      -1,
   } },
   /* replace1579_1_1_0 -> 11 in the cache */
   /* replace1579_1_1_1_0 -> 41 in the cache */
   /* replace1579_1_1_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4439 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4450, 4451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4340, 4452 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1580_0 -> 4015 in the cache */
   /* search1580_1_0 -> 243 in the cache */
   /* search1580_1 -> 4430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4015, 4430 },
      -1,
   } },

   /* replace1580_0_0 -> 21 in the cache */
   /* replace1580_0_1 -> 4449 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4449 },
      -1,
   } },
   /* replace1580_1_0_0 -> 21 in the cache */
   /* replace1580_1_0_1 -> 847 in the cache */
   /* replace1580_1_0 -> 4348 in the cache */
   /* replace1580_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1580_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4456, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4348, 4457 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4455, 4458 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1581_0_0 -> 11 in the cache */
   /* search1581_0 -> 1757 in the cache */
   /* search1581_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1757, 3996 },
      -1,
   } },

   /* replace1581_0_0 -> 4449 in the cache */
   /* replace1581_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4449, 41 },
      -1,
   } },
   /* replace1581_1_0_0 -> 847 in the cache */
   /* replace1581_1_0_1 -> 41 in the cache */
   /* replace1581_1_0 -> 4355 in the cache */
   /* replace1581_1_1_0 -> 11 in the cache */
   /* replace1581_1_1_1_0 -> 41 in the cache */
   /* replace1581_1_1_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4439 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4355, 4462 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4461, 4463 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1582_0 -> 4015 in the cache */
   /* search1582_1_0 -> 243 in the cache */
   /* search1582_1 -> 4430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4015, 4430 },
      -1,
   } },

   /* replace1582_0_0 -> 21 in the cache */
   /* replace1582_0_1 -> 847 in the cache */
   /* replace1582_0 -> 4360 in the cache */
   /* replace1582_1_0_0 -> 21 in the cache */
   /* replace1582_1_0_1 -> 4449 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4449 },
      -1,
   } },
   /* replace1582_1_1_0_0 -> 21 in the cache */
   /* replace1582_1_1_0 -> 4456 in the cache */
   /* replace1582_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4456, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4466, 4467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4360, 4468 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1583_0_0 -> 16 in the cache */
   /* search1583_0 -> 1841 in the cache */
   /* search1583_1_0 -> 2045 in the cache */
   /* search1583_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1841, 4320 },
      -1,
   } },

   /* replace1583_0 -> 16 in the cache */
   /* replace1583_1_0 -> 2045 in the cache */
   /* replace1583_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 2954 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1584_0_0 -> 16 in the cache */
   /* search1584_0 -> 1841 in the cache */
   /* search1584_1_0 -> 2045 in the cache */
   /* search1584_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1841, 4320 },
      -1,
   } },

   /* replace1584_0 -> 16 in the cache */
   /* replace1584_1_0 -> 2045 in the cache */
   /* replace1584_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 2954 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1585_0_0 -> 16 in the cache */
   /* search1585_0 -> 1841 in the cache */
   /* search1585_1_0 -> 2045 in the cache */
   /* search1585_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1841, 4320 },
      -1,
   } },

   /* replace1585_0 -> 16 in the cache */
   /* replace1585_1_0 -> 2045 in the cache */
   /* replace1585_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 2954 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1586_0_0 -> 16 in the cache */
   /* search1586_0 -> 1841 in the cache */
   /* search1586_1_0 -> 2045 in the cache */
   /* search1586_1 -> 4320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1841, 4320 },
      -1,
   } },

   /* replace1586_0 -> 16 in the cache */
   /* replace1586_1_0 -> 2045 in the cache */
   /* replace1586_1 -> 2954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 2954 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1587_0_0 -> 3895 in the cache */
   /* search1587_0 -> 4325 in the cache */
   /* search1587_1_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4325, 4478 },
      -1,
   } },

   /* replace1587_0_0 -> 3895 in the cache */
   /* replace1587_0 -> 4283 in the cache */
   /* replace1587_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4283, 360 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1588_0_0 -> 3895 in the cache */
   /* search1588_0 -> 4325 in the cache */
   /* search1588_1_0 -> 360 in the cache */
   /* search1588_1 -> 4478 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4325, 4478 },
      -1,
   } },

   /* replace1588_0_0 -> 3895 in the cache */
   /* replace1588_0 -> 4283 in the cache */
   /* replace1588_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4283, 360 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1589_0_0 -> 16 in the cache */
   /* search1589_0 -> 1841 in the cache */
   /* search1589_1_0 -> 243 in the cache */
   /* search1589_1 -> 4430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1841, 4430 },
      -1,
   } },

   /* replace1589_0 -> 16 in the cache */
   /* replace1589_1_0 -> 243 in the cache */
   /* replace1589_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 2974 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1590_0_0 -> 16 in the cache */
   /* search1590_0 -> 1841 in the cache */
   /* search1590_1_0 -> 243 in the cache */
   /* search1590_1 -> 4430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1841, 4430 },
      -1,
   } },

   /* replace1590_0 -> 16 in the cache */
   /* replace1590_1_0 -> 243 in the cache */
   /* replace1590_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 2974 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1591_0_0 -> 16 in the cache */
   /* search1591_0 -> 1841 in the cache */
   /* search1591_1_0 -> 243 in the cache */
   /* search1591_1 -> 4430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1841, 4430 },
      -1,
   } },

   /* replace1591_0 -> 16 in the cache */
   /* replace1591_1_0 -> 243 in the cache */
   /* replace1591_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 2974 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1592_0_0 -> 16 in the cache */
   /* search1592_0 -> 1841 in the cache */
   /* search1592_1_0 -> 243 in the cache */
   /* search1592_1 -> 4430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1841, 4430 },
      -1,
   } },

   /* replace1592_0 -> 16 in the cache */
   /* replace1592_1_0 -> 243 in the cache */
   /* replace1592_1 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 2974 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1593_0_0 -> 496 in the cache */
   /* search1593_0 -> 4435 in the cache */
   /* search1593_1_0 -> 360 in the cache */
   /* search1593_1 -> 4478 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4435, 4478 },
      -1,
   } },

   /* replace1593_0_0 -> 496 in the cache */
   /* replace1593_0 -> 4387 in the cache */
   /* replace1593_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4387, 360 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1594_0_0 -> 496 in the cache */
   /* search1594_0 -> 4435 in the cache */
   /* search1594_1_0 -> 360 in the cache */
   /* search1594_1 -> 4478 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4435, 4478 },
      -1,
   } },

   /* replace1594_0_0 -> 496 in the cache */
   /* replace1594_0 -> 4387 in the cache */
   /* replace1594_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4387, 360 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1595_0_0 -> 16 in the cache */
   /* search1595_0 -> 1841 in the cache */
   /* search1595_1_0 -> 36 in the cache */
   /* search1595_1 -> 2970 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1841, 2970 },
      -1,
   } },

   /* replace1595_0 -> 16 in the cache */
   /* replace1595_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4496 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1596_0_0 -> 16 in the cache */
   /* search1596_0 -> 1841 in the cache */
   /* search1596_1_0 -> 36 in the cache */
   /* search1596_1 -> 2970 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1841, 2970 },
      -1,
   } },

   /* replace1596_0 -> 16 in the cache */
   /* replace1596_1_0 -> 36 in the cache */
   /* replace1596_1 -> 4496 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4496 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1597_0_0 -> 16 in the cache */
   /* search1597_0 -> 1841 in the cache */
   /* search1597_1_0 -> 36 in the cache */
   /* search1597_1 -> 2970 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1841, 2970 },
      -1,
   } },

   /* replace1597_0 -> 16 in the cache */
   /* replace1597_1_0 -> 36 in the cache */
   /* replace1597_1 -> 4496 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4496 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1598_0_0 -> 16 in the cache */
   /* search1598_0 -> 1841 in the cache */
   /* search1598_1_0 -> 36 in the cache */
   /* search1598_1 -> 2970 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1841, 2970 },
      -1,
   } },

   /* replace1598_0 -> 16 in the cache */
   /* replace1598_1_0 -> 36 in the cache */
   /* replace1598_1 -> 4496 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4496 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1599_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 358 },
      -1,
   } },
   /* search1599_1_0 -> 360 in the cache */
   /* search1599_1 -> 4478 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4504, 4478 },
      -1,
   } },

   /* replace1599_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 358 },
      -1,
   } },
   /* replace1599_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4506, 360 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1600_0_0 -> 358 in the cache */
   /* search1600_0 -> 4504 in the cache */
   /* search1600_1_0 -> 360 in the cache */
   /* search1600_1 -> 4478 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4504, 4478 },
      -1,
   } },

   /* replace1600_0_0 -> 358 in the cache */
   /* replace1600_0 -> 4506 in the cache */
   /* replace1600_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4506, 360 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1601_0_0 -> 16 in the cache */
   /* search1601_0 -> 1841 in the cache */
   /* search1601_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1841, 3996 },
      -1,
   } },

   /* replace1601_0_0 -> 16 in the cache */
   /* replace1601_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4511 },
      -1,
   } },
   /* replace1601_1_0_0_0 -> 41 in the cache */
   /* replace1601_1_0_0 -> 4511 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4511 },
      -1,
   } },
   /* replace1601_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4513, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4512, 4514 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1602_0_0 -> 16 in the cache */
   /* search1602_0 -> 1841 in the cache */
   /* search1602_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1841, 3996 },
      -1,
   } },

   /* replace1602_0_0 -> 16 in the cache */
   /* replace1602_0_1_0 -> 41 in the cache */
   /* replace1602_0_1 -> 4511 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4511 },
      -1,
   } },
   /* replace1602_1_0_0_0 -> 41 in the cache */
   /* replace1602_1_0_0 -> 4511 in the cache */
   /* replace1602_1_0 -> 4513 in the cache */
   /* replace1602_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4513, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4517, 4518 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b')))) */
   /* search1603_0_0 -> 16 in the cache */
   /* search1603_0 -> 1841 in the cache */
   /* search1603_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1841, 3996 },
      -1,
   } },

   /* replace1603_0_0 -> 847 in the cache */
   /* replace1603_0_1 -> 41 in the cache */
   /* replace1603_0 -> 4340 in the cache */
   /* replace1603_1_0_0 -> 2985 in the cache */
   /* replace1603_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2985, 41 },
      -1,
   } },
   /* replace1603_1_1_0 -> 16 in the cache */
   /* replace1603_1_1_1_0 -> 41 in the cache */
   /* replace1603_1_1_1 -> 4511 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4521, 4522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4340, 4523 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b'))) */
   /* search1604_0 -> 4015 in the cache */
   /* search1604_1_0 -> 36 in the cache */
   /* search1604_1 -> 2970 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4015, 2970 },
      -1,
   } },

   /* replace1604_0_0 -> 21 in the cache */
   /* replace1604_0_1 -> 2985 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 2985 },
      -1,
   } },
   /* replace1604_1_0_0 -> 21 in the cache */
   /* replace1604_1_0_1 -> 847 in the cache */
   /* replace1604_1_0 -> 4348 in the cache */
   /* replace1604_1_1_0_0 -> 21 in the cache */
   /* replace1604_1_1_0 -> 2977 in the cache */
   /* replace1604_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2977, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4348, 4527 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4526, 4528 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b')))) */
   /* search1605_0_0 -> 16 in the cache */
   /* search1605_0 -> 1841 in the cache */
   /* search1605_1 -> 3996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1841, 3996 },
      -1,
   } },

   /* replace1605_0_0 -> 2985 in the cache */
   /* replace1605_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2985, 41 },
      -1,
   } },
   /* replace1605_1_0_0 -> 847 in the cache */
   /* replace1605_1_0_1 -> 41 in the cache */
   /* replace1605_1_0 -> 4355 in the cache */
   /* replace1605_1_1_0 -> 16 in the cache */
   /* replace1605_1_1_1_0 -> 41 in the cache */
   /* replace1605_1_1_1 -> 4511 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4511 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4355, 4532 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4531, 4533 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b'))) */
   /* search1606_0 -> 4015 in the cache */
   /* search1606_1_0 -> 36 in the cache */
   /* search1606_1 -> 2970 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4015, 2970 },
      -1,
   } },

   /* replace1606_0_0 -> 21 in the cache */
   /* replace1606_0_1 -> 847 in the cache */
   /* replace1606_0 -> 4360 in the cache */
   /* replace1606_1_0_0 -> 21 in the cache */
   /* replace1606_1_0_1 -> 2985 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 2985 },
      -1,
   } },
   /* replace1606_1_1_0_0 -> 21 in the cache */
   /* replace1606_1_1_0 -> 2977 in the cache */
   /* replace1606_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2977, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4536, 4537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4360, 4538 },
      -1,
   } },

   /* ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1607_0_0 -> 11 in the cache */
   /* search1607_0 -> 1730 in the cache */
   /* search1607_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1730, 4540 },
      -1,
   } },

   /* replace1607_0 -> 11 in the cache */
   /* replace1607_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 4542 },
      -1,
   } },

   /* ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1608_0_0 -> 11 in the cache */
   /* search1608_0 -> 1730 in the cache */
   /* search1608_1_0 -> 243 in the cache */
   /* search1608_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1730, 4540 },
      -1,
   } },

   /* replace1608_0 -> 11 in the cache */
   /* replace1608_1_0 -> 243 in the cache */
   /* replace1608_1 -> 4542 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 11, 4542 },
      -1,
   } },

   /* ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1609_0_0 -> 11 in the cache */
   /* search1609_0 -> 1730 in the cache */
   /* search1609_1_0 -> 243 in the cache */
   /* search1609_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1730, 4540 },
      -1,
   } },

   /* replace1609_0 -> 11 in the cache */
   /* replace1609_1_0 -> 243 in the cache */
   /* replace1609_1 -> 4542 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 4542 },
      -1,
   } },

   /* ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1610_0_0 -> 11 in the cache */
   /* search1610_0 -> 1730 in the cache */
   /* search1610_1_0 -> 243 in the cache */
   /* search1610_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1730, 4540 },
      -1,
   } },

   /* replace1610_0 -> 11 in the cache */
   /* replace1610_1_0 -> 243 in the cache */
   /* replace1610_1 -> 4542 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 4542 },
      -1,
   } },

   /* ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1611_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1611_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4550, 4551 },
      -1,
   } },

   /* replace1611_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 496 },
      -1,
   } },
   /* replace1611_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4553, 507 },
      -1,
   } },

   /* ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1612_0_0 -> 496 in the cache */
   /* search1612_0 -> 4550 in the cache */
   /* search1612_1_0 -> 507 in the cache */
   /* search1612_1 -> 4551 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4550, 4551 },
      -1,
   } },

   /* replace1612_0_0 -> 496 in the cache */
   /* replace1612_0 -> 4553 in the cache */
   /* replace1612_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4553, 507 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1613_0_0 -> 11 in the cache */
   /* search1613_0 -> 1753 in the cache */
   /* search1613_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1753, 4557 },
      -1,
   } },

   /* replace1613_0 -> 11 in the cache */
   /* replace1613_1_0 -> 243 in the cache */
   /* replace1613_1 -> 4542 in the cache */
   /* replace1613 -> 4543 in the cache */

   /* ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1614_0_0 -> 11 in the cache */
   /* search1614_0 -> 1753 in the cache */
   /* search1614_1_0 -> 243 in the cache */
   /* search1614_1 -> 4557 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1753, 4557 },
      -1,
   } },

   /* replace1614_0 -> 11 in the cache */
   /* replace1614_1_0 -> 243 in the cache */
   /* replace1614_1 -> 4542 in the cache */
   /* replace1614 -> 4545 in the cache */

   /* ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1615_0_0 -> 11 in the cache */
   /* search1615_0 -> 1753 in the cache */
   /* search1615_1_0 -> 243 in the cache */
   /* search1615_1 -> 4557 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1753, 4557 },
      -1,
   } },

   /* replace1615_0 -> 11 in the cache */
   /* replace1615_1_0 -> 243 in the cache */
   /* replace1615_1 -> 4542 in the cache */
   /* replace1615 -> 4547 in the cache */

   /* ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1616_0_0 -> 11 in the cache */
   /* search1616_0 -> 1753 in the cache */
   /* search1616_1_0 -> 243 in the cache */
   /* search1616_1 -> 4557 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1753, 4557 },
      -1,
   } },

   /* replace1616_0 -> 11 in the cache */
   /* replace1616_1_0 -> 243 in the cache */
   /* replace1616_1 -> 4542 in the cache */
   /* replace1616 -> 4549 in the cache */

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1617_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1617_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4562, 4563 },
      -1,
   } },

   /* replace1617_0_0 -> 496 in the cache */
   /* replace1617_0 -> 4553 in the cache */
   /* replace1617_1 -> 507 in the cache */
   /* replace1617 -> 4554 in the cache */

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1618_0_0 -> 496 in the cache */
   /* search1618_0 -> 4562 in the cache */
   /* search1618_1_0 -> 507 in the cache */
   /* search1618_1 -> 4563 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4562, 4563 },
      -1,
   } },

   /* replace1618_0_0 -> 496 in the cache */
   /* replace1618_0 -> 4553 in the cache */
   /* replace1618_1 -> 507 in the cache */
   /* replace1618 -> 4556 in the cache */

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1619_0_0 -> 16 in the cache */
   /* search1619_0 -> 1837 in the cache */
   /* search1619_1_0 -> 243 in the cache */
   /* search1619_1 -> 4557 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1837, 4557 },
      -1,
   } },

   /* replace1619_0 -> 16 in the cache */
   /* replace1619_1_0 -> 243 in the cache */
   /* replace1619_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4540 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1620_0_0 -> 16 in the cache */
   /* search1620_0 -> 1837 in the cache */
   /* search1620_1_0 -> 243 in the cache */
   /* search1620_1 -> 4557 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1837, 4557 },
      -1,
   } },

   /* replace1620_0 -> 16 in the cache */
   /* replace1620_1_0 -> 243 in the cache */
   /* replace1620_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4540 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1621_0_0 -> 16 in the cache */
   /* search1621_0 -> 1837 in the cache */
   /* search1621_1_0 -> 243 in the cache */
   /* search1621_1 -> 4557 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1837, 4557 },
      -1,
   } },

   /* replace1621_0 -> 16 in the cache */
   /* replace1621_1_0 -> 243 in the cache */
   /* replace1621_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4540 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1622_0_0 -> 16 in the cache */
   /* search1622_0 -> 1837 in the cache */
   /* search1622_1_0 -> 243 in the cache */
   /* search1622_1 -> 4557 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1837, 4557 },
      -1,
   } },

   /* replace1622_0 -> 16 in the cache */
   /* replace1622_1_0 -> 243 in the cache */
   /* replace1622_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4540 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1623_0_0 -> 496 in the cache */
   /* search1623_0 -> 4562 in the cache */
   /* search1623_1_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4562, 4574 },
      -1,
   } },

   /* replace1623_0_0 -> 496 in the cache */
   /* replace1623_0 -> 4550 in the cache */
   /* replace1623_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4550, 360 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1624_0_0 -> 496 in the cache */
   /* search1624_0 -> 4562 in the cache */
   /* search1624_1_0 -> 360 in the cache */
   /* search1624_1 -> 4574 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4562, 4574 },
      -1,
   } },

   /* replace1624_0_0 -> 496 in the cache */
   /* replace1624_0 -> 4550 in the cache */
   /* replace1624_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4550, 360 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1625_0_0 -> 16 in the cache */
   /* search1625_0 -> 1837 in the cache */
   /* search1625_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1837, 4579 },
      -1,
   } },

   /* replace1625_0 -> 16 in the cache */
   /* replace1625_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4581 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1626_0_0 -> 16 in the cache */
   /* search1626_0 -> 1837 in the cache */
   /* search1626_1_0 -> 36 in the cache */
   /* search1626_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1837, 4579 },
      -1,
   } },

   /* replace1626_0 -> 16 in the cache */
   /* replace1626_1_0 -> 36 in the cache */
   /* replace1626_1 -> 4581 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4581 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1627_0_0 -> 16 in the cache */
   /* search1627_0 -> 1837 in the cache */
   /* search1627_1_0 -> 36 in the cache */
   /* search1627_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1837, 4579 },
      -1,
   } },

   /* replace1627_0 -> 16 in the cache */
   /* replace1627_1_0 -> 36 in the cache */
   /* replace1627_1 -> 4581 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4581 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1628_0_0 -> 16 in the cache */
   /* search1628_0 -> 1837 in the cache */
   /* search1628_1_0 -> 36 in the cache */
   /* search1628_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1837, 4579 },
      -1,
   } },

   /* replace1628_0 -> 16 in the cache */
   /* replace1628_1_0 -> 36 in the cache */
   /* replace1628_1 -> 4581 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4581 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1629_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 358 },
      -1,
   } },
   /* search1629_1_0 -> 360 in the cache */
   /* search1629_1 -> 4574 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4589, 4574 },
      -1,
   } },

   /* replace1629_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 358 },
      -1,
   } },
   /* replace1629_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4591, 360 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1630_0_0 -> 358 in the cache */
   /* search1630_0 -> 4589 in the cache */
   /* search1630_1_0 -> 360 in the cache */
   /* search1630_1 -> 4574 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4589, 4574 },
      -1,
   } },

   /* replace1630_0_0 -> 358 in the cache */
   /* replace1630_0 -> 4591 in the cache */
   /* replace1630_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4591, 360 },
      -1,
   } },

   /* ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a') */
   /* search1631_0_0 -> 21 in the cache */
   /* search1631_0_1 -> 2985 in the cache */
   /* search1631_0 -> 2986 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 1,
      { 2986 },
      -1,
   } },

   /* replace1631_0 -> 21 in the cache */
   /* replace1631 -> 2977 in the cache */

   /* ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a') */
   /* search1632_0_0 -> 16 in the cache */
   /* search1632_0_1 -> 797 in the cache */
   /* search1632_0 -> 951 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 951 },
      -1,
   } },

   /* replace1632_0 -> 16 in the cache */
   /* replace1632 -> 2980 in the cache */

   /* ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a') */
   /* search1633_0_0 -> 21 in the cache */
   /* search1633_0_1 -> 4449 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4449 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 4597 },
      -1,
   } },

   /* replace1633_0 -> 21 in the cache */
   /* replace1633 -> 4456 in the cache */

   /* ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a') */
   /* search1634_0_0 -> 11 in the cache */
   /* search1634_0_1 -> 1946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1946 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4599 },
      -1,
   } },

   /* replace1634_0 -> 11 in the cache */
   /* replace1634 -> 1942 in the cache */

   /* ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a') */
   /* search1635_0_0 -> 16 in the cache */
   /* search1635_0_1 -> 774 in the cache */
   /* search1635_0 -> 958 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 958 },
      -1,
   } },

   /* replace1635_0 -> 16 in the cache */
   /* replace1635 -> 1958 in the cache */

   /* ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a') */
   /* search1636_0_0 -> 21 in the cache */
   /* search1636_0_1 -> 4341 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4341 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4602 },
      -1,
   } },

   /* replace1636_0 -> 21 in the cache */
   /* replace1636 -> 4349 in the cache */

   /* ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1637_0_0 -> 11 in the cache */
   /* search1637_0 -> 1942 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1942 },
      6,
   } },

   /* replace1637 -> 11 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1638_0 -> 11 in the cache */
   /* search1638_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 804 },
      6,
   } },

   /* replace1638 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1639_0 -> 502 in the cache */
   /* search1639_1_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4606 },
      -1,
   } },
   /* search1639_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4607, 469 },
      6,
   } },

   /* replace1639_0 -> 502 in the cache */
   /* replace1639_1 -> 507 in the cache */
   /* replace1639_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 507, 469 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1640_0 -> 502 in the cache */
   /* search1640_1_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4610 },
      -1,
   } },
   /* search1640_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4611, 469 },
      6,
   } },

   /* replace1640_0 -> 502 in the cache */
   /* replace1640_1 -> 507 in the cache */
   /* replace1640_2 -> 469 in the cache */
   /* replace1640 -> 4609 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1641_0 -> 502 in the cache */
   /* search1641_1_0 -> 507 in the cache */
   /* search1641_1_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 507, 804 },
      -1,
   } },
   /* search1641_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4613, 469 },
      6,
   } },

   /* replace1641_0 -> 502 in the cache */
   /* replace1641_1 -> 507 in the cache */
   /* replace1641_2 -> 469 in the cache */
   /* replace1641 -> 4609 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1642_0_0_0 -> 11 in the cache */
   /* search1642_0_0 -> 1942 in the cache */
   /* search1642_0 -> 1943 in the cache */
   /* search1642_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1943, 243 },
      6,
   } },

   /* replace1642_0 -> 11 in the cache */
   /* replace1642_1 -> 243 in the cache */
   /* replace1642 -> 3670 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1643_0_0_0 -> 11 in the cache */
   /* search1643_0_0 -> 3926 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3926 },
      -1,
   } },
   /* search1643_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4616, 243 },
      6,
   } },

   /* replace1643_0 -> 11 in the cache */
   /* replace1643_1 -> 243 in the cache */
   /* replace1643 -> 3670 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1644_0_0 -> 11 in the cache */
   /* search1644_0_1 -> 804 in the cache */
   /* search1644_0 -> 3088 in the cache */
   /* search1644_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3088, 243 },
      6,
   } },

   /* replace1644_0 -> 11 in the cache */
   /* replace1644_1 -> 243 in the cache */
   /* replace1644 -> 3670 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1645_0_0_0 -> 11 in the cache */
   /* search1645_0_0 -> 1942 in the cache */
   /* search1645_0 -> 1943 in the cache */
   /* search1645_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1943, 243 },
      6,
   } },

   /* replace1645_0 -> 11 in the cache */
   /* replace1645_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 243 },
      -1,
   } },

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1646_0_0_0 -> 11 in the cache */
   /* search1646_0_0 -> 3926 in the cache */
   /* search1646_0 -> 4616 in the cache */
   /* search1646_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4616, 243 },
      6,
   } },

   /* replace1646_0 -> 11 in the cache */
   /* replace1646_1 -> 243 in the cache */
   /* replace1646 -> 4620 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1647_0_0 -> 11 in the cache */
   /* search1647_0_1 -> 804 in the cache */
   /* search1647_0 -> 3088 in the cache */
   /* search1647_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3088, 243 },
      6,
   } },

   /* replace1647_0 -> 11 in the cache */
   /* replace1647_1 -> 243 in the cache */
   /* replace1647 -> 4620 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1648_0_0_0 -> 11 in the cache */
   /* search1648_0_0 -> 1942 in the cache */
   /* search1648_0 -> 1943 in the cache */
   /* search1648_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1943, 243 },
      6,
   } },

   /* replace1648_0 -> 11 in the cache */
   /* replace1648_1 -> 243 in the cache */
   /* replace1648 -> 1956 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1649_0_0_0 -> 11 in the cache */
   /* search1649_0_0 -> 3926 in the cache */
   /* search1649_0 -> 4616 in the cache */
   /* search1649_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4616, 243 },
      6,
   } },

   /* replace1649_0 -> 11 in the cache */
   /* replace1649_1 -> 243 in the cache */
   /* replace1649 -> 1956 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1650_0_0 -> 11 in the cache */
   /* search1650_0_1 -> 804 in the cache */
   /* search1650_0 -> 3088 in the cache */
   /* search1650_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3088, 243 },
      6,
   } },

   /* replace1650_0 -> 11 in the cache */
   /* replace1650_1 -> 243 in the cache */
   /* replace1650 -> 1956 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1651_0_0_0 -> 11 in the cache */
   /* search1651_0_0 -> 1942 in the cache */
   /* search1651_0 -> 1943 in the cache */
   /* search1651_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1943, 243 },
      6,
   } },

   /* replace1651_0 -> 11 in the cache */
   /* replace1651_1 -> 243 in the cache */
   /* replace1651 -> 1998 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1652_0_0_0 -> 11 in the cache */
   /* search1652_0_0 -> 3926 in the cache */
   /* search1652_0 -> 4616 in the cache */
   /* search1652_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4616, 243 },
      6,
   } },

   /* replace1652_0 -> 11 in the cache */
   /* replace1652_1 -> 243 in the cache */
   /* replace1652 -> 1998 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1653_0_0 -> 11 in the cache */
   /* search1653_0_1 -> 804 in the cache */
   /* search1653_0 -> 3088 in the cache */
   /* search1653_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3088, 243 },
      6,
   } },

   /* replace1653_0 -> 11 in the cache */
   /* replace1653_1 -> 243 in the cache */
   /* replace1653 -> 1998 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1654_0_0_0 -> 11 in the cache */
   /* search1654_0_0 -> 1942 in the cache */
   /* search1654_0 -> 1943 in the cache */
   /* search1654_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1943, 243 },
      6,
   } },

   /* replace1654_0 -> 11 in the cache */
   /* replace1654_1 -> 243 in the cache */
   /* replace1654 -> 2022 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1655_0_0_0 -> 11 in the cache */
   /* search1655_0_0 -> 3926 in the cache */
   /* search1655_0 -> 4616 in the cache */
   /* search1655_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4616, 243 },
      6,
   } },

   /* replace1655_0 -> 11 in the cache */
   /* replace1655_1 -> 243 in the cache */
   /* replace1655 -> 2022 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1656_0_0 -> 11 in the cache */
   /* search1656_0_1 -> 804 in the cache */
   /* search1656_0 -> 3088 in the cache */
   /* search1656_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3088, 243 },
      6,
   } },

   /* replace1656_0 -> 11 in the cache */
   /* replace1656_1 -> 243 in the cache */
   /* replace1656 -> 2022 in the cache */

   /* ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1657_0_0 -> 11 in the cache */
   /* search1657_0 -> 1942 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1942 },
      6,
   } },

   /* replace1657 -> 11 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1658_0 -> 11 in the cache */
   /* search1658_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 804 },
      6,
   } },

   /* replace1658 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1659_0 -> 502 in the cache */
   /* search1659_1_0_0 -> 507 in the cache */
   /* search1659_1_0 -> 4606 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4606 },
      -1,
   } },
   /* search1659_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4634, 469 },
      6,
   } },

   /* replace1659_0 -> 502 in the cache */
   /* replace1659_1 -> 507 in the cache */
   /* replace1659_2 -> 469 in the cache */
   /* replace1659 -> 4609 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1660_0 -> 502 in the cache */
   /* search1660_1_0_0 -> 507 in the cache */
   /* search1660_1_0 -> 4610 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4610 },
      -1,
   } },
   /* search1660_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4636, 469 },
      6,
   } },

   /* replace1660_0 -> 502 in the cache */
   /* replace1660_1 -> 507 in the cache */
   /* replace1660_2 -> 469 in the cache */
   /* replace1660 -> 4609 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1661_0 -> 502 in the cache */
   /* search1661_1_0 -> 507 in the cache */
   /* search1661_1_1 -> 804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 507, 804 },
      -1,
   } },
   /* search1661_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4638, 469 },
      6,
   } },

   /* replace1661_0 -> 502 in the cache */
   /* replace1661_1 -> 507 in the cache */
   /* replace1661_2 -> 469 in the cache */
   /* replace1661 -> 4609 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1662_0_0_0 -> 11 in the cache */
   /* search1662_0_0 -> 1942 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1942 },
      -1,
   } },
   /* search1662_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4640, 243 },
      6,
   } },

   /* replace1662_0 -> 11 in the cache */
   /* replace1662_1 -> 243 in the cache */
   /* replace1662 -> 3670 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1663_0_0_0 -> 11 in the cache */
   /* search1663_0_0 -> 3926 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3926 },
      -1,
   } },
   /* search1663_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4642, 243 },
      6,
   } },

   /* replace1663_0 -> 11 in the cache */
   /* replace1663_1 -> 243 in the cache */
   /* replace1663 -> 3670 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1664_0_0 -> 11 in the cache */
   /* search1664_0_1 -> 804 in the cache */
   /* search1664_0 -> 3109 in the cache */
   /* search1664_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3109, 243 },
      6,
   } },

   /* replace1664_0 -> 11 in the cache */
   /* replace1664_1 -> 243 in the cache */
   /* replace1664 -> 3670 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1665_0_0_0 -> 11 in the cache */
   /* search1665_0_0 -> 1942 in the cache */
   /* search1665_0 -> 4640 in the cache */
   /* search1665_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4640, 243 },
      6,
   } },

   /* replace1665_0 -> 11 in the cache */
   /* replace1665_1 -> 243 in the cache */
   /* replace1665 -> 4620 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1666_0_0_0 -> 11 in the cache */
   /* search1666_0_0 -> 3926 in the cache */
   /* search1666_0 -> 4642 in the cache */
   /* search1666_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4642, 243 },
      6,
   } },

   /* replace1666_0 -> 11 in the cache */
   /* replace1666_1 -> 243 in the cache */
   /* replace1666 -> 4620 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1667_0_0 -> 11 in the cache */
   /* search1667_0_1 -> 804 in the cache */
   /* search1667_0 -> 3109 in the cache */
   /* search1667_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3109, 243 },
      6,
   } },

   /* replace1667_0 -> 11 in the cache */
   /* replace1667_1 -> 243 in the cache */
   /* replace1667 -> 4620 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1668_0_0_0 -> 11 in the cache */
   /* search1668_0_0 -> 1942 in the cache */
   /* search1668_0 -> 4640 in the cache */
   /* search1668_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4640, 243 },
      6,
   } },

   /* replace1668_0 -> 11 in the cache */
   /* replace1668_1 -> 243 in the cache */
   /* replace1668 -> 1956 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1669_0_0_0 -> 11 in the cache */
   /* search1669_0_0 -> 3926 in the cache */
   /* search1669_0 -> 4642 in the cache */
   /* search1669_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4642, 243 },
      6,
   } },

   /* replace1669_0 -> 11 in the cache */
   /* replace1669_1 -> 243 in the cache */
   /* replace1669 -> 1956 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1670_0_0 -> 11 in the cache */
   /* search1670_0_1 -> 804 in the cache */
   /* search1670_0 -> 3109 in the cache */
   /* search1670_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3109, 243 },
      6,
   } },

   /* replace1670_0 -> 11 in the cache */
   /* replace1670_1 -> 243 in the cache */
   /* replace1670 -> 1956 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1671_0_0_0 -> 11 in the cache */
   /* search1671_0_0 -> 1942 in the cache */
   /* search1671_0 -> 4640 in the cache */
   /* search1671_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4640, 243 },
      6,
   } },

   /* replace1671_0 -> 11 in the cache */
   /* replace1671_1 -> 243 in the cache */
   /* replace1671 -> 1998 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1672_0_0_0 -> 11 in the cache */
   /* search1672_0_0 -> 3926 in the cache */
   /* search1672_0 -> 4642 in the cache */
   /* search1672_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4642, 243 },
      6,
   } },

   /* replace1672_0 -> 11 in the cache */
   /* replace1672_1 -> 243 in the cache */
   /* replace1672 -> 1998 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1673_0_0 -> 11 in the cache */
   /* search1673_0_1 -> 804 in the cache */
   /* search1673_0 -> 3109 in the cache */
   /* search1673_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3109, 243 },
      6,
   } },

   /* replace1673_0 -> 11 in the cache */
   /* replace1673_1 -> 243 in the cache */
   /* replace1673 -> 1998 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1674_0_0_0 -> 11 in the cache */
   /* search1674_0_0 -> 1942 in the cache */
   /* search1674_0 -> 4640 in the cache */
   /* search1674_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4640, 243 },
      6,
   } },

   /* replace1674_0 -> 11 in the cache */
   /* replace1674_1 -> 243 in the cache */
   /* replace1674 -> 2022 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1675_0_0_0 -> 11 in the cache */
   /* search1675_0_0 -> 3926 in the cache */
   /* search1675_0 -> 4642 in the cache */
   /* search1675_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4642, 243 },
      6,
   } },

   /* replace1675_0 -> 11 in the cache */
   /* replace1675_1 -> 243 in the cache */
   /* replace1675 -> 2022 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1676_0_0 -> 11 in the cache */
   /* search1676_0_1 -> 804 in the cache */
   /* search1676_0 -> 3109 in the cache */
   /* search1676_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3109, 243 },
      6,
   } },

   /* replace1676_0 -> 11 in the cache */
   /* replace1676_1 -> 243 in the cache */
   /* replace1676 -> 2022 in the cache */

   /* ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1677_0_0 -> 16 in the cache */
   /* search1677_0 -> 1958 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1958 },
      6,
   } },

   /* replace1677 -> 16 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1678_0 -> 16 in the cache */
   /* search1678_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 120 },
      6,
   } },

   /* replace1678 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1679_0 -> 502 in the cache */
   /* search1679_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4659 },
      -1,
   } },
   /* search1679_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4660, 540 },
      6,
   } },

   /* replace1679_0 -> 502 in the cache */
   /* replace1679_1 -> 360 in the cache */
   /* replace1679_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 360, 540 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1680_0 -> 502 in the cache */
   /* search1680_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4663 },
      -1,
   } },
   /* search1680_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4664, 540 },
      6,
   } },

   /* replace1680_0 -> 502 in the cache */
   /* replace1680_1 -> 360 in the cache */
   /* replace1680_2 -> 540 in the cache */
   /* replace1680 -> 4662 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1681_0 -> 502 in the cache */
   /* search1681_1_0 -> 360 in the cache */
   /* search1681_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1681_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4666, 540 },
      6,
   } },

   /* replace1681_0 -> 502 in the cache */
   /* replace1681_1 -> 360 in the cache */
   /* replace1681_2 -> 540 in the cache */
   /* replace1681 -> 4662 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1682_0_0_0 -> 16 in the cache */
   /* search1682_0_0 -> 1958 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1958 },
      -1,
   } },
   /* search1682_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4668, 36 },
      6,
   } },

   /* replace1682_0 -> 16 in the cache */
   /* replace1682_1 -> 36 in the cache */
   /* replace1682 -> 3690 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1683_0_0_0 -> 16 in the cache */
   /* search1683_0_0 -> 3878 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3878 },
      -1,
   } },
   /* search1683_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4670, 36 },
      6,
   } },

   /* replace1683_0 -> 16 in the cache */
   /* replace1683_1 -> 36 in the cache */
   /* replace1683 -> 3690 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1684_0_0 -> 16 in the cache */
   /* search1684_0_1 -> 120 in the cache */
   /* search1684_0 -> 393 in the cache */
   /* search1684_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1684_0 -> 16 in the cache */
   /* replace1684_1 -> 36 in the cache */
   /* replace1684 -> 3690 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1685_0_0_0 -> 16 in the cache */
   /* search1685_0_0 -> 1958 in the cache */
   /* search1685_0 -> 4668 in the cache */
   /* search1685_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4668, 36 },
      6,
   } },

   /* replace1685_0 -> 16 in the cache */
   /* replace1685_1 -> 36 in the cache */
   /* replace1685 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1686_0_0_0 -> 16 in the cache */
   /* search1686_0_0 -> 3878 in the cache */
   /* search1686_0 -> 4670 in the cache */
   /* search1686_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4670, 36 },
      6,
   } },

   /* replace1686_0 -> 16 in the cache */
   /* replace1686_1 -> 36 in the cache */
   /* replace1686 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1687_0_0 -> 16 in the cache */
   /* search1687_0_1 -> 120 in the cache */
   /* search1687_0 -> 393 in the cache */
   /* search1687_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1687_0 -> 16 in the cache */
   /* replace1687_1 -> 36 in the cache */
   /* replace1687 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1688_0_0_0 -> 16 in the cache */
   /* search1688_0_0 -> 1958 in the cache */
   /* search1688_0 -> 4668 in the cache */
   /* search1688_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4668, 36 },
      6,
   } },

   /* replace1688_0 -> 16 in the cache */
   /* replace1688_1 -> 36 in the cache */
   /* replace1688 -> 1964 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1689_0_0_0 -> 16 in the cache */
   /* search1689_0_0 -> 3878 in the cache */
   /* search1689_0 -> 4670 in the cache */
   /* search1689_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4670, 36 },
      6,
   } },

   /* replace1689_0 -> 16 in the cache */
   /* replace1689_1 -> 36 in the cache */
   /* replace1689 -> 1964 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1690_0_0 -> 16 in the cache */
   /* search1690_0_1 -> 120 in the cache */
   /* search1690_0 -> 393 in the cache */
   /* search1690_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1690_0 -> 16 in the cache */
   /* replace1690_1 -> 36 in the cache */
   /* replace1690 -> 1964 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1691_0_0_0 -> 16 in the cache */
   /* search1691_0_0 -> 1958 in the cache */
   /* search1691_0 -> 4668 in the cache */
   /* search1691_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4668, 36 },
      6,
   } },

   /* replace1691_0 -> 16 in the cache */
   /* replace1691_1 -> 36 in the cache */
   /* replace1691 -> 2002 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1692_0_0_0 -> 16 in the cache */
   /* search1692_0_0 -> 3878 in the cache */
   /* search1692_0 -> 4670 in the cache */
   /* search1692_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4670, 36 },
      6,
   } },

   /* replace1692_0 -> 16 in the cache */
   /* replace1692_1 -> 36 in the cache */
   /* replace1692 -> 2002 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1693_0_0 -> 16 in the cache */
   /* search1693_0_1 -> 120 in the cache */
   /* search1693_0 -> 393 in the cache */
   /* search1693_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1693_0 -> 16 in the cache */
   /* replace1693_1 -> 36 in the cache */
   /* replace1693 -> 2002 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1694_0_0_0 -> 16 in the cache */
   /* search1694_0_0 -> 1958 in the cache */
   /* search1694_0 -> 4668 in the cache */
   /* search1694_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4668, 36 },
      6,
   } },

   /* replace1694_0 -> 16 in the cache */
   /* replace1694_1 -> 36 in the cache */
   /* replace1694 -> 2026 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1695_0_0_0 -> 16 in the cache */
   /* search1695_0_0 -> 3878 in the cache */
   /* search1695_0 -> 4670 in the cache */
   /* search1695_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4670, 36 },
      6,
   } },

   /* replace1695_0 -> 16 in the cache */
   /* replace1695_1 -> 36 in the cache */
   /* replace1695 -> 2026 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1696_0_0 -> 16 in the cache */
   /* search1696_0_1 -> 120 in the cache */
   /* search1696_0 -> 393 in the cache */
   /* search1696_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1696_0 -> 16 in the cache */
   /* replace1696_1 -> 36 in the cache */
   /* replace1696 -> 2026 in the cache */

   /* ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1697_0_0 -> 16 in the cache */
   /* search1697_0 -> 1958 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1958 },
      6,
   } },

   /* replace1697 -> 16 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1698_0 -> 16 in the cache */
   /* search1698_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 120 },
      6,
   } },

   /* replace1698 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1699_0 -> 502 in the cache */
   /* search1699_1_0_0 -> 360 in the cache */
   /* search1699_1_0 -> 4659 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4659 },
      -1,
   } },
   /* search1699_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4687, 540 },
      6,
   } },

   /* replace1699_0 -> 502 in the cache */
   /* replace1699_1 -> 360 in the cache */
   /* replace1699_2 -> 540 in the cache */
   /* replace1699 -> 4662 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1700_0 -> 502 in the cache */
   /* search1700_1_0_0 -> 360 in the cache */
   /* search1700_1_0 -> 4663 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4663 },
      -1,
   } },
   /* search1700_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4689, 540 },
      6,
   } },

   /* replace1700_0 -> 502 in the cache */
   /* replace1700_1 -> 360 in the cache */
   /* replace1700_2 -> 540 in the cache */
   /* replace1700 -> 4662 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1701_0 -> 502 in the cache */
   /* search1701_1_0 -> 360 in the cache */
   /* search1701_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1701_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4691, 540 },
      6,
   } },

   /* replace1701_0 -> 502 in the cache */
   /* replace1701_1 -> 360 in the cache */
   /* replace1701_2 -> 540 in the cache */
   /* replace1701 -> 4662 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1702_0_0_0 -> 16 in the cache */
   /* search1702_0_0 -> 1958 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1958 },
      -1,
   } },
   /* search1702_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4693, 36 },
      6,
   } },

   /* replace1702_0 -> 16 in the cache */
   /* replace1702_1 -> 36 in the cache */
   /* replace1702 -> 3690 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1703_0_0_0 -> 16 in the cache */
   /* search1703_0_0 -> 3878 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3878 },
      -1,
   } },
   /* search1703_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4695, 36 },
      6,
   } },

   /* replace1703_0 -> 16 in the cache */
   /* replace1703_1 -> 36 in the cache */
   /* replace1703 -> 3690 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1704_0_0 -> 16 in the cache */
   /* search1704_0_1 -> 120 in the cache */
   /* search1704_0 -> 374 in the cache */
   /* search1704_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1704_0 -> 16 in the cache */
   /* replace1704_1 -> 36 in the cache */
   /* replace1704 -> 3690 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1705_0_0_0 -> 16 in the cache */
   /* search1705_0_0 -> 1958 in the cache */
   /* search1705_0 -> 4693 in the cache */
   /* search1705_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4693, 36 },
      6,
   } },

   /* replace1705_0 -> 16 in the cache */
   /* replace1705_1 -> 36 in the cache */
   /* replace1705 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1706_0_0_0 -> 16 in the cache */
   /* search1706_0_0 -> 3878 in the cache */
   /* search1706_0 -> 4695 in the cache */
   /* search1706_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4695, 36 },
      6,
   } },

   /* replace1706_0 -> 16 in the cache */
   /* replace1706_1 -> 36 in the cache */
   /* replace1706 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1707_0_0 -> 16 in the cache */
   /* search1707_0_1 -> 120 in the cache */
   /* search1707_0 -> 374 in the cache */
   /* search1707_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1707_0 -> 16 in the cache */
   /* replace1707_1 -> 36 in the cache */
   /* replace1707 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1708_0_0_0 -> 16 in the cache */
   /* search1708_0_0 -> 1958 in the cache */
   /* search1708_0 -> 4693 in the cache */
   /* search1708_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4693, 36 },
      6,
   } },

   /* replace1708_0 -> 16 in the cache */
   /* replace1708_1 -> 36 in the cache */
   /* replace1708 -> 1964 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1709_0_0_0 -> 16 in the cache */
   /* search1709_0_0 -> 3878 in the cache */
   /* search1709_0 -> 4695 in the cache */
   /* search1709_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4695, 36 },
      6,
   } },

   /* replace1709_0 -> 16 in the cache */
   /* replace1709_1 -> 36 in the cache */
   /* replace1709 -> 1964 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1710_0_0 -> 16 in the cache */
   /* search1710_0_1 -> 120 in the cache */
   /* search1710_0 -> 374 in the cache */
   /* search1710_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1710_0 -> 16 in the cache */
   /* replace1710_1 -> 36 in the cache */
   /* replace1710 -> 1964 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1711_0_0_0 -> 16 in the cache */
   /* search1711_0_0 -> 1958 in the cache */
   /* search1711_0 -> 4693 in the cache */
   /* search1711_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4693, 36 },
      6,
   } },

   /* replace1711_0 -> 16 in the cache */
   /* replace1711_1 -> 36 in the cache */
   /* replace1711 -> 2002 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1712_0_0_0 -> 16 in the cache */
   /* search1712_0_0 -> 3878 in the cache */
   /* search1712_0 -> 4695 in the cache */
   /* search1712_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4695, 36 },
      6,
   } },

   /* replace1712_0 -> 16 in the cache */
   /* replace1712_1 -> 36 in the cache */
   /* replace1712 -> 2002 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1713_0_0 -> 16 in the cache */
   /* search1713_0_1 -> 120 in the cache */
   /* search1713_0 -> 374 in the cache */
   /* search1713_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1713_0 -> 16 in the cache */
   /* replace1713_1 -> 36 in the cache */
   /* replace1713 -> 2002 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1714_0_0_0 -> 16 in the cache */
   /* search1714_0_0 -> 1958 in the cache */
   /* search1714_0 -> 4693 in the cache */
   /* search1714_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4693, 36 },
      6,
   } },

   /* replace1714_0 -> 16 in the cache */
   /* replace1714_1 -> 36 in the cache */
   /* replace1714 -> 2026 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1715_0_0_0 -> 16 in the cache */
   /* search1715_0_0 -> 3878 in the cache */
   /* search1715_0 -> 4695 in the cache */
   /* search1715_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4695, 36 },
      6,
   } },

   /* replace1715_0 -> 16 in the cache */
   /* replace1715_1 -> 36 in the cache */
   /* replace1715 -> 2026 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1716_0_0 -> 16 in the cache */
   /* search1716_0_1 -> 120 in the cache */
   /* search1716_0 -> 374 in the cache */
   /* search1716_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1716_0 -> 16 in the cache */
   /* replace1716_1 -> 36 in the cache */
   /* replace1716 -> 2026 in the cache */

   /* ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1717_0_0 -> 16 in the cache */
   /* search1717_0 -> 2980 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2980 },
      7,
   } },

   /* replace1717 -> 16 in the cache */

   /* ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1718_0 -> 16 in the cache */
   /* search1718_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 120 },
      7,
   } },

   /* replace1718 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1719_0 -> 502 in the cache */
   /* search1719_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4712 },
      -1,
   } },
   /* search1719_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4713, 540 },
      7,
   } },

   /* replace1719_0 -> 502 in the cache */
   /* replace1719_1 -> 360 in the cache */
   /* replace1719_2 -> 540 in the cache */
   /* replace1719 -> 4662 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1720_0 -> 502 in the cache */
   /* search1720_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4715 },
      -1,
   } },
   /* search1720_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4716, 540 },
      7,
   } },

   /* replace1720_0 -> 502 in the cache */
   /* replace1720_1 -> 360 in the cache */
   /* replace1720_2 -> 540 in the cache */
   /* replace1720 -> 4662 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1721_0 -> 502 in the cache */
   /* search1721_1_0 -> 360 in the cache */
   /* search1721_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1721_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4718, 540 },
      7,
   } },

   /* replace1721_0 -> 502 in the cache */
   /* replace1721_1 -> 360 in the cache */
   /* replace1721_2 -> 540 in the cache */
   /* replace1721 -> 4662 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1722_0_0_0 -> 16 in the cache */
   /* search1722_0_0 -> 2980 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2980 },
      -1,
   } },
   /* search1722_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4720, 36 },
      7,
   } },

   /* replace1722_0 -> 16 in the cache */
   /* replace1722_1 -> 36 in the cache */
   /* replace1722 -> 3690 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1723_0_0_0 -> 16 in the cache */
   /* search1723_0_0 -> 3880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3880 },
      -1,
   } },
   /* search1723_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4722, 36 },
      7,
   } },

   /* replace1723_0 -> 16 in the cache */
   /* replace1723_1 -> 36 in the cache */
   /* replace1723 -> 3690 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1724_0_0 -> 16 in the cache */
   /* search1724_0_1 -> 120 in the cache */
   /* search1724_0 -> 425 in the cache */
   /* search1724_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1724_0 -> 16 in the cache */
   /* replace1724_1 -> 36 in the cache */
   /* replace1724 -> 3690 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1725_0_0_0 -> 16 in the cache */
   /* search1725_0_0 -> 2980 in the cache */
   /* search1725_0 -> 4720 in the cache */
   /* search1725_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4720, 36 },
      7,
   } },

   /* replace1725_0 -> 16 in the cache */
   /* replace1725_1 -> 36 in the cache */
   /* replace1725 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1726_0_0_0 -> 16 in the cache */
   /* search1726_0_0 -> 3880 in the cache */
   /* search1726_0 -> 4722 in the cache */
   /* search1726_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4722, 36 },
      7,
   } },

   /* replace1726_0 -> 16 in the cache */
   /* replace1726_1 -> 36 in the cache */
   /* replace1726 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1727_0_0 -> 16 in the cache */
   /* search1727_0_1 -> 120 in the cache */
   /* search1727_0 -> 425 in the cache */
   /* search1727_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1727_0 -> 16 in the cache */
   /* replace1727_1 -> 36 in the cache */
   /* replace1727 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1728_0_0_0 -> 16 in the cache */
   /* search1728_0_0 -> 2980 in the cache */
   /* search1728_0 -> 4720 in the cache */
   /* search1728_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4720, 36 },
      7,
   } },

   /* replace1728_0 -> 16 in the cache */
   /* replace1728_1 -> 36 in the cache */
   /* replace1728 -> 1964 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1729_0_0_0 -> 16 in the cache */
   /* search1729_0_0 -> 3880 in the cache */
   /* search1729_0 -> 4722 in the cache */
   /* search1729_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4722, 36 },
      7,
   } },

   /* replace1729_0 -> 16 in the cache */
   /* replace1729_1 -> 36 in the cache */
   /* replace1729 -> 1964 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1730_0_0 -> 16 in the cache */
   /* search1730_0_1 -> 120 in the cache */
   /* search1730_0 -> 425 in the cache */
   /* search1730_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1730_0 -> 16 in the cache */
   /* replace1730_1 -> 36 in the cache */
   /* replace1730 -> 1964 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1731_0_0_0 -> 16 in the cache */
   /* search1731_0_0 -> 2980 in the cache */
   /* search1731_0 -> 4720 in the cache */
   /* search1731_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4720, 36 },
      7,
   } },

   /* replace1731_0 -> 16 in the cache */
   /* replace1731_1 -> 36 in the cache */
   /* replace1731 -> 2002 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1732_0_0_0 -> 16 in the cache */
   /* search1732_0_0 -> 3880 in the cache */
   /* search1732_0 -> 4722 in the cache */
   /* search1732_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4722, 36 },
      7,
   } },

   /* replace1732_0 -> 16 in the cache */
   /* replace1732_1 -> 36 in the cache */
   /* replace1732 -> 2002 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1733_0_0 -> 16 in the cache */
   /* search1733_0_1 -> 120 in the cache */
   /* search1733_0 -> 425 in the cache */
   /* search1733_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1733_0 -> 16 in the cache */
   /* replace1733_1 -> 36 in the cache */
   /* replace1733 -> 2002 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1734_0_0_0 -> 16 in the cache */
   /* search1734_0_0 -> 2980 in the cache */
   /* search1734_0 -> 4720 in the cache */
   /* search1734_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4720, 36 },
      7,
   } },

   /* replace1734_0 -> 16 in the cache */
   /* replace1734_1 -> 36 in the cache */
   /* replace1734 -> 2026 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1735_0_0_0 -> 16 in the cache */
   /* search1735_0_0 -> 3880 in the cache */
   /* search1735_0 -> 4722 in the cache */
   /* search1735_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4722, 36 },
      7,
   } },

   /* replace1735_0 -> 16 in the cache */
   /* replace1735_1 -> 36 in the cache */
   /* replace1735 -> 2026 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1736_0_0 -> 16 in the cache */
   /* search1736_0_1 -> 120 in the cache */
   /* search1736_0 -> 425 in the cache */
   /* search1736_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1736_0 -> 16 in the cache */
   /* replace1736_1 -> 36 in the cache */
   /* replace1736 -> 2026 in the cache */

   /* ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1737_0_0 -> 16 in the cache */
   /* search1737_0 -> 2980 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2980 },
      7,
   } },

   /* replace1737 -> 16 in the cache */

   /* ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1738_0 -> 16 in the cache */
   /* search1738_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 120 },
      7,
   } },

   /* replace1738 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1739_0 -> 502 in the cache */
   /* search1739_1_0_0 -> 360 in the cache */
   /* search1739_1_0 -> 4712 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4712 },
      -1,
   } },
   /* search1739_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4739, 540 },
      7,
   } },

   /* replace1739_0 -> 502 in the cache */
   /* replace1739_1 -> 360 in the cache */
   /* replace1739_2 -> 540 in the cache */
   /* replace1739 -> 4662 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1740_0 -> 502 in the cache */
   /* search1740_1_0_0 -> 360 in the cache */
   /* search1740_1_0 -> 4715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4715 },
      -1,
   } },
   /* search1740_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4741, 540 },
      7,
   } },

   /* replace1740_0 -> 502 in the cache */
   /* replace1740_1 -> 360 in the cache */
   /* replace1740_2 -> 540 in the cache */
   /* replace1740 -> 4662 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1741_0 -> 502 in the cache */
   /* search1741_1_0 -> 360 in the cache */
   /* search1741_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1741_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4743, 540 },
      7,
   } },

   /* replace1741_0 -> 502 in the cache */
   /* replace1741_1 -> 360 in the cache */
   /* replace1741_2 -> 540 in the cache */
   /* replace1741 -> 4662 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1742_0_0_0 -> 16 in the cache */
   /* search1742_0_0 -> 2980 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2980 },
      -1,
   } },
   /* search1742_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4745, 36 },
      7,
   } },

   /* replace1742_0 -> 16 in the cache */
   /* replace1742_1 -> 36 in the cache */
   /* replace1742 -> 3690 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1743_0_0_0 -> 16 in the cache */
   /* search1743_0_0 -> 3880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3880 },
      -1,
   } },
   /* search1743_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4747, 36 },
      7,
   } },

   /* replace1743_0 -> 16 in the cache */
   /* replace1743_1 -> 36 in the cache */
   /* replace1743 -> 3690 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1744_0_0 -> 16 in the cache */
   /* search1744_0_1 -> 120 in the cache */
   /* search1744_0 -> 417 in the cache */
   /* search1744_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1744_0 -> 16 in the cache */
   /* replace1744_1 -> 36 in the cache */
   /* replace1744 -> 3690 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1745_0_0_0 -> 16 in the cache */
   /* search1745_0_0 -> 2980 in the cache */
   /* search1745_0 -> 4745 in the cache */
   /* search1745_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4745, 36 },
      7,
   } },

   /* replace1745_0 -> 16 in the cache */
   /* replace1745_1 -> 36 in the cache */
   /* replace1745 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1746_0_0_0 -> 16 in the cache */
   /* search1746_0_0 -> 3880 in the cache */
   /* search1746_0 -> 4747 in the cache */
   /* search1746_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4747, 36 },
      7,
   } },

   /* replace1746_0 -> 16 in the cache */
   /* replace1746_1 -> 36 in the cache */
   /* replace1746 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1747_0_0 -> 16 in the cache */
   /* search1747_0_1 -> 120 in the cache */
   /* search1747_0 -> 417 in the cache */
   /* search1747_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1747_0 -> 16 in the cache */
   /* replace1747_1 -> 36 in the cache */
   /* replace1747 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1748_0_0_0 -> 16 in the cache */
   /* search1748_0_0 -> 2980 in the cache */
   /* search1748_0 -> 4745 in the cache */
   /* search1748_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4745, 36 },
      7,
   } },

   /* replace1748_0 -> 16 in the cache */
   /* replace1748_1 -> 36 in the cache */
   /* replace1748 -> 1964 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1749_0_0_0 -> 16 in the cache */
   /* search1749_0_0 -> 3880 in the cache */
   /* search1749_0 -> 4747 in the cache */
   /* search1749_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4747, 36 },
      7,
   } },

   /* replace1749_0 -> 16 in the cache */
   /* replace1749_1 -> 36 in the cache */
   /* replace1749 -> 1964 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1750_0_0 -> 16 in the cache */
   /* search1750_0_1 -> 120 in the cache */
   /* search1750_0 -> 417 in the cache */
   /* search1750_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1750_0 -> 16 in the cache */
   /* replace1750_1 -> 36 in the cache */
   /* replace1750 -> 1964 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1751_0_0_0 -> 16 in the cache */
   /* search1751_0_0 -> 2980 in the cache */
   /* search1751_0 -> 4745 in the cache */
   /* search1751_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4745, 36 },
      7,
   } },

   /* replace1751_0 -> 16 in the cache */
   /* replace1751_1 -> 36 in the cache */
   /* replace1751 -> 2002 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1752_0_0_0 -> 16 in the cache */
   /* search1752_0_0 -> 3880 in the cache */
   /* search1752_0 -> 4747 in the cache */
   /* search1752_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4747, 36 },
      7,
   } },

   /* replace1752_0 -> 16 in the cache */
   /* replace1752_1 -> 36 in the cache */
   /* replace1752 -> 2002 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1753_0_0 -> 16 in the cache */
   /* search1753_0_1 -> 120 in the cache */
   /* search1753_0 -> 417 in the cache */
   /* search1753_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1753_0 -> 16 in the cache */
   /* replace1753_1 -> 36 in the cache */
   /* replace1753 -> 2002 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1754_0_0_0 -> 16 in the cache */
   /* search1754_0_0 -> 2980 in the cache */
   /* search1754_0 -> 4745 in the cache */
   /* search1754_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4745, 36 },
      7,
   } },

   /* replace1754_0 -> 16 in the cache */
   /* replace1754_1 -> 36 in the cache */
   /* replace1754 -> 2026 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1755_0_0_0 -> 16 in the cache */
   /* search1755_0_0 -> 3880 in the cache */
   /* search1755_0 -> 4747 in the cache */
   /* search1755_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4747, 36 },
      7,
   } },

   /* replace1755_0 -> 16 in the cache */
   /* replace1755_1 -> 36 in the cache */
   /* replace1755 -> 2026 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1756_0_0 -> 16 in the cache */
   /* search1756_0_1 -> 120 in the cache */
   /* search1756_0 -> 417 in the cache */
   /* search1756_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1756_0 -> 16 in the cache */
   /* replace1756_1 -> 36 in the cache */
   /* replace1756 -> 2026 in the cache */

   /* ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* exp */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 4762, 4763 },
      -1,
   } },

   /* replace1757_0_0 -> 4762 in the cache */
   /* replace1757_0_1_0_0_0_0_0_0 -> 4763 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1e /* -30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 4763, 4765 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1e /* 30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 4766, 4767 },
      -1,
   } },
   /* replace1757_0_1_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4768, 377 },
      -1,
   } },
   /* replace1757_0_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 4769, 14 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xa /* 10 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 4770, 4771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 3,
      { 4772 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 4762, 4773 },
      -1,
   } },
   /* replace1757_1_0_0_0_0_0_0 -> 4763 in the cache */
   /* replace1757_1_0_0_0_0_0_1 -> 4765 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 4763, 4765 },
      -1,
   } },
   /* replace1757_1_0_0_0_0_1 -> 4767 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 4775, 4767 },
      -1,
   } },
   /* replace1757_1_0_0_0_1_0_0_0 -> 4763 in the cache */
   /* replace1757_1_0_0_0_1_0_0_1 -> 4765 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 4763, 4765 },
      -1,
   } },
   /* replace1757_1_0_0_0_1_0_1 -> 4767 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 4777, 4767 },
      -1,
   } },
   /* replace1757_1_0_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4778, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 4776, 4779 },
      -1,
   } },
   /* replace1757_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 4780, 14 },
      -1,
   } },
   /* replace1757_1_0_1 -> 4771 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4781, 4771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 5,
      { 4782 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 4774, 4783 },
      -1,
   } },

   /* ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23)) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1758_1 -> 4763 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 4785, 4763 },
      -1,
   } },

   /* replace1758_0_0 -> 4785 in the cache */
   /* replace1758_0_1_0_0_0_0_0 -> 4763 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0xfe /* -254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 4763, 4787 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfe /* 254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 4788, 4789 },
      -1,
   } },
   /* replace1758_0_1_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4790, 377 },
      -1,
   } },
   /* replace1758_0_1_0_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 4791, 3964 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x17 /* 23 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 4792, 4793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 4785, 4794 },
      -1,
   } },
   /* replace1758_1_0_0_0_0_0 -> 4763 in the cache */
   /* replace1758_1_0_0_0_0_1 -> 4787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 4763, 4787 },
      -1,
   } },
   /* replace1758_1_0_0_0_1 -> 4789 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 4796, 4789 },
      -1,
   } },
   /* replace1758_1_0_0_1_0_0_0 -> 4763 in the cache */
   /* replace1758_1_0_0_1_0_0_1 -> 4787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 4763, 4787 },
      -1,
   } },
   /* replace1758_1_0_0_1_0_1 -> 4789 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 4798, 4789 },
      -1,
   } },
   /* replace1758_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4799, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 4797, 4800 },
      -1,
   } },
   /* replace1758_1_0_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 4801, 3964 },
      -1,
   } },
   /* replace1758_1_1 -> 4793 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4802, 4793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 4795, 4803 },
      -1,
   } },

   /* ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1759_1 -> 4763 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 4805, 4763 },
      -1,
   } },

   /* replace1759_0_0 -> 4805 in the cache */
   /* replace1759_0_1_0 -> 120 in the cache */
   /* replace1759_0_1_1_0_0_0_0_0 -> 4763 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x7fe /* -2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 4763, 4807 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fe /* 2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 4808, 4809 },
      -1,
   } },
   /* replace1759_0_1_1_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4810, 377 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ff /* 1023 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 4811, 4812 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x14 /* 20 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 4813, 4814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 3,
      { 120, 4815 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 4805, 4816 },
      -1,
   } },
   /* replace1759_1_0 -> 120 in the cache */
   /* replace1759_1_1_0_0_0_0_0 -> 4763 in the cache */
   /* replace1759_1_1_0_0_0_0_1 -> 4807 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 4763, 4807 },
      -1,
   } },
   /* replace1759_1_1_0_0_0_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 4818, 4809 },
      -1,
   } },
   /* replace1759_1_1_0_0_1_0_0_0 -> 4763 in the cache */
   /* replace1759_1_1_0_0_1_0_0_1 -> 4807 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 4763, 4807 },
      -1,
   } },
   /* replace1759_1_1_0_0_1_0_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 4820, 4809 },
      -1,
   } },
   /* replace1759_1_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4821, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 4819, 4822 },
      -1,
   } },
   /* replace1759_1_1_0_1 -> 4812 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 4823, 4812 },
      -1,
   } },
   /* replace1759_1_1_1 -> 4814 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4824, 4814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 5,
      { 120, 4825 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 4817, 4826 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x') */
   /* search1760_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1760_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4785, 801 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1760_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 4785, 801 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      8, 1,
      { 4828, 4829 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff /* 16711935 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 4830, 4831 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_0_0_0_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4832, 778 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1760_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1760_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1760_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1760_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1760_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      10, 1,
      { 4828, 4829 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff00 /* 4278255360 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 4834, 4835 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_0_0_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4836, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 4833, 4837 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f /* 252645135 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 4838, 4839 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4840, 4841 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      14, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_1_0_0_0_0_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 4843, 4831 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_1_0_0_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4844, 778 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1760_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      16, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_1_0_0_1_0_1 -> 4835 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 4846, 4835 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_1_0_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4847, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 4845, 4848 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f0 /* 4042322160 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 4849, 4850 },
      -1,
   } },
   /* search1760_0_0_0_0_0_0_1_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4851, 4841 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 4842, 4852 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x33333333 /* 858993459 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 4853, 4854 },
      -1,
   } },
   /* search1760_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 4855, 382 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      22, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_0_0_0_0_0_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 4857, 4831 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_0_0_0_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4858, 778 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1760_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      24, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_0_0_0_1_0_1 -> 4835 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 4860, 4835 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_0_0_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4861, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 4859, 4862 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_0_0_1 -> 4839 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 4863, 4839 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_0_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4864, 4841 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      28, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_1_0_0_0_0_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 4866, 4831 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_1_0_0_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4867, 778 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1760_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      30, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_1_0_0_1_0_1 -> 4835 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 4869, 4835 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_1_0_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4870, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 4868, 4871 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_1_0_1 -> 4850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 4872, 4850 },
      -1,
   } },
   /* search1760_0_0_0_1_0_0_1_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4873, 4841 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 4865, 4874 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xcccccccc /* 3435973836 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 4875, 4876 },
      -1,
   } },
   /* search1760_0_0_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 4877, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 4856, 4878 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x55555555 /* 1431655765 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 4879, 4880 },
      -1,
   } },
   /* search1760_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 30,
      { 4881, 377 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      38, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_0_0_0_0_0_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 4883, 4831 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_0_0_0_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4884, 778 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1760_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      40, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_0_0_0_1_0_1 -> 4835 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 4886, 4835 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_0_0_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4887, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 4885, 4888 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_0_0_1 -> 4839 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 4889, 4839 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_0_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4890, 4841 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      44, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_1_0_0_0_0_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 4892, 4831 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_1_0_0_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4893, 778 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1760_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      46, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_1_0_0_1_0_1 -> 4835 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 4895, 4835 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_1_0_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4896, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 4894, 4897 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_1_0_1 -> 4850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 4898, 4850 },
      -1,
   } },
   /* search1760_1_0_0_0_0_0_1_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4899, 4841 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 4891, 4900 },
      -1,
   } },
   /* search1760_1_0_0_0_0_1 -> 4854 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 4901, 4854 },
      -1,
   } },
   /* search1760_1_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 4902, 382 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      52, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_0_0_0_0_0_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 4904, 4831 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_0_0_0_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4905, 778 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1760_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      54, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_0_0_0_1_0_1 -> 4835 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 4907, 4835 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_0_0_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4908, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 4906, 4909 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_0_0_1 -> 4839 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 4910, 4839 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_0_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4911, 4841 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      58, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_1_0_0_0_0_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 4913, 4831 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_1_0_0_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4914, 778 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1760_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      60, 1,
      { 4828, 4829 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_1_0_0_1_0_1 -> 4835 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 4916, 4835 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_1_0_0_1_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4917, 778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 4915, 4918 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_1_0_1 -> 4850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 4919, 4850 },
      -1,
   } },
   /* search1760_1_0_0_1_0_0_1_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4920, 4841 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 4912, 4921 },
      -1,
   } },
   /* search1760_1_0_0_1_0_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 4922, 4876 },
      -1,
   } },
   /* search1760_1_0_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 4923, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 4903, 4924 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xaaaaaaaa /* 2863311530 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 4925, 4926 },
      -1,
   } },
   /* search1760_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 30,
      { 4927, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 4882, 4928 },
      -1,
   } },

   /* replace1760_0 -> 4785 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 4785 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x') */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 4829 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0 -> 4830 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4830, 377 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_0_0_0_0_1 -> 4926 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 4931, 4926 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 4829 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0 -> 4834 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4834, 377 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_0_0_0_1_1 -> 4880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 4933, 4880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 4932, 4934 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4935, 382 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_0_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 4936, 4876 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 4829 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0 -> 4843 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4843, 377 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_0_1 -> 4926 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 4938, 4926 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 4829 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0 -> 4846 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4846, 377 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_1_1 -> 4880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 4940, 4880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 4939, 4941 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 4942, 382 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_1 -> 4854 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 4943, 4854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 4937, 4944 },
      -1,
   } },
   /* search1761_0_0_0_0_0_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 4945, 4841 },
      -1,
   } },
   /* search1761_0_0_0_0_1 -> 4850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 4946, 4850 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 4829 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0 -> 4857 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4857, 377 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_0_1 -> 4926 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 4948, 4926 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 4829 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0 -> 4860 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4860, 377 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_1_1 -> 4880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 4950, 4880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 4949, 4951 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4952, 382 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 4953, 4876 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 4829 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0 -> 4866 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4866, 377 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_0_1 -> 4926 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 4955, 4926 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 4829 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0 -> 4869 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4869, 377 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_1_1 -> 4880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 4957, 4880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 4956, 4958 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 4959, 382 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_1 -> 4854 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 4960, 4854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 4954, 4961 },
      -1,
   } },
   /* search1761_0_0_0_1_0_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 4962, 4841 },
      -1,
   } },
   /* search1761_0_0_0_1_1 -> 4839 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 4963, 4839 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 4947, 4964 },
      -1,
   } },
   /* search1761_0_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 29,
      { 4965, 778 },
      -1,
   } },
   /* search1761_0_1 -> 4835 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 4966, 4835 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 4829 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0 -> 4883 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4883, 377 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_0_1 -> 4926 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 4968, 4926 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 4829 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0 -> 4886 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4886, 377 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_1_1 -> 4880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 4970, 4880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 4969, 4971 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4972, 382 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 4973, 4876 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 4829 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0 -> 4892 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4892, 377 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_0_1 -> 4926 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 4975, 4926 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 4829 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0 -> 4895 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4895, 377 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_1_1 -> 4880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 4977, 4880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 4976, 4978 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 4979, 382 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_1 -> 4854 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 4980, 4854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 4974, 4981 },
      -1,
   } },
   /* search1761_1_0_0_0_0_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 4982, 4841 },
      -1,
   } },
   /* search1761_1_0_0_0_1 -> 4850 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 4983, 4850 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 4829 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0 -> 4904 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4904, 377 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_0_1 -> 4926 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 4985, 4926 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 4829 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0 -> 4907 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4907, 377 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_1_1 -> 4880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 4987, 4880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 4986, 4988 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4989, 382 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 4990, 4876 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4785 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 801 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 4828 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4785 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 801 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 4829 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0 -> 4913 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4913, 377 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_0_1 -> 4926 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 4992, 4926 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4785 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 801 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 4828 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4785 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 801 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 4829 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0 -> 4916 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4916, 377 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_1_1 -> 4880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 4994, 4880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 4993, 4995 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 4996, 382 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_1 -> 4854 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 4997, 4854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 4991, 4998 },
      -1,
   } },
   /* search1761_1_0_0_1_0_1 -> 4841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 4999, 4841 },
      -1,
   } },
   /* search1761_1_0_0_1_1 -> 4839 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5000, 4839 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 4984, 5001 },
      -1,
   } },
   /* search1761_1_0_1 -> 778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 29,
      { 5002, 778 },
      -1,
   } },
   /* search1761_1_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5003, 4831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 4967, 5004 },
      -1,
   } },

   /* replace1761_0 -> 4785 in the cache */
   /* replace1761 -> 4930 in the cache */

   /* ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b') */
   /* search1762_0_0 -> 0 in the cache */
   /* search1762_0_1 -> 3 in the cache */
   /* search1762_0 -> 1027 in the cache */
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1027, 5006 },
      -1,
   } },

   /* replace1762_0 -> 0 in the cache */
   /* replace1762_1 -> 3 in the cache */
   /* replace1762 -> 2342 in the cache */

   /* ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b') */
   /* search1763_0_0 -> 0 in the cache */
   /* search1763_0_1 -> 3 in the cache */
   /* search1763_0 -> 1021 in the cache */
   /* search1763_1 -> 5006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1021, 5006 },
      -1,
   } },

   /* replace1763_0 -> 0 in the cache */
   /* replace1763_1 -> 3 in the cache */
   /* replace1763 -> 2377 in the cache */

   /* ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b') */
   /* search1764_0_0 -> 0 in the cache */
   /* search1764_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 5009, 5010 },
      -1,
   } },

   /* replace1764_0 -> 0 in the cache */
   /* replace1764_1 -> 3 in the cache */
   /* replace1764 -> 2362 in the cache */

   /* ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b') */
   /* search1765_0_0 -> 0 in the cache */
   /* search1765_0_1 -> 3 in the cache */
   /* search1765_0 -> 3722 in the cache */
   /* search1765_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 3722, 5010 },
      -1,
   } },

   /* replace1765_0 -> 0 in the cache */
   /* replace1765_1 -> 3 in the cache */
   /* replace1765 -> 2392 in the cache */

   /* ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b') */
   /* search1766_0_0 -> 0 in the cache */
   /* search1766_0_1 -> 3 in the cache */
   /* search1766_0 -> 1027 in the cache */
   /* search1766_1 -> 5006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1027, 5006 },
      -1,
   } },

   /* replace1766_0 -> 0 in the cache */
   /* replace1766_1 -> 3 in the cache */
   /* replace1766 -> 2348 in the cache */

   /* ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b') */
   /* search1767_0_0 -> 0 in the cache */
   /* search1767_0_1 -> 3 in the cache */
   /* search1767_0 -> 1021 in the cache */
   /* search1767_1 -> 5006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1021, 5006 },
      -1,
   } },

   /* replace1767_0 -> 0 in the cache */
   /* replace1767_1 -> 3 in the cache */
   /* replace1767 -> 2381 in the cache */

   /* ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b') */
   /* search1768_0_0 -> 0 in the cache */
   /* search1768_0_1 -> 3 in the cache */
   /* search1768_0 -> 5009 in the cache */
   /* search1768_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 5009, 5010 },
      -1,
   } },

   /* replace1768_0 -> 0 in the cache */
   /* replace1768_1 -> 3 in the cache */
   /* replace1768 -> 2366 in the cache */

   /* ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b') */
   /* search1769_0_0 -> 0 in the cache */
   /* search1769_0_1 -> 3 in the cache */
   /* search1769_0 -> 3722 in the cache */
   /* search1769_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 3722, 5010 },
      -1,
   } },

   /* replace1769_0 -> 0 in the cache */
   /* replace1769_1 -> 3 in the cache */
   /* replace1769 -> 2396 in the cache */

   /* ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b') */
   /* search1770_0_0 -> 0 in the cache */
   /* search1770_0_1 -> 3 in the cache */
   /* search1770_0 -> 1027 in the cache */
   /* search1770_1 -> 5006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1027, 5006 },
      -1,
   } },

   /* replace1770_0 -> 0 in the cache */
   /* replace1770_1 -> 3 in the cache */
   /* replace1770 -> 2355 in the cache */

   /* ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b') */
   /* search1771_0_0 -> 0 in the cache */
   /* search1771_0_1 -> 3 in the cache */
   /* search1771_0 -> 1021 in the cache */
   /* search1771_1 -> 5006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1021, 5006 },
      -1,
   } },

   /* replace1771_0 -> 0 in the cache */
   /* replace1771_1 -> 3 in the cache */
   /* replace1771 -> 2387 in the cache */

   /* ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b') */
   /* search1772_0_0 -> 0 in the cache */
   /* search1772_0_1 -> 3 in the cache */
   /* search1772_0 -> 5009 in the cache */
   /* search1772_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 5009, 5010 },
      -1,
   } },

   /* replace1772_0 -> 0 in the cache */
   /* replace1772_1 -> 3 in the cache */
   /* replace1772 -> 2372 in the cache */

   /* ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b') */
   /* search1773_0_0 -> 0 in the cache */
   /* search1773_0_1 -> 3 in the cache */
   /* search1773_0 -> 3722 in the cache */
   /* search1773_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 3722, 5010 },
      -1,
   } },

   /* replace1773_0 -> 0 in the cache */
   /* replace1773_1 -> 3 in the cache */
   /* replace1773 -> 2402 in the cache */

   /* ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b') */
   /* search1774_0_0 -> 0 in the cache */
   /* search1774_0_1 -> 3 in the cache */
   /* search1774_0 -> 1027 in the cache */
   /* search1774_1 -> 5006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1027, 5006 },
      -1,
   } },

   /* replace1774_0 -> 0 in the cache */
   /* replace1774_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b') */
   /* search1775_0_0 -> 0 in the cache */
   /* search1775_0_1 -> 3 in the cache */
   /* search1775_0 -> 1021 in the cache */
   /* search1775_1 -> 5006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1021, 5006 },
      -1,
   } },

   /* replace1775_0 -> 0 in the cache */
   /* replace1775_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b') */
   /* search1776_0_0 -> 0 in the cache */
   /* search1776_0_1 -> 3 in the cache */
   /* search1776_0 -> 5009 in the cache */
   /* search1776_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 5009, 5010 },
      -1,
   } },

   /* replace1776_0 -> 0 in the cache */
   /* replace1776_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b') */
   /* search1777_0_0 -> 0 in the cache */
   /* search1777_0_1 -> 3 in the cache */
   /* search1777_0 -> 3722 in the cache */
   /* search1777_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 3722, 5010 },
      -1,
   } },

   /* replace1777_0 -> 0 in the cache */
   /* replace1777_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b') */
   /* search1778_0_0 -> 0 in the cache */
   /* search1778_0_1 -> 3 in the cache */
   /* search1778_0 -> 1027 in the cache */
   /* search1778_1 -> 5006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1027, 5006 },
      -1,
   } },

   /* replace1778_0 -> 0 in the cache */
   /* replace1778_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b') */
   /* search1779_0_0 -> 0 in the cache */
   /* search1779_0_1 -> 3 in the cache */
   /* search1779_0 -> 1021 in the cache */
   /* search1779_1 -> 5006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1021, 5006 },
      -1,
   } },

   /* replace1779_0 -> 0 in the cache */
   /* replace1779_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b') */
   /* search1780_0_0 -> 0 in the cache */
   /* search1780_0_1 -> 3 in the cache */
   /* search1780_0 -> 5009 in the cache */
   /* search1780_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 5009, 5010 },
      -1,
   } },

   /* replace1780_0 -> 0 in the cache */
   /* replace1780_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b') */
   /* search1781_0_0 -> 0 in the cache */
   /* search1781_0_1 -> 3 in the cache */
   /* search1781_0 -> 3722 in the cache */
   /* search1781_1 -> 5010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 3722, 5010 },
      -1,
   } },

   /* replace1781_0 -> 0 in the cache */
   /* replace1781_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b') */
   /* search1782_0_0 -> 0 in the cache */
   /* search1782_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1782_1_0 -> 0 in the cache */
   /* search1782_1_1 -> 3 in the cache */
   /* search1782_1 -> 996 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5037, 996 },
      -1,
   } },

   /* replace1782_0 -> 0 in the cache */
   /* replace1782_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a') */
   /* search1783_0_0 -> 32 in the cache */
   /* search1783_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   /* search1783_1_0 -> 2187 in the cache */
   /* search1783_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5040, 5041 },
      -1,
   } },

   /* replace1783_0 -> 2187 in the cache */
   /* replace1783_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 2187, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b') */
   /* search1784_0_0 -> 0 in the cache */
   /* search1784_0_1 -> 0 in the cache */
   /* search1784_0 -> 5037 in the cache */
   /* search1784_1_0 -> 0 in the cache */
   /* search1784_1_1 -> 3 in the cache */
   /* search1784_1 -> 993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5037, 993 },
      -1,
   } },

   /* replace1784_0 -> 0 in the cache */
   /* replace1784_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a') */
   /* search1785_0_0 -> 32 in the cache */
   /* search1785_0_1 -> 32 in the cache */
   /* search1785_0 -> 5040 in the cache */
   /* search1785_1_0 -> 2187 in the cache */
   /* search1785_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5040, 5046 },
      -1,
   } },

   /* replace1785_0 -> 2187 in the cache */
   /* replace1785_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 2187, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b') */
   /* search1786_0_0 -> 0 in the cache */
   /* search1786_0_1 -> 0 in the cache */
   /* search1786_0 -> 5037 in the cache */
   /* search1786_1_0 -> 0 in the cache */
   /* search1786_1_1 -> 3 in the cache */
   /* search1786_1 -> 1021 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5037, 1021 },
      -1,
   } },

   /* replace1786_0 -> 0 in the cache */
   /* replace1786_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a') */
   /* search1787_0_0 -> 32 in the cache */
   /* search1787_0_1 -> 32 in the cache */
   /* search1787_0 -> 5040 in the cache */
   /* search1787_1_0 -> 2187 in the cache */
   /* search1787_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 2187, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5040, 5051 },
      -1,
   } },

   /* replace1787_0 -> 2187 in the cache */
   /* replace1787_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 2187, 32 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd')) */
   /* search1788_0_0 -> 706 in the cache */
   /* search1788_0_1 -> 975 in the cache */
   /* search1788_0_2 -> 3168 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 975, 3168 },
      -1,
   } },
   /* search1788_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 5054, 978 },
      -1,
   } },

   /* replace1788_0 -> 706 in the cache */
   /* replace1788_1_0 -> 148 in the cache */
   /* replace1788_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1788_2_0 -> 150 in the cache */
   /* replace1788_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5056, 5057 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd')) */
   /* search1789_0_0 -> 706 in the cache */
   /* search1789_0_1 -> 975 in the cache */
   /* search1789_0_2 -> 3168 in the cache */
   /* search1789_0 -> 5054 in the cache */
   /* search1789_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 5054, 978 },
      -1,
   } },

   /* replace1789_0 -> 706 in the cache */
   /* replace1789_1_0 -> 148 in the cache */
   /* replace1789_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1789_2_0 -> 150 in the cache */
   /* replace1789_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5060, 5061 },
      -1,
   } },

   /* ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd')) */
   /* search1790_0_0 -> 706 in the cache */
   /* search1790_0_1 -> 975 in the cache */
   /* search1790_0_2 -> 3168 in the cache */
   /* search1790_0 -> 5054 in the cache */
   /* search1790_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 5054, 978 },
      -1,
   } },

   /* replace1790_0 -> 706 in the cache */
   /* replace1790_1_0 -> 148 in the cache */
   /* replace1790_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1790_2_0 -> 150 in the cache */
   /* replace1790_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5064, 5065 },
      -1,
   } },

   /* ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd')) */
   /* search1791_0_0 -> 706 in the cache */
   /* search1791_0_1 -> 975 in the cache */
   /* search1791_0_2 -> 3168 in the cache */
   /* search1791_0 -> 5054 in the cache */
   /* search1791_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 5054, 978 },
      -1,
   } },

   /* replace1791_0 -> 706 in the cache */
   /* replace1791_1_0 -> 148 in the cache */
   /* replace1791_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1791_2_0 -> 150 in the cache */
   /* replace1791_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5068, 5069 },
      -1,
   } },

   /* ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd')) */
   /* search1792_0_0 -> 706 in the cache */
   /* search1792_0_1 -> 975 in the cache */
   /* search1792_0_2 -> 3168 in the cache */
   /* search1792_0 -> 5054 in the cache */
   /* search1792_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5054, 978 },
      -1,
   } },

   /* replace1792_0 -> 706 in the cache */
   /* replace1792_1_0 -> 148 in the cache */
   /* replace1792_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1792_2_0 -> 150 in the cache */
   /* replace1792_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5072, 5073 },
      -1,
   } },

   /* ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1793_1_0 -> 1116 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1116, 5076, 5077 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5075, 5078 },
      -1,
   } },

   /* replace1793_0 -> 1116 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5080, 5081 },
      -1,
   } },
   /* replace1793_2_0 -> 5080 in the cache */
   /* replace1793_2_1 -> 1655 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5080, 1655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1116, 5082, 5083 },
      -1,
   } },

   /* ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd')) */
   /* search1794_0_0 -> 706 in the cache */
   /* search1794_0_1 -> 975 in the cache */
   /* search1794_0_2 -> 3168 in the cache */
   /* search1794_0 -> 5054 in the cache */
   /* search1794_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5054, 978 },
      -1,
   } },

   /* replace1794_0 -> 706 in the cache */
   /* replace1794_1_0 -> 148 in the cache */
   /* replace1794_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1794_2_0 -> 150 in the cache */
   /* replace1794_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5086, 5087 },
      -1,
   } },

   /* ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c')) */
   /* search1795_0 -> 5075 in the cache */
   /* search1795_1_0 -> 1116 in the cache */
   /* search1795_1_1 -> 5076 in the cache */
   /* search1795_1_2 -> 5077 in the cache */
   /* search1795_1 -> 5078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5075, 5078 },
      -1,
   } },

   /* replace1795_0 -> 1116 in the cache */
   /* replace1795_1_0 -> 5080 in the cache */
   /* replace1795_1_1 -> 5081 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5080, 5081 },
      -1,
   } },
   /* replace1795_2_0 -> 5080 in the cache */
   /* replace1795_2_1 -> 1655 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5080, 1655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1116, 5090, 5091 },
      -1,
   } },

   /* ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd')) */
   /* search1796_0_0 -> 706 in the cache */
   /* search1796_0_1 -> 975 in the cache */
   /* search1796_0_2 -> 3168 in the cache */
   /* search1796_0 -> 5054 in the cache */
   /* search1796_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5054, 978 },
      -1,
   } },

   /* replace1796_0 -> 706 in the cache */
   /* replace1796_1_0 -> 148 in the cache */
   /* replace1796_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1796_2_0 -> 150 in the cache */
   /* replace1796_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5094, 5095 },
      -1,
   } },

   /* ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c')) */
   /* search1797_0 -> 5075 in the cache */
   /* search1797_1_0 -> 1116 in the cache */
   /* search1797_1_1 -> 5076 in the cache */
   /* search1797_1_2 -> 5077 in the cache */
   /* search1797_1 -> 5078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5075, 5078 },
      -1,
   } },

   /* replace1797_0 -> 1116 in the cache */
   /* replace1797_1_0 -> 5080 in the cache */
   /* replace1797_1_1 -> 5081 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5080, 5081 },
      -1,
   } },
   /* replace1797_2_0 -> 5080 in the cache */
   /* replace1797_2_1 -> 1655 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5080, 1655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1116, 5098, 5099 },
      -1,
   } },

   /* ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd')) */
   /* search1798_0_0 -> 706 in the cache */
   /* search1798_0_1 -> 975 in the cache */
   /* search1798_0_2 -> 3168 in the cache */
   /* search1798_0 -> 5054 in the cache */
   /* search1798_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5054, 978 },
      -1,
   } },

   /* replace1798_0 -> 706 in the cache */
   /* replace1798_1_0 -> 148 in the cache */
   /* replace1798_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1798_2_0 -> 150 in the cache */
   /* replace1798_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5102, 5103 },
      -1,
   } },

   /* ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c')) */
   /* search1799_0 -> 5075 in the cache */
   /* search1799_1_0 -> 1116 in the cache */
   /* search1799_1_1 -> 5076 in the cache */
   /* search1799_1_2 -> 5077 in the cache */
   /* search1799_1 -> 5078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5075, 5078 },
      -1,
   } },

   /* replace1799_0 -> 1116 in the cache */
   /* replace1799_1_0 -> 5080 in the cache */
   /* replace1799_1_1 -> 5081 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5080, 5081 },
      -1,
   } },
   /* replace1799_2_0 -> 5080 in the cache */
   /* replace1799_2_1 -> 1655 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5080, 1655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1116, 5106, 5107 },
      -1,
   } },

   /* ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd')) */
   /* search1800_0_0 -> 706 in the cache */
   /* search1800_0_1 -> 975 in the cache */
   /* search1800_0_2 -> 3168 in the cache */
   /* search1800_0 -> 5054 in the cache */
   /* search1800_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5054, 978 },
      -1,
   } },

   /* replace1800_0 -> 706 in the cache */
   /* replace1800_1_0 -> 148 in the cache */
   /* replace1800_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1800_2_0 -> 150 in the cache */
   /* replace1800_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5110, 5111 },
      -1,
   } },

   /* ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c')) */
   /* search1801_0 -> 5075 in the cache */
   /* search1801_1_0 -> 1116 in the cache */
   /* search1801_1_1 -> 5076 in the cache */
   /* search1801_1_2 -> 5077 in the cache */
   /* search1801_1 -> 5078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5075, 5078 },
      -1,
   } },

   /* replace1801_0 -> 1116 in the cache */
   /* replace1801_1_0 -> 5080 in the cache */
   /* replace1801_1_1 -> 5081 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5080, 5081 },
      -1,
   } },
   /* replace1801_2_0 -> 5080 in the cache */
   /* replace1801_2_1 -> 1655 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5080, 1655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1116, 5114, 5115 },
      -1,
   } },

   /* ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd')) */
   /* search1802_0_0 -> 706 in the cache */
   /* search1802_0_1 -> 975 in the cache */
   /* search1802_0_2 -> 3168 in the cache */
   /* search1802_0 -> 5054 in the cache */
   /* search1802_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5054, 978 },
      -1,
   } },

   /* replace1802_0 -> 706 in the cache */
   /* replace1802_1_0 -> 148 in the cache */
   /* replace1802_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1802_2_0 -> 150 in the cache */
   /* replace1802_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5118, 5119 },
      -1,
   } },

   /* ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c')) */
   /* search1803_0 -> 5075 in the cache */
   /* search1803_1_0 -> 1116 in the cache */
   /* search1803_1_1 -> 5076 in the cache */
   /* search1803_1_2 -> 5077 in the cache */
   /* search1803_1 -> 5078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5075, 5078 },
      -1,
   } },

   /* replace1803_0 -> 1116 in the cache */
   /* replace1803_1_0 -> 5080 in the cache */
   /* replace1803_1_1 -> 5081 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5080, 5081 },
      -1,
   } },
   /* replace1803_2_0 -> 5080 in the cache */
   /* replace1803_2_1 -> 1655 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5080, 1655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1116, 5122, 5123 },
      -1,
   } },

   /* ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd')) */
   /* search1804_0_0 -> 706 in the cache */
   /* search1804_0_1 -> 975 in the cache */
   /* search1804_0_2 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 975, 150 },
      0,
   } },
   /* search1804_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 5125, 978 },
      -1,
   } },

   /* replace1804_0 -> 706 in the cache */
   /* replace1804_1_0 -> 148 in the cache */
   /* replace1804_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1804_2_0 -> 150 in the cache */
   /* replace1804_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5127, 5128 },
      -1,
   } },

   /* ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd')) */
   /* search1805_0_0 -> 706 in the cache */
   /* search1805_0_1 -> 975 in the cache */
   /* search1805_0_2 -> 150 in the cache */
   /* search1805_0 -> 5125 in the cache */
   /* search1805_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 5125, 978 },
      -1,
   } },

   /* replace1805_0 -> 706 in the cache */
   /* replace1805_1_0 -> 148 in the cache */
   /* replace1805_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1805_2_0 -> 150 in the cache */
   /* replace1805_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5131, 5132 },
      -1,
   } },

   /* ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd')) */
   /* search1806_0_0 -> 706 in the cache */
   /* search1806_0_1 -> 33 in the cache */
   /* search1806_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 33, 133 },
      0,
   } },
   /* search1806_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 5134, 296 },
      -1,
   } },

   /* replace1806_0 -> 706 in the cache */
   /* replace1806_1_0 -> 36 in the cache */
   /* replace1806_1_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 161 },
      -1,
   } },
   /* replace1806_2_0 -> 133 in the cache */
   /* replace1806_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5136, 5137 },
      -1,
   } },

   /* ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd')) */
   /* search1807_0_0 -> 706 in the cache */
   /* search1807_0_1 -> 975 in the cache */
   /* search1807_0_2 -> 150 in the cache */
   /* search1807_0 -> 5125 in the cache */
   /* search1807_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5125, 978 },
      -1,
   } },

   /* replace1807_0 -> 706 in the cache */
   /* replace1807_1_0 -> 148 in the cache */
   /* replace1807_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1807_2_0 -> 150 in the cache */
   /* replace1807_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5140, 5141 },
      -1,
   } },

   /* ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd')) */
   /* search1808_0_0 -> 706 in the cache */
   /* search1808_0_1 -> 975 in the cache */
   /* search1808_0_2 -> 150 in the cache */
   /* search1808_0 -> 5125 in the cache */
   /* search1808_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5125, 978 },
      -1,
   } },

   /* replace1808_0 -> 706 in the cache */
   /* replace1808_1_0 -> 148 in the cache */
   /* replace1808_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1808_2_0 -> 150 in the cache */
   /* replace1808_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5144, 5145 },
      -1,
   } },

   /* ('fddx', 'a') => 0.0 */
   /* search1809_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1809 -> 113 in the cache */

   /* ('fddx_fine', 'a') => 0.0 */
   /* search1810_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1810 -> 113 in the cache */

   /* ('fddx_coarse', 'a') => 0.0 */
   /* search1811_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1811 -> 113 in the cache */

   /* ('fddy', 'a') => 0.0 */
   /* search1812_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1812 -> 113 in the cache */

   /* ('fddy_fine', 'a') => 0.0 */
   /* search1813_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1813 -> 113 in the cache */

   /* ('fddy_coarse', 'a') => 0.0 */
   /* search1814_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1814 -> 113 in the cache */

   /* ('umul_low', '#a(is_lower_half_zero)', 'b') => 0 */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      30,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1815_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_low,
      0, 1,
      { 5153, 36 },
      -1,
   } },

   /* replace1815 -> 120 in the cache */

   /* ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c */
   /* search1816_0 -> 5153 in the cache */
   /* search1816_1 -> 36 in the cache */
   /* search1816_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 5153, 36, 133 },
      -1,
   } },

   /* replace1816 -> 133 in the cache */

   /* ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c */
   /* search1817_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      31,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1817_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 16, 5156, 133 },
      -1,
   } },

   /* replace1817 -> 133 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1818_0 -> 706 in the cache */
   /* search1818_1_0 -> 698 in the cache */
   /* search1818_1_1 -> 699 in the cache */
   /* search1818_1_2 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 698, 699, 708 },
      0,
   } },
   /* search1818_2_0 -> 698 in the cache */
   /* search1818_2_1 -> 699 in the cache */
   /* search1818_2_2 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 698, 699, 710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5158, 5159 },
      -1,
   } },

   /* replace1818_0 -> 698 in the cache */
   /* replace1818_1 -> 699 in the cache */
   /* replace1818_2_0 -> 706 in the cache */
   /* replace1818_2_1 -> 708 in the cache */
   /* replace1818_2_2 -> 710 in the cache */
   /* replace1818_2 -> 1242 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 698, 699, 1242 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1819_0 -> 706 in the cache */
   /* search1819_1_0 -> 698 in the cache */
   /* search1819_1_1 -> 699 in the cache */
   /* search1819_1_2 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 698, 699, 708 },
      -1,
   } },
   /* search1819_2_0 -> 698 in the cache */
   /* search1819_2_1 -> 699 in the cache */
   /* search1819_2_2 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 698, 699, 710 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5162, 5163 },
      -1,
   } },

   /* replace1819_0 -> 698 in the cache */
   /* replace1819_1 -> 699 in the cache */
   /* replace1819_2_0 -> 706 in the cache */
   /* replace1819_2_1 -> 708 in the cache */
   /* replace1819_2_2 -> 710 in the cache */
   /* replace1819_2 -> 1242 in the cache */
   /* replace1819 -> 5161 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1820_0 -> 706 in the cache */
   /* search1820_1_0 -> 698 in the cache */
   /* search1820_1_1 -> 699 in the cache */
   /* search1820_1_2 -> 708 in the cache */
   /* search1820_1 -> 5158 in the cache */
   /* search1820_2_0 -> 698 in the cache */
   /* search1820_2_1 -> 710 in the cache */
   /* search1820_2_2 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 698, 710, 708 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5158, 5165 },
      -1,
   } },

   /* replace1820_0 -> 698 in the cache */
   /* replace1820_1_0 -> 706 in the cache */
   /* replace1820_1_1 -> 699 in the cache */
   /* replace1820_1_2 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 699, 710 },
      -1,
   } },
   /* replace1820_2 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 698, 5167, 708 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1821_0 -> 706 in the cache */
   /* search1821_1_0 -> 698 in the cache */
   /* search1821_1_1 -> 699 in the cache */
   /* search1821_1_2 -> 708 in the cache */
   /* search1821_1 -> 5162 in the cache */
   /* search1821_2_0 -> 698 in the cache */
   /* search1821_2_1 -> 710 in the cache */
   /* search1821_2_2 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 698, 710, 708 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5162, 5169 },
      -1,
   } },

   /* replace1821_0 -> 698 in the cache */
   /* replace1821_1_0 -> 706 in the cache */
   /* replace1821_1_1 -> 699 in the cache */
   /* replace1821_1_2 -> 710 in the cache */
   /* replace1821_1 -> 5167 in the cache */
   /* replace1821_2 -> 708 in the cache */
   /* replace1821 -> 5168 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1822_0 -> 706 in the cache */
   /* search1822_1_0 -> 148 in the cache */
   /* search1822_1_1 -> 150 in the cache */
   /* search1822_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 148, 150, 151 },
      0,
   } },
   /* search1822_2_0 -> 1248 in the cache */
   /* search1822_2_1 -> 150 in the cache */
   /* search1822_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1248, 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5171, 5172 },
      -1,
   } },

   /* replace1822_0_0 -> 706 in the cache */
   /* replace1822_0_1 -> 148 in the cache */
   /* replace1822_0_2 -> 1248 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 148, 1248 },
      -1,
   } },
   /* replace1822_1 -> 150 in the cache */
   /* replace1822_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 5174, 150, 151 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1823_0 -> 706 in the cache */
   /* search1823_1_0 -> 148 in the cache */
   /* search1823_1_1 -> 150 in the cache */
   /* search1823_1_2 -> 151 in the cache */
   /* search1823_1 -> 663 in the cache */
   /* search1823_2_0 -> 1248 in the cache */
   /* search1823_2_1 -> 150 in the cache */
   /* search1823_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1248, 150, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 663, 5176 },
      -1,
   } },

   /* replace1823_0_0 -> 706 in the cache */
   /* replace1823_0_1 -> 148 in the cache */
   /* replace1823_0_2 -> 1248 in the cache */
   /* replace1823_0 -> 5174 in the cache */
   /* replace1823_1 -> 150 in the cache */
   /* replace1823_2 -> 151 in the cache */
   /* replace1823 -> 5175 in the cache */

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1824_0 -> 706 in the cache */
   /* search1824_1_0 -> 36 in the cache */
   /* search1824_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 133 },
      0,
   } },
   /* search1824_2_0 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5179 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5178, 5180 },
      -1,
   } },

   /* replace1824_0 -> 36 in the cache */
   /* replace1824_1_0 -> 706 in the cache */
   /* replace1824_1_1 -> 133 in the cache */
   /* replace1824_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 5182 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1825_0 -> 706 in the cache */
   /* search1825_1_0 -> 36 in the cache */
   /* search1825_1_1 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 332 },
      0,
   } },
   /* search1825_2_0 -> 36 in the cache */
   /* search1825_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5184, 5185 },
      -1,
   } },

   /* replace1825_0 -> 36 in the cache */
   /* replace1825_1_0 -> 706 in the cache */
   /* replace1825_1_1 -> 133 in the cache */
   /* replace1825_1_2 -> 161 in the cache */
   /* replace1825_1 -> 5182 in the cache */
   /* replace1825 -> 5183 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1826_0 -> 706 in the cache */
   /* search1826_1_0 -> 36 in the cache */
   /* search1826_1_1 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 332 },
      -1,
   } },
   /* search1826_2_0 -> 36 in the cache */
   /* search1826_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5187, 5188 },
      -1,
   } },

   /* replace1826_0 -> 36 in the cache */
   /* replace1826_1_0 -> 706 in the cache */
   /* replace1826_1_1 -> 133 in the cache */
   /* replace1826_1_2 -> 161 in the cache */
   /* replace1826_1 -> 5182 in the cache */
   /* replace1826 -> 5183 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1827_0 -> 706 in the cache */
   /* search1827_1_0 -> 36 in the cache */
   /* search1827_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 133 },
      -1,
   } },
   /* search1827_2_0 -> 36 in the cache */
   /* search1827_2_1 -> 5179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5179 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5190, 5191 },
      -1,
   } },

   /* replace1827_0 -> 36 in the cache */
   /* replace1827_1_0 -> 706 in the cache */
   /* replace1827_1_1 -> 133 in the cache */
   /* replace1827_1_2 -> 161 in the cache */
   /* replace1827_1 -> 5182 in the cache */
   /* replace1827 -> 5183 in the cache */

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1828_0 -> 706 in the cache */
   /* search1828_1_0 -> 148 in the cache */
   /* search1828_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1828_2_0 -> 148 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5193, 5195 },
      -1,
   } },

   /* replace1828_0 -> 148 in the cache */
   /* replace1828_1_0 -> 706 in the cache */
   /* replace1828_1_1 -> 150 in the cache */
   /* replace1828_1_2 -> 151 in the cache */
   /* replace1828_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1829_0 -> 706 in the cache */
   /* search1829_1_0 -> 148 in the cache */
   /* search1829_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1829_2_0 -> 148 in the cache */
   /* search1829_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5198, 5199 },
      -1,
   } },

   /* replace1829_0 -> 148 in the cache */
   /* replace1829_1_0 -> 706 in the cache */
   /* replace1829_1_1 -> 150 in the cache */
   /* replace1829_1_2 -> 151 in the cache */
   /* replace1829_1 -> 1237 in the cache */
   /* replace1829 -> 5197 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1830_0 -> 706 in the cache */
   /* search1830_1_0 -> 148 in the cache */
   /* search1830_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1830_2_0 -> 148 in the cache */
   /* search1830_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5201, 5202 },
      -1,
   } },

   /* replace1830_0 -> 148 in the cache */
   /* replace1830_1_0 -> 706 in the cache */
   /* replace1830_1_1 -> 150 in the cache */
   /* replace1830_1_2 -> 151 in the cache */
   /* replace1830_1 -> 1237 in the cache */
   /* replace1830 -> 5197 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1831_0 -> 706 in the cache */
   /* search1831_1_0 -> 148 in the cache */
   /* search1831_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1831_2_0 -> 148 in the cache */
   /* search1831_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5204, 5205 },
      -1,
   } },

   /* replace1831_0 -> 148 in the cache */
   /* replace1831_1_0 -> 706 in the cache */
   /* replace1831_1_1 -> 150 in the cache */
   /* replace1831_1_2 -> 151 in the cache */
   /* replace1831_1 -> 1237 in the cache */
   /* replace1831 -> 5197 in the cache */

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1832_0 -> 706 in the cache */
   /* search1832_1_0 -> 148 in the cache */
   /* search1832_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1832_2_0 -> 148 in the cache */
   /* search1832_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5207, 5208 },
      -1,
   } },

   /* replace1832_0 -> 148 in the cache */
   /* replace1832_1_0 -> 706 in the cache */
   /* replace1832_1_1 -> 150 in the cache */
   /* replace1832_1_2 -> 151 in the cache */
   /* replace1832_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1833_0 -> 706 in the cache */
   /* search1833_1_0 -> 148 in the cache */
   /* search1833_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1833_2_0 -> 148 in the cache */
   /* search1833_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5211, 5212 },
      -1,
   } },

   /* replace1833_0 -> 148 in the cache */
   /* replace1833_1_0 -> 706 in the cache */
   /* replace1833_1_1 -> 150 in the cache */
   /* replace1833_1_2 -> 151 in the cache */
   /* replace1833_1 -> 1237 in the cache */
   /* replace1833 -> 5210 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1834_0 -> 706 in the cache */
   /* search1834_1_0 -> 148 in the cache */
   /* search1834_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1834_2_0 -> 148 in the cache */
   /* search1834_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5214, 5215 },
      -1,
   } },

   /* replace1834_0 -> 148 in the cache */
   /* replace1834_1_0 -> 706 in the cache */
   /* replace1834_1_1 -> 150 in the cache */
   /* replace1834_1_2 -> 151 in the cache */
   /* replace1834_1 -> 1237 in the cache */
   /* replace1834 -> 5210 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1835_0 -> 706 in the cache */
   /* search1835_1_0 -> 148 in the cache */
   /* search1835_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1835_2_0 -> 148 in the cache */
   /* search1835_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5217, 5218 },
      -1,
   } },

   /* replace1835_0 -> 148 in the cache */
   /* replace1835_1_0 -> 706 in the cache */
   /* replace1835_1_1 -> 150 in the cache */
   /* replace1835_1_2 -> 151 in the cache */
   /* replace1835_1 -> 1237 in the cache */
   /* replace1835 -> 5210 in the cache */

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1836_0 -> 706 in the cache */
   /* search1836_1_0 -> 148 in the cache */
   /* search1836_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1836_2_0 -> 148 in the cache */
   /* search1836_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5220, 5221 },
      -1,
   } },

   /* replace1836_0 -> 148 in the cache */
   /* replace1836_1_0 -> 706 in the cache */
   /* replace1836_1_1 -> 150 in the cache */
   /* replace1836_1_2 -> 151 in the cache */
   /* replace1836_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1837_0 -> 706 in the cache */
   /* search1837_1_0 -> 148 in the cache */
   /* search1837_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1837_2_0 -> 148 in the cache */
   /* search1837_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5224, 5225 },
      -1,
   } },

   /* replace1837_0 -> 148 in the cache */
   /* replace1837_1_0 -> 706 in the cache */
   /* replace1837_1_1 -> 150 in the cache */
   /* replace1837_1_2 -> 151 in the cache */
   /* replace1837_1 -> 1237 in the cache */
   /* replace1837 -> 5223 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1838_0 -> 706 in the cache */
   /* search1838_1_0 -> 148 in the cache */
   /* search1838_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1838_2_0 -> 148 in the cache */
   /* search1838_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5227, 5228 },
      -1,
   } },

   /* replace1838_0 -> 148 in the cache */
   /* replace1838_1_0 -> 706 in the cache */
   /* replace1838_1_1 -> 150 in the cache */
   /* replace1838_1_2 -> 151 in the cache */
   /* replace1838_1 -> 1237 in the cache */
   /* replace1838 -> 5223 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1839_0 -> 706 in the cache */
   /* search1839_1_0 -> 148 in the cache */
   /* search1839_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1839_2_0 -> 148 in the cache */
   /* search1839_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5230, 5231 },
      -1,
   } },

   /* replace1839_0 -> 148 in the cache */
   /* replace1839_1_0 -> 706 in the cache */
   /* replace1839_1_1 -> 150 in the cache */
   /* replace1839_1_2 -> 151 in the cache */
   /* replace1839_1 -> 1237 in the cache */
   /* replace1839 -> 5223 in the cache */

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1840_0 -> 706 in the cache */
   /* search1840_1_0 -> 148 in the cache */
   /* search1840_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1840_2_0 -> 148 in the cache */
   /* search1840_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5233, 5234 },
      -1,
   } },

   /* replace1840_0 -> 148 in the cache */
   /* replace1840_1_0 -> 706 in the cache */
   /* replace1840_1_1 -> 150 in the cache */
   /* replace1840_1_2 -> 151 in the cache */
   /* replace1840_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1841_0 -> 706 in the cache */
   /* search1841_1_0 -> 148 in the cache */
   /* search1841_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1841_2_0 -> 148 in the cache */
   /* search1841_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5237, 5238 },
      -1,
   } },

   /* replace1841_0 -> 148 in the cache */
   /* replace1841_1_0 -> 706 in the cache */
   /* replace1841_1_1 -> 150 in the cache */
   /* replace1841_1_2 -> 151 in the cache */
   /* replace1841_1 -> 1237 in the cache */
   /* replace1841 -> 5236 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1842_0 -> 706 in the cache */
   /* search1842_1_0 -> 148 in the cache */
   /* search1842_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1842_2_0 -> 148 in the cache */
   /* search1842_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5240, 5241 },
      -1,
   } },

   /* replace1842_0 -> 148 in the cache */
   /* replace1842_1_0 -> 706 in the cache */
   /* replace1842_1_1 -> 150 in the cache */
   /* replace1842_1_2 -> 151 in the cache */
   /* replace1842_1 -> 1237 in the cache */
   /* replace1842 -> 5236 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1843_0 -> 706 in the cache */
   /* search1843_1_0 -> 148 in the cache */
   /* search1843_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1843_2_0 -> 148 in the cache */
   /* search1843_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5243, 5244 },
      -1,
   } },

   /* replace1843_0 -> 148 in the cache */
   /* replace1843_1_0 -> 706 in the cache */
   /* replace1843_1_1 -> 150 in the cache */
   /* replace1843_1_2 -> 151 in the cache */
   /* replace1843_1 -> 1237 in the cache */
   /* replace1843 -> 5236 in the cache */

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1844_0 -> 706 in the cache */
   /* search1844_1_0 -> 148 in the cache */
   /* search1844_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1844_2_0 -> 148 in the cache */
   /* search1844_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5246, 5247 },
      -1,
   } },

   /* replace1844_0 -> 148 in the cache */
   /* replace1844_1_0 -> 706 in the cache */
   /* replace1844_1_1 -> 150 in the cache */
   /* replace1844_1_2 -> 151 in the cache */
   /* replace1844_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1845_0 -> 706 in the cache */
   /* search1845_1_0 -> 148 in the cache */
   /* search1845_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1845_2_0 -> 148 in the cache */
   /* search1845_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5250, 5251 },
      -1,
   } },

   /* replace1845_0 -> 148 in the cache */
   /* replace1845_1_0 -> 706 in the cache */
   /* replace1845_1_1 -> 150 in the cache */
   /* replace1845_1_2 -> 151 in the cache */
   /* replace1845_1 -> 1237 in the cache */
   /* replace1845 -> 5249 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1846_0 -> 706 in the cache */
   /* search1846_1_0 -> 148 in the cache */
   /* search1846_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1846_2_0 -> 148 in the cache */
   /* search1846_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5253, 5254 },
      -1,
   } },

   /* replace1846_0 -> 148 in the cache */
   /* replace1846_1_0 -> 706 in the cache */
   /* replace1846_1_1 -> 150 in the cache */
   /* replace1846_1_2 -> 151 in the cache */
   /* replace1846_1 -> 1237 in the cache */
   /* replace1846 -> 5249 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1847_0 -> 706 in the cache */
   /* search1847_1_0 -> 148 in the cache */
   /* search1847_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1847_2_0 -> 148 in the cache */
   /* search1847_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5256, 5257 },
      -1,
   } },

   /* replace1847_0 -> 148 in the cache */
   /* replace1847_1_0 -> 706 in the cache */
   /* replace1847_1_1 -> 150 in the cache */
   /* replace1847_1_2 -> 151 in the cache */
   /* replace1847_1 -> 1237 in the cache */
   /* replace1847 -> 5249 in the cache */

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1848_0 -> 706 in the cache */
   /* search1848_1_0 -> 148 in the cache */
   /* search1848_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1848_2_0 -> 148 in the cache */
   /* search1848_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5259, 5260 },
      -1,
   } },

   /* replace1848_0 -> 148 in the cache */
   /* replace1848_1_0 -> 706 in the cache */
   /* replace1848_1_1 -> 150 in the cache */
   /* replace1848_1_2 -> 151 in the cache */
   /* replace1848_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1849_0 -> 706 in the cache */
   /* search1849_1_0 -> 148 in the cache */
   /* search1849_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1849_2_0 -> 148 in the cache */
   /* search1849_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5263, 5264 },
      -1,
   } },

   /* replace1849_0 -> 148 in the cache */
   /* replace1849_1_0 -> 706 in the cache */
   /* replace1849_1_1 -> 150 in the cache */
   /* replace1849_1_2 -> 151 in the cache */
   /* replace1849_1 -> 1237 in the cache */
   /* replace1849 -> 5262 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1850_0 -> 706 in the cache */
   /* search1850_1_0 -> 148 in the cache */
   /* search1850_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1850_2_0 -> 148 in the cache */
   /* search1850_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5266, 5267 },
      -1,
   } },

   /* replace1850_0 -> 148 in the cache */
   /* replace1850_1_0 -> 706 in the cache */
   /* replace1850_1_1 -> 150 in the cache */
   /* replace1850_1_2 -> 151 in the cache */
   /* replace1850_1 -> 1237 in the cache */
   /* replace1850 -> 5262 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1851_0 -> 706 in the cache */
   /* search1851_1_0 -> 148 in the cache */
   /* search1851_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1851_2_0 -> 148 in the cache */
   /* search1851_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5269, 5270 },
      -1,
   } },

   /* replace1851_0 -> 148 in the cache */
   /* replace1851_1_0 -> 706 in the cache */
   /* replace1851_1_1 -> 150 in the cache */
   /* replace1851_1_2 -> 151 in the cache */
   /* replace1851_1 -> 1237 in the cache */
   /* replace1851 -> 5262 in the cache */

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1852_0 -> 706 in the cache */
   /* search1852_1_0 -> 148 in the cache */
   /* search1852_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1852_2_0 -> 148 in the cache */
   /* search1852_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5272, 5273 },
      -1,
   } },

   /* replace1852_0 -> 148 in the cache */
   /* replace1852_1_0 -> 706 in the cache */
   /* replace1852_1_1 -> 150 in the cache */
   /* replace1852_1_2 -> 151 in the cache */
   /* replace1852_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1853_0 -> 706 in the cache */
   /* search1853_1_0 -> 148 in the cache */
   /* search1853_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1853_2_0 -> 148 in the cache */
   /* search1853_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5276, 5277 },
      -1,
   } },

   /* replace1853_0 -> 148 in the cache */
   /* replace1853_1_0 -> 706 in the cache */
   /* replace1853_1_1 -> 150 in the cache */
   /* replace1853_1_2 -> 151 in the cache */
   /* replace1853_1 -> 1237 in the cache */
   /* replace1853 -> 5275 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1854_0 -> 706 in the cache */
   /* search1854_1_0 -> 148 in the cache */
   /* search1854_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1854_2_0 -> 148 in the cache */
   /* search1854_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5279, 5280 },
      -1,
   } },

   /* replace1854_0 -> 148 in the cache */
   /* replace1854_1_0 -> 706 in the cache */
   /* replace1854_1_1 -> 150 in the cache */
   /* replace1854_1_2 -> 151 in the cache */
   /* replace1854_1 -> 1237 in the cache */
   /* replace1854 -> 5275 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1855_0 -> 706 in the cache */
   /* search1855_1_0 -> 148 in the cache */
   /* search1855_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1855_2_0 -> 148 in the cache */
   /* search1855_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5282, 5283 },
      -1,
   } },

   /* replace1855_0 -> 148 in the cache */
   /* replace1855_1_0 -> 706 in the cache */
   /* replace1855_1_1 -> 150 in the cache */
   /* replace1855_1_2 -> 151 in the cache */
   /* replace1855_1 -> 1237 in the cache */
   /* replace1855 -> 5275 in the cache */

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1856_0 -> 706 in the cache */
   /* search1856_1_0 -> 148 in the cache */
   /* search1856_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1856_2_0 -> 148 in the cache */
   /* search1856_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5285, 5286 },
      -1,
   } },

   /* replace1856_0 -> 148 in the cache */
   /* replace1856_1_0 -> 706 in the cache */
   /* replace1856_1_1 -> 150 in the cache */
   /* replace1856_1_2 -> 151 in the cache */
   /* replace1856_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1857_0 -> 706 in the cache */
   /* search1857_1_0 -> 148 in the cache */
   /* search1857_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1857_2_0 -> 148 in the cache */
   /* search1857_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5289, 5290 },
      -1,
   } },

   /* replace1857_0 -> 148 in the cache */
   /* replace1857_1_0 -> 706 in the cache */
   /* replace1857_1_1 -> 150 in the cache */
   /* replace1857_1_2 -> 151 in the cache */
   /* replace1857_1 -> 1237 in the cache */
   /* replace1857 -> 5288 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1858_0 -> 706 in the cache */
   /* search1858_1_0 -> 148 in the cache */
   /* search1858_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1858_2_0 -> 148 in the cache */
   /* search1858_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5292, 5293 },
      -1,
   } },

   /* replace1858_0 -> 148 in the cache */
   /* replace1858_1_0 -> 706 in the cache */
   /* replace1858_1_1 -> 150 in the cache */
   /* replace1858_1_2 -> 151 in the cache */
   /* replace1858_1 -> 1237 in the cache */
   /* replace1858 -> 5288 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1859_0 -> 706 in the cache */
   /* search1859_1_0 -> 148 in the cache */
   /* search1859_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1859_2_0 -> 148 in the cache */
   /* search1859_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5295, 5296 },
      -1,
   } },

   /* replace1859_0 -> 148 in the cache */
   /* replace1859_1_0 -> 706 in the cache */
   /* replace1859_1_1 -> 150 in the cache */
   /* replace1859_1_2 -> 151 in the cache */
   /* replace1859_1 -> 1237 in the cache */
   /* replace1859 -> 5288 in the cache */

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1860_0 -> 706 in the cache */
   /* search1860_1_0 -> 148 in the cache */
   /* search1860_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1860_2_0 -> 148 in the cache */
   /* search1860_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5298, 5299 },
      -1,
   } },

   /* replace1860_0 -> 148 in the cache */
   /* replace1860_1_0 -> 706 in the cache */
   /* replace1860_1_1 -> 150 in the cache */
   /* replace1860_1_2 -> 151 in the cache */
   /* replace1860_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1861_0 -> 706 in the cache */
   /* search1861_1_0 -> 148 in the cache */
   /* search1861_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1861_2_0 -> 148 in the cache */
   /* search1861_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5302, 5303 },
      -1,
   } },

   /* replace1861_0 -> 148 in the cache */
   /* replace1861_1_0 -> 706 in the cache */
   /* replace1861_1_1 -> 150 in the cache */
   /* replace1861_1_2 -> 151 in the cache */
   /* replace1861_1 -> 1237 in the cache */
   /* replace1861 -> 5301 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1862_0 -> 706 in the cache */
   /* search1862_1_0 -> 148 in the cache */
   /* search1862_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1862_2_0 -> 148 in the cache */
   /* search1862_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5305, 5306 },
      -1,
   } },

   /* replace1862_0 -> 148 in the cache */
   /* replace1862_1_0 -> 706 in the cache */
   /* replace1862_1_1 -> 150 in the cache */
   /* replace1862_1_2 -> 151 in the cache */
   /* replace1862_1 -> 1237 in the cache */
   /* replace1862 -> 5301 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1863_0 -> 706 in the cache */
   /* search1863_1_0 -> 148 in the cache */
   /* search1863_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1863_2_0 -> 148 in the cache */
   /* search1863_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5308, 5309 },
      -1,
   } },

   /* replace1863_0 -> 148 in the cache */
   /* replace1863_1_0 -> 706 in the cache */
   /* replace1863_1_1 -> 150 in the cache */
   /* replace1863_1_2 -> 151 in the cache */
   /* replace1863_1 -> 1237 in the cache */
   /* replace1863 -> 5301 in the cache */

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1864_0 -> 706 in the cache */
   /* search1864_1_0 -> 148 in the cache */
   /* search1864_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1864_2_0 -> 148 in the cache */
   /* search1864_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5311, 5312 },
      -1,
   } },

   /* replace1864_0 -> 148 in the cache */
   /* replace1864_1_0 -> 706 in the cache */
   /* replace1864_1_1 -> 150 in the cache */
   /* replace1864_1_2 -> 151 in the cache */
   /* replace1864_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1865_0 -> 706 in the cache */
   /* search1865_1_0 -> 148 in the cache */
   /* search1865_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1865_2_0 -> 148 in the cache */
   /* search1865_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5315, 5316 },
      -1,
   } },

   /* replace1865_0 -> 148 in the cache */
   /* replace1865_1_0 -> 706 in the cache */
   /* replace1865_1_1 -> 150 in the cache */
   /* replace1865_1_2 -> 151 in the cache */
   /* replace1865_1 -> 1237 in the cache */
   /* replace1865 -> 5314 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1866_0 -> 706 in the cache */
   /* search1866_1_0 -> 148 in the cache */
   /* search1866_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1866_2_0 -> 148 in the cache */
   /* search1866_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5318, 5319 },
      -1,
   } },

   /* replace1866_0 -> 148 in the cache */
   /* replace1866_1_0 -> 706 in the cache */
   /* replace1866_1_1 -> 150 in the cache */
   /* replace1866_1_2 -> 151 in the cache */
   /* replace1866_1 -> 1237 in the cache */
   /* replace1866 -> 5314 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1867_0 -> 706 in the cache */
   /* search1867_1_0 -> 148 in the cache */
   /* search1867_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1867_2_0 -> 148 in the cache */
   /* search1867_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5321, 5322 },
      -1,
   } },

   /* replace1867_0 -> 148 in the cache */
   /* replace1867_1_0 -> 706 in the cache */
   /* replace1867_1_1 -> 150 in the cache */
   /* replace1867_1_2 -> 151 in the cache */
   /* replace1867_1 -> 1237 in the cache */
   /* replace1867 -> 5314 in the cache */

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1868_0 -> 706 in the cache */
   /* search1868_1_0 -> 148 in the cache */
   /* search1868_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1868_2_0 -> 148 in the cache */
   /* search1868_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5324, 5325 },
      -1,
   } },

   /* replace1868_0 -> 148 in the cache */
   /* replace1868_1_0 -> 706 in the cache */
   /* replace1868_1_1 -> 150 in the cache */
   /* replace1868_1_2 -> 151 in the cache */
   /* replace1868_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1869_0 -> 706 in the cache */
   /* search1869_1_0 -> 148 in the cache */
   /* search1869_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1869_2_0 -> 148 in the cache */
   /* search1869_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5328, 5329 },
      -1,
   } },

   /* replace1869_0 -> 148 in the cache */
   /* replace1869_1_0 -> 706 in the cache */
   /* replace1869_1_1 -> 150 in the cache */
   /* replace1869_1_2 -> 151 in the cache */
   /* replace1869_1 -> 1237 in the cache */
   /* replace1869 -> 5327 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1870_0 -> 706 in the cache */
   /* search1870_1_0 -> 148 in the cache */
   /* search1870_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1870_2_0 -> 148 in the cache */
   /* search1870_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5331, 5332 },
      -1,
   } },

   /* replace1870_0 -> 148 in the cache */
   /* replace1870_1_0 -> 706 in the cache */
   /* replace1870_1_1 -> 150 in the cache */
   /* replace1870_1_2 -> 151 in the cache */
   /* replace1870_1 -> 1237 in the cache */
   /* replace1870 -> 5327 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1871_0 -> 706 in the cache */
   /* search1871_1_0 -> 148 in the cache */
   /* search1871_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1871_2_0 -> 148 in the cache */
   /* search1871_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5334, 5335 },
      -1,
   } },

   /* replace1871_0 -> 148 in the cache */
   /* replace1871_1_0 -> 706 in the cache */
   /* replace1871_1_1 -> 150 in the cache */
   /* replace1871_1_2 -> 151 in the cache */
   /* replace1871_1 -> 1237 in the cache */
   /* replace1871 -> 5327 in the cache */

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1872_0 -> 706 in the cache */
   /* search1872_1_0 -> 148 in the cache */
   /* search1872_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1872_2_0 -> 148 in the cache */
   /* search1872_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 5194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5337, 5338 },
      -1,
   } },

   /* replace1872_0 -> 148 in the cache */
   /* replace1872_1_0 -> 706 in the cache */
   /* replace1872_1_1 -> 150 in the cache */
   /* replace1872_1_2 -> 151 in the cache */
   /* replace1872_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1873_0 -> 706 in the cache */
   /* search1873_1_0 -> 148 in the cache */
   /* search1873_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 3183 },
      0,
   } },
   /* search1873_2_0 -> 148 in the cache */
   /* search1873_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5341, 5342 },
      -1,
   } },

   /* replace1873_0 -> 148 in the cache */
   /* replace1873_1_0 -> 706 in the cache */
   /* replace1873_1_1 -> 150 in the cache */
   /* replace1873_1_2 -> 151 in the cache */
   /* replace1873_1 -> 1237 in the cache */
   /* replace1873 -> 5340 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1874_0 -> 706 in the cache */
   /* search1874_1_0 -> 148 in the cache */
   /* search1874_1_1 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 3183 },
      -1,
   } },
   /* search1874_2_0 -> 148 in the cache */
   /* search1874_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5344, 5345 },
      -1,
   } },

   /* replace1874_0 -> 148 in the cache */
   /* replace1874_1_0 -> 706 in the cache */
   /* replace1874_1_1 -> 150 in the cache */
   /* replace1874_1_2 -> 151 in the cache */
   /* replace1874_1 -> 1237 in the cache */
   /* replace1874 -> 5340 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1875_0 -> 706 in the cache */
   /* search1875_1_0 -> 148 in the cache */
   /* search1875_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1875_2_0 -> 148 in the cache */
   /* search1875_2_1 -> 5194 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 5194 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 706, 5347, 5348 },
      -1,
   } },

   /* replace1875_0 -> 148 in the cache */
   /* replace1875_1_0 -> 706 in the cache */
   /* replace1875_1_1 -> 150 in the cache */
   /* replace1875_1_2 -> 151 in the cache */
   /* replace1875_1 -> 1237 in the cache */
   /* replace1875 -> 5340 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1876_0 -> 706 in the cache */
   /* search1876_1_0 -> 148 in the cache */
   /* search1876_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 150 },
      0,
   } },
   /* search1876_2_0 -> 148 in the cache */
   /* search1876_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5350, 5351 },
      -1,
   } },

   /* replace1876_0 -> 148 in the cache */
   /* replace1876_1_0 -> 706 in the cache */
   /* replace1876_1_1 -> 150 in the cache */
   /* replace1876_1_2 -> 151 in the cache */
   /* replace1876_1 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 1237 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1877_0 -> 706 in the cache */
   /* search1877_1_0 -> 148 in the cache */
   /* search1877_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 150 },
      -1,
   } },
   /* search1877_2_0 -> 148 in the cache */
   /* search1877_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5354, 5355 },
      -1,
   } },

   /* replace1877_0 -> 148 in the cache */
   /* replace1877_1_0 -> 706 in the cache */
   /* replace1877_1_1 -> 150 in the cache */
   /* replace1877_1_2 -> 151 in the cache */
   /* replace1877_1 -> 1237 in the cache */
   /* replace1877 -> 5353 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1878_0 -> 706 in the cache */
   /* search1878_1_0 -> 125 in the cache */
   /* search1878_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 125, 127 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1878_2_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5358, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5357, 5359 },
      -1,
   } },

   /* replace1878_0_0 -> 706 in the cache */
   /* replace1878_0_1 -> 125 in the cache */
   /* replace1878_0_2 -> 5358 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 125, 5358 },
      -1,
   } },
   /* replace1878_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5361, 127 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1879_0 -> 706 in the cache */
   /* search1879_1_0 -> 125 in the cache */
   /* search1879_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   /* search1879_2_0 -> 5358 in the cache */
   /* search1879_2_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5358, 127 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 706, 5363, 5364 },
      -1,
   } },

   /* replace1879_0_0 -> 706 in the cache */
   /* replace1879_0_1 -> 125 in the cache */
   /* replace1879_0_2 -> 5358 in the cache */
   /* replace1879_0 -> 5361 in the cache */
   /* replace1879_1 -> 127 in the cache */
   /* replace1879 -> 5362 in the cache */

   /* ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b')) */
   /* search1880_0 -> 502 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5366 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5367, 5369 },
      -1,
   } },

   /* replace1880_0_0 -> 502 in the cache */
   /* replace1880_0_1 -> 5366 in the cache */
   /* replace1880_0_2 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5366, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b')) */
   /* search1881_0 -> 502 in the cache */
   /* search1881_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5366 },
      0,
   } },
   /* search1881_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5373, 5374 },
      -1,
   } },

   /* replace1881_0_0 -> 502 in the cache */
   /* replace1881_0_1 -> 5366 in the cache */
   /* replace1881_0_2 -> 5368 in the cache */
   /* replace1881_0 -> 5371 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b')) */
   /* search1882_0 -> 502 in the cache */
   /* search1882_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5366 },
      0,
   } },
   /* search1882_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5377, 5378 },
      -1,
   } },

   /* replace1882_0_0 -> 502 in the cache */
   /* replace1882_0_1 -> 5366 in the cache */
   /* replace1882_0_2 -> 5368 in the cache */
   /* replace1882_0 -> 5371 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b')) */
   /* search1883_0 -> 502 in the cache */
   /* search1883_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5366 },
      0,
   } },
   /* search1883_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5381, 5382 },
      -1,
   } },

   /* replace1883_0_0 -> 502 in the cache */
   /* replace1883_0_1 -> 5366 in the cache */
   /* replace1883_0_2 -> 5368 in the cache */
   /* replace1883_0 -> 5371 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b')) */
   /* search1884_0 -> 502 in the cache */
   /* search1884_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5366 },
      0,
   } },
   /* search1884_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5385, 5386 },
      -1,
   } },

   /* replace1884_0_0 -> 502 in the cache */
   /* replace1884_0_1 -> 5366 in the cache */
   /* replace1884_0_2 -> 5368 in the cache */
   /* replace1884_0 -> 5371 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1885_0 -> 502 in the cache */
   /* search1885_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5366 },
      0,
   } },
   /* search1885_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5389, 5390 },
      -1,
   } },

   /* replace1885_0_0 -> 502 in the cache */
   /* replace1885_0_1 -> 5366 in the cache */
   /* replace1885_0_2 -> 5368 in the cache */
   /* replace1885_0 -> 5371 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b')) */
   /* search1886_0 -> 502 in the cache */
   /* search1886_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5366 },
      0,
   } },
   /* search1886_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5393, 5394 },
      -1,
   } },

   /* replace1886_0_0 -> 502 in the cache */
   /* replace1886_0_1 -> 5366 in the cache */
   /* replace1886_0_2 -> 5368 in the cache */
   /* replace1886_0 -> 5371 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b')) */
   /* search1887_0 -> 502 in the cache */
   /* search1887_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5366 },
      0,
   } },
   /* search1887_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5397, 5398 },
      -1,
   } },

   /* replace1887_0_0 -> 502 in the cache */
   /* replace1887_0_1 -> 5366 in the cache */
   /* replace1887_0_2 -> 5368 in the cache */
   /* replace1887_0 -> 5371 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b')) */
   /* search1888_0 -> 502 in the cache */
   /* search1888_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5366 },
      0,
   } },
   /* search1888_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5401, 5402 },
      -1,
   } },

   /* replace1888_0_0 -> 502 in the cache */
   /* replace1888_0_1 -> 5366 in the cache */
   /* replace1888_0_2 -> 5368 in the cache */
   /* replace1888_0 -> 5371 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b')) */
   /* search1889_0 -> 502 in the cache */
   /* search1889_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5366 },
      0,
   } },
   /* search1889_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5368 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5405, 5406 },
      -1,
   } },

   /* replace1889_0_0 -> 502 in the cache */
   /* replace1889_0_1 -> 5366 in the cache */
   /* replace1889_0_2 -> 5368 in the cache */
   /* replace1889_0 -> 5371 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5371 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1890_0 -> 502 in the cache */
   /* search1890_1_0 -> 5366 in the cache */
   /* search1890_1 -> 5389 in the cache */
   /* search1890_2_0 -> 5368 in the cache */
   /* search1890_2 -> 5390 in the cache */
   /* search1890 -> 5391 in the cache */

   /* replace1890_0_0 -> 502 in the cache */
   /* replace1890_0_1 -> 5366 in the cache */
   /* replace1890_0_2 -> 5368 in the cache */
   /* replace1890_0 -> 5371 in the cache */
   /* replace1890 -> 5392 in the cache */

   /* ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b')) */
   /* search1891_0_0 -> 502 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5409, 5410 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5411 },
      -1,
   } },

   /* replace1891_0 -> 502 in the cache */
   /* replace1891_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5366 },
      -1,
   } },
   /* replace1891_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5413, 5414 },
      -1,
   } },

   /* ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b')) */
   /* search1892_0_0 -> 502 in the cache */
   /* search1892_0_1 -> 5409 in the cache */
   /* search1892_0_2 -> 5410 in the cache */
   /* search1892_0 -> 5411 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5411 },
      -1,
   } },

   /* replace1892_0 -> 502 in the cache */
   /* replace1892_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5366 },
      -1,
   } },
   /* replace1892_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5417, 5418 },
      -1,
   } },

   /* ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b')) */
   /* search1893_0_0 -> 502 in the cache */
   /* search1893_0_1 -> 5409 in the cache */
   /* search1893_0_2 -> 5410 in the cache */
   /* search1893_0 -> 5411 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5411 },
      -1,
   } },

   /* replace1893_0 -> 502 in the cache */
   /* replace1893_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5366 },
      -1,
   } },
   /* replace1893_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5421, 5422 },
      -1,
   } },

   /* ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b')) */
   /* search1894_0_0 -> 502 in the cache */
   /* search1894_0_1 -> 5409 in the cache */
   /* search1894_0_2 -> 5410 in the cache */
   /* search1894_0 -> 5411 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5411 },
      -1,
   } },

   /* replace1894_0 -> 502 in the cache */
   /* replace1894_1_0 -> 5366 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5366 },
      -1,
   } },
   /* replace1894_2_0 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5425, 5426 },
      -1,
   } },

   /* ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216)) */
   /* search1895_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 16 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ffffff /* 33554431 */ },
   } },
   /* replace1895_1_0_0 -> 16 in the cache */
   /* replace1895_1_0_1 -> 377 in the cache */
   /* replace1895_1_0 -> 940 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1000000 /* 16777216 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 940, 5430 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5429, 5431 },
      -1,
   } },

   /* ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b')) */
   /* search1896_0_0 -> 16 in the cache */
   /* search1896_0_1 -> 36 in the cache */
   /* search1896_0 -> 2882 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 2882 },
      -1,
   } },

   /* replace1896_0_0 -> 16 in the cache */
   /* replace1896_0 -> 3571 in the cache */
   /* replace1896_1_0 -> 36 in the cache */
   /* replace1896_1 -> 3568 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3571, 3568 },
      -1,
   } },

   /* ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b')) */
   /* search1897_0_0 -> 16 in the cache */
   /* search1897_0_1 -> 36 in the cache */
   /* search1897_0 -> 2882 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 2882 },
      -1,
   } },

   /* replace1897_0_0 -> 16 in the cache */
   /* replace1897_0 -> 1926 in the cache */
   /* replace1897_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1926, 5436 },
      -1,
   } },

   /* ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b')) */
   /* search1898_0_0 -> 16 in the cache */
   /* search1898_0_1 -> 36 in the cache */
   /* search1898_0 -> 2882 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2882 },
      -1,
   } },

   /* replace1898_0_0 -> 16 in the cache */
   /* replace1898_0 -> 2980 in the cache */
   /* replace1898_1_0 -> 36 in the cache */
   /* replace1898_1 -> 4394 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2980, 4394 },
      -1,
   } },

   /* ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b')) */
   /* search1899_0_0 -> 16 in the cache */
   /* search1899_0_1 -> 36 in the cache */
   /* search1899_0 -> 2882 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2882 },
      -1,
   } },

   /* replace1899_0_0 -> 16 in the cache */
   /* replace1899_0 -> 3880 in the cache */
   /* replace1899_1_0 -> 36 in the cache */
   /* replace1899_1 -> 4065 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3880, 4065 },
      -1,
   } },

   /* ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b')) */
   /* search1900_0_0 -> 16 in the cache */
   /* search1900_0_1 -> 36 in the cache */
   /* search1900_0 -> 2882 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 2882 },
      -1,
   } },

   /* replace1900_0_0 -> 16 in the cache */
   /* replace1900_0 -> 1937 in the cache */
   /* replace1900_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1937, 5443 },
      -1,
   } },

   /* ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c')) */
   /* search1901_0_0 -> 16 in the cache */
   /* search1901_0_1 -> 36 in the cache */
   /* search1901_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5445 },
      -1,
   } },

   /* replace1901_0_0 -> 16 in the cache */
   /* replace1901_0 -> 3571 in the cache */
   /* replace1901_1_0 -> 36 in the cache */
   /* replace1901_1 -> 3568 in the cache */
   /* replace1901_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3571, 3568, 5447 },
      -1,
   } },

   /* ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c')) */
   /* search1902_0_0 -> 16 in the cache */
   /* search1902_0_1 -> 36 in the cache */
   /* search1902_0_2 -> 133 in the cache */
   /* search1902_0 -> 5445 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5445 },
      -1,
   } },

   /* replace1902_0_0 -> 16 in the cache */
   /* replace1902_0 -> 1926 in the cache */
   /* replace1902_1_0 -> 36 in the cache */
   /* replace1902_1 -> 5436 in the cache */
   /* replace1902_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1926, 5436, 5450 },
      -1,
   } },

   /* ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c')) */
   /* search1903_0_0 -> 16 in the cache */
   /* search1903_0_1 -> 36 in the cache */
   /* search1903_0_2 -> 133 in the cache */
   /* search1903_0 -> 5445 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5445 },
      -1,
   } },

   /* replace1903_0_0 -> 16 in the cache */
   /* replace1903_0 -> 2980 in the cache */
   /* replace1903_1_0 -> 36 in the cache */
   /* replace1903_1 -> 4394 in the cache */
   /* replace1903_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 2980, 4394, 5453 },
      -1,
   } },

   /* ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c')) */
   /* search1904_0_0 -> 16 in the cache */
   /* search1904_0_1 -> 36 in the cache */
   /* search1904_0_2 -> 133 in the cache */
   /* search1904_0 -> 5445 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5445 },
      -1,
   } },

   /* replace1904_0_0 -> 16 in the cache */
   /* replace1904_0 -> 3880 in the cache */
   /* replace1904_1_0 -> 36 in the cache */
   /* replace1904_1 -> 4065 in the cache */
   /* replace1904_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3880, 4065, 5456 },
      -1,
   } },

   /* ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c')) */
   /* search1905_0_0 -> 16 in the cache */
   /* search1905_0_1 -> 36 in the cache */
   /* search1905_0_2 -> 133 in the cache */
   /* search1905_0 -> 5445 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5445 },
      -1,
   } },

   /* replace1905_0_0 -> 16 in the cache */
   /* replace1905_0 -> 1937 in the cache */
   /* replace1905_1_0 -> 36 in the cache */
   /* replace1905_1 -> 5443 in the cache */
   /* replace1905_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1937, 5443, 5459 },
      -1,
   } },

   /* ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd')) */
   /* search1906_0_0 -> 16 in the cache */
   /* search1906_0_1 -> 36 in the cache */
   /* search1906_0_2 -> 133 in the cache */
   /* search1906_0_3 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 16, 36, 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5461 },
      -1,
   } },

   /* replace1906_0_0 -> 16 in the cache */
   /* replace1906_0 -> 3571 in the cache */
   /* replace1906_1_0 -> 36 in the cache */
   /* replace1906_1 -> 3568 in the cache */
   /* replace1906_2_0 -> 133 in the cache */
   /* replace1906_2 -> 5447 in the cache */
   /* replace1906_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3571, 3568, 5447, 5463 },
      -1,
   } },

   /* ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd')) */
   /* search1907_0_0 -> 16 in the cache */
   /* search1907_0_1 -> 36 in the cache */
   /* search1907_0_2 -> 133 in the cache */
   /* search1907_0_3 -> 161 in the cache */
   /* search1907_0 -> 5461 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5461 },
      -1,
   } },

   /* replace1907_0_0 -> 16 in the cache */
   /* replace1907_0 -> 1926 in the cache */
   /* replace1907_1_0 -> 36 in the cache */
   /* replace1907_1 -> 5436 in the cache */
   /* replace1907_2_0 -> 133 in the cache */
   /* replace1907_2 -> 5450 in the cache */
   /* replace1907_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1926, 5436, 5450, 5466 },
      -1,
   } },

   /* ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd')) */
   /* search1908_0_0 -> 16 in the cache */
   /* search1908_0_1 -> 36 in the cache */
   /* search1908_0_2 -> 133 in the cache */
   /* search1908_0_3 -> 161 in the cache */
   /* search1908_0 -> 5461 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5461 },
      -1,
   } },

   /* replace1908_0_0 -> 16 in the cache */
   /* replace1908_0 -> 2980 in the cache */
   /* replace1908_1_0 -> 36 in the cache */
   /* replace1908_1 -> 4394 in the cache */
   /* replace1908_2_0 -> 133 in the cache */
   /* replace1908_2 -> 5453 in the cache */
   /* replace1908_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 2980, 4394, 5453, 5469 },
      -1,
   } },

   /* ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd')) */
   /* search1909_0_0 -> 16 in the cache */
   /* search1909_0_1 -> 36 in the cache */
   /* search1909_0_2 -> 133 in the cache */
   /* search1909_0_3 -> 161 in the cache */
   /* search1909_0 -> 5461 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5461 },
      -1,
   } },

   /* replace1909_0_0 -> 16 in the cache */
   /* replace1909_0 -> 3880 in the cache */
   /* replace1909_1_0 -> 36 in the cache */
   /* replace1909_1 -> 4065 in the cache */
   /* replace1909_2_0 -> 133 in the cache */
   /* replace1909_2 -> 5456 in the cache */
   /* replace1909_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3880, 4065, 5456, 5472 },
      -1,
   } },

   /* ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd')) */
   /* search1910_0_0 -> 16 in the cache */
   /* search1910_0_1 -> 36 in the cache */
   /* search1910_0_2 -> 133 in the cache */
   /* search1910_0_3 -> 161 in the cache */
   /* search1910_0 -> 5461 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5461 },
      -1,
   } },

   /* replace1910_0_0 -> 16 in the cache */
   /* replace1910_0 -> 1937 in the cache */
   /* replace1910_1_0 -> 36 in the cache */
   /* replace1910_1 -> 5443 in the cache */
   /* replace1910_2_0 -> 133 in the cache */
   /* replace1910_2 -> 5459 in the cache */
   /* replace1910_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1937, 5443, 5459, 5475 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
   (is_used_by_if),
   (is_not_used_by_if),
   (is_used_by_non_fsat),
   (no_signed_wrap),
   (only_lower_8_bits_used),
   (only_lower_16_bits_used),
};

static const nir_search_variable_cond nir_opt_algebraic_variable_cond[] = {
   (is_pos_power_of_two),
   (is_neg_power_of_two),
   (is_bitcount2),
   (is_finite_not_zero),
   (is_finite),
   (is_not_const),
   (is_not_const_zero),
   (is_ult_0xfffc07fc),
   (is_not_fmul),
   (is_first_5_bits_uge_2),
   (is_unsigned_multiple_of_4),
   (is_unsigned_multiple_of_2),
   (is_unsigned_multiple_of_8),
   (is_unsigned_multiple_of_16),
   (is_unsigned_multiple_of_32),
   (is_unsigned_multiple_of_64),
   (is_a_number),
   (is_gt_0_and_lt_1),
   (is_zero_to_one),
   (is_not_negative),
   (is_integral),
   (is_not_positive),
   (is_not_zero),
   (is_a_number_not_negative),
   (is_a_number_not_positive),
   (is_gt_zero),
   (is_lt_zero),
   (is_a_number_gt_zero),
   (is_a_number_lt_zero),
   (is_fmul),
   (is_lower_half_zero),
   (is_upper_half_zero),
};

static const struct transform nir_opt_algebraic_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2455, 1169, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2887, 2977, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 54, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 57, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 32, 0 },
   { 67, 68, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 61, 0 },
   { 78, 81, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 62, 61, 0 },
   { 64, 61, 0 },
   { 82, 81, 1 },
   { 83, 88, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 61, 0 },
   { 66, 61, 0 },
   { 89, 95, 1 },
   { 96, 97, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2829, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2830, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 2717, 0 },
   { 2718, 2719, 0 },
   { 2720, 1173, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 121, 16, 0 },
   { 123, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 253, 254, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1446, 36 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 120, 0 },
   { 225, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 3584, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 333, 335, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 333, 335, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 336, 338, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 336, 338, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 437, 438, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 36, 0 },
   { 437, 438, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 36, 0 },
   { 348, 349, 7 },
   { 437, 438, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 319, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 434, 319, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 350, 351, 8 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 350, 351, 8 },
   { 434, 319, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 342, 344, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 342, 344, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 345, 347, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 345, 347, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 443, 444, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 288, 36, 0 },
   { 443, 444, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 288, 36, 0 },
   { 354, 355, 7 },
   { 443, 444, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 441, 442, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 36, 0 },
   { 441, 442, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 36, 0 },
   { 356, 357, 8 },
   { 441, 442, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 291, 36, 0 },
   { 339, 341, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 291, 36, 0 },
   { 339, 341, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 36, 0 },
   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 36, 0 },
   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 36, 0 },
   { 293, 36, 0 },
   { 352, 353, 7 },
   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 669, 673, 20 },
   { 2826, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 674, 676, 21 },
   { 2824, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 675, 679, 23 },
   { 2827, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 680, 682, 24 },
   { 2825, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 714, 719, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 750, 751, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 748, 749, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 746, 747, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 742, 745, 0 },
   { 746, 747, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 752, 745, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2459, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2459, 1169, 0 },
   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2910, 2911, 54 },
   { 2912, 387, 54 },
   { 2913, 2914, 54 },
   { 2944, 420, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2457, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2457, 1169, 0 },
   { 2458, 32, 0 },
   { 2910, 2911, 54 },
   { 2912, 387, 54 },
   { 2913, 2914, 54 },
   { 2944, 420, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 1418, 3392, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 1418, 3392, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { 2877, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { 2876, 1177, 0 },
   { 3399, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { 2876, 1177, 0 },
   { 2877, 1024, 0 },
   { 3399, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1265, 61, 0 },
   { 1266, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { 1268, 32, 0 },
   { 1269, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3495, 3498, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3495, 3498, 80 },
   { 4605, 11, 0 },
   { 4658, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3490, 3494, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3490, 3494, 80 },
   { 4633, 11, 0 },
   { 4686, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3499, 3503, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3499, 3503, 81 },
   { 4738, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3504, 3507, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3504, 3507, 81 },
   { 4711, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 2294, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 2294, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 2294, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 2294, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2288, 2295, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2288, 2295, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2288, 2295, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2288, 2295, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2290, 2296, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2292, 2297, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2316, 2323, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2324, 2326, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2327, 2329, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2330, 2333, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2334, 2338, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2339, 2341, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2342, 2347, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2354, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 2361, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2362, 2365, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 2371, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 2376, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2377, 2380, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 2386, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2387, 2391, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2392, 2395, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2396, 2401, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2402, 2406, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3131, 3132, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3131, 3132, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2465, 2468, 46 },
   { 2472, 2475, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2478, 2480, 46 },
   { 2483, 2485, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2490, 2493, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2490, 2493, 47 },
   { 2515, 32, 0 },
   { 2516, 236, 0 },
   { 2517, 2514, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2490, 2493, 47 },
   { 2518, 2488, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2490, 2493, 47 },
   { 2515, 32, 0 },
   { 2516, 236, 0 },
   { 2517, 2514, 0 },
   { 2518, 2488, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2507, 2561, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2556, 2558, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2555, 2536, 0 },
   { 2556, 2558, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2563, 2645, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2715, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2759, 36, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2878, 2972, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2888, 2979, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2896, 2980, 60 },
   { 2896, 2980, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2898, 2981, 60 },
   { 2898, 2981, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3436, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2932, 393, 54 },
   { 2933, 396, 54 },
   { 2934, 400, 54 },
   { 2935, 403, 54 },
   { 2948, 425, 55 },
   { 2949, 428, 55 },
   { 3436, 120, 0 },
   { 3438, 3440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3437, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2936, 374, 54 },
   { 2937, 378, 54 },
   { 2938, 383, 54 },
   { 2939, 387, 54 },
   { 2950, 417, 55 },
   { 2951, 420, 55 },
   { 3437, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2973, 2976, 58 },
   { 2973, 3576, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2983, 3574, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2990, 3575, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3018, 3573, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3018, 3573, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3018, 3573, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3018, 3573, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3127, 16, 0 },
   { 3128, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3129, 3130, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3133, 3135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3136, 3137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3486, 3489, 79 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3471, 3475, 77 },
   { 3471, 3479, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3481, 3485, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3288, 3291, 61 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3292, 3295, 61 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3296, 3299, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3300, 3302, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3307, 3311, 64 },
   { 3307, 3408, 73 },
   { 3307, 3410, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3312, 3315, 65 },
   { 3326, 3330, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3316, 3318, 65 },
   { 3331, 3333, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3319, 3322, 65 },
   { 3334, 3338, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3323, 3325, 65 },
   { 3339, 3341, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3342, 3346, 67 },
   { 3347, 3349, 68 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3350, 3351, 68 },
   { 3352, 3355, 69 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3356, 3369, 70 },
   { 3648, 3659, 101 },
   { 3668, 3679, 101 },
   { 3688, 3698, 101 },
   { 3356, 3713, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3370, 3378, 70 },
   { 3660, 3667, 101 },
   { 3680, 3687, 101 },
   { 3699, 3706, 101 },
   { 3370, 3718, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3414, 3417, 75 },
   { 3414, 3464, 76 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3418, 3420, 75 },
   { 3418, 3470, 76 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3421, 2448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3509, 3515, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3516, 3521, 83 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3522, 3529, 84 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3530, 3535, 85 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3536, 3541, 86 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3542, 3549, 87 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3550, 3557, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3558, 3567, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3577, 3579, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3585, 900, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3590, 95 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3591, 3595, 96 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3596, 3597, 97 },
   { 3596, 49, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3598, 3591, 98 },
   { 3598, 3600, 96 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3601, 3586, 99 },
   { 3601, 49, 95 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3602, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3603, 536, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3602, 3597, 0 },
   { 3603, 536, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3603, 536, 0 },
   { 3604, 3605, 0 },
   { 3606, 3608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3602, 3597, 0 },
   { 3603, 536, 0 },
   { 3604, 3605, 0 },
   { 3606, 3608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3610, 3612, 1 },
   { 3614, 3618, 1 },
   { 3619, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3770, 706, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3771, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3772, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3773, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4764, 4784, 104 },
   { 4786, 4804, 104 },
   { 4806, 4827, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5147, 113, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5148, 113, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5149, 113, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5150, 113, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5151, 113, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5152, 113, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5154, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5157, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5155, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5155, 133, 0 },
   { 5157, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5428, 5432, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 4620, 0 },
   { 4675, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4647, 4620, 0 },
   { 4700, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4727, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 3163, 3164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 3163, 3164, 0 },
   { 3207, 3164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 971, 974, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 5143, 5146, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4622, 4620, 0 },
   { 4675, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4647, 4620, 0 },
   { 4700, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4727, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { 4622, 4620, 0 },
   { 4675, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { 4647, 4620, 0 },
   { 4700, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { 4727, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2409, 2410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 4620, 0 },
   { 4647, 4620, 0 },
   { 4675, 49, 0 },
   { 4700, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 4620, 0 },
   { 4675, 49, 0 },
   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 4620, 0 },
   { 4675, 49, 0 },
   { 4727, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4647, 4620, 0 },
   { 4700, 49, 0 },
   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4647, 4620, 0 },
   { 4700, 49, 0 },
   { 4727, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4727, 49, 0 },
   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3253, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { 3253, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 191, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3193, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3193, 3194, 0 },
   { 3235, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 297, 299, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 301, 302, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 308, 309, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 311, 312, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 304, 306, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5139, 5142, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 177, 179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4618, 3670, 0 },
   { 4644, 3670, 0 },
   { 4672, 3690, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4724, 3690, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3017, 3018, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2548, 2550, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3281, 103, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3281, 103, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3281, 103, 0 },
   { 3643, 3625, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3281, 103, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2548, 2550, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3281, 103, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3281, 103, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3281, 103, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3281, 103, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2725, 706, 0 },
   { 2726, 1072, 0 },
   { 2729, 2730, 0 },
   { 2731, 2732, 0 },
   { 2735, 2736, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2744, 2745, 0 },
   { 2746, 2747, 0 },
   { 2748, 2749, 53 },
   { 2750, 2751, 53 },
   { 2754, 2755, 53 },
   { 2756, 2757, 53 },
   { 2758, 3, 0 },
   { 2761, 2164, 0 },
   { 2762, 2764, 0 },
   { 2766, 1168, 0 },
   { 2767, 2763, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5222, 5223, 0 },
   { 5226, 5223, 0 },
   { 5229, 5223, 0 },
   { 5232, 5223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5403, 5404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5407, 5408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5209, 5210, 0 },
   { 5213, 5210, 0 },
   { 5216, 5210, 0 },
   { 5219, 5210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5196, 5197, 0 },
   { 5200, 5197, 0 },
   { 5203, 5197, 0 },
   { 5206, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5181, 5183, 0 },
   { 5186, 5183, 0 },
   { 5189, 5183, 0 },
   { 5192, 5183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5235, 5236, 0 },
   { 5239, 5236, 0 },
   { 5242, 5236, 0 },
   { 5245, 5236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5248, 5249, 0 },
   { 5252, 5249, 0 },
   { 5255, 5249, 0 },
   { 5258, 5249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5391, 5392, 0 },
   { 5391, 5392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5160, 5161, 0 },
   { 5164, 5161, 0 },
   { 5166, 5168, 0 },
   { 5170, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 1238, 1236, 0 },
   { 1241, 1243, 0 },
   { 1246, 1243, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3282, 3283, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1706, 1708, 0 },
   { 1813, 1815, 0 },
   { 1896, 1898, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5274, 5275, 0 },
   { 5278, 5275, 0 },
   { 5281, 5275, 0 },
   { 5284, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5287, 5288, 0 },
   { 5291, 5288, 0 },
   { 5294, 5288, 0 },
   { 5297, 5288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5300, 5301, 0 },
   { 5304, 5301, 0 },
   { 5307, 5301, 0 },
   { 5310, 5301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5313, 5314, 0 },
   { 5317, 5314, 0 },
   { 5320, 5314, 0 },
   { 5323, 5314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5326, 5327, 0 },
   { 5330, 5327, 0 },
   { 5333, 5327, 0 },
   { 5336, 5327, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5339, 5340, 0 },
   { 5343, 5340, 0 },
   { 5346, 5340, 0 },
   { 5349, 5340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4614, 4609, 0 },
   { 4667, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4639, 4609, 0 },
   { 4692, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4744, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4719, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5261, 5262, 0 },
   { 5265, 5262, 0 },
   { 5268, 5262, 0 },
   { 5271, 5262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5383, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5387, 5388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5352, 5353, 0 },
   { 5356, 5353, 0 },
   { 5360, 5362, 0 },
   { 5365, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5379, 5380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5370, 5372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5375, 5376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5395, 5396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 5399, 5400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3263, 3254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3265, 3257, 0 },
   { 3268, 3257, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3266, 3260, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2065, 2066, 0 },
   { 2091, 2092, 0 },
   { 2117, 895, 0 },
   { 2142, 2143, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2065, 2066, 0 },
   { 2091, 2092, 0 },
   { 2117, 895, 0 },
   { 2142, 2143, 0 },
   { 2455, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 769, 771, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 773, 783, 0 },
   { 796, 805, 0 },
   { 818, 826, 0 },
   { 839, 848, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 967, 969, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 939, 940, 0 },
   { 946, 947, 0 },
   { 952, 953, 0 },
   { 960, 961, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 860, 863, 0 },
   { 868, 871, 0 },
   { 876, 878, 0 },
   { 883, 886, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 860, 863, 0 },
   { 868, 871, 0 },
   { 876, 878, 0 },
   { 883, 886, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 860, 863, 0 },
   { 868, 871, 0 },
   { 876, 878, 0 },
   { 883, 886, 0 },
   { 2065, 2066, 0 },
   { 2091, 2092, 0 },
   { 2117, 895, 0 },
   { 2142, 2143, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 860, 863, 0 },
   { 868, 871, 0 },
   { 876, 878, 0 },
   { 883, 886, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 864, 863, 0 },
   { 872, 871, 0 },
   { 879, 878, 0 },
   { 887, 886, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 864, 863, 0 },
   { 872, 871, 0 },
   { 879, 878, 0 },
   { 887, 886, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 864, 863, 0 },
   { 872, 871, 0 },
   { 879, 878, 0 },
   { 887, 886, 0 },
   { 2065, 2066, 0 },
   { 2091, 2092, 0 },
   { 2117, 895, 0 },
   { 2142, 2143, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 864, 863, 0 },
   { 872, 871, 0 },
   { 879, 878, 0 },
   { 887, 886, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2456, 32, 0 },
   { 3012, 3013, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 899, 900, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 895, 0 },
   { 941, 940, 0 },
   { 948, 947, 0 },
   { 955, 953, 0 },
   { 963, 961, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 904, 906, 0 },
   { 910, 912, 0 },
   { 916, 918, 0 },
   { 922, 924, 0 },
   { 928, 930, 0 },
   { 934, 936, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2447, 2448, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2447, 2448, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { 3237, 3239, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2446, 3, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 943, 942, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 965, 964, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1994, 1995, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 2447, 2448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 184, 0 },
   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 5049, 5050, 0 },
   { 5052, 5053, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 5038, 5039, 0 },
   { 5042, 5043, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 5044, 5045, 0 },
   { 5047, 5048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1023, 1024, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2411, 2410, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1985, 1987, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1990, 1991, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2451, 2452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1026, 1024, 0 },
   { 1557, 1559, 0 },
   { 1560, 1562, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1026, 1024, 0 },
   { 1557, 1559, 0 },
   { 1560, 1562, 0 },
   { 1573, 1559, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1026, 1024, 0 },
   { 1557, 1559, 0 },
   { 1560, 1562, 0 },
   { 1683, 1684, 0 },
   { 1685, 1684, 0 },
   { 1790, 1791, 0 },
   { 1792, 1791, 0 },
   { 1873, 1874, 0 },
   { 1875, 1874, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1026, 1024, 0 },
   { 1557, 1559, 0 },
   { 1560, 1562, 0 },
   { 1573, 1559, 0 },
   { 1683, 1684, 0 },
   { 1685, 1684, 0 },
   { 1790, 1791, 0 },
   { 1792, 1791, 0 },
   { 1873, 1874, 0 },
   { 1875, 1874, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1026, 1024, 0 },
   { 1557, 1559, 0 },
   { 1560, 1562, 0 },
   { 1578, 1562, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1026, 1024, 0 },
   { 1557, 1559, 0 },
   { 1560, 1562, 0 },
   { 1578, 1562, 0 },
   { 1683, 1684, 0 },
   { 1685, 1684, 0 },
   { 1790, 1791, 0 },
   { 1792, 1791, 0 },
   { 1873, 1874, 0 },
   { 1875, 1874, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1026, 1024, 0 },
   { 1557, 1559, 0 },
   { 1560, 1562, 0 },
   { 1573, 1559, 0 },
   { 1578, 1562, 0 },
   { 1683, 1684, 0 },
   { 1685, 1684, 0 },
   { 1790, 1791, 0 },
   { 1792, 1791, 0 },
   { 1873, 1874, 0 },
   { 1875, 1874, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1563, 1565, 0 },
   { 1566, 1568, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1563, 1565, 0 },
   { 1566, 1568, 0 },
   { 1581, 1565, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1202, 34 },
   { 1563, 1565, 0 },
   { 1566, 1568, 0 },
   { 1686, 1687, 0 },
   { 1688, 1687, 0 },
   { 1793, 1794, 0 },
   { 1795, 1794, 0 },
   { 1876, 1877, 0 },
   { 1878, 1877, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1202, 34 },
   { 1563, 1565, 0 },
   { 1566, 1568, 0 },
   { 1581, 1565, 0 },
   { 1686, 1687, 0 },
   { 1688, 1687, 0 },
   { 1793, 1794, 0 },
   { 1795, 1794, 0 },
   { 1876, 1877, 0 },
   { 1878, 1877, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1563, 1565, 0 },
   { 1566, 1568, 0 },
   { 1584, 1568, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1202, 34 },
   { 1563, 1565, 0 },
   { 1566, 1568, 0 },
   { 1584, 1568, 0 },
   { 1686, 1687, 0 },
   { 1688, 1687, 0 },
   { 1793, 1794, 0 },
   { 1795, 1794, 0 },
   { 1876, 1877, 0 },
   { 1878, 1877, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1202, 34 },
   { 1563, 1565, 0 },
   { 1566, 1568, 0 },
   { 1581, 1565, 0 },
   { 1584, 1568, 0 },
   { 1686, 1687, 0 },
   { 1688, 1687, 0 },
   { 1793, 1794, 0 },
   { 1795, 1794, 0 },
   { 1876, 1877, 0 },
   { 1878, 1877, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1031, 1024, 0 },
   { 1625, 1626, 0 },
   { 1627, 1628, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1033, 1024, 0 },
   { 1633, 1634, 0 },
   { 1635, 1636, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1629, 1630, 0 },
   { 1631, 1632, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1637, 1638, 0 },
   { 1639, 1640, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1029, 1024, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2047, 2049, 39 },
   { 2047, 2055, 41 },
   { 2073, 2075, 39 },
   { 2073, 2081, 41 },
   { 2099, 2101, 39 },
   { 2099, 2107, 41 },
   { 2124, 2126, 39 },
   { 2124, 2132, 41 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2059, 2060, 42 },
   { 2085, 2086, 42 },
   { 2111, 2112, 42 },
   { 2136, 2137, 42 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1973, 1974, 0 },
   { 2434, 32, 0 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4625, 1956, 0 },
   { 4650, 1956, 0 },
   { 4678, 1964, 0 },
   { 4703, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1968, 1970, 0 },
   { 2434, 32, 0 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1977, 1978, 0 },
   { 2434, 32, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4730, 1964, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1981, 1982, 0 },
   { 2434, 32, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 2444, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 2445, 2228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 2445, 2228, 0 },
   { 3241, 3243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2018, 2019, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 2445, 2228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2412, 2413, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2013, 2015, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2016, 2017, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 2453, 2454, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1524, 1526, 0 },
   { 1530, 1532, 0 },
   { 1666, 999, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1524, 1526, 0 },
   { 1530, 1532, 0 },
   { 1545, 1526, 0 },
   { 1666, 999, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1524, 1526, 0 },
   { 1530, 1532, 0 },
   { 1666, 999, 0 },
   { 1669, 1671, 0 },
   { 1674, 1671, 0 },
   { 1776, 1778, 0 },
   { 1781, 1778, 0 },
   { 1859, 1861, 0 },
   { 1864, 1861, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1524, 1526, 0 },
   { 1530, 1532, 0 },
   { 1545, 1526, 0 },
   { 1666, 999, 0 },
   { 1669, 1671, 0 },
   { 1674, 1671, 0 },
   { 1776, 1778, 0 },
   { 1781, 1778, 0 },
   { 1859, 1861, 0 },
   { 1864, 1861, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1524, 1526, 0 },
   { 1530, 1532, 0 },
   { 1550, 1532, 0 },
   { 1666, 999, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1524, 1526, 0 },
   { 1530, 1532, 0 },
   { 1550, 1532, 0 },
   { 1666, 999, 0 },
   { 1669, 1671, 0 },
   { 1674, 1671, 0 },
   { 1776, 1778, 0 },
   { 1781, 1778, 0 },
   { 1859, 1861, 0 },
   { 1864, 1861, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1524, 1526, 0 },
   { 1530, 1532, 0 },
   { 1545, 1526, 0 },
   { 1550, 1532, 0 },
   { 1666, 999, 0 },
   { 1669, 1671, 0 },
   { 1674, 1671, 0 },
   { 1776, 1778, 0 },
   { 1781, 1778, 0 },
   { 1859, 1861, 0 },
   { 1864, 1861, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1535, 1537, 0 },
   { 1540, 1542, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1535, 1537, 0 },
   { 1540, 1542, 0 },
   { 1553, 1537, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1535, 1537, 0 },
   { 1540, 1542, 0 },
   { 1677, 1679, 0 },
   { 1682, 1679, 0 },
   { 1784, 1786, 0 },
   { 1789, 1786, 0 },
   { 1867, 1869, 0 },
   { 1872, 1869, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1535, 1537, 0 },
   { 1540, 1542, 0 },
   { 1553, 1537, 0 },
   { 1677, 1679, 0 },
   { 1682, 1679, 0 },
   { 1784, 1786, 0 },
   { 1789, 1786, 0 },
   { 1867, 1869, 0 },
   { 1872, 1869, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1535, 1537, 0 },
   { 1540, 1542, 0 },
   { 1556, 1542, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1535, 1537, 0 },
   { 1540, 1542, 0 },
   { 1556, 1542, 0 },
   { 1677, 1679, 0 },
   { 1682, 1679, 0 },
   { 1784, 1786, 0 },
   { 1789, 1786, 0 },
   { 1867, 1869, 0 },
   { 1872, 1869, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1535, 1537, 0 },
   { 1540, 1542, 0 },
   { 1553, 1537, 0 },
   { 1556, 1542, 0 },
   { 1677, 1679, 0 },
   { 1682, 1679, 0 },
   { 1784, 1786, 0 },
   { 1789, 1786, 0 },
   { 1867, 1869, 0 },
   { 1872, 1869, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1587, 1589, 0 },
   { 1592, 1594, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1607, 1609, 0 },
   { 1612, 1614, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1597, 1599, 0 },
   { 1602, 1604, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1617, 1619, 0 },
   { 1622, 1624, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2154, 2155, 0 },
   { 2158, 2159, 0 },
   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2056, 2058, 42 },
   { 2082, 2084, 42 },
   { 2108, 2110, 42 },
   { 2133, 2135, 42 },
   { 2150, 2151, 0 },
   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2052, 2053, 40 },
   { 2052, 2061, 41 },
   { 2078, 2079, 40 },
   { 2078, 2087, 41 },
   { 2104, 2105, 40 },
   { 2104, 2113, 41 },
   { 2129, 2130, 40 },
   { 2129, 2138, 41 },
   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2007, 2008, 0 },
   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4653, 1998, 0 },
   { 4681, 2002, 0 },
   { 4706, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4681, 2002, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2004, 2006, 0 },
   { 2437, 32, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4653, 1998, 0 },
   { 4706, 2002, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2009, 2010, 0 },
   { 2437, 32, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4733, 2002, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2011, 2012, 0 },
   { 2437, 32, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 3019, 3018, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4631, 2022, 0 },
   { 4684, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4656, 2022, 0 },
   { 4709, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4736, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { 4631, 2022, 0 },
   { 4684, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { 4656, 2022, 0 },
   { 4709, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { 4736, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { 3245, 3247, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2042, 2043, 0 },
   { 2440, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2037, 2039, 0 },
   { 2440, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2040, 2041, 0 },
   { 2440, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2031, 2032, 0 },
   { 2440, 61, 0 },
   { 4631, 2022, 0 },
   { 4684, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4631, 2022, 0 },
   { 4656, 2022, 0 },
   { 4684, 2026, 0 },
   { 4709, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4631, 2022, 0 },
   { 4684, 2026, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4631, 2022, 0 },
   { 4684, 2026, 0 },
   { 4736, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2028, 2030, 0 },
   { 2440, 61, 0 },
   { 4656, 2022, 0 },
   { 4709, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4656, 2022, 0 },
   { 4709, 2026, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4656, 2022, 0 },
   { 4709, 2026, 0 },
   { 4736, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2033, 2034, 0 },
   { 2440, 61, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4736, 2026, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2035, 2036, 0 },
   { 2440, 61, 0 },
   { 4736, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2069, 2070, 0 },
   { 2095, 2096, 0 },
   { 2120, 2121, 0 },
   { 2146, 2147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2069, 2070, 0 },
   { 2095, 2096, 0 },
   { 2120, 2121, 0 },
   { 2146, 2147, 0 },
   { 2459, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2459, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 865, 867, 0 },
   { 873, 875, 0 },
   { 880, 882, 0 },
   { 888, 890, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 865, 867, 0 },
   { 873, 875, 0 },
   { 880, 882, 0 },
   { 888, 890, 0 },
   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 2942, 425, 55 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 865, 867, 0 },
   { 873, 875, 0 },
   { 880, 882, 0 },
   { 888, 890, 0 },
   { 2069, 2070, 0 },
   { 2095, 2096, 0 },
   { 2120, 2121, 0 },
   { 2146, 2147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 865, 867, 0 },
   { 873, 875, 0 },
   { 880, 882, 0 },
   { 888, 890, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 785, 787, 0 },
   { 807, 809, 0 },
   { 828, 830, 0 },
   { 850, 852, 0 },
   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { 3014, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2067, 2068, 0 },
   { 2093, 2094, 0 },
   { 2118, 2119, 0 },
   { 2144, 2145, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2067, 2068, 0 },
   { 2093, 2094, 0 },
   { 2118, 2119, 0 },
   { 2144, 2145, 0 },
   { 2457, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2910, 2911, 54 },
   { 2912, 387, 54 },
   { 2913, 2914, 54 },
   { 2943, 417, 55 },
   { 2944, 420, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2910, 2911, 54 },
   { 2912, 387, 54 },
   { 2913, 2914, 54 },
   { 2944, 420, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2067, 2068, 0 },
   { 2093, 2094, 0 },
   { 2118, 2119, 0 },
   { 2144, 2145, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 789, 794, 0 },
   { 811, 816, 0 },
   { 832, 837, 0 },
   { 854, 859, 0 },
   { 2458, 32, 0 },
   { 2910, 2911, 54 },
   { 2912, 387, 54 },
   { 2913, 2914, 54 },
   { 2944, 420, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3087, 3088, 0 },
   { 3090, 400, 0 },
   { 3091, 396, 0 },
   { 3092, 393, 0 },
   { 3094, 3065, 0 },
   { 3096, 3060, 0 },
   { 3098, 3055, 0 },
   { 3100, 3052, 0 },
   { 3102, 3048, 0 },
   { 3104, 3044, 0 },
   { 3106, 3107, 0 },
   { 3495, 3498, 80 },
   { 4605, 11, 0 },
   { 4658, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3037, 2905, 0 },
   { 3039, 396, 0 },
   { 3040, 400, 0 },
   { 3041, 403, 0 },
   { 3043, 3044, 0 },
   { 3046, 3048, 0 },
   { 3050, 3052, 0 },
   { 3053, 3055, 0 },
   { 3058, 3060, 0 },
   { 3063, 3065, 0 },
   { 3066, 2909, 0 },
   { 3495, 3498, 80 },
   { 4605, 11, 0 },
   { 4658, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3067, 2905, 0 },
   { 3069, 396, 0 },
   { 3070, 400, 0 },
   { 3071, 403, 0 },
   { 3073, 3044, 0 },
   { 3075, 3048, 0 },
   { 3077, 3052, 0 },
   { 3079, 3055, 0 },
   { 3081, 3060, 0 },
   { 3083, 3065, 0 },
   { 3084, 2909, 0 },
   { 3495, 3498, 80 },
   { 4605, 11, 0 },
   { 4658, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2941, 2925, 0 },
   { 3495, 3498, 80 },
   { 4605, 11, 0 },
   { 4658, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2940, 2925, 0 },
   { 3495, 3498, 80 },
   { 4605, 11, 0 },
   { 4658, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3085, 2919, 0 },
   { 3495, 3498, 80 },
   { 4605, 11, 0 },
   { 4658, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3029, 3030, 0 },
   { 3031, 3032, 0 },
   { 3033, 3034, 0 },
   { 3035, 3036, 0 },
   { 3495, 3498, 80 },
   { 4605, 11, 0 },
   { 4658, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3108, 3109, 0 },
   { 3110, 383, 0 },
   { 3111, 378, 0 },
   { 3112, 374, 0 },
   { 3113, 3114, 0 },
   { 3115, 3116, 0 },
   { 3117, 3118, 0 },
   { 3119, 3120, 0 },
   { 3121, 3122, 0 },
   { 3123, 3124, 0 },
   { 3125, 3126, 0 },
   { 3490, 3494, 80 },
   { 4633, 11, 0 },
   { 4686, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3021, 3022, 0 },
   { 3023, 3024, 0 },
   { 3025, 3026, 0 },
   { 3027, 3028, 0 },
   { 3490, 3494, 80 },
   { 4633, 11, 0 },
   { 4686, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2889, 21, 0 },
   { 2878, 2972, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 48, 49, 0 },
   { 2887, 2977, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 51, 49, 0 },
   { 2887, 2977, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2887, 2977, 59 },
   { 2987, 2887, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2879, 16, 0 },
   { 2887, 2977, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 99, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 0 },
   { 2829, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 104, 0 },
   { 2829, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2829, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2287, 2286, 0 },
   { 2829, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2288, 0 },
   { 2829, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2291, 2290, 0 },
   { 2829, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 2292, 0 },
   { 2829, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2829, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 109, 110, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3740, 706, 0 },
   { 3743, 6, 0 },
   { 3747, 11, 0 },
   { 3749, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3178, 3180, 0 },
   { 3182, 3180, 0 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3178, 3180, 0 },
   { 3182, 3180, 0 },
   { 3209, 3180, 0 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3185, 3187, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3185, 3187, 0 },
   { 3216, 3218, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3189, 3191, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3189, 3191, 0 },
   { 3226, 3228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 5126, 5129, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 169, 164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3151, 3153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3151, 3153, 0 },
   { 3196, 3153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3159, 3161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3159, 3161, 0 },
   { 3200, 3161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 5130, 5133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { 5130, 5133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2414, 1208, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2546, 2547, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2551, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 3140, 3141, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 3276, 3277, 0 },
   { 3279, 3280, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3140, 3141, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3155, 3157, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3155, 3157, 0 },
   { 3198, 3157, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 5135, 5138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3276, 3277, 0 },
   { 3279, 3280, 0 },
   { 5135, 5138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 3140, 3141, 6 },
   { 3276, 3277, 0 },
   { 3279, 3280, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 2553, 2554, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3169, 3171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3169, 3171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3169, 3171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3169, 3171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3169, 3171, 0 },
   { 3203, 3171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3169, 3171, 0 },
   { 3203, 3171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3169, 3171, 0 },
   { 3203, 3171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3169, 3171, 0 },
   { 3203, 3171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3174, 3175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3174, 3175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3174, 3175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3174, 3175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3143, 3144, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3143, 3144, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3143, 3144, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { 3143, 3144, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 172, 174, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3172, 3173, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3172, 3173, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 172, 174, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3172, 3173, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3172, 3173, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3172, 3173, 0 },
   { 3204, 3173, 0 },
   { 3205, 3175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3172, 3173, 0 },
   { 3204, 3173, 0 },
   { 3205, 3175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 172, 174, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3172, 3173, 0 },
   { 3204, 3173, 0 },
   { 3205, 3175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3172, 3173, 0 },
   { 3204, 3173, 0 },
   { 3205, 3175, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3145, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 253, 254, 6 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3145, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3145, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 26 },
   { 694, 273, 29 },
   { 3145, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1446, 36 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1446, 36 },
   { 1459, 202, 0 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1454, 1456, 0 },
   { 202, 1446, 36 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1458, 1457, 0 },
   { 202, 1446, 36 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2408, 1199, 0 },
   { 2432, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1131, 1132, 0 },
   { 2432, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1052, 1053, 0 },
   { 2408, 1199, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1131, 1132, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1131, 1132, 0 },
   { 1150, 1152, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1063, 1002, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { 5055, 5058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1166, 1072, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1185, 1175, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1038, 1039, 0 },
   { 2408, 1199, 0 },
   { 2432, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1131, 1132, 0 },
   { 2408, 1199, 0 },
   { 2432, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1104, 1103, 0 },
   { 1335, 1103, 0 },
   { 1339, 1103, 0 },
   { 1343, 1103, 0 },
   { 2432, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1177, 0 },
   { 4541, 4543, 103 },
   { 4558, 4543, 103 },
   { 4566, 4567, 0 },
   { 4580, 4582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1112, 670, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2195, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2189, 2190, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1044, 1045, 0 },
   { 1112, 670, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1194, 1195, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1181, 1182, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1057, 1059, 0 },
   { 1067, 1068, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { 5079, 5084, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2195, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1192, 1193, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2189, 2190, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1042, 1043, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1025, 0 },
   { 1112, 670, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1180, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1112, 670, 0 },
   { 1127, 1128, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 2195, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 2189, 2190, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 1136, 1139, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { 5071, 5074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2191, 1025, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2191, 1025, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1112, 670, 0 },
   { 2191, 1025, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2191, 1025, 0 },
   { 2195, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2189, 2190, 0 },
   { 2191, 1025, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1190, 1191, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2196, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2196, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1112, 670, 0 },
   { 2196, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2195, 1024, 0 },
   { 2196, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2189, 2190, 0 },
   { 2196, 1024, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { 4548, 4549, 103 },
   { 4555, 4556, 103 },
   { 4561, 4549, 103 },
   { 4565, 4556, 103 },
   { 4572, 4573, 0 },
   { 4577, 4578, 0 },
   { 4587, 4588, 0 },
   { 4593, 4594, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1113, 1114, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2193, 1177, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2197, 2198, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1048, 1049, 0 },
   { 1113, 1114, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1198, 1199, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1178, 1179, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { 5089, 5092, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2193, 1177, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1188, 1189, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2197, 2198, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1046, 1047, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1036, 1037, 0 },
   { 1113, 1114, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1129, 1130, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1129, 1130, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1113, 1114, 0 },
   { 1129, 1130, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1129, 1130, 0 },
   { 2193, 1177, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1129, 1130, 0 },
   { 2197, 2198, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1129, 1130, 0 },
   { 1145, 1146, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1062, 993, 0 },
   { 1066, 1049, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { 5085, 5088, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2199, 1037, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2199, 1037, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1113, 1114, 0 },
   { 2199, 1037, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2193, 1177, 0 },
   { 2199, 1037, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2197, 2198, 0 },
   { 2199, 1037, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1186, 1187, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2194, 1177, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2194, 1177, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1113, 1114, 0 },
   { 2194, 1177, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2193, 1177, 0 },
   { 2194, 1177, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2194, 1177, 0 },
   { 2197, 2198, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { 4546, 4547, 103 },
   { 4552, 4554, 103 },
   { 4560, 4547, 103 },
   { 4564, 4554, 103 },
   { 4570, 4571, 0 },
   { 4575, 4576, 0 },
   { 4585, 4586, 0 },
   { 4590, 4592, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2407, 1195, 0 },
   { 2433, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1133, 1134, 0 },
   { 2433, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1050, 1051, 0 },
   { 2407, 1195, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1172, 1173, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1133, 1134, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1133, 1134, 0 },
   { 1158, 1159, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1064, 999, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { 5059, 5062, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1167, 706, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1184, 1173, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1040, 1041, 0 },
   { 2407, 1195, 0 },
   { 2433, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1133, 1134, 0 },
   { 2407, 1195, 0 },
   { 2433, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1093, 1092, 0 },
   { 1336, 1320, 0 },
   { 1340, 1320, 0 },
   { 1344, 1320, 0 },
   { 2433, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1024, 0 },
   { 4544, 4545, 103 },
   { 4559, 4545, 103 },
   { 4568, 4569, 0 },
   { 4583, 4584, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1436, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1436, 32, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1500, 1501, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1214, 1217, 0 },
   { 1260, 32, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1446, 202, 34 },
   { 1450, 1451, 34 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1436, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1431, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1436, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1436, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1210, 1208, 0 },
   { 1260, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1440, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1440, 103, 0 },
   { 1444, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1498, 1499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1448, 202, 34 },
   { 1453, 1451, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1440, 103, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1440, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 1261, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 101, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5412, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2063, 6, 0 },
   { 2089, 11, 0 },
   { 2115, 16, 0 },
   { 2140, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 106, 0 },
   { 2830, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 106, 0 },
   { 2830, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2830, 32, 0 },
   { 5416, 5419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 112, 0 },
   { 2716, 2717, 0 },
   { 2718, 2719, 0 },
   { 2720, 1173, 0 },
   { 111, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 2717, 0 },
   { 2718, 2719, 0 },
   { 2720, 1173, 0 },
   { 2795, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 2717, 0 },
   { 2718, 2719, 0 },
   { 2720, 1173, 0 },
   { 2788, 11, 0 },
   { 2790, 16, 0 },
   { 3741, 706, 0 },
   { 3745, 6, 0 },
   { 2788, 11, 0 },
   { 2790, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 2717, 0 },
   { 2718, 2719, 0 },
   { 2720, 1173, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 2717, 0 },
   { 2718, 2719, 0 },
   { 2720, 1173, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 3579, 3577, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { 1437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1432, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1441, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1441, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 3581, 3577, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1441, 106, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { 1441, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1715, 11, 0 },
   { 1822, 16, 0 },
   { 1905, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3752, 2779, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2791, 2792, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1713, 11, 0 },
   { 1820, 16, 0 },
   { 1903, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1741, 1742, 0 },
   { 1764, 1765, 0 },
   { 1848, 1849, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1929, 1930, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1717, 11, 0 },
   { 1824, 16, 0 },
   { 1907, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3751, 2779, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2793, 2794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1716, 11, 0 },
   { 1823, 16, 0 },
   { 1906, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1739, 1740, 0 },
   { 1762, 1763, 0 },
   { 1846, 1847, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1927, 1928, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1744, 1745, 0 },
   { 1767, 1745, 0 },
   { 1850, 1743, 0 },
   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1736, 1333, 0 },
   { 1759, 1333, 0 },
   { 1843, 1337, 0 },
   { 3750, 1457, 0 },
   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { 5462, 5464, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { 5446, 5448, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { 5433, 5434, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1747, 1748, 0 },
   { 1769, 1748, 0 },
   { 1851, 1746, 0 },
   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1731, 11, 0 },
   { 1754, 11, 0 },
   { 1838, 16, 0 },
   { 2822, 16, 0 },
   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2815, 16, 0 },
   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2820, 1923, 0 },
   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2821, 1920, 0 },
   { 3767, 11, 0 },
   { 3768, 16, 0 },
   { 3769, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1921, 1922, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2809, 1333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5465, 5467, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5449, 5451, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5435, 5437, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1924, 1925, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2798, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2797, 1199, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5420, 5423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 998, 999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2442, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 992, 993, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 995, 996, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1001, 1002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1004, 1005, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1007, 1008, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1010, 1011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1013, 1014, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1016, 1017, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1019, 1020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 447, 448, 14 },
   { 451, 453, 14 },
   { 522, 523, 16 },
   { 524, 526, 16 },
   { 588, 589, 18 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 461, 464, 14 },
   { 522, 523, 16 },
   { 533, 535, 16 },
   { 588, 589, 18 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 279, 281, 0 },
   { 447, 448, 14 },
   { 451, 453, 14 },
   { 522, 523, 16 },
   { 524, 526, 16 },
   { 588, 589, 18 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 447, 448, 14 },
   { 461, 464, 14 },
   { 522, 523, 16 },
   { 533, 535, 16 },
   { 588, 589, 18 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 457, 459, 14 },
   { 524, 526, 16 },
   { 529, 531, 16 },
   { 592, 594, 18 },
   { 598, 600, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 457, 459, 14 },
   { 524, 526, 16 },
   { 529, 531, 16 },
   { 592, 594, 18 },
   { 598, 600, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 447, 448, 14 },
   { 451, 453, 14 },
   { 457, 459, 14 },
   { 522, 523, 16 },
   { 524, 526, 16 },
   { 529, 531, 16 },
   { 588, 589, 18 },
   { 592, 594, 18 },
   { 598, 600, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { 662, 664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { 662, 664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 461, 464, 14 },
   { 522, 523, 16 },
   { 533, 535, 16 },
   { 588, 589, 18 },
   { 602, 605, 18 },
   { 662, 664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1162, 1163, 0 },
   { 2425, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1162, 1163, 0 },
   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1350, 1351, 0 },
   { 1355, 1354, 0 },
   { 1372, 1373, 0 },
   { 1377, 1376, 0 },
   { 1394, 1395, 0 },
   { 1399, 1398, 0 },
   { 1414, 1415, 0 },
   { 1419, 1418, 0 },
   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { 5063, 5066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1072, 0 },
   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1358, 1351, 0 },
   { 1360, 1354, 0 },
   { 1380, 1373, 0 },
   { 1382, 1376, 0 },
   { 1402, 1395, 0 },
   { 1403, 1398, 0 },
   { 1422, 1415, 0 },
   { 1424, 1418, 0 },
   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1363, 1351, 0 },
   { 1365, 1354, 0 },
   { 1385, 1373, 0 },
   { 1387, 1376, 0 },
   { 1406, 1395, 0 },
   { 1407, 1398, 0 },
   { 1427, 1415, 0 },
   { 1429, 1418, 0 },
   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { 3904, 3909, 102 },
   { 3951, 3956, 102 },
   { 3997, 4002, 102 },
   { 4064, 4069, 103 },
   { 4115, 4120, 103 },
   { 4193, 4198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { 4247, 4250, 102 },
   { 4287, 4291, 102 },
   { 4329, 4334, 102 },
   { 4393, 4398, 103 },
   { 4438, 4443, 103 },
   { 4510, 4515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { 3458, 3455, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { 3454, 3455, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1318, 1103, 0 },
   { 1323, 1103, 0 },
   { 1327, 1103, 0 },
   { 1331, 1103, 0 },
   { 2425, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 3886, 3888, 102 },
   { 3943, 3888, 102 },
   { 3988, 3888, 102 },
   { 4035, 4036, 103 },
   { 4049, 4051, 103 },
   { 4100, 4036, 103 },
   { 4108, 4051, 103 },
   { 4152, 4153, 0 },
   { 4165, 4166, 0 },
   { 4178, 4180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 4231, 4233, 102 },
   { 4279, 4233, 102 },
   { 4321, 4233, 102 },
   { 4365, 4366, 103 },
   { 4378, 4380, 103 },
   { 4423, 4366, 103 },
   { 4431, 4380, 103 },
   { 4470, 4471, 0 },
   { 4483, 4484, 0 },
   { 4495, 4497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 2426, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1352, 1351, 0 },
   { 1353, 1354, 0 },
   { 1374, 1373, 0 },
   { 1375, 1376, 0 },
   { 1396, 1395, 0 },
   { 1397, 1398, 0 },
   { 1416, 1415, 0 },
   { 1417, 1418, 0 },
   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { 5067, 5070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1171, 706, 0 },
   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1357, 1354, 0 },
   { 1361, 1351, 0 },
   { 1379, 1376, 0 },
   { 1383, 1373, 0 },
   { 1401, 1398, 0 },
   { 1404, 1395, 0 },
   { 1421, 1418, 0 },
   { 1425, 1415, 0 },
   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1362, 1354, 0 },
   { 1366, 1351, 0 },
   { 1384, 1376, 0 },
   { 1388, 1373, 0 },
   { 1405, 1398, 0 },
   { 1408, 1395, 0 },
   { 1426, 1418, 0 },
   { 1430, 1415, 0 },
   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { 3910, 3913, 102 },
   { 3957, 3960, 102 },
   { 4003, 4006, 102 },
   { 4070, 4073, 103 },
   { 4121, 4124, 103 },
   { 4199, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { 4251, 4254, 102 },
   { 4292, 4295, 102 },
   { 4335, 4338, 102 },
   { 4399, 4402, 103 },
   { 4444, 4447, 103 },
   { 4516, 4519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { 3457, 3453, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { 3448, 3453, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 1320, 0 },
   { 1324, 1320, 0 },
   { 1328, 1320, 0 },
   { 1332, 1320, 0 },
   { 2426, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { 3889, 3890, 102 },
   { 3944, 3890, 102 },
   { 3989, 3890, 102 },
   { 4037, 4038, 103 },
   { 4052, 4053, 103 },
   { 4101, 4038, 103 },
   { 4109, 4053, 103 },
   { 4154, 4155, 0 },
   { 4167, 4168, 0 },
   { 4181, 4182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { 4234, 4235, 102 },
   { 4280, 4235, 102 },
   { 4322, 4235, 102 },
   { 4367, 4368, 103 },
   { 4381, 4382, 103 },
   { 4424, 4368, 103 },
   { 4432, 4382, 103 },
   { 4472, 4473, 0 },
   { 4485, 4486, 0 },
   { 4498, 4499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2208, 2209, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 1024, 0 },
   { 2427, 1024, 0 },
   { 2876, 1177, 0 },
   { 3399, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { 2876, 1177, 0 },
   { 3399, 3396, 72 },
   { 5113, 5116, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1024, 0 },
   { 2427, 1024, 0 },
   { 2876, 1177, 0 },
   { 3399, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1024, 0 },
   { 2272, 2273, 0 },
   { 2427, 1024, 0 },
   { 2876, 1177, 0 },
   { 3399, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2208, 2209, 0 },
   { 2427, 1024, 0 },
   { 2876, 1177, 0 },
   { 3399, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2208, 2209, 0 },
   { 2249, 2251, 0 },
   { 2427, 1024, 0 },
   { 2876, 1177, 0 },
   { 3399, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { 2876, 1177, 0 },
   { 3399, 3396, 72 },
   { 4261, 4266, 102 },
   { 4302, 4307, 102 },
   { 4346, 4352, 102 },
   { 4408, 4412, 103 },
   { 4454, 4459, 103 },
   { 4525, 4529, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1024, 0 },
   { 2427, 1024, 0 },
   { 2877, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 1024, 0 },
   { 2229, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1024, 0 },
   { 2229, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2208, 2209, 0 },
   { 2229, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { 2877, 1024, 0 },
   { 5109, 5112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 1032, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 1032, 0 },
   { 2427, 1024, 0 },
   { 2877, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 1032, 0 },
   { 2227, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 1032, 0 },
   { 2220, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2208, 2209, 0 },
   { 2210, 1032, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 1032, 0 },
   { 2253, 2255, 0 },
   { 2427, 1024, 0 },
   { 2877, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1024, 0 },
   { 2427, 1024, 0 },
   { 2877, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1024, 0 },
   { 2227, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1024, 0 },
   { 2221, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2208, 2209, 0 },
   { 2221, 1024, 0 },
   { 2427, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1024, 0 },
   { 2274, 2275, 0 },
   { 2427, 1024, 0 },
   { 2877, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { 2877, 1024, 0 },
   { 4255, 4260, 102 },
   { 4296, 4301, 102 },
   { 4339, 4345, 102 },
   { 4403, 4407, 103 },
   { 4448, 4453, 103 },
   { 4520, 4524, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { 4238, 4239, 102 },
   { 4245, 4246, 102 },
   { 4282, 4239, 102 },
   { 4286, 4246, 102 },
   { 4324, 4239, 102 },
   { 4328, 4246, 102 },
   { 4371, 4372, 103 },
   { 4376, 4377, 103 },
   { 4385, 4386, 103 },
   { 4391, 4392, 103 },
   { 4426, 4372, 103 },
   { 4429, 4377, 103 },
   { 4434, 4386, 103 },
   { 4437, 4392, 103 },
   { 4476, 4477, 0 },
   { 4481, 4482, 0 },
   { 4489, 4490, 0 },
   { 4493, 4494, 0 },
   { 4502, 4503, 0 },
   { 4508, 4509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 2223, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2428, 1177, 0 },
   { 5121, 5124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1177, 0 },
   { 2257, 2259, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 2223, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 2223, 0 },
   { 2276, 2277, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2428, 1177, 0 },
   { 4273, 4278, 102 },
   { 4314, 4319, 102 },
   { 4359, 4364, 102 },
   { 4418, 4422, 103 },
   { 4465, 4469, 103 },
   { 4535, 4539, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 1177, 0 },
   { 2231, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1177, 0 },
   { 2231, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 2223, 0 },
   { 2231, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2428, 1177, 0 },
   { 5117, 5120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 2225, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 2225, 0 },
   { 2230, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1177, 0 },
   { 2224, 2225, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 2223, 0 },
   { 2224, 2225, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 2225, 0 },
   { 2278, 2279, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2213, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2213, 1177, 0 },
   { 2230, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1177, 0 },
   { 2213, 1177, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2213, 1177, 0 },
   { 2222, 2223, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2213, 1177, 0 },
   { 2261, 2263, 0 },
   { 2428, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2428, 1177, 0 },
   { 4267, 4272, 102 },
   { 4308, 4313, 102 },
   { 4353, 4358, 102 },
   { 4413, 4417, 103 },
   { 4460, 4464, 103 },
   { 4530, 4534, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2428, 1177, 0 },
   { 4236, 4237, 102 },
   { 4242, 4244, 102 },
   { 4281, 4237, 102 },
   { 4285, 4244, 102 },
   { 4323, 4237, 102 },
   { 4327, 4244, 102 },
   { 4369, 4370, 103 },
   { 4374, 4375, 103 },
   { 4383, 4384, 103 },
   { 4388, 4390, 103 },
   { 4425, 4370, 103 },
   { 4428, 4375, 103 },
   { 4433, 4384, 103 },
   { 4436, 4390, 103 },
   { 4474, 4475, 0 },
   { 4479, 4480, 0 },
   { 4487, 4488, 0 },
   { 4491, 4492, 0 },
   { 4500, 4501, 0 },
   { 4505, 4507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3423, 3424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3421, 2448, 0 },
   { 3423, 3424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { 4595, 2977, 0 },
   { 4596, 2980, 0 },
   { 4598, 4456, 0 },
   { 4600, 1942, 0 },
   { 4601, 1958, 0 },
   { 4603, 4349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1737, 1321, 0 },
   { 1760, 1321, 0 },
   { 1844, 1325, 0 },
   { 3756, 2779, 0 },
   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { 5471, 5473, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { 5455, 5457, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { 5440, 5441, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1733, 11, 0 },
   { 1756, 11, 0 },
   { 1840, 16, 0 },
   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { 3775, 3776, 0 },
   { 3783, 3776, 0 },
   { 3789, 3776, 0 },
   { 3795, 3776, 0 },
   { 3800, 3801, 0 },
   { 3804, 3774, 0 },
   { 3808, 3774, 0 },
   { 3812, 3774, 0 },
   { 3816, 3817, 0 },
   { 3820, 3817, 0 },
   { 3822, 3823, 0 },
   { 3826, 3782, 0 },
   { 3830, 3782, 0 },
   { 3834, 3835, 0 },
   { 3838, 3835, 0 },
   { 3840, 3841, 0 },
   { 3843, 3835, 0 },
   { 3845, 3841, 0 },
   { 3847, 1732, 0 },
   { 3849, 3788, 0 },
   { 3853, 3854, 0 },
   { 3857, 3854, 0 },
   { 3859, 3860, 0 },
   { 3863, 3854, 0 },
   { 3865, 3860, 0 },
   { 3867, 1755, 0 },
   { 3869, 3854, 0 },
   { 3871, 3860, 0 },
   { 3873, 1755, 0 },
   { 3875, 1839, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { 3778, 3779, 0 },
   { 3785, 3779, 0 },
   { 3791, 3779, 0 },
   { 3797, 3779, 0 },
   { 3805, 3777, 0 },
   { 3809, 3777, 0 },
   { 3813, 3777, 0 },
   { 3827, 3784, 0 },
   { 3831, 3784, 0 },
   { 3850, 3790, 0 },
   { 4632, 11, 0 },
   { 4685, 16, 0 },
   { 4737, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2816, 16, 0 },
   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2818, 1934, 0 },
   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { 3877, 3878, 0 },
   { 3877, 3878, 0 },
   { 3879, 3880, 0 },
   { 3879, 3880, 0 },
   { 3881, 3760, 0 },
   { 3881, 3760, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1738, 1321, 0 },
   { 1761, 1321, 0 },
   { 1845, 1325, 0 },
   { 3754, 2779, 0 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { 5468, 5470, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { 5452, 5454, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { 5438, 5439, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2922, 2924, 54 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { 3780, 3776, 0 },
   { 3786, 3776, 0 },
   { 3792, 3776, 0 },
   { 3798, 3776, 0 },
   { 3806, 3774, 0 },
   { 3810, 3774, 0 },
   { 3814, 3774, 0 },
   { 3828, 3782, 0 },
   { 3832, 3782, 0 },
   { 3851, 3788, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1735, 11, 0 },
   { 1758, 11, 0 },
   { 1842, 16, 0 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { 3781, 3779, 0 },
   { 3787, 3779, 0 },
   { 3793, 3779, 0 },
   { 3799, 3779, 0 },
   { 3802, 3803, 0 },
   { 3807, 3777, 0 },
   { 3811, 3777, 0 },
   { 3815, 3777, 0 },
   { 3818, 3819, 0 },
   { 3821, 3819, 0 },
   { 3824, 3825, 0 },
   { 3829, 3784, 0 },
   { 3833, 3784, 0 },
   { 3836, 3837, 0 },
   { 3839, 3837, 0 },
   { 3842, 2952, 0 },
   { 3844, 3837, 0 },
   { 3846, 2952, 0 },
   { 3848, 1734, 0 },
   { 3852, 3790, 0 },
   { 3855, 3856, 0 },
   { 3858, 3856, 0 },
   { 3861, 3862, 0 },
   { 3864, 3856, 0 },
   { 3866, 3862, 0 },
   { 3868, 1757, 0 },
   { 3870, 3856, 0 },
   { 3872, 3862, 0 },
   { 3874, 1757, 0 },
   { 3876, 1841, 0 },
   { 4604, 11, 0 },
   { 4657, 16, 0 },
   { 4710, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2817, 16, 0 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2918, 2920, 54 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2819, 1931, 0 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { 3882, 1958, 0 },
   { 3882, 1958, 0 },
   { 3883, 2980, 0 },
   { 3883, 2980, 0 },
   { 3884, 3765, 0 },
   { 3884, 3765, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2888, 2979, 59 },
   { 2994, 2888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2880, 36, 0 },
   { 2888, 2979, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2896, 2980, 60 },
   { 2984, 2896, 0 },
   { 2896, 2980, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2896, 2980, 60 },
   { 2998, 2896, 0 },
   { 2999, 2898, 0 },
   { 2896, 2980, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2898, 2981, 60 },
   { 2991, 2898, 0 },
   { 2898, 2981, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3426, 3419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3428, 3419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3428, 3419, 0 },
   { 3436, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3426, 3419, 0 },
   { 3428, 3419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3429, 3416, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3430, 3416, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3430, 3416, 0 },
   { 3437, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3429, 3416, 0 },
   { 3430, 3416, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2982, 2983, 0 },
   { 2983, 3574, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2997, 2990, 0 },
   { 2983, 3574, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2995, 2983, 0 },
   { 2996, 2990, 0 },
   { 2983, 3574, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2989, 2990, 0 },
   { 2990, 3575, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3432, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3435, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3432, 3433, 0 },
   { 3435, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1024, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2201, 2202, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 5097, 5100, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1024, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1024, 0 },
   { 2264, 2265, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2201, 2202, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2201, 2202, 0 },
   { 2233, 2235, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 3923, 3929, 102 },
   { 3969, 3974, 102 },
   { 4016, 4022, 102 },
   { 4082, 4087, 103 },
   { 4133, 4139, 103 },
   { 4211, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 1418, 3392, 72 },
   { 5093, 5096, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1030, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1030, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 3385, 3387, 71 },
   { 1418, 3392, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1030, 0 },
   { 2214, 1024, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2201, 2202, 0 },
   { 2203, 1030, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1030, 0 },
   { 2237, 2239, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 3385, 3387, 71 },
   { 1418, 3392, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2215, 1024, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2215, 1024, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 3380, 3383, 71 },
   { 1418, 3392, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1024, 0 },
   { 2215, 1024, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2201, 2202, 0 },
   { 2215, 1024, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2215, 1024, 0 },
   { 2266, 2267, 0 },
   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 3380, 3383, 71 },
   { 1418, 3392, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 1418, 3392, 72 },
   { 3914, 3921, 102 },
   { 3961, 3968, 102 },
   { 4007, 4014, 102 },
   { 4074, 4081, 103 },
   { 4125, 4132, 103 },
   { 4203, 4210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 3893, 3894, 102 },
   { 3902, 3903, 102 },
   { 3946, 3894, 102 },
   { 3950, 3903, 102 },
   { 3991, 3894, 102 },
   { 3995, 3903, 102 },
   { 4041, 4042, 103 },
   { 4046, 4047, 103 },
   { 4056, 4057, 103 },
   { 4062, 4063, 103 },
   { 4103, 4042, 103 },
   { 4106, 4047, 103 },
   { 4111, 4057, 103 },
   { 4114, 4063, 103 },
   { 4158, 4159, 0 },
   { 4163, 4164, 0 },
   { 4171, 4172, 0 },
   { 4175, 4176, 0 },
   { 4185, 4186, 0 },
   { 4191, 4192, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 1177, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 5105, 5108, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 1177, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 1177, 0 },
   { 2241, 2243, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2268, 2269, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 3936, 3941, 102 },
   { 3981, 3986, 102 },
   { 4029, 4034, 102 },
   { 4094, 4099, 103 },
   { 4146, 4151, 103 },
   { 4224, 4229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 1415, 3393, 72 },
   { 5101, 5104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2218, 2219, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2218, 2219, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 3390, 3391, 71 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 1177, 0 },
   { 2218, 2219, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2218, 2219, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2218, 2219, 0 },
   { 2270, 2271, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 3390, 3391, 71 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2206, 1177, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2206, 1177, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 3388, 3389, 71 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 1177, 0 },
   { 2206, 1177, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2206, 1177, 0 },
   { 2216, 2217, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2206, 1177, 0 },
   { 2245, 2247, 0 },
   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 3388, 3389, 71 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 1415, 3393, 72 },
   { 3930, 3935, 102 },
   { 3975, 3980, 102 },
   { 4023, 4028, 102 },
   { 4088, 4093, 103 },
   { 4140, 4145, 103 },
   { 4218, 4223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 3891, 3892, 102 },
   { 3899, 3901, 102 },
   { 3945, 3892, 102 },
   { 3949, 3901, 102 },
   { 3990, 3892, 102 },
   { 3994, 3901, 102 },
   { 4039, 4040, 103 },
   { 4044, 4045, 103 },
   { 4054, 4055, 103 },
   { 4059, 4061, 103 },
   { 4102, 4040, 103 },
   { 4105, 4045, 103 },
   { 4110, 4055, 103 },
   { 4113, 4061, 103 },
   { 4156, 4157, 0 },
   { 4161, 4162, 0 },
   { 4169, 4170, 0 },
   { 4173, 4174, 0 },
   { 4183, 4184, 0 },
   { 4188, 4190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3577, 3579, 91 },
   { 5424, 5427, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2342, 2347, 44 },
   { 5008, 2377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2342, 2347, 44 },
   { 5007, 2342, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2354, 44 },
   { 5014, 2381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2354, 44 },
   { 5013, 2348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 2361, 44 },
   { 5018, 2387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 2361, 44 },
   { 5017, 2355, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5023, 5024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5021, 5022, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5031, 5032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5029, 5030, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2811, 1321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2801, 2802, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2812, 1321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2803, 2804, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3753, 1457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1749, 1750, 0 },
   { 1770, 1771, 0 },
   { 1852, 1853, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1938, 1939, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3755, 1457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1710, 1711, 0 },
   { 1817, 1818, 0 },
   { 1900, 1901, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1751, 1752, 0 },
   { 1772, 1773, 0 },
   { 1854, 1855, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1940, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2810, 1321, 0 },
   { 2810, 1321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5474, 5476, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5458, 5460, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5442, 5444, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1935, 1936, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1932, 1933, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2799, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2800, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2813, 1333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2805, 2806, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2814, 1333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2807, 2808, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 722, 724, 32 },
   { 734, 735, 0 },
   { 750, 751, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 722, 724, 32 },
   { 729, 731, 0 },
   { 734, 735, 0 },
   { 750, 751, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 722, 724, 32 },
   { 726, 249, 0 },
   { 729, 731, 0 },
   { 734, 735, 0 },
   { 750, 751, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 739, 731, 0 },
   { 748, 749, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 737, 249, 0 },
   { 739, 731, 0 },
   { 748, 749, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 741, 249, 0 },
   { 746, 747, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 741, 249, 0 },
   { 742, 745, 0 },
   { 746, 747, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2168, 2169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2362, 2365, 44 },
   { 5012, 2392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2362, 2365, 44 },
   { 5011, 2362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 2371, 44 },
   { 5016, 2396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 2371, 44 },
   { 5015, 2366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 2376, 44 },
   { 5020, 2402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 2376, 44 },
   { 5019, 2372, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5027, 5028, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5025, 5026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5035, 5036, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5033, 5034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1281, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1265, 61, 0 },
   { 1266, 32, 0 },
   { 1281, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1265, 61, 0 },
   { 1266, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1281, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { 1273, 1274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { 1268, 32, 0 },
   { 1269, 63, 0 },
   { 1273, 1274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2967, 2968, 0 },
   { 3504, 3507, 81 },
   { 4711, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2969, 2968, 0 },
   { 3504, 3507, 81 },
   { 4711, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3015, 3011, 0 },
   { 3504, 3507, 81 },
   { 4711, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2290, 2296, 43 },
   { 2302, 2286, 0 },
   { 2310, 2288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2290, 2296, 43 },
   { 2303, 2288, 0 },
   { 2311, 2286, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2290, 2296, 43 },
   { 2299, 2290, 0 },
   { 2308, 2292, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2290, 2296, 43 },
   { 2301, 2292, 0 },
   { 2309, 2290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2292, 2297, 43 },
   { 2306, 2286, 0 },
   { 2314, 2288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2292, 2297, 43 },
   { 2307, 2288, 0 },
   { 2315, 2286, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2292, 2297, 43 },
   { 2304, 2290, 0 },
   { 2312, 2292, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2292, 2297, 43 },
   { 2305, 2292, 0 },
   { 2313, 2290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2759, 36, 0 },
   { 3624, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2759, 36, 0 },
   { 3621, 3622, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2759, 36, 0 },
   { 3621, 3622, 100 },
   { 3624, 3625, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2759, 36, 0 },
   { 3627, 3628, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2759, 36, 0 },
   { 3630, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2759, 36, 0 },
   { 3627, 3628, 100 },
   { 3630, 3631, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2489, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2542, 2543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2534, 2535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2537, 2538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2540, 2541, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2525, 2527, 0 },
   { 2507, 2561, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2528, 2529, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2560, 2539, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2559, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2562, 2507, 51 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2530, 2533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2487, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2490, 2493, 47 },
   { 2515, 32, 0 },
   { 2516, 236, 0 },
   { 2517, 2514, 0 },
   { 2522, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2881, 2882, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2884, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2893, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2895, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2886, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 196, 3, 0 },
   { 3193, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 196, 3, 0 },
   { 3193, 3194, 0 },
   { 3235, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4618, 3670, 0 },
   { 4672, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4618, 3670, 0 },
   { 4643, 3670, 0 },
   { 4672, 3690, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4618, 3670, 0 },
   { 4641, 3670, 0 },
   { 4672, 3690, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4617, 3670, 0 },
   { 4618, 3670, 0 },
   { 4671, 3690, 0 },
   { 4672, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4615, 3670, 0 },
   { 4618, 3670, 0 },
   { 4669, 3690, 0 },
   { 4672, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4644, 3670, 0 },
   { 4697, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 3670, 0 },
   { 4644, 3670, 0 },
   { 4696, 3690, 0 },
   { 4697, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 3670, 0 },
   { 4644, 3670, 0 },
   { 4694, 3690, 0 },
   { 4697, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4617, 3670, 0 },
   { 4644, 3670, 0 },
   { 4671, 3690, 0 },
   { 4697, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4615, 3670, 0 },
   { 4644, 3670, 0 },
   { 4669, 3690, 0 },
   { 4697, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { 4749, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4724, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4724, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { 4724, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4643, 3670, 0 },
   { 4696, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4641, 3670, 0 },
   { 4694, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4617, 3670, 0 },
   { 4671, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4615, 3670, 0 },
   { 4669, 3690, 0 },
   { 4721, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 3670, 0 },
   { 4643, 3670, 0 },
   { 4694, 3690, 0 },
   { 4696, 3690, 0 },
   { 4746, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4617, 3670, 0 },
   { 4643, 3670, 0 },
   { 4671, 3690, 0 },
   { 4696, 3690, 0 },
   { 4723, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4615, 3670, 0 },
   { 4643, 3670, 0 },
   { 4669, 3690, 0 },
   { 4696, 3690, 0 },
   { 4721, 3690, 0 },
   { 4748, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4617, 3670, 0 },
   { 4641, 3670, 0 },
   { 4671, 3690, 0 },
   { 4694, 3690, 0 },
   { 4723, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4615, 3670, 0 },
   { 4641, 3670, 0 },
   { 4669, 3690, 0 },
   { 4694, 3690, 0 },
   { 4721, 3690, 0 },
   { 4746, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4615, 3670, 0 },
   { 4617, 3670, 0 },
   { 4669, 3690, 0 },
   { 4671, 3690, 0 },
   { 4721, 3690, 0 },
   { 4723, 3690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3008, 3009, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4646, 4620, 0 },
   { 4699, 49, 0 },
   { 4751, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4645, 4620, 0 },
   { 4698, 49, 0 },
   { 4750, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4621, 4620, 0 },
   { 4674, 49, 0 },
   { 4726, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4619, 4620, 0 },
   { 4673, 49, 0 },
   { 4725, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 979, 983, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 971, 974, 0 },
   { 979, 983, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4646, 4620, 0 },
   { 4699, 49, 0 },
   { 4751, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4645, 4620, 0 },
   { 4698, 49, 0 },
   { 4750, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4621, 4620, 0 },
   { 4674, 49, 0 },
   { 4726, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4619, 4620, 0 },
   { 4673, 49, 0 },
   { 4725, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { 4646, 4620, 0 },
   { 4699, 49, 0 },
   { 4751, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { 4645, 4620, 0 },
   { 4698, 49, 0 },
   { 4750, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { 4621, 4620, 0 },
   { 4674, 49, 0 },
   { 4726, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { 4619, 4620, 0 },
   { 4673, 49, 0 },
   { 4725, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 4620, 0 },
   { 4646, 4620, 0 },
   { 4675, 49, 0 },
   { 4699, 49, 0 },
   { 4751, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 4620, 0 },
   { 4645, 4620, 0 },
   { 4675, 49, 0 },
   { 4698, 49, 0 },
   { 4750, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4621, 4620, 0 },
   { 4622, 4620, 0 },
   { 4674, 49, 0 },
   { 4675, 49, 0 },
   { 4726, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4619, 4620, 0 },
   { 4622, 4620, 0 },
   { 4673, 49, 0 },
   { 4675, 49, 0 },
   { 4725, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4646, 4620, 0 },
   { 4647, 4620, 0 },
   { 4699, 49, 0 },
   { 4700, 49, 0 },
   { 4751, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4645, 4620, 0 },
   { 4647, 4620, 0 },
   { 4698, 49, 0 },
   { 4700, 49, 0 },
   { 4750, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4621, 4620, 0 },
   { 4647, 4620, 0 },
   { 4674, 49, 0 },
   { 4700, 49, 0 },
   { 4726, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4619, 4620, 0 },
   { 4647, 4620, 0 },
   { 4673, 49, 0 },
   { 4700, 49, 0 },
   { 4725, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4646, 4620, 0 },
   { 4699, 49, 0 },
   { 4751, 49, 0 },
   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4645, 4620, 0 },
   { 4698, 49, 0 },
   { 4750, 49, 0 },
   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4621, 4620, 0 },
   { 4674, 49, 0 },
   { 4726, 49, 0 },
   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4619, 4620, 0 },
   { 4673, 49, 0 },
   { 4725, 49, 0 },
   { 4752, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4646, 4620, 0 },
   { 4699, 49, 0 },
   { 4727, 49, 0 },
   { 4751, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4645, 4620, 0 },
   { 4698, 49, 0 },
   { 4727, 49, 0 },
   { 4750, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4621, 4620, 0 },
   { 4674, 49, 0 },
   { 4726, 49, 0 },
   { 4727, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4619, 4620, 0 },
   { 4673, 49, 0 },
   { 4725, 49, 0 },
   { 4727, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4645, 4620, 0 },
   { 4646, 4620, 0 },
   { 4698, 49, 0 },
   { 4699, 49, 0 },
   { 4750, 49, 0 },
   { 4751, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4621, 4620, 0 },
   { 4646, 4620, 0 },
   { 4674, 49, 0 },
   { 4699, 49, 0 },
   { 4726, 49, 0 },
   { 4751, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4619, 4620, 0 },
   { 4646, 4620, 0 },
   { 4673, 49, 0 },
   { 4699, 49, 0 },
   { 4725, 49, 0 },
   { 4751, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4621, 4620, 0 },
   { 4645, 4620, 0 },
   { 4674, 49, 0 },
   { 4698, 49, 0 },
   { 4726, 49, 0 },
   { 4750, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4619, 4620, 0 },
   { 4645, 4620, 0 },
   { 4673, 49, 0 },
   { 4698, 49, 0 },
   { 4725, 49, 0 },
   { 4750, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4619, 4620, 0 },
   { 4621, 4620, 0 },
   { 4673, 49, 0 },
   { 4674, 49, 0 },
   { 4725, 49, 0 },
   { 4726, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 860, 863, 0 },
   { 868, 871, 0 },
   { 876, 878, 0 },
   { 883, 886, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 864, 863, 0 },
   { 872, 871, 0 },
   { 879, 878, 0 },
   { 887, 886, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 985, 988, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 762, 766, 0 },
   { 967, 969, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 967, 969, 0 },
   { 985, 988, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2456, 32, 0 },
   { 3002, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2459, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 865, 867, 0 },
   { 873, 875, 0 },
   { 880, 882, 0 },
   { 888, 890, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { 3005, 3001, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1097, 1096, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1101, 1100, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1052, 1053, 0 },
   { 1154, 1157, 0 },
   { 2408, 1199, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1095, 1096, 0 },
   { 1131, 1132, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1099, 1100, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1098, 1096, 0 },
   { 2408, 1199, 0 },
   { 2432, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1038, 1039, 0 },
   { 1105, 1103, 0 },
   { 2408, 1199, 0 },
   { 2432, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1082, 1079, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1089, 1087, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1050, 1051, 0 },
   { 1160, 1161, 0 },
   { 2407, 1195, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1078, 1079, 0 },
   { 1133, 1134, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1086, 1087, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1079, 0 },
   { 2407, 1195, 0 },
   { 2433, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1040, 1041, 0 },
   { 1094, 1092, 0 },
   { 2407, 1195, 0 },
   { 2433, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { 5130, 5133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 240, 238, 0 },
   { 3151, 3153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 240, 238, 0 },
   { 3151, 3153, 0 },
   { 3196, 3153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3138, 3139, 0 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 238, 0 },
   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 364, 365, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 364, 365, 9 },
   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 372, 373, 9 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 500, 501, 0 },
   { 505, 506, 0 },
   { 568, 569, 0 },
   { 572, 573, 0 },
   { 640, 641, 0 },
   { 644, 645, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 511, 513, 0 },
   { 577, 579, 0 },
   { 650, 652, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 370, 371, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 370, 371, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 370, 371, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 370, 371, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 370, 371, 9 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 370, 371, 9 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 370, 371, 9 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 370, 371, 9 },
   { 372, 373, 9 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4652, 1998, 0 },
   { 4705, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4651, 1998, 0 },
   { 4704, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 4652, 1998, 0 },
   { 4705, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 4651, 1998, 0 },
   { 4704, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2438, 32, 0 },
   { 2439, 1177, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2468, 2465, 45 },
   { 2475, 2472, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 4652, 1998, 0 },
   { 4705, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 4651, 1998, 0 },
   { 4704, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { 4652, 1998, 0 },
   { 4705, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { 4651, 1998, 0 },
   { 4704, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2480, 2478, 45 },
   { 2485, 2483, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 4652, 1998, 0 },
   { 4705, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 4651, 1998, 0 },
   { 4704, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 63, 0 },
   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1645, 1648, 0 },
   { 1652, 1648, 0 },
   { 1657, 1660, 0 },
   { 1664, 1660, 0 },
   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4652, 1998, 0 },
   { 4705, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4651, 1998, 0 },
   { 4704, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 4652, 1998, 0 },
   { 4705, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 4651, 1998, 0 },
   { 4704, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 1177, 0 },
   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4652, 1998, 0 },
   { 4681, 2002, 0 },
   { 4705, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4628, 1998, 0 },
   { 4651, 1998, 0 },
   { 4681, 2002, 0 },
   { 4704, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4628, 1998, 0 },
   { 4680, 2002, 0 },
   { 4681, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4628, 1998, 0 },
   { 4679, 2002, 0 },
   { 4681, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4652, 1998, 0 },
   { 4653, 1998, 0 },
   { 4705, 2002, 0 },
   { 4706, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4651, 1998, 0 },
   { 4653, 1998, 0 },
   { 4704, 2002, 0 },
   { 4706, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4653, 1998, 0 },
   { 4680, 2002, 0 },
   { 4706, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4653, 1998, 0 },
   { 4679, 2002, 0 },
   { 4706, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4652, 1998, 0 },
   { 4705, 2002, 0 },
   { 4757, 2002, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4651, 1998, 0 },
   { 4704, 2002, 0 },
   { 4756, 2002, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { 4758, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4652, 1998, 0 },
   { 4705, 2002, 0 },
   { 4733, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4651, 1998, 0 },
   { 4704, 2002, 0 },
   { 4733, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { 4733, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2468, 2465, 45 },
   { 2475, 2472, 45 },
   { 2480, 2478, 45 },
   { 2485, 2483, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4680, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2770, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4651, 1998, 0 },
   { 4652, 1998, 0 },
   { 4704, 2002, 0 },
   { 4705, 2002, 0 },
   { 4756, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4652, 1998, 0 },
   { 4680, 2002, 0 },
   { 4705, 2002, 0 },
   { 4732, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4652, 1998, 0 },
   { 4679, 2002, 0 },
   { 4705, 2002, 0 },
   { 4731, 2002, 0 },
   { 4757, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4627, 1998, 0 },
   { 4651, 1998, 0 },
   { 4680, 2002, 0 },
   { 4704, 2002, 0 },
   { 4732, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4651, 1998, 0 },
   { 4679, 2002, 0 },
   { 4704, 2002, 0 },
   { 4731, 2002, 0 },
   { 4756, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4627, 1998, 0 },
   { 4679, 2002, 0 },
   { 4680, 2002, 0 },
   { 4731, 2002, 0 },
   { 4732, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4626, 1998, 0 },
   { 4679, 2002, 0 },
   { 4731, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 3010, 3009, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3726, 3727, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3732, 3733, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3738, 3739, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3721, 3724, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3729, 3730, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3735, 3736, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4649, 1956, 0 },
   { 4702, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4648, 1956, 0 },
   { 4701, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4624, 1956, 0 },
   { 4677, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2446, 3, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2446, 3, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2781, 1457, 0 },
   { 2782, 2779, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { 4649, 1956, 0 },
   { 4702, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { 4648, 1956, 0 },
   { 4701, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { 4624, 1956, 0 },
   { 4677, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1945, 1948, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 2447, 2448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { 4649, 1956, 0 },
   { 4702, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { 4648, 1956, 0 },
   { 4701, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { 4624, 1956, 0 },
   { 4677, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2447, 2448, 0 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 184, 0 },
   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4649, 1956, 0 },
   { 4702, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4648, 1956, 0 },
   { 4701, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4624, 1956, 0 },
   { 4677, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 2451, 2452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2047, 2049, 39 },
   { 2047, 2055, 41 },
   { 2073, 2075, 39 },
   { 2073, 2081, 41 },
   { 2099, 2101, 39 },
   { 2099, 2107, 41 },
   { 2124, 2126, 39 },
   { 2124, 2132, 41 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1029, 1024, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4625, 1956, 0 },
   { 4678, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4625, 1956, 0 },
   { 4649, 1956, 0 },
   { 4678, 1964, 0 },
   { 4702, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4625, 1956, 0 },
   { 4648, 1956, 0 },
   { 4678, 1964, 0 },
   { 4701, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4624, 1956, 0 },
   { 4625, 1956, 0 },
   { 4677, 1964, 0 },
   { 4678, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4625, 1956, 0 },
   { 4676, 1964, 0 },
   { 4678, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4650, 1956, 0 },
   { 4703, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4649, 1956, 0 },
   { 4650, 1956, 0 },
   { 4702, 1964, 0 },
   { 4703, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4648, 1956, 0 },
   { 4650, 1956, 0 },
   { 4701, 1964, 0 },
   { 4703, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4624, 1956, 0 },
   { 4650, 1956, 0 },
   { 4677, 1964, 0 },
   { 4703, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4650, 1956, 0 },
   { 4676, 1964, 0 },
   { 4703, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4649, 1956, 0 },
   { 4702, 1964, 0 },
   { 4754, 1964, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4648, 1956, 0 },
   { 4701, 1964, 0 },
   { 4753, 1964, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4624, 1956, 0 },
   { 4677, 1964, 0 },
   { 4729, 1964, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { 4755, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4649, 1956, 0 },
   { 4702, 1964, 0 },
   { 4730, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4648, 1956, 0 },
   { 4701, 1964, 0 },
   { 4730, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4624, 1956, 0 },
   { 4677, 1964, 0 },
   { 4729, 1964, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { 4730, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4649, 1956, 0 },
   { 4702, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4648, 1956, 0 },
   { 4701, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4624, 1956, 0 },
   { 4677, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2446, 3, 0 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 2768, 2769, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 4649, 1956, 0 },
   { 4702, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 4648, 1956, 0 },
   { 4701, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 4624, 1956, 0 },
   { 4677, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1347, 1348, 0 },
   { 1369, 1370, 0 },
   { 1391, 1392, 0 },
   { 1411, 1412, 0 },
   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4649, 1956, 0 },
   { 4702, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4648, 1956, 0 },
   { 4701, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4624, 1956, 0 },
   { 4677, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2047, 2049, 39 },
   { 2047, 2055, 41 },
   { 2073, 2075, 39 },
   { 2073, 2081, 41 },
   { 2099, 2101, 39 },
   { 2099, 2107, 41 },
   { 2124, 2126, 39 },
   { 2124, 2132, 41 },
   { 2434, 32, 0 },
   { 2901, 2903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4648, 1956, 0 },
   { 4649, 1956, 0 },
   { 4701, 1964, 0 },
   { 4702, 1964, 0 },
   { 4753, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4624, 1956, 0 },
   { 4649, 1956, 0 },
   { 4677, 1964, 0 },
   { 4702, 1964, 0 },
   { 4729, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4649, 1956, 0 },
   { 4676, 1964, 0 },
   { 4702, 1964, 0 },
   { 4728, 1964, 0 },
   { 4754, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4624, 1956, 0 },
   { 4648, 1956, 0 },
   { 4677, 1964, 0 },
   { 4701, 1964, 0 },
   { 4729, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4648, 1956, 0 },
   { 4676, 1964, 0 },
   { 4701, 1964, 0 },
   { 4728, 1964, 0 },
   { 4753, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4624, 1956, 0 },
   { 4676, 1964, 0 },
   { 4677, 1964, 0 },
   { 4728, 1964, 0 },
   { 4729, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 32, 0 },
   { 4623, 1956, 0 },
   { 4676, 1964, 0 },
   { 4728, 1964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 2284, 0 },
   { 2830, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2891, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1109, 1079, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1042, 1043, 0 },
   { 1197, 1195, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1042, 1043, 0 },
   { 1141, 1144, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1042, 1043, 0 },
   { 2422, 706, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 1219, 996, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 1136, 1139, 0 },
   { 1219, 996, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1111, 1096, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1046, 1047, 0 },
   { 1200, 1199, 0 },
   { 1200, 1199, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1046, 1047, 0 },
   { 1147, 1148, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1046, 1047, 0 },
   { 1074, 1072, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1434, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1510, 1512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1303, 1305, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1434, 1196, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1510, 1512, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1303, 1305, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1303, 1305, 0 },
   { 1431, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1434, 1196, 0 },
   { 1436, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1436, 32, 0 },
   { 1510, 1512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1303, 1305, 0 },
   { 1436, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1431, 1196, 0 },
   { 1434, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1431, 1196, 0 },
   { 1510, 1512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1434, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1510, 1512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1303, 1305, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1434, 1196, 0 },
   { 1510, 1512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1303, 1305, 0 },
   { 1431, 1196, 0 },
   { 1434, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1303, 1305, 0 },
   { 1431, 1196, 0 },
   { 1510, 1512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1438, 32, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1442, 103, 0 },
   { 1504, 1507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1288, 1290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1438, 32, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1442, 103, 0 },
   { 1504, 1507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1516, 1517, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1448, 202, 34 },
   { 1453, 1451, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1288, 1290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1288, 1290, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1438, 32, 0 },
   { 1440, 103, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1440, 103, 0 },
   { 1442, 103, 0 },
   { 1504, 1507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1440, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1288, 1290, 0 },
   { 1440, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1438, 32, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1442, 103, 0 },
   { 1504, 1507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1438, 32, 0 },
   { 1442, 103, 0 },
   { 1504, 1507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1438, 32, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1288, 1290, 0 },
   { 1438, 32, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1209, 0 },
   { 1261, 32, 0 },
   { 1442, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1442, 103, 0 },
   { 1504, 1507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1288, 1290, 0 },
   { 1442, 103, 0 },
   { 1504, 1507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1271, 1223, 0 },
   { 1288, 1290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1446, 36 },
   { 1462, 1464, 34 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1446, 36 },
   { 1467, 1469, 34 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1446, 36 },
   { 1472, 1474, 37 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1446, 36 },
   { 1476, 1480, 34 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1446, 36 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1446, 36 },
   { 2415, 1205, 0 },
   { 2832, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 678, 674, 22 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 3, 0 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 3211, 3214, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 3220, 3224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 3230, 3233, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 756, 758, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 678, 674, 22 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 201, 3, 0 },
   { 3178, 3180, 0 },
   { 3182, 3180, 0 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 201, 3, 0 },
   { 3178, 3180, 0 },
   { 3182, 3180, 0 },
   { 3209, 3180, 0 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 201, 3, 0 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 678, 674, 22 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 201, 3, 0 },
   { 678, 674, 22 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2490, 2493, 47 },
   { 2515, 32, 0 },
   { 2516, 236, 0 },
   { 2517, 2514, 0 },
   { 2524, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2494, 2490, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2494, 2490, 48 },
   { 2506, 2507, 0 },
   { 2510, 236, 0 },
   { 2513, 2514, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { 1435, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1313, 1315, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { 1435, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1313, 1315, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1313, 1315, 0 },
   { 1432, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { 1435, 1433, 0 },
   { 1437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1313, 1315, 0 },
   { 1437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1432, 1433, 0 },
   { 1435, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { 1435, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1313, 1315, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1313, 1315, 0 },
   { 1432, 1433, 0 },
   { 1435, 1433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { 2784, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1439, 32, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { 1298, 1300, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1439, 32, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 3581, 3577, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { 1298, 1300, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { 1298, 1300, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1439, 32, 0 },
   { 1441, 106, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1441, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { 1298, 1300, 0 },
   { 1441, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { 1439, 32, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1439, 32, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { 1298, 1300, 0 },
   { 1439, 32, 0 },
   { 1443, 106, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1443, 106, 35 },
   { 2783, 2769, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 32, 0 },
   { 1276, 1277, 0 },
   { 1298, 1300, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1024, 0 },
   { 2777, 706, 0 },
   { 2872, 1024, 0 },
   { 2873, 1177, 0 },
   { 2874, 1177, 0 },
   { 1418, 3392, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 1024, 0 },
   { 2778, 706, 0 },
   { 2876, 1177, 0 },
   { 3399, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 1177, 0 },
   { 2776, 1072, 0 },
   { 2869, 1177, 0 },
   { 2870, 1024, 0 },
   { 2871, 1024, 0 },
   { 1415, 3393, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 1177, 0 },
   { 2721, 706, 0 },
   { 2724, 1072, 0 },
   { 2772, 1072, 0 },
   { 2773, 706, 0 },
   { 2868, 1024, 0 },
   { 3397, 3398, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 1024, 0 },
   { 2722, 1072, 0 },
   { 2723, 706, 0 },
   { 2774, 706, 0 },
   { 2775, 1072, 0 },
   { 2867, 1177, 0 },
   { 3394, 3396, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2167, 1320, 0 },
   { 2426, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1281, 1282, 0 },
   { 1308, 1310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1265, 61, 0 },
   { 1266, 32, 0 },
   { 1281, 1282, 0 },
   { 1308, 1310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1281, 1282, 0 },
   { 1308, 1310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 2786, 2769, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { 1273, 1274, 0 },
   { 1293, 1295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { 1268, 32, 0 },
   { 1269, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { 1268, 32, 0 },
   { 1269, 63, 0 },
   { 1273, 1274, 0 },
   { 1293, 1295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { 1273, 1274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { 2785, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 32, 0 },
   { 1273, 1274, 0 },
   { 1293, 1295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2727, 1058, 0 },
   { 2728, 665, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3643, 3625, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3643, 3625, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1222, 1223, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3642, 3622, 100 },
   { 3643, 3625, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3647, 3631, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3647, 3631, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 1227, 1228, 0 },
   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3645, 3628, 100 },
   { 3647, 3631, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2282, 2283, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3635, 3636, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3635, 3636, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2282, 2283, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3633, 3634, 100 },
   { 3635, 3636, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3640, 3641, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3640, 3641, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4637, 4609, 0 },
   { 4690, 4662, 0 },
   { 4742, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4635, 4609, 0 },
   { 4688, 4662, 0 },
   { 4740, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4612, 4609, 0 },
   { 4665, 4662, 0 },
   { 4717, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1236, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3285, 3287, 0 },
   { 3637, 3638, 100 },
   { 3640, 3641, 100 },
   { 4608, 4609, 0 },
   { 4661, 4662, 0 },
   { 4714, 4662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3256, 3254, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3259, 3257, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1079, 0 },
   { 1258, 1087, 0 },
   { 1259, 1087, 0 },
   { 2758, 3, 0 },
   { 3262, 3260, 0 },
   { 3637, 3638, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3443, 3441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3446, 3441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1521, 1520, 0 },
   { 3495, 3498, 80 },
   { 4605, 11, 0 },
   { 4658, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4655, 2022, 0 },
   { 4708, 2026, 0 },
   { 4760, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4654, 2022, 0 },
   { 4707, 2026, 0 },
   { 4759, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4630, 2022, 0 },
   { 4683, 2026, 0 },
   { 4735, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4629, 2022, 0 },
   { 4682, 2026, 0 },
   { 4734, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { 4655, 2022, 0 },
   { 4708, 2026, 0 },
   { 4760, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { 4654, 2022, 0 },
   { 4707, 2026, 0 },
   { 4759, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { 4630, 2022, 0 },
   { 4683, 2026, 0 },
   { 4735, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 2441, 32, 0 },
   { 4629, 2022, 0 },
   { 4682, 2026, 0 },
   { 4734, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4631, 2022, 0 },
   { 4655, 2022, 0 },
   { 4684, 2026, 0 },
   { 4708, 2026, 0 },
   { 4760, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4631, 2022, 0 },
   { 4654, 2022, 0 },
   { 4684, 2026, 0 },
   { 4707, 2026, 0 },
   { 4759, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4630, 2022, 0 },
   { 4631, 2022, 0 },
   { 4683, 2026, 0 },
   { 4684, 2026, 0 },
   { 4735, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4629, 2022, 0 },
   { 4631, 2022, 0 },
   { 4682, 2026, 0 },
   { 4684, 2026, 0 },
   { 4734, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4655, 2022, 0 },
   { 4656, 2022, 0 },
   { 4708, 2026, 0 },
   { 4709, 2026, 0 },
   { 4760, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4654, 2022, 0 },
   { 4656, 2022, 0 },
   { 4707, 2026, 0 },
   { 4709, 2026, 0 },
   { 4759, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4630, 2022, 0 },
   { 4656, 2022, 0 },
   { 4683, 2026, 0 },
   { 4709, 2026, 0 },
   { 4735, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4629, 2022, 0 },
   { 4656, 2022, 0 },
   { 4682, 2026, 0 },
   { 4709, 2026, 0 },
   { 4734, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4655, 2022, 0 },
   { 4708, 2026, 0 },
   { 4760, 2026, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4654, 2022, 0 },
   { 4707, 2026, 0 },
   { 4759, 2026, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4630, 2022, 0 },
   { 4683, 2026, 0 },
   { 4735, 2026, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4629, 2022, 0 },
   { 4682, 2026, 0 },
   { 4734, 2026, 0 },
   { 4761, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4655, 2022, 0 },
   { 4708, 2026, 0 },
   { 4736, 2026, 0 },
   { 4760, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4654, 2022, 0 },
   { 4707, 2026, 0 },
   { 4736, 2026, 0 },
   { 4759, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4630, 2022, 0 },
   { 4683, 2026, 0 },
   { 4735, 2026, 0 },
   { 4736, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4629, 2022, 0 },
   { 4682, 2026, 0 },
   { 4734, 2026, 0 },
   { 4736, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4654, 2022, 0 },
   { 4655, 2022, 0 },
   { 4707, 2026, 0 },
   { 4708, 2026, 0 },
   { 4759, 2026, 0 },
   { 4760, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4630, 2022, 0 },
   { 4655, 2022, 0 },
   { 4683, 2026, 0 },
   { 4708, 2026, 0 },
   { 4735, 2026, 0 },
   { 4760, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4629, 2022, 0 },
   { 4655, 2022, 0 },
   { 4682, 2026, 0 },
   { 4708, 2026, 0 },
   { 4734, 2026, 0 },
   { 4760, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4630, 2022, 0 },
   { 4654, 2022, 0 },
   { 4683, 2026, 0 },
   { 4707, 2026, 0 },
   { 4735, 2026, 0 },
   { 4759, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4629, 2022, 0 },
   { 4654, 2022, 0 },
   { 4682, 2026, 0 },
   { 4707, 2026, 0 },
   { 4734, 2026, 0 },
   { 4759, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4629, 2022, 0 },
   { 4630, 2022, 0 },
   { 4682, 2026, 0 },
   { 4683, 2026, 0 },
   { 4734, 2026, 0 },
   { 4735, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 61, 0 },
   { 4629, 2022, 0 },
   { 4682, 2026, 0 },
   { 4734, 2026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1735, 11, 0 },
   { 1758, 11, 0 },
   { 1842, 16, 0 },
   { 1951, 1948, 0 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { 3781, 3779, 0 },
   { 3787, 3779, 0 },
   { 3793, 3779, 0 },
   { 3799, 3779, 0 },
   { 3802, 3803, 0 },
   { 3807, 3777, 0 },
   { 3811, 3777, 0 },
   { 3815, 3777, 0 },
   { 3818, 3819, 0 },
   { 3821, 3819, 0 },
   { 3824, 3825, 0 },
   { 3829, 3784, 0 },
   { 3833, 3784, 0 },
   { 3836, 3837, 0 },
   { 3839, 3837, 0 },
   { 3842, 2952, 0 },
   { 3844, 3837, 0 },
   { 3846, 2952, 0 },
   { 3848, 1734, 0 },
   { 3852, 3790, 0 },
   { 3855, 3856, 0 },
   { 3858, 3856, 0 },
   { 3861, 3862, 0 },
   { 3864, 3856, 0 },
   { 3866, 3862, 0 },
   { 3868, 1757, 0 },
   { 3870, 3856, 0 },
   { 3872, 3862, 0 },
   { 3874, 1757, 0 },
   { 3876, 1841, 0 },
   { 4604, 11, 0 },
   { 4657, 16, 0 },
   { 4710, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1735, 11, 0 },
   { 1758, 11, 0 },
   { 1842, 16, 0 },
   { 2930, 2931, 0 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { 3781, 3779, 0 },
   { 3787, 3779, 0 },
   { 3793, 3779, 0 },
   { 3799, 3779, 0 },
   { 3802, 3803, 0 },
   { 3807, 3777, 0 },
   { 3811, 3777, 0 },
   { 3815, 3777, 0 },
   { 3818, 3819, 0 },
   { 3821, 3819, 0 },
   { 3824, 3825, 0 },
   { 3829, 3784, 0 },
   { 3833, 3784, 0 },
   { 3836, 3837, 0 },
   { 3839, 3837, 0 },
   { 3842, 2952, 0 },
   { 3844, 3837, 0 },
   { 3846, 2952, 0 },
   { 3848, 1734, 0 },
   { 3852, 3790, 0 },
   { 3855, 3856, 0 },
   { 3858, 3856, 0 },
   { 3861, 3862, 0 },
   { 3864, 3856, 0 },
   { 3866, 3862, 0 },
   { 3868, 1757, 0 },
   { 3870, 3856, 0 },
   { 3872, 3862, 0 },
   { 3874, 1757, 0 },
   { 3876, 1841, 0 },
   { 4604, 11, 0 },
   { 4657, 16, 0 },
   { 4710, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2927, 2929, 0 },
   { 3757, 706, 0 },
   { 3758, 6, 0 },
   { 3759, 11, 0 },
   { 3760, 16, 0 },
   { 3761, 21, 0 },
   { 3778, 3779, 0 },
   { 3785, 3779, 0 },
   { 3791, 3779, 0 },
   { 3797, 3779, 0 },
   { 3805, 3777, 0 },
   { 3809, 3777, 0 },
   { 3813, 3777, 0 },
   { 3827, 3784, 0 },
   { 3831, 3784, 0 },
   { 3850, 3790, 0 },
   { 4632, 11, 0 },
   { 4685, 16, 0 },
   { 4737, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2063, 6, 0 },
   { 2089, 11, 0 },
   { 2115, 16, 0 },
   { 2140, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2464, 2465, 45 },
   { 2471, 2472, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2477, 2478, 45 },
   { 2482, 2483, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2464, 2465, 45 },
   { 2471, 2472, 45 },
   { 2480, 2478, 45 },
   { 2485, 2483, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2468, 2465, 45 },
   { 2475, 2472, 45 },
   { 2477, 2478, 45 },
   { 2482, 2483, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2464, 2465, 45 },
   { 2471, 2472, 45 },
   { 2477, 2478, 45 },
   { 2482, 2483, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 895, 0 },
   { 941, 940, 0 },
   { 948, 947, 0 },
   { 955, 953, 0 },
   { 963, 961, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 943, 942, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 965, 964, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { 678, 674, 22 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { 678, 674, 22 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 3, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 3, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { 3251, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 1721, 1722, 38 },
   { 1828, 1829, 38 },
   { 1911, 1912, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1997, 1999, 0 },
   { 2001, 2003, 0 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1955, 1957, 0 },
   { 1963, 1965, 0 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2021, 2023, 0 },
   { 2025, 2027, 0 },
   { 3762, 706, 0 },
   { 3763, 6, 0 },
   { 3764, 11, 0 },
   { 3765, 16, 0 },
   { 3766, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 939, 940, 0 },
   { 946, 947, 0 },
   { 952, 953, 0 },
   { 960, 961, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1484, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1484, 1485, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1446, 202, 34 },
   { 1450, 1451, 34 },
   { 1484, 1485, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 2833, 202, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1484, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1436, 32, 0 },
   { 1484, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1436, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1484, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1431, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1434, 1196, 0 },
   { 1484, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1434, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1484, 1485, 0 },
   { 1510, 1512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1510, 1512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1303, 1305, 0 },
   { 1484, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1279, 1225, 0 },
   { 1303, 1305, 0 },
   { 1431, 1196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1260, 32, 0 },
   { 1431, 1196, 0 },
   { 1484, 1485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3270, 3271, 0 },
   { 3273, 3274, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 495, 490, 0 },
   { 505, 506, 0 },
   { 564, 559, 0 },
   { 572, 573, 0 },
   { 635, 630, 0 },
   { 644, 645, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 372, 373, 9 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 683, 685, 25 },
   { 219, 687, 26 },
   { 688, 690, 27 },
   { 691, 685, 28 },
   { 692, 687, 29 },
   { 693, 690, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1102, 1103, 0 },
   { 1131, 1132, 0 },
   { 2432, 1177, 0 },
   { 2849, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1091, 1092, 0 },
   { 1133, 1134, 0 },
   { 2433, 1024, 0 },
   { 2848, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2500, 2503, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1042, 1043, 0 },
   { 1108, 1079, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1046, 1047, 0 },
   { 1110, 1096, 0 },
   { 2431, 1177, 0 },
   { 2852, 1177, 0 },
   { 2855, 1024, 0 },
   { 2858, 1024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1489, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1489, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1489, 1490, 0 },
   { 3579, 3577, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { 1489, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1437, 32, 0 },
   { 1489, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1489, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1432, 1433, 0 },
   { 1435, 1433, 0 },
   { 1489, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 32, 0 },
   { 1284, 1285, 0 },
   { 1313, 1315, 0 },
   { 1489, 1490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1494, 1495, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1265, 61, 0 },
   { 1266, 32, 0 },
   { 1494, 1495, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1281, 1282, 0 },
   { 1494, 1495, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 32, 0 },
   { 1281, 1282, 0 },
   { 1308, 1310, 0 },
   { 1494, 1495, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 1728, 1729, 38 },
   { 1835, 1836, 38 },
   { 1918, 1919, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 2445, 2228, 0 },
   { 2963, 2965, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 1136, 1139, 0 },
   { 2429, 1024, 0 },
   { 2837, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 1136, 1139, 0 },
   { 1219, 996, 0 },
   { 2429, 1024, 0 },
   { 2841, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1123, 1126, 0 },
   { 2191, 1025, 0 },
   { 2429, 1024, 0 },
   { 2860, 1024, 0 },
   { 2863, 1177, 0 },
   { 2866, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 2844, 2836, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 32, 0 },
   { 1516, 1517, 34 },
   { 2846, 2840, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 705, 713, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 519, 520, 15 },
   { 585, 586, 17 },
   { 658, 659, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 477, 478, 15 },
   { 548, 549, 17 },
   { 618, 619, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 477, 478, 15 },
   { 482, 472, 15 },
   { 548, 549, 17 },
   { 552, 543, 17 },
   { 618, 619, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 477, 478, 15 },
   { 482, 472, 15 },
   { 542, 543, 17 },
   { 548, 549, 17 },
   { 552, 543, 17 },
   { 612, 613, 19 },
   { 618, 619, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 492, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 561, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 477, 478, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 542, 543, 17 },
   { 548, 549, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 612, 613, 19 },
   { 618, 619, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 477, 478, 15 },
   { 548, 549, 17 },
   { 618, 619, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2174, 2177, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2182, 2186, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2174, 2177, 0 },
   { 2182, 2186, 0 },
   { 2434, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2446, 3, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1079, 0 },
   { 1257, 1079, 0 },
   { 1259, 1087, 0 },
   { 1696, 1703, 0 },
   { 1803, 1810, 0 },
   { 1886, 1893, 0 },
   { 2758, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 895, 0 },
   { 941, 940, 0 },
   { 948, 947, 0 },
   { 955, 953, 0 },
   { 963, 961, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 943, 942, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 965, 964, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 939, 940, 0 },
   { 946, 947, 0 },
   { 952, 953, 0 },
   { 960, 961, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2446, 3, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 895, 0 },
   { 941, 940, 0 },
   { 948, 947, 0 },
   { 955, 953, 0 },
   { 963, 961, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 943, 942, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 965, 964, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 939, 940, 0 },
   { 946, 947, 0 },
   { 952, 953, 0 },
   { 960, 961, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2446, 3, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 895, 0 },
   { 941, 940, 0 },
   { 948, 947, 0 },
   { 955, 953, 0 },
   { 963, 961, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 943, 942, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 965, 964, 0 },
   { 2417, 2418, 0 },
   { 2420, 2421, 0 },
   { 2434, 32, 0 },
   { 2435, 32, 0 },
   { 2436, 61, 0 },
   { 2915, 2916, 54 },
   { 2946, 2947, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 939, 940, 0 },
   { 946, 947, 0 },
   { 952, 953, 0 },
   { 960, 961, 0 },
   { 2456, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2460, 32, 0 },
   { 2904, 2905, 54 },
   { 964, 403, 54 },
   { 2907, 2909, 54 },
   { 956, 428, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2437, 32, 0 },
   { 2444, 3, 0 },
   { 5005, 4930, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 32, 0 },
   { 4929, 4930, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_pass_op_table[nir_num_search_ops] = {
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         5,
         13,
         5,
         5,
         5,
         5,
         0,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         15,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         2,
         3,
         2,
         2,
         340,
         2,
         2,
         2,
         341,
         342,
         343,
         344,
         2,
         2,
         2314,
         2315,
         2316,
         2317,
         3,
         3,
         345,
         346,
         347,
         348,
         349,
         3,
         350,
         351,
         352,
         353,
         2318,
         2319,
         2320,
         2321,
         2322,
         2323,
         2,
         345,
         2,
         2,
         340,
         2,
         2,
         2,
         341,
         342,
         343,
         344,
         2,
         2,
         2314,
         2315,
         2316,
         2317,
         2,
         346,
         2,
         2,
         340,
         2,
         2,
         2,
         341,
         342,
         343,
         344,
         2,
         2,
         2314,
         2315,
         2316,
         2317,
         340,
         347,
         340,
         340,
         340,
         340,
         340,
         340,
         354,
         355,
         356,
         357,
         340,
         340,
         2324,
         2325,
         2326,
         2327,
         2,
         348,
         2,
         2,
         340,
         2,
         2,
         2,
         341,
         342,
         343,
         344,
         2,
         2,
         2314,
         2315,
         2316,
         2317,
         2,
         349,
         2,
         2,
         340,
         2,
         2,
         2,
         341,
         342,
         343,
         344,
         2,
         2,
         2314,
         2315,
         2316,
         2317,
         2,
         3,
         2,
         2,
         340,
         2,
         2,
         358,
         341,
         342,
         343,
         344,
         2,
         2,
         2314,
         2315,
         2316,
         2317,
         341,
         350,
         341,
         341,
         354,
         341,
         341,
         341,
         341,
         359,
         360,
         361,
         341,
         341,
         2328,
         2329,
         2330,
         2331,
         342,
         351,
         342,
         342,
         355,
         342,
         342,
         342,
         359,
         342,
         362,
         363,
         342,
         342,
         2332,
         2333,
         2334,
         2335,
         343,
         352,
         343,
         343,
         356,
         343,
         343,
         343,
         360,
         362,
         343,
         364,
         343,
         343,
         2336,
         2337,
         2338,
         2339,
         344,
         353,
         344,
         344,
         357,
         344,
         344,
         344,
         361,
         363,
         364,
         344,
         344,
         344,
         2340,
         2341,
         2342,
         2343,
         2,
         2318,
         2,
         2,
         340,
         2,
         2,
         2,
         341,
         342,
         343,
         344,
         2,
         2,
         2314,
         2315,
         2316,
         2317,
         2,
         2319,
         2,
         2,
         340,
         2,
         2,
         2,
         341,
         342,
         343,
         344,
         2,
         2,
         2314,
         2315,
         2316,
         2317,
         2314,
         2320,
         2314,
         2314,
         2324,
         2314,
         2314,
         2314,
         2328,
         2332,
         2336,
         2340,
         2314,
         2314,
         2314,
         2344,
         2345,
         2346,
         2315,
         2321,
         2315,
         2315,
         2325,
         2315,
         2315,
         2315,
         2329,
         2333,
         2337,
         2341,
         2315,
         2315,
         2344,
         2315,
         2347,
         2348,
         2316,
         2322,
         2316,
         2316,
         2326,
         2316,
         2316,
         2316,
         2330,
         2334,
         2338,
         2342,
         2316,
         2316,
         2345,
         2347,
         2316,
         2349,
         2317,
         2323,
         2317,
         2317,
         2327,
         2317,
         2317,
         2317,
         2331,
         2335,
         2339,
         2343,
         2317,
         2317,
         2346,
         2348,
         2349,
         2317,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         4,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         4,
         14,
         4,
         4,
         4,
         4,
         0,
         11,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         19,
         0,
         5,
         5,
         3,
         6,
         20,
         15,
         3,
         6,
         21,
         5,
         5,
         3,
         6,
         22,
         15,
         3,
         6,
         23,
         5,
         5,
         3,
         6,
         0,
         15,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         4,
         5,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         6,
         7,
         6,
         6,
         6,
         1341,
         6,
         6,
         6,
         1342,
         6,
         6,
         6,
         2351,
         6,
         6,
         6,
         1341,
         6,
         1341,
         6,
         1341,
         6,
         1341,
         4,
         1343,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1344,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1345,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1346,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         1347,
         1348,
         1347,
         1347,
         1347,
         1349,
         1347,
         1347,
         1347,
         1350,
         1347,
         1347,
         1347,
         2352,
         1347,
         1347,
         1347,
         1349,
         1347,
         1349,
         1347,
         1349,
         1347,
         1349,
         1351,
         1352,
         1351,
         1351,
         1351,
         1353,
         1351,
         1351,
         1351,
         1354,
         1351,
         1351,
         1351,
         2353,
         1351,
         1351,
         1351,
         1353,
         1351,
         1353,
         1351,
         1353,
         1351,
         1353,
         4,
         1355,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         5,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1356,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         2354,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         2355,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1345,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         2356,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         2357,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         2358,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         3032,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         3123,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         3129,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         3133,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         3138,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         3142,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         3147,
         4,
         4,
         4,
         1339,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         2350,
         4,
         4,
         4,
         1339,
         4,
         1339,
         4,
         1339,
         4,
         1339,
      },
   },
   [nir_op_unpack_64_2x32_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         8,
         1566,
         1567,
         1568,
         1569,
      },
   },
   [nir_op_imul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_umul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_udiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         11,
         0,
         11,
      },
   },
   [nir_op_idiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         12,
         0,
         0,
         12,
         0,
         365,
         366,
         365,
      },
   },
   [nir_op_umod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         13,
         0,
         13,
      },
   },
   [nir_op_imod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         14,
         0,
         14,
      },
   },
   [nir_op_irem] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         15,
         0,
         15,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         14,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         10,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         9,
         9,
         9,
         9,
         9,
         9,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         5,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         16,
         1570,
         1571,
         1572,
         1573,
         1574,
         1575,
         1576,
         1577,
         1578,
         1579,
         1580,
         1581,
         1582,
         2682,
         2683,
         2684,
         3025,
      },
   },
   [nir_op_ineg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         4,
         6,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         17,
         1839,
         1840,
         1841,
         1842,
         1843,
         2992,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         18,
         1583,
         1584,
         1585,
         1586,
         1587,
         1588,
         1589,
         1590,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         19,
         2135,
         2136,
         2137,
      },
   },
   [nir_op_iabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         20,
         1844,
         1845,
         1846,
         2602,
      },
   },
   [nir_search_op_f2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         21,
         1591,
         1592,
      },
   },
   [nir_search_op_i2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         22,
         1847,
         1848,
         1849,
         1850,
         1851,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         7,
         8,
         7,
         8,
         7,
         8,
         9,
         10,
         9,
         10,
         9,
         10,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         14,
         2,
         2,
         15,
         16,
         17,
         18,
         19,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         3,
         21,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         20,
         3,
         3,
         3,
         3,
         3,
         5,
         22,
         5,
         5,
         23,
         24,
         5,
         5,
         5,
         5,
         5,
         22,
         5,
         5,
         5,
         23,
         24,
         22,
         5,
         5,
         23,
         24,
         5,
         22,
         22,
         22,
         25,
         26,
         5,
         23,
         24,
         23,
         24,
         23,
         27,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         28,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         30,
         31,
         5,
         5,
         30,
         31,
         5,
         5,
         5,
         30,
         31,
         5,
         22,
         32,
         33,
         34,
         22,
         5,
         30,
         31,
         5,
         30,
         31,
         5,
         23,
         35,
         36,
         23,
         24,
         37,
         38,
         24,
         5,
         5,
         30,
         31,
         5,
         30,
         31,
         31,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         11,
         11,
         11,
         20,
         3,
         21,
         21,
         21,
         21,
         21,
         21,
         4,
         4,
         20,
         20,
         3,
         20,
         20,
         3,
         0,
         2,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         21,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         20,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         43,
         44,
         43,
         44,
         43,
         44,
         43,
         45,
         43,
         44,
         43,
         44,
         46,
         47,
         48,
         49,
         43,
         44,
         50,
         51,
         52,
         44,
         43,
         44,
         53,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         21,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 54,
      .table = (const uint16_t []) {
      
         23,
         24,
         1593,
         1594,
         1594,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         1593,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         24,
         24,
         1595,
         1596,
         1597,
         24,
         24,
         1598,
         1599,
         1600,
         1601,
         24,
         1602,
         24,
         2667,
         2668,
         2669,
         2670,
         2671,
         2672,
         2673,
         2674,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         3003,
         3003,
         3004,
         3003,
         3003,
         3005,
         3005,
         3003,
         3003,
         3006,
         3007,
         2671,
         3110,
         24,
         3003,
         3003,
         24,
         3005,
         24,
         3003,
         3004,
         3003,
         3003,
         3003,
         1593,
         1595,
         1593,
         1603,
         1603,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2675,
         2675,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3008,
         3008,
         3009,
         3009,
         3008,
         3008,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3009,
         1593,
         3008,
         1593,
         3008,
         3008,
         3008,
         1594,
         1596,
         1603,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1603,
         1603,
         1603,
         1603,
         1603,
         2676,
         2666,
         2666,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3010,
         3010,
         1594,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         1594,
         1603,
         1603,
         1603,
         1594,
         3010,
         3010,
         1594,
         3011,
         1594,
         3010,
         1594,
         3010,
         3010,
         3010,
         1594,
         1597,
         1603,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1603,
         1603,
         1603,
         1603,
         1603,
         2676,
         2666,
         2666,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3010,
         3010,
         1594,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         1594,
         1603,
         1603,
         1603,
         1594,
         3010,
         3010,
         1594,
         3011,
         1594,
         3010,
         1594,
         3010,
         3010,
         3010,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1604,
         1604,
         1604,
         1604,
         1604,
         1604,
         23,
         23,
         3012,
         3013,
         1604,
         3012,
         3013,
         3014,
         3015,
         3012,
         3013,
         23,
         1593,
         1593,
         1593,
         1604,
         3013,
         3013,
         1604,
         3015,
         1604,
         3013,
         1604,
         3012,
         3013,
         3013,
         23,
         24,
         1593,
         1594,
         1594,
         23,
         1606,
         23,
         23,
         1607,
         1607,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         1593,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         23,
         1598,
         1593,
         1594,
         1594,
         1605,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3016,
         3016,
         1605,
         3016,
         3016,
         3017,
         3017,
         3016,
         3016,
         23,
         1593,
         1593,
         1593,
         1605,
         3016,
         3016,
         1605,
         3017,
         1605,
         3016,
         1605,
         3016,
         3016,
         3016,
         23,
         1599,
         1593,
         1594,
         1594,
         1605,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3016,
         3016,
         1605,
         3016,
         3016,
         3017,
         3017,
         3016,
         3016,
         23,
         1593,
         1593,
         1593,
         1605,
         3016,
         3016,
         1605,
         3017,
         1605,
         3016,
         1605,
         3016,
         3016,
         3016,
         23,
         1600,
         1593,
         1594,
         1594,
         23,
         1607,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         1593,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         23,
         1601,
         1593,
         1594,
         1594,
         23,
         1607,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         1593,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         23,
         24,
         1593,
         1594,
         1594,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         2677,
         23,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         1593,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         23,
         1602,
         1593,
         1594,
         1594,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         1593,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         23,
         24,
         1593,
         1594,
         1594,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1608,
         1593,
         1593,
         1593,
         1593,
         2678,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1608,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         2678,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         1593,
         2667,
         1593,
         1603,
         1603,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2675,
         2675,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3008,
         3008,
         3009,
         3009,
         3008,
         3008,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3009,
         1593,
         3008,
         1593,
         3008,
         3008,
         3008,
         1593,
         2668,
         1593,
         1603,
         1603,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2675,
         2675,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3008,
         3008,
         3009,
         3009,
         3008,
         3008,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3009,
         1593,
         3008,
         1593,
         3008,
         3008,
         3008,
         1593,
         2669,
         1593,
         1603,
         1603,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2675,
         2675,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3008,
         3008,
         3009,
         3009,
         3008,
         3008,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3009,
         1593,
         3008,
         1593,
         3008,
         3008,
         3008,
         1593,
         2670,
         1593,
         1603,
         1603,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2675,
         2675,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3008,
         3008,
         3009,
         3009,
         3008,
         3008,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3009,
         1593,
         3008,
         1593,
         3008,
         3008,
         3008,
         1593,
         2671,
         1593,
         1603,
         1603,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2678,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2675,
         2675,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2678,
         3008,
         3008,
         1593,
         3008,
         3008,
         3009,
         3009,
         3008,
         3008,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3009,
         1593,
         3008,
         1593,
         3008,
         3008,
         3008,
         2665,
         2672,
         2665,
         2676,
         2676,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2679,
         2679,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         2665,
         3018,
         3018,
         2665,
         3018,
         3018,
         3019,
         3019,
         3018,
         3018,
         2665,
         2665,
         2665,
         2665,
         2665,
         3018,
         3018,
         2665,
         3019,
         2665,
         3018,
         2665,
         3018,
         3018,
         3018,
         2666,
         2673,
         2675,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2675,
         2675,
         2675,
         2675,
         2675,
         2679,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         3020,
         3020,
         2666,
         3020,
         3020,
         3021,
         3021,
         3020,
         3020,
         2666,
         2675,
         2675,
         2675,
         2666,
         3020,
         3020,
         2666,
         3021,
         2666,
         3020,
         2666,
         3020,
         3020,
         3020,
         2666,
         2674,
         2675,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2675,
         2675,
         2675,
         2675,
         2675,
         2679,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         3020,
         3020,
         2666,
         3020,
         3020,
         3021,
         3021,
         3020,
         3020,
         2666,
         2675,
         2675,
         2675,
         2666,
         3020,
         3020,
         2666,
         3021,
         2666,
         3020,
         2666,
         3020,
         3020,
         3020,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1604,
         1604,
         1604,
         1604,
         1604,
         1604,
         23,
         23,
         3012,
         3013,
         1604,
         3012,
         3013,
         3014,
         3015,
         3012,
         3013,
         23,
         1593,
         1593,
         1593,
         3111,
         3013,
         3013,
         3111,
         3015,
         3111,
         3013,
         3111,
         3112,
         3113,
         3113,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1604,
         1604,
         1604,
         1604,
         1604,
         1604,
         23,
         23,
         3012,
         3013,
         1604,
         3012,
         3013,
         3014,
         3015,
         3012,
         3013,
         23,
         1593,
         1593,
         1593,
         1604,
         3114,
         3114,
         1604,
         3115,
         1604,
         3114,
         1604,
         3012,
         3013,
         3114,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1604,
         1604,
         2680,
         1604,
         2680,
         2680,
         23,
         23,
         3012,
         3013,
         1604,
         3012,
         3013,
         3014,
         3015,
         3022,
         3023,
         23,
         1593,
         1593,
         1593,
         1604,
         3013,
         3013,
         1604,
         3015,
         2680,
         3023,
         1604,
         3012,
         3013,
         3013,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1604,
         1604,
         1604,
         1604,
         1604,
         1604,
         23,
         23,
         3012,
         3013,
         1604,
         3012,
         3013,
         3014,
         3015,
         3012,
         3013,
         23,
         1593,
         1593,
         1593,
         3111,
         3114,
         3114,
         3111,
         3115,
         3111,
         3114,
         3111,
         3112,
         3113,
         3116,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1604,
         1604,
         2680,
         1604,
         2680,
         2680,
         23,
         23,
         3012,
         3013,
         1604,
         3012,
         3013,
         3014,
         3015,
         3022,
         3023,
         23,
         1593,
         1593,
         1593,
         3111,
         3013,
         3013,
         3111,
         3015,
         3117,
         3023,
         3111,
         3112,
         3113,
         3113,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1604,
         1604,
         2680,
         1604,
         2680,
         2680,
         23,
         23,
         3012,
         3013,
         1604,
         3012,
         3013,
         3014,
         3015,
         3022,
         3023,
         23,
         1593,
         1593,
         1593,
         1604,
         3114,
         3114,
         1604,
         3115,
         2680,
         3118,
         1604,
         3012,
         3013,
         3114,
         23,
         24,
         1593,
         1594,
         1594,
         23,
         23,
         23,
         23,
         23,
         23,
         2677,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         2677,
         23,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         1593,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         23,
         24,
         1593,
         1594,
         1594,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1608,
         1593,
         1593,
         1593,
         1593,
         2678,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1608,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         3024,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         3001,
         3003,
         3008,
         3010,
         3010,
         3012,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3012,
         3012,
         3012,
         3012,
         3012,
         3012,
         3001,
         3001,
         3012,
         3013,
         3012,
         3012,
         3013,
         3014,
         3015,
         3012,
         3013,
         3001,
         3008,
         3008,
         3008,
         3012,
         3013,
         3013,
         3012,
         3015,
         3012,
         3013,
         3012,
         3012,
         3013,
         3013,
         3001,
         3003,
         3008,
         3010,
         3010,
         3013,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3013,
         3013,
         3013,
         3013,
         3013,
         3013,
         3001,
         3001,
         3013,
         3013,
         3013,
         3013,
         3013,
         3015,
         3015,
         3013,
         3013,
         3001,
         3008,
         3008,
         3008,
         3013,
         3013,
         3013,
         3013,
         3015,
         3013,
         3013,
         3013,
         3013,
         3013,
         3013,
         23,
         3004,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         1604,
         1604,
         1604,
         1604,
         1604,
         1604,
         23,
         23,
         3012,
         3013,
         1604,
         3012,
         3013,
         3014,
         3015,
         3012,
         3013,
         23,
         1593,
         1593,
         1593,
         3111,
         3013,
         3013,
         3111,
         3015,
         3111,
         3013,
         3111,
         3112,
         3113,
         3113,
         3001,
         3003,
         3008,
         3010,
         3010,
         3012,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3012,
         3012,
         3012,
         3012,
         3012,
         3012,
         3001,
         3001,
         3012,
         3013,
         3012,
         3012,
         3013,
         3014,
         3015,
         3012,
         3013,
         3001,
         3008,
         3008,
         3008,
         3112,
         3013,
         3013,
         3112,
         3015,
         3112,
         3013,
         3112,
         3112,
         3113,
         3113,
         3001,
         3003,
         3008,
         3010,
         3010,
         3013,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3013,
         3013,
         3013,
         3013,
         3013,
         3013,
         3001,
         3001,
         3013,
         3013,
         3013,
         3013,
         3013,
         3015,
         3015,
         3013,
         3013,
         3001,
         3008,
         3008,
         3008,
         3113,
         3013,
         3013,
         3113,
         3015,
         3113,
         3013,
         3113,
         3113,
         3113,
         3113,
         3002,
         3005,
         3009,
         3011,
         3011,
         3014,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3014,
         3014,
         3014,
         3014,
         3014,
         3014,
         3002,
         3002,
         3014,
         3015,
         3014,
         3014,
         3015,
         3014,
         3015,
         3014,
         3015,
         3002,
         3009,
         3009,
         3009,
         3014,
         3115,
         3115,
         3014,
         3115,
         3014,
         3115,
         3014,
         3014,
         3015,
         3115,
         3002,
         3005,
         3009,
         3011,
         3011,
         3015,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3015,
         3015,
         3015,
         3015,
         3015,
         3015,
         3002,
         3002,
         3015,
         3015,
         3015,
         3015,
         3015,
         3015,
         3015,
         3015,
         3015,
         3002,
         3009,
         3009,
         3009,
         3015,
         3115,
         3115,
         3015,
         3115,
         3015,
         3115,
         3015,
         3015,
         3015,
         3115,
         3001,
         3003,
         3008,
         3010,
         3010,
         3012,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3012,
         3012,
         3022,
         3012,
         3022,
         3022,
         3001,
         3001,
         3012,
         3013,
         3012,
         3012,
         3013,
         3014,
         3015,
         3022,
         3023,
         3001,
         3008,
         3008,
         3008,
         3012,
         3013,
         3013,
         3012,
         3015,
         3022,
         3023,
         3012,
         3012,
         3013,
         3013,
         3001,
         3003,
         3008,
         3010,
         3010,
         3013,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3013,
         3013,
         3023,
         3013,
         3023,
         3023,
         3001,
         3001,
         3013,
         3013,
         3013,
         3013,
         3013,
         3015,
         3015,
         3023,
         3023,
         3001,
         3008,
         3008,
         3008,
         3013,
         3013,
         3013,
         3013,
         3015,
         3023,
         3023,
         3013,
         3013,
         3013,
         3013,
         23,
         3006,
         1593,
         1594,
         1594,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3001,
         3001,
         23,
         3001,
         3001,
         3002,
         3002,
         3001,
         3001,
         23,
         1593,
         1593,
         1593,
         23,
         3001,
         3001,
         23,
         3002,
         23,
         3001,
         23,
         3001,
         3001,
         3001,
         1593,
         3007,
         1593,
         1603,
         1603,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2675,
         2675,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3008,
         3008,
         3009,
         3009,
         3008,
         3008,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3009,
         1593,
         3008,
         1593,
         3008,
         3008,
         3008,
         1593,
         2671,
         1593,
         1603,
         1603,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2678,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2675,
         2675,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         3024,
         3008,
         3008,
         1593,
         3008,
         3008,
         3009,
         3009,
         3008,
         3008,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3009,
         1593,
         3008,
         1593,
         3008,
         3008,
         3008,
         1593,
         3110,
         1593,
         1603,
         1603,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2675,
         2675,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3008,
         3008,
         3009,
         3009,
         3008,
         3008,
         1593,
         1593,
         1593,
         1593,
         1593,
         3008,
         3008,
         1593,
         3009,
         1593,
         3008,
         1593,
         3008,
         3008,
         3008,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         3111,
         1604,
         1604,
         3111,
         3111,
         1604,
         23,
         23,
         3012,
         3013,
         3111,
         3112,
         3113,
         3014,
         3015,
         3012,
         3013,
         23,
         1593,
         1593,
         1593,
         3111,
         3013,
         3113,
         3111,
         3015,
         3111,
         3013,
         3111,
         3112,
         3113,
         3113,
         3001,
         3003,
         3008,
         3010,
         3010,
         3013,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3013,
         3114,
         3013,
         3114,
         3013,
         3114,
         3001,
         3001,
         3013,
         3013,
         3013,
         3013,
         3013,
         3115,
         3115,
         3013,
         3013,
         3001,
         3008,
         3008,
         3008,
         3013,
         3013,
         3013,
         3114,
         3115,
         3013,
         3013,
         3013,
         3013,
         3013,
         3013,
         3001,
         3003,
         3008,
         3010,
         3010,
         3013,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3013,
         3114,
         3013,
         3114,
         3013,
         3114,
         3001,
         3001,
         3013,
         3013,
         3013,
         3013,
         3013,
         3115,
         3115,
         3013,
         3013,
         3001,
         3008,
         3008,
         3008,
         3113,
         3013,
         3013,
         3116,
         3115,
         3113,
         3013,
         3113,
         3113,
         3113,
         3113,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         3111,
         1604,
         1604,
         3111,
         3111,
         1604,
         23,
         23,
         3012,
         3013,
         3111,
         3112,
         3113,
         3014,
         3015,
         3012,
         3013,
         23,
         1593,
         1593,
         1593,
         3111,
         3114,
         3116,
         3111,
         3115,
         3111,
         3114,
         3111,
         3112,
         3113,
         3116,
         3002,
         3005,
         3009,
         3011,
         3011,
         3015,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3015,
         3115,
         3015,
         3115,
         3015,
         3115,
         3002,
         3002,
         3015,
         3015,
         3015,
         3015,
         3015,
         3115,
         3115,
         3015,
         3015,
         3002,
         3009,
         3009,
         3009,
         3015,
         3115,
         3115,
         3115,
         3115,
         3015,
         3115,
         3015,
         3015,
         3015,
         3115,
         23,
         24,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         3111,
         1604,
         2680,
         3111,
         3117,
         2680,
         23,
         23,
         3012,
         3013,
         3111,
         3112,
         3113,
         3014,
         3015,
         3022,
         3023,
         23,
         1593,
         1593,
         1593,
         3111,
         3013,
         3113,
         3111,
         3015,
         3117,
         3023,
         3111,
         3112,
         3113,
         3113,
         3001,
         3003,
         3008,
         3010,
         3010,
         3013,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3013,
         3114,
         3023,
         3114,
         3023,
         3118,
         3001,
         3001,
         3013,
         3013,
         3013,
         3013,
         3013,
         3115,
         3115,
         3023,
         3023,
         3001,
         3008,
         3008,
         3008,
         3013,
         3013,
         3013,
         3114,
         3115,
         3023,
         3023,
         3013,
         3013,
         3013,
         3013,
         23,
         3004,
         1593,
         1594,
         1594,
         1604,
         23,
         1605,
         1605,
         23,
         23,
         23,
         23,
         23,
         1593,
         1593,
         1593,
         1593,
         1593,
         2665,
         2666,
         2666,
         3111,
         1604,
         1604,
         3111,
         3111,
         1604,
         23,
         23,
         3012,
         3013,
         3111,
         3112,
         3113,
         3014,
         3015,
         3012,
         3013,
         23,
         1593,
         1593,
         1593,
         3111,
         3013,
         3113,
         3111,
         3015,
         3111,
         3013,
         3111,
         3112,
         3113,
         3113,
         3001,
         3003,
         3008,
         3010,
         3010,
         3012,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3112,
         3012,
         3012,
         3112,
         3112,
         3012,
         3001,
         3001,
         3012,
         3013,
         3112,
         3112,
         3113,
         3014,
         3015,
         3012,
         3013,
         3001,
         3008,
         3008,
         3008,
         3112,
         3013,
         3113,
         3112,
         3015,
         3112,
         3013,
         3112,
         3112,
         3113,
         3113,
         3001,
         3003,
         3008,
         3010,
         3010,
         3013,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3113,
         3013,
         3013,
         3113,
         3113,
         3013,
         3001,
         3001,
         3013,
         3013,
         3113,
         3113,
         3113,
         3015,
         3015,
         3013,
         3013,
         3001,
         3008,
         3008,
         3008,
         3113,
         3013,
         3113,
         3113,
         3015,
         3113,
         3013,
         3113,
         3113,
         3113,
         3113,
         3001,
         3003,
         3008,
         3010,
         3010,
         3013,
         3001,
         3016,
         3016,
         3001,
         3001,
         3001,
         3001,
         3001,
         3008,
         3008,
         3008,
         3008,
         3008,
         3018,
         3020,
         3020,
         3113,
         3114,
         3013,
         3116,
         3113,
         3114,
         3001,
         3001,
         3013,
         3013,
         3113,
         3113,
         3113,
         3115,
         3115,
         3013,
         3013,
         3001,
         3008,
         3008,
         3008,
         3113,
         3013,
         3113,
         3116,
         3115,
         3113,
         3013,
         3113,
         3113,
         3113,
         3113,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         27,
         28,
         0,
         0,
         0,
         0,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         20,
         20,
         20,
         20,
         20,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         25,
         23,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 31,
      .table = (const uint16_t []) {
      
         25,
         26,
         25,
         25,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         25,
         25,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         25,
         25,
         25,
         367,
         26,
         26,
         26,
         378,
         379,
         380,
         381,
         382,
         383,
         384,
         385,
         386,
         387,
         388,
         389,
         390,
         391,
         26,
         26,
         26,
         2229,
         2230,
         2231,
         2232,
         2233,
         2234,
         26,
         26,
         26,
         26,
         379,
         25,
         26,
         392,
         392,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         25,
         25,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         25,
         25,
         25,
         367,
         25,
         378,
         392,
         392,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         25,
         25,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         25,
         25,
         25,
         367,
         367,
         379,
         367,
         367,
         367,
         393,
         394,
         395,
         396,
         397,
         398,
         399,
         367,
         400,
         401,
         402,
         403,
         367,
         367,
         367,
         2235,
         2236,
         2237,
         2238,
         2239,
         2240,
         367,
         367,
         367,
         367,
         367,
         25,
         380,
         25,
         25,
         393,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         25,
         25,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         25,
         25,
         25,
         393,
         368,
         381,
         368,
         368,
         394,
         368,
         368,
         404,
         405,
         406,
         407,
         408,
         368,
         409,
         410,
         411,
         412,
         368,
         368,
         368,
         2224,
         2224,
         2241,
         2242,
         2243,
         2244,
         368,
         368,
         368,
         368,
         394,
         369,
         382,
         369,
         369,
         395,
         369,
         404,
         369,
         413,
         414,
         415,
         416,
         369,
         417,
         418,
         419,
         420,
         369,
         369,
         369,
         2245,
         2246,
         2247,
         2248,
         2249,
         2250,
         369,
         369,
         369,
         369,
         395,
         370,
         383,
         370,
         370,
         396,
         370,
         405,
         413,
         370,
         421,
         422,
         423,
         370,
         424,
         425,
         426,
         427,
         370,
         370,
         370,
         2251,
         2252,
         2253,
         2254,
         2255,
         2256,
         370,
         370,
         370,
         370,
         396,
         371,
         384,
         371,
         371,
         397,
         371,
         406,
         414,
         421,
         371,
         428,
         429,
         371,
         430,
         431,
         432,
         433,
         371,
         371,
         371,
         2257,
         2258,
         2259,
         2260,
         2261,
         2262,
         371,
         371,
         371,
         371,
         397,
         372,
         385,
         372,
         372,
         398,
         372,
         407,
         415,
         422,
         428,
         372,
         434,
         372,
         435,
         436,
         437,
         438,
         372,
         372,
         372,
         2263,
         2264,
         2265,
         2266,
         2267,
         2268,
         372,
         372,
         372,
         372,
         398,
         373,
         386,
         373,
         373,
         399,
         373,
         408,
         416,
         423,
         429,
         434,
         373,
         373,
         439,
         440,
         441,
         442,
         373,
         373,
         373,
         2269,
         2270,
         2271,
         2272,
         2273,
         2274,
         373,
         373,
         373,
         373,
         399,
         25,
         387,
         25,
         25,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         25,
         25,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         25,
         25,
         25,
         367,
         374,
         388,
         374,
         374,
         400,
         374,
         409,
         417,
         424,
         430,
         435,
         439,
         374,
         374,
         443,
         444,
         445,
         374,
         374,
         374,
         2275,
         2276,
         2277,
         2278,
         2279,
         2280,
         374,
         374,
         374,
         374,
         400,
         375,
         389,
         375,
         375,
         401,
         375,
         410,
         418,
         425,
         431,
         436,
         440,
         375,
         443,
         375,
         446,
         447,
         375,
         375,
         375,
         2281,
         2282,
         2283,
         2284,
         2285,
         2286,
         375,
         375,
         375,
         375,
         401,
         376,
         390,
         376,
         376,
         402,
         376,
         411,
         419,
         426,
         432,
         437,
         441,
         376,
         444,
         446,
         376,
         448,
         376,
         376,
         376,
         2287,
         2288,
         2289,
         2290,
         2291,
         2292,
         376,
         376,
         376,
         376,
         402,
         377,
         391,
         377,
         377,
         403,
         377,
         412,
         420,
         427,
         433,
         438,
         442,
         377,
         445,
         447,
         448,
         377,
         377,
         377,
         377,
         2293,
         2294,
         2295,
         2296,
         2297,
         2298,
         377,
         377,
         377,
         377,
         403,
         25,
         26,
         25,
         25,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         449,
         449,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         25,
         25,
         25,
         367,
         25,
         26,
         25,
         25,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         449,
         25,
         449,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         25,
         25,
         25,
         367,
         25,
         26,
         25,
         25,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         449,
         449,
         449,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         25,
         25,
         25,
         367,
         2223,
         2229,
         2223,
         2223,
         2235,
         2223,
         2224,
         2245,
         2251,
         2257,
         2263,
         2269,
         2223,
         2275,
         2281,
         2287,
         2293,
         2223,
         2223,
         2223,
         2223,
         2224,
         2299,
         2300,
         2301,
         2302,
         2223,
         2223,
         2223,
         2223,
         2235,
         2224,
         2230,
         2224,
         2224,
         2236,
         2224,
         2224,
         2246,
         2252,
         2258,
         2264,
         2270,
         2224,
         2276,
         2282,
         2288,
         2294,
         2224,
         2224,
         2224,
         2224,
         2224,
         2303,
         2304,
         2305,
         2306,
         2224,
         2224,
         2224,
         2224,
         2236,
         2225,
         2231,
         2225,
         2225,
         2237,
         2225,
         2241,
         2247,
         2253,
         2259,
         2265,
         2271,
         2225,
         2277,
         2283,
         2289,
         2295,
         2225,
         2225,
         2225,
         2299,
         2303,
         2225,
         2307,
         2308,
         2309,
         2225,
         2225,
         2225,
         2225,
         2237,
         2226,
         2232,
         2226,
         2226,
         2238,
         2226,
         2242,
         2248,
         2254,
         2260,
         2266,
         2272,
         2226,
         2278,
         2284,
         2290,
         2296,
         2226,
         2226,
         2226,
         2300,
         2304,
         2307,
         2226,
         2310,
         2311,
         2226,
         2226,
         2226,
         2226,
         2238,
         2227,
         2233,
         2227,
         2227,
         2239,
         2227,
         2243,
         2249,
         2255,
         2261,
         2267,
         2273,
         2227,
         2279,
         2285,
         2291,
         2297,
         2227,
         2227,
         2227,
         2301,
         2305,
         2308,
         2310,
         2227,
         2312,
         2227,
         2227,
         2227,
         2227,
         2239,
         2228,
         2234,
         2228,
         2228,
         2240,
         2228,
         2244,
         2250,
         2256,
         2262,
         2268,
         2274,
         2228,
         2280,
         2286,
         2292,
         2298,
         2228,
         2228,
         2228,
         2302,
         2306,
         2309,
         2311,
         2312,
         2228,
         2228,
         2228,
         2228,
         2228,
         2240,
         25,
         26,
         25,
         25,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         25,
         25,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         2313,
         2313,
         25,
         367,
         25,
         26,
         25,
         25,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         25,
         25,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         2313,
         25,
         2313,
         25,
         367,
         25,
         26,
         25,
         25,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         25,
         25,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         2313,
         2313,
         2313,
         25,
         367,
         25,
         26,
         25,
         25,
         367,
         25,
         368,
         369,
         370,
         371,
         372,
         373,
         25,
         374,
         375,
         376,
         377,
         25,
         25,
         25,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         25,
         25,
         25,
         25,
         3100,
         367,
         379,
         367,
         367,
         367,
         393,
         394,
         395,
         396,
         397,
         398,
         399,
         367,
         400,
         401,
         402,
         403,
         367,
         367,
         367,
         2235,
         2236,
         2237,
         2238,
         2239,
         2240,
         367,
         367,
         367,
         3100,
         367,
      },
   },
   [nir_op_usadd_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         27,
         27,
         27,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         9,
         10,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         15,
         15,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         20,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         4,
         4,
         4,
         4,
         3,
         20,
         3,
         3,
         3,
         20,
         3,
         20,
         3,
         3,
         3,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         22,
         7,
         18,
         0,
         19,
         19,
         19,
         19,
         23,
         19,
         0,
         0,
         18,
         18,
         0,
         18,
         18,
         0,
         0,
         2,
         2,
         2,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         19,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         0,
         0,
         0,
         0,
         18,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 25,
      .table = (const uint16_t []) {
      
         28,
         29,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1611,
         28,
         1612,
         1613,
         28,
         1614,
         28,
         28,
         2378,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
         29,
         29,
         1615,
         1616,
         1617,
         1618,
         1619,
         1620,
         1621,
         1622,
         1623,
         1624,
         29,
         1625,
         29,
         1622,
         2382,
         1615,
         2383,
         2384,
         2385,
         2386,
         3054,
         3055,
         3109,
         1609,
         1615,
         1609,
         1609,
         1609,
         1609,
         1609,
         1626,
         1627,
         1609,
         1628,
         1629,
         1609,
         1630,
         1609,
         1609,
         2387,
         1609,
         2388,
         2389,
         2390,
         2390,
         3056,
         3057,
         1609,
         28,
         1616,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1631,
         28,
         1612,
         1613,
         28,
         1614,
         28,
         28,
         2378,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
         28,
         1617,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1631,
         28,
         1612,
         1613,
         28,
         1614,
         28,
         28,
         2378,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
         28,
         1618,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1611,
         28,
         1612,
         1613,
         28,
         1614,
         28,
         28,
         2378,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
         28,
         1619,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1611,
         28,
         1612,
         1613,
         28,
         1614,
         28,
         28,
         2378,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
         1610,
         1620,
         1626,
         1610,
         1610,
         1610,
         1610,
         1632,
         1633,
         1610,
         1634,
         1635,
         1610,
         1636,
         1610,
         1610,
         2391,
         2392,
         2393,
         2394,
         2395,
         2395,
         3058,
         3059,
         1610,
         1611,
         1621,
         1627,
         1631,
         1631,
         1611,
         1611,
         1633,
         1611,
         1611,
         1637,
         1638,
         1611,
         1639,
         1611,
         1611,
         2396,
         1627,
         2397,
         2398,
         2399,
         2399,
         3060,
         3061,
         1611,
         28,
         1622,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1611,
         28,
         1612,
         1613,
         28,
         1614,
         28,
         28,
         2378,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
         1612,
         1623,
         1628,
         1612,
         1612,
         1612,
         1612,
         1634,
         1637,
         1612,
         1612,
         1640,
         1612,
         1641,
         1612,
         1612,
         2378,
         1628,
         2400,
         2401,
         2402,
         2402,
         3062,
         3063,
         1612,
         1613,
         1624,
         1629,
         1613,
         1613,
         1613,
         1613,
         1635,
         1638,
         1613,
         1640,
         1642,
         1613,
         1643,
         1613,
         1613,
         2403,
         1629,
         2404,
         2405,
         2406,
         2406,
         3064,
         3065,
         1613,
         28,
         29,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1611,
         28,
         1612,
         1613,
         1644,
         1614,
         28,
         28,
         2378,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
         1614,
         1625,
         1630,
         1614,
         1614,
         1614,
         1614,
         1636,
         1639,
         1614,
         1641,
         1643,
         1614,
         1614,
         1614,
         1614,
         2407,
         1630,
         2408,
         2409,
         2410,
         2410,
         3066,
         3067,
         1614,
         28,
         29,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1611,
         28,
         1612,
         1613,
         28,
         1614,
         1645,
         28,
         2378,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
         28,
         1622,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1611,
         28,
         1612,
         1613,
         28,
         1614,
         28,
         2411,
         2412,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
         2378,
         2382,
         2387,
         2378,
         2378,
         2378,
         2378,
         2391,
         2396,
         2378,
         2378,
         2403,
         2378,
         2407,
         2378,
         2412,
         2412,
         2387,
         2413,
         2414,
         2415,
         2415,
         3068,
         3069,
         2378,
         1609,
         1615,
         1609,
         1609,
         1609,
         1609,
         1609,
         2392,
         1627,
         1609,
         1628,
         1629,
         1609,
         1630,
         1609,
         1609,
         2387,
         1609,
         2388,
         2389,
         2390,
         2390,
         3070,
         3057,
         1609,
         2379,
         2383,
         2388,
         2379,
         2379,
         2379,
         2379,
         2393,
         2397,
         2379,
         2400,
         2404,
         2379,
         2408,
         2379,
         2379,
         2413,
         2388,
         2379,
         2380,
         2416,
         2416,
         3071,
         3053,
         2379,
         2380,
         2384,
         2389,
         2380,
         2380,
         2380,
         2380,
         2394,
         2398,
         2380,
         2401,
         2405,
         2380,
         2409,
         2380,
         2380,
         2414,
         2389,
         2380,
         2417,
         2418,
         2418,
         3072,
         3073,
         2380,
         2381,
         2385,
         2390,
         2381,
         2381,
         2381,
         2381,
         2395,
         2399,
         2381,
         2402,
         2406,
         2381,
         2410,
         2381,
         2381,
         2415,
         2390,
         2416,
         2418,
         2381,
         2381,
         3074,
         3075,
         2381,
         2381,
         2386,
         2390,
         2381,
         2381,
         2381,
         2381,
         2395,
         2399,
         2381,
         2402,
         2406,
         2381,
         2410,
         2381,
         2381,
         2415,
         2390,
         2416,
         2418,
         2381,
         2381,
         3074,
         3075,
         2381,
         3052,
         3054,
         3056,
         3052,
         3052,
         3052,
         3052,
         3058,
         3060,
         3052,
         3062,
         3064,
         3052,
         3066,
         3052,
         3052,
         3068,
         3070,
         3071,
         3072,
         3074,
         3074,
         3058,
         3076,
         3052,
         3053,
         3055,
         3057,
         3053,
         3053,
         3053,
         3053,
         3059,
         3061,
         3053,
         3063,
         3065,
         3053,
         3067,
         3053,
         3053,
         3069,
         3057,
         3053,
         3073,
         3075,
         3075,
         3076,
         3073,
         3053,
         28,
         3109,
         1609,
         28,
         28,
         28,
         28,
         1610,
         1611,
         28,
         1612,
         1613,
         28,
         1614,
         28,
         28,
         2378,
         1609,
         2379,
         2380,
         2381,
         2381,
         3052,
         3053,
         28,
      },
   },
   [nir_op_fmulz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         30,
         31,
         1646,
         30,
         30,
         30,
         1647,
         30,
         31,
         31,
         1648,
         1649,
         1650,
         1651,
         1652,
         31,
         1646,
         1648,
         1646,
         1646,
         1646,
         1646,
         1653,
         1646,
         30,
         1649,
         1646,
         30,
         30,
         30,
         1647,
         30,
         30,
         1650,
         1646,
         30,
         30,
         30,
         1647,
         30,
         30,
         1651,
         1646,
         30,
         30,
         30,
         1647,
         30,
         1647,
         1652,
         1653,
         1647,
         1647,
         1647,
         1647,
         1647,
         30,
         31,
         1646,
         30,
         30,
         30,
         1647,
         1654,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         11,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         12,
         4,
         3,
         3,
         3,
         11,
         3,
         3,
         3,
         3,
         3,
         11,
         3,
         3,
         11,
         3,
         11,
         3,
         11,
         11,
         3,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         14,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         10,
         10,
         10,
         15,
         10,
         0,
         0,
         10,
         10,
         0,
         10,
         10,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         10,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         13,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         36,
         37,
         36,
         1664,
         1664,
         36,
         1665,
         36,
         36,
         36,
         36,
         1664,
         1664,
         1665,
         1665,
         36,
         1666,
         1667,
         1666,
         1668,
         1668,
         1666,
         1669,
         1666,
         1666,
         1666,
         1666,
         1668,
         1668,
         1669,
         1669,
         1666,
         1670,
         1671,
         1670,
         1672,
         1672,
         1670,
         1673,
         1670,
         1670,
         1670,
         1670,
         1672,
         1672,
         1673,
         1673,
         1670,
         1674,
         1675,
         1674,
         1676,
         1676,
         1674,
         1677,
         1674,
         1674,
         1674,
         1674,
         1676,
         1676,
         1677,
         1677,
         1674,
         1678,
         1679,
         1678,
         1680,
         1680,
         1678,
         1681,
         1678,
         1678,
         1678,
         1678,
         1680,
         1680,
         1681,
         1681,
         1678,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         2424,
         34,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         2425,
         2426,
         2425,
         2427,
         2427,
         2425,
         2428,
         2425,
         2425,
         2425,
         2425,
         2427,
         2427,
         2428,
         2428,
         2425,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         1670,
         1671,
         1670,
         1672,
         1672,
         1670,
         1673,
         1670,
         1670,
         1670,
         1670,
         1672,
         1672,
         1673,
         1673,
         1670,
         1674,
         1675,
         1674,
         1676,
         1676,
         1674,
         1677,
         1674,
         1674,
         1674,
         1674,
         1676,
         1676,
         1677,
         1677,
         1674,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         3078,
         3078,
         1658,
         1658,
         34,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         1666,
         1667,
         1666,
         1668,
         1668,
         1666,
         1669,
         1666,
         1666,
         1666,
         1666,
         1668,
         1668,
         1669,
         1669,
         1666,
         1682,
         1683,
         1682,
         1684,
         1684,
         1682,
         1685,
         1682,
         1682,
         1682,
         1682,
         1684,
         1684,
         1685,
         1685,
         1682,
         1659,
         1660,
         1659,
         1686,
         1686,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1686,
         1686,
         1662,
         1662,
         1659,
         1659,
         1660,
         1659,
         1686,
         1686,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1686,
         1686,
         1662,
         1662,
         1659,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         1687,
         1688,
         1687,
         1689,
         1689,
         1687,
         1690,
         1687,
         1687,
         1687,
         1687,
         1689,
         1689,
         1690,
         2429,
         1687,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         2430,
         2431,
         2430,
         2432,
         2432,
         2430,
         2433,
         2430,
         2430,
         2430,
         2430,
         2432,
         2432,
         2433,
         2433,
         2430,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         1659,
         1660,
         1659,
         1686,
         1686,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1686,
         1686,
         1662,
         1662,
         1659,
         1659,
         1660,
         1659,
         1686,
         1686,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1686,
         1686,
         1662,
         1662,
         1659,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         3079,
         3079,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         1670,
         1671,
         1670,
         1672,
         1672,
         1670,
         1673,
         1670,
         1670,
         1670,
         1670,
         1672,
         1672,
         1673,
         1673,
         1670,
         1659,
         1660,
         1659,
         1686,
         1686,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1686,
         1686,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2434,
         2434,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2434,
         2434,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         3080,
         3080,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         1674,
         1675,
         1674,
         1676,
         1676,
         1674,
         1677,
         1674,
         1674,
         1674,
         1674,
         1676,
         1676,
         1677,
         1677,
         1674,
         1659,
         1660,
         1659,
         1686,
         1686,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1686,
         1686,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2434,
         2434,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2434,
         2434,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         3080,
         3080,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         1678,
         1679,
         1678,
         1680,
         1680,
         1678,
         1681,
         1678,
         1678,
         1678,
         1678,
         1680,
         1680,
         1681,
         1681,
         1678,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         2419,
         32,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         2424,
         34,
         1687,
         1688,
         1687,
         1689,
         1689,
         1687,
         1690,
         1687,
         1687,
         1687,
         1687,
         1689,
         1689,
         1690,
         2429,
         1687,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         2419,
         32,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2435,
         2420,
         2436,
         2437,
         2436,
         2438,
         2438,
         2436,
         2439,
         2436,
         2436,
         2436,
         2436,
         2438,
         2438,
         2439,
         2440,
         2436,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         2419,
         32,
         32,
         33,
         32,
         2441,
         2441,
         32,
         1656,
         32,
         32,
         32,
         32,
         2441,
         2441,
         1656,
         2419,
         32,
         32,
         33,
         32,
         2441,
         2441,
         32,
         1656,
         32,
         32,
         32,
         32,
         2441,
         2441,
         1656,
         2419,
         32,
         2436,
         2437,
         2436,
         2438,
         2438,
         2436,
         2439,
         2436,
         2436,
         2436,
         2436,
         3081,
         3081,
         2439,
         2440,
         2436,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         2419,
         32,
         2442,
         2443,
         2442,
         2444,
         2444,
         2442,
         2445,
         2442,
         2442,
         2442,
         2442,
         2444,
         2444,
         2445,
         2445,
         2442,
         2446,
         2447,
         2446,
         2448,
         2448,
         2446,
         2449,
         2446,
         2446,
         2446,
         2446,
         2448,
         2448,
         2449,
         2449,
         2446,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         2425,
         2426,
         2425,
         2427,
         2427,
         2425,
         2428,
         2425,
         2425,
         2425,
         2425,
         2427,
         2427,
         2428,
         2428,
         2425,
         2430,
         2431,
         2430,
         2432,
         2432,
         2430,
         2433,
         2430,
         2430,
         2430,
         2430,
         2432,
         2432,
         2433,
         2433,
         2430,
         2420,
         2421,
         2420,
         2434,
         2434,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2434,
         2434,
         2423,
         2423,
         2420,
         2420,
         2421,
         2420,
         2434,
         2434,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2434,
         2434,
         2423,
         2423,
         2420,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2435,
         2420,
         2446,
         2447,
         2446,
         2448,
         2448,
         2446,
         2449,
         2446,
         2446,
         2446,
         2446,
         2448,
         2448,
         2449,
         2449,
         2446,
         2446,
         2447,
         2446,
         2448,
         2448,
         2446,
         2449,
         2446,
         2446,
         2446,
         2446,
         2448,
         2448,
         2449,
         2449,
         2446,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         2420,
         2421,
         2420,
         2434,
         2434,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2434,
         2434,
         2423,
         2423,
         2420,
         2420,
         2421,
         2420,
         2434,
         2434,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2434,
         2434,
         2423,
         2423,
         2420,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         3082,
         3082,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         2436,
         2437,
         2436,
         2438,
         2438,
         2436,
         2439,
         2436,
         2436,
         2436,
         2436,
         2438,
         2438,
         2439,
         2440,
         2436,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         1670,
         1671,
         1670,
         1672,
         1672,
         1670,
         1673,
         1670,
         1670,
         1670,
         1670,
         1672,
         1672,
         1673,
         1673,
         1670,
         1659,
         1660,
         1659,
         1686,
         1686,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1686,
         1686,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2434,
         2434,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2434,
         2434,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         3080,
         3080,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         1674,
         1675,
         1674,
         1676,
         1676,
         1674,
         1677,
         1674,
         1674,
         1674,
         1674,
         1676,
         1676,
         1677,
         1677,
         1674,
         1659,
         1660,
         1659,
         1686,
         1686,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1686,
         1686,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2434,
         2434,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2434,
         2434,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         3080,
         3080,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         2441,
         2441,
         32,
         1656,
         32,
         32,
         32,
         32,
         2441,
         2441,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         1657,
         1657,
         1658,
         1658,
         34,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         1661,
         1661,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         2441,
         2441,
         32,
         1656,
         32,
         32,
         32,
         32,
         2441,
         2441,
         1656,
         2419,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         2422,
         2422,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         1663,
         1663,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         1655,
         1655,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         34,
         35,
         34,
         1657,
         1657,
         34,
         1658,
         34,
         34,
         34,
         34,
         3078,
         3078,
         1658,
         1658,
         34,
         1659,
         1660,
         1659,
         1661,
         1661,
         1659,
         1662,
         1659,
         1659,
         1659,
         1659,
         3079,
         3079,
         1662,
         1662,
         1659,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         3080,
         3080,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         3080,
         3080,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         2436,
         2437,
         2436,
         2438,
         2438,
         2436,
         2439,
         2436,
         2436,
         2436,
         2436,
         3081,
         3081,
         2439,
         2440,
         2436,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         2420,
         2421,
         2420,
         2422,
         2422,
         2420,
         2423,
         2420,
         2420,
         2420,
         2420,
         3082,
         3082,
         2423,
         2423,
         2420,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         3080,
         3080,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1663,
         1663,
         32,
         1656,
         32,
         32,
         32,
         32,
         3080,
         3080,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
         32,
         33,
         32,
         1655,
         1655,
         32,
         1656,
         32,
         32,
         32,
         32,
         3077,
         3077,
         1656,
         1656,
         32,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         38,
         39,
         38,
         1691,
         1691,
         1692,
         40,
         41,
         40,
         1693,
         1693,
         1694,
         38,
         39,
         38,
         1691,
         1691,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1691,
         1691,
         1692,
         40,
         41,
         40,
         1693,
         1693,
         1694,
         42,
         43,
         42,
         1696,
         1696,
         1697,
         40,
         41,
         40,
         1693,
         1693,
         1694,
         1698,
         1699,
         1698,
         1700,
         1700,
         1701,
         1702,
         1703,
         1702,
         1704,
         1704,
         1705,
         40,
         41,
         40,
         1693,
         1693,
         1694,
         38,
         39,
         38,
         1691,
         1691,
         1692,
         40,
         41,
         40,
         1693,
         1693,
         1694,
         1706,
         1707,
         1706,
         1708,
         1708,
         1709,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1691,
         1691,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         1698,
         1699,
         1698,
         1700,
         1700,
         1701,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         1702,
         1703,
         1702,
         1704,
         1704,
         1705,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1691,
         1691,
         1692,
         40,
         41,
         40,
         1693,
         1693,
         1694,
         38,
         39,
         38,
         1691,
         1691,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1695,
         1695,
         1692,
         38,
         39,
         38,
         1691,
         1691,
         1692,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         4,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         12,
         13,
         14,
         15,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         25,
         26,
         27,
         26,
         27,
         28,
         28,
         28,
         28,
         29,
         29,
         29,
         29,
         30,
         30,
         31,
         32,
         33,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         38,
         39,
         40,
         41,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         4,
         3,
         3,
         3,
         4,
         3,
         3,
         4,
         4,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         44,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         13,
         12,
         12,
         13,
         13,
         14,
         14,
         15,
         14,
         15,
         14,
         15,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         17,
         17,
         17,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         18,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         17,
         21,
         21,
         21,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         22,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         22,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         21,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         46,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         47,
         32,
         32,
         48,
         49,
         32,
         32,
         31,
         31,
         31,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         33,
         33,
         33,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         27,
         26,
         27,
         26,
         26,
         27,
         26,
         27,
         26,
         26,
         27,
         27,
         26,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         54,
         4,
         12,
         12,
         12,
         55,
         13,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         16,
         16,
         16,
         16,
         16,
         16,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         19,
         18,
         18,
         18,
         18,
         18,
         23,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         28,
         29,
         32,
         34,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         53,
         51,
         45,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         58,
         4,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         25,
         0,
         18,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         59,
         18,
         18,
         18,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         60,
         61,
         8,
         0,
         8,
         8,
         4,
         13,
         9,
         62,
         63,
         64,
         8,
         8,
         8,
         4,
         13,
         9,
         65,
         66,
         67,
         8,
         8,
         8,
         4,
         13,
         9,
         65,
      },
      
      .num_filtered_states = 68,
      .table = (const uint16_t []) {
      
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         45,
         45,
         1363,
         45,
         1364,
         1365,
         45,
         1366,
         1367,
         1368,
         45,
         45,
         45,
         1369,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         1370,
         45,
         1371,
         45,
         1372,
         45,
         1373,
         2523,
         2524,
         2525,
         2526,
         2527,
         45,
         45,
         2528,
         2529,
         2530,
         2531,
         2999,
         3000,
         45,
         45,
         45,
         3125,
         3127,
         3128,
         3135,
         3136,
         3137,
         3144,
         3145,
         3146,
         44,
         1363,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         1374,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         1374,
         44,
         44,
         44,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         44,
         1364,
         44,
         1374,
         1374,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         1374,
         44,
         44,
         44,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         44,
         1365,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         2532,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1357,
         1366,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1375,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1376,
         1357,
         1377,
         1357,
         1378,
         1357,
         1379,
         2533,
         1375,
         1357,
         2534,
         2535,
         1357,
         1357,
         2536,
         2537,
         2538,
         2539,
         1357,
         1357,
         1357,
         1357,
         1357,
         1375,
         1357,
         1357,
         1375,
         1357,
         1357,
         1375,
         1357,
         1357,
         1357,
         1367,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1375,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1357,
         1376,
         1357,
         1377,
         1357,
         1378,
         1357,
         1379,
         2533,
         1375,
         1357,
         2534,
         2535,
         1357,
         1357,
         2536,
         2537,
         2538,
         2539,
         1357,
         1357,
         1357,
         1357,
         1357,
         1375,
         1357,
         1357,
         1375,
         1357,
         1357,
         1375,
         1357,
         1357,
         1358,
         1368,
         1358,
         1358,
         1358,
         1358,
         1358,
         1375,
         1375,
         1380,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1381,
         1358,
         1382,
         1358,
         1383,
         1358,
         1384,
         2540,
         1380,
         1358,
         2541,
         2542,
         1358,
         1358,
         2543,
         2544,
         2545,
         2546,
         1358,
         1358,
         1358,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1385,
         44,
         44,
         44,
         44,
         44,
         44,
         1386,
         1386,
         1386,
         1386,
         1387,
         1387,
         1387,
         1387,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         1389,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         1390,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         1390,
         44,
         44,
         44,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         44,
         1369,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         1390,
         1390,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         1390,
         44,
         44,
         44,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         1392,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2547,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         1392,
         1392,
         1392,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1386,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         1393,
         1393,
         1393,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1386,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         1394,
         1395,
         1396,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1386,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         1395,
         1397,
         1398,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1386,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         1396,
         1398,
         1399,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1400,
         1400,
         1400,
         1400,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1400,
         1401,
         1402,
         1403,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1400,
         1402,
         1404,
         1405,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1400,
         1403,
         1405,
         1406,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1407,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1408,
         1408,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1408,
         1408,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         3119,
         3120,
         3121,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1409,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1410,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1411,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1412,
         1412,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1413,
         1412,
         1412,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2548,
         1413,
         1413,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1412,
         1412,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2549,
         1412,
         1412,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1412,
         1412,
         44,
         1414,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2549,
         1412,
         1412,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1415,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1359,
         1370,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1415,
         1415,
         1359,
         1416,
         1359,
         1417,
         1359,
         1418,
         2550,
         1381,
         1359,
         2551,
         2552,
         1359,
         1359,
         2553,
         2554,
         2555,
         2556,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1419,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1360,
         1371,
         1360,
         1360,
         1360,
         1360,
         1360,
         1377,
         1377,
         1382,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1416,
         1419,
         1419,
         1360,
         1420,
         1360,
         1421,
         2557,
         1382,
         1360,
         2558,
         2559,
         1360,
         1360,
         2560,
         2561,
         2562,
         2563,
         1360,
         1360,
         1360,
         1360,
         1360,
         1382,
         1360,
         1360,
         1382,
         1360,
         1360,
         1382,
         1360,
         1360,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1422,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1361,
         1372,
         1361,
         1361,
         1361,
         1361,
         1361,
         1378,
         1378,
         1383,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1417,
         1361,
         1420,
         1422,
         1422,
         1361,
         1423,
         2564,
         1383,
         1361,
         2565,
         2566,
         1361,
         1361,
         2567,
         2568,
         2569,
         2570,
         1361,
         1361,
         1361,
         1361,
         1361,
         1383,
         1361,
         1361,
         1383,
         1361,
         1361,
         1383,
         1361,
         1361,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1424,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1362,
         1373,
         1362,
         1362,
         1362,
         1362,
         1362,
         1379,
         1379,
         1384,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1418,
         1362,
         1421,
         1362,
         1423,
         1424,
         1424,
         2571,
         1384,
         1362,
         2572,
         2573,
         1362,
         1362,
         2574,
         2575,
         2576,
         2577,
         1362,
         1362,
         1362,
         1362,
         1362,
         1384,
         1362,
         1362,
         1384,
         1362,
         1362,
         1384,
         1362,
         1362,
         2516,
         2523,
         2516,
         2516,
         2516,
         2516,
         2516,
         2533,
         2533,
         2540,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2516,
         2550,
         2516,
         2557,
         2516,
         2564,
         2516,
         2571,
         2540,
         2540,
         2516,
         2578,
         2579,
         2516,
         2516,
         2580,
         2581,
         2582,
         2583,
         2516,
         2516,
         2516,
         2516,
         2516,
         2540,
         2516,
         2516,
         2540,
         2516,
         2516,
         2540,
         2516,
         2516,
         1358,
         2524,
         1358,
         1358,
         1358,
         1358,
         1358,
         1375,
         1375,
         1380,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1381,
         1358,
         1382,
         1358,
         1383,
         1358,
         1384,
         2540,
         1380,
         1358,
         2541,
         2542,
         1358,
         1358,
         2543,
         2544,
         2545,
         2546,
         1358,
         1358,
         1358,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         44,
         2525,
         44,
         44,
         44,
         44,
         2532,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         2584,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         2517,
         2526,
         2517,
         2517,
         2517,
         2517,
         2517,
         2534,
         2534,
         2541,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2547,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2551,
         2517,
         2558,
         2517,
         2565,
         2517,
         2572,
         2578,
         2541,
         2517,
         2547,
         2585,
         2517,
         2517,
         2586,
         2587,
         2588,
         2589,
         2517,
         2517,
         2547,
         2547,
         2547,
         2541,
         2517,
         2517,
         2541,
         2517,
         2517,
         2541,
         2517,
         2517,
         2518,
         2527,
         2518,
         2518,
         2518,
         2518,
         2518,
         2535,
         2535,
         2542,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2548,
         2549,
         2549,
         2518,
         2552,
         2518,
         2559,
         2518,
         2566,
         2518,
         2573,
         2579,
         2542,
         2518,
         2585,
         2548,
         2548,
         2548,
         2590,
         2591,
         2592,
         2593,
         2518,
         2518,
         2518,
         2518,
         2518,
         2542,
         2518,
         2518,
         2542,
         2518,
         2518,
         2542,
         2518,
         2518,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1413,
         1412,
         1412,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2548,
         1413,
         2594,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1413,
         1412,
         1412,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2548,
         2594,
         1413,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         44,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         2519,
         2528,
         2519,
         2519,
         2519,
         2519,
         2519,
         2536,
         2536,
         2543,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2553,
         2519,
         2560,
         2519,
         2567,
         2519,
         2574,
         2580,
         2543,
         2519,
         2586,
         2590,
         2519,
         2519,
         2519,
         2595,
         2596,
         2597,
         2519,
         2519,
         2519,
         2519,
         2519,
         2543,
         2519,
         2519,
         2543,
         2519,
         2519,
         2543,
         2519,
         2519,
         2520,
         2529,
         2520,
         2520,
         2520,
         2520,
         2520,
         2537,
         2537,
         2544,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2554,
         2520,
         2561,
         2520,
         2568,
         2520,
         2575,
         2581,
         2544,
         2520,
         2587,
         2591,
         2520,
         2520,
         2595,
         2520,
         2598,
         2599,
         2520,
         2520,
         2520,
         2520,
         2520,
         2544,
         2520,
         2520,
         2544,
         2520,
         2520,
         2544,
         2520,
         2520,
         2521,
         2530,
         2521,
         2521,
         2521,
         2521,
         2521,
         2538,
         2538,
         2545,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2555,
         2521,
         2562,
         2521,
         2569,
         2521,
         2576,
         2582,
         2545,
         2521,
         2588,
         2592,
         2521,
         2521,
         2596,
         2598,
         2521,
         2600,
         2521,
         2521,
         2521,
         2521,
         2521,
         2545,
         2521,
         2521,
         2545,
         2521,
         2521,
         2545,
         2521,
         2521,
         2522,
         2531,
         2522,
         2522,
         2522,
         2522,
         2522,
         2539,
         2539,
         2546,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2556,
         2522,
         2563,
         2522,
         2570,
         2522,
         2577,
         2583,
         2546,
         2522,
         2589,
         2593,
         2522,
         2522,
         2597,
         2599,
         2600,
         2601,
         2522,
         2522,
         2522,
         2522,
         2522,
         2546,
         2522,
         2522,
         2546,
         2522,
         2522,
         2546,
         2522,
         2522,
         44,
         2999,
         44,
         1374,
         1374,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         1374,
         44,
         44,
         44,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         44,
         3000,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         1390,
         1390,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         1390,
         44,
         44,
         44,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         1392,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         3119,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2547,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         1392,
         1392,
         1392,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         1392,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         3120,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2547,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         1392,
         1392,
         1392,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         1392,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         3121,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2547,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         44,
         1392,
         1392,
         1392,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         44,
         44,
         1358,
         3125,
         1358,
         1358,
         1358,
         1358,
         1358,
         1375,
         1375,
         1380,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1381,
         1358,
         1382,
         1358,
         1383,
         1358,
         1384,
         2540,
         1380,
         1358,
         2541,
         2542,
         1358,
         1358,
         2543,
         2544,
         2545,
         2546,
         1358,
         1358,
         1358,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         44,
         3127,
         44,
         1374,
         1374,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         1374,
         44,
         44,
         44,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         44,
         3128,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         1390,
         1390,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         1390,
         44,
         44,
         44,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         1358,
         3135,
         1358,
         1358,
         1358,
         1358,
         1358,
         1375,
         1375,
         1380,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1381,
         1358,
         1382,
         1358,
         1383,
         1358,
         1384,
         2540,
         1380,
         1358,
         2541,
         2542,
         1358,
         1358,
         2543,
         2544,
         2545,
         2546,
         1358,
         1358,
         1358,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         44,
         3136,
         44,
         1374,
         1374,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         1374,
         44,
         44,
         44,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         44,
         3137,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         1390,
         1390,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         1390,
         44,
         44,
         44,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         1358,
         3144,
         1358,
         1358,
         1358,
         1358,
         1358,
         1375,
         1375,
         1380,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1381,
         1358,
         1382,
         1358,
         1383,
         1358,
         1384,
         2540,
         1380,
         1358,
         2541,
         2542,
         1358,
         1358,
         2543,
         2544,
         2545,
         2546,
         1358,
         1358,
         1358,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         1380,
         1358,
         1358,
         44,
         3145,
         44,
         1374,
         1374,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         1374,
         44,
         44,
         44,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         1358,
         1374,
         44,
         44,
         3146,
         44,
         44,
         44,
         44,
         44,
         1357,
         1357,
         1358,
         44,
         44,
         1390,
         1390,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         2516,
         1358,
         44,
         2517,
         2518,
         44,
         44,
         2519,
         2520,
         2521,
         2522,
         44,
         1390,
         44,
         44,
         44,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
         1358,
         44,
         1390,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         10,
         11,
         12,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         22,
         23,
         23,
         23,
         23,
         24,
         24,
         24,
         24,
         25,
         25,
         25,
         25,
         26,
         27,
         0,
         28,
         0,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         31,
         0,
         0,
         0,
         0,
         32,
         0,
         0,
         33,
         34,
         35,
         36,
         37,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         42,
         2,
         42,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         42,
         2,
         3,
         2,
         42,
         43,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         46,
         9,
         46,
         9,
         10,
         9,
         46,
         10,
         10,
         11,
         11,
         12,
         11,
         12,
         11,
         12,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         14,
         14,
         14,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         15,
         14,
         15,
         14,
         15,
         14,
         14,
         14,
         15,
         15,
         14,
         15,
         14,
         14,
         14,
         15,
         14,
         15,
         14,
         14,
         14,
         14,
         18,
         18,
         18,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         19,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         19,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         18,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         0,
         0,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         26,
         26,
         26,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         48,
         49,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         50,
         51,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         55,
         55,
         55,
         3,
         3,
         3,
         3,
         3,
         56,
         56,
         56,
         10,
         10,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         13,
         13,
         13,
         13,
         13,
         13,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         16,
         15,
         15,
         15,
         15,
         15,
         20,
         19,
         19,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         24,
         25,
         28,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         51,
         49,
         47,
         5,
         5,
         5,
         58,
         5,
         5,
         59,
         60,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         13,
         13,
         13,
         61,
         62,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         22,
         0,
         15,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         3,
         10,
         4,
         0,
         63,
         64,
         65,
         66,
         5,
         5,
         3,
         10,
         4,
         67,
         68,
         69,
         70,
         5,
         5,
         3,
         10,
         4,
         71,
         72,
         73,
         74,
         5,
         5,
      },
      
      .num_filtered_states = 75,
      .table = (const uint16_t []) {
      
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         47,
         47,
         47,
         47,
         1434,
         1435,
         1436,
         47,
         47,
         47,
         47,
         47,
         47,
         1437,
         1438,
         1438,
         1438,
         1438,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         1439,
         47,
         47,
         1440,
         47,
         47,
         1441,
         47,
         1442,
         47,
         1443,
         47,
         47,
         47,
         47,
         47,
         1435,
         1436,
         47,
         47,
         2454,
         2455,
         2456,
         2457,
         47,
         47,
         47,
         47,
         47,
         1435,
         1435,
         1434,
         1434,
         47,
         47,
         1434,
         1434,
         47,
         47,
         1434,
         1434,
         47,
         47,
         1434,
         1434,
         47,
         47,
         46,
         47,
         46,
         1444,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         1444,
         1426,
         1426,
         2458,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         2993,
         1426,
         1426,
         1425,
         1425,
         1444,
         46,
         1425,
         1425,
         1444,
         46,
         1425,
         1425,
         1444,
         46,
         1425,
         1425,
         1444,
         46,
         46,
         47,
         1444,
         1444,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         1445,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         1444,
         1444,
         1426,
         1426,
         2458,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         1444,
         2993,
         1426,
         1426,
         1425,
         1425,
         1444,
         1445,
         1425,
         1425,
         1444,
         1445,
         1425,
         1425,
         1444,
         1445,
         1425,
         1425,
         1444,
         1445,
         1425,
         1434,
         1425,
         1425,
         1446,
         1447,
         1447,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1448,
         1449,
         1449,
         1449,
         1449,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1450,
         1425,
         1425,
         1451,
         1425,
         1425,
         1452,
         1425,
         1453,
         1425,
         1454,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1425,
         1425,
         2459,
         2460,
         2461,
         2462,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1426,
         1435,
         1426,
         1426,
         1447,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1455,
         1456,
         1456,
         1456,
         1456,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1457,
         1426,
         1426,
         1458,
         1426,
         1426,
         1459,
         1426,
         1460,
         1426,
         1461,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         2463,
         2464,
         2465,
         2466,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1426,
         1436,
         1426,
         1426,
         1447,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1455,
         1456,
         1456,
         1456,
         1456,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1457,
         1426,
         1426,
         1458,
         1426,
         1426,
         1459,
         1426,
         1460,
         1426,
         1461,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         2463,
         2464,
         2465,
         2466,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         1462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         1463,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         1464,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         1465,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         2467,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         2994,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         1465,
         1425,
         1425,
         46,
         1465,
         1425,
         1425,
         46,
         1465,
         1425,
         1425,
         46,
         1465,
         46,
         47,
         46,
         1445,
         1425,
         1426,
         1426,
         46,
         46,
         1465,
         1465,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         2467,
         1445,
         1426,
         1426,
         1465,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         2994,
         1465,
         1426,
         1426,
         1425,
         1425,
         1445,
         1465,
         1425,
         1425,
         1445,
         1465,
         1425,
         1425,
         1445,
         1465,
         1425,
         1425,
         1445,
         1465,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         1466,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         1466,
         1466,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1427,
         1437,
         1427,
         1427,
         1448,
         1455,
         1455,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1467,
         1468,
         1468,
         1468,
         1468,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1469,
         1427,
         1427,
         1470,
         1427,
         1427,
         1471,
         1427,
         1472,
         1427,
         1473,
         1427,
         1427,
         1427,
         1427,
         1427,
         1455,
         1455,
         1427,
         1427,
         2468,
         2469,
         2470,
         2471,
         1427,
         1427,
         1427,
         1427,
         1427,
         1455,
         1455,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1428,
         1438,
         1428,
         1428,
         1449,
         1456,
         1456,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1468,
         1474,
         1474,
         1474,
         1474,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1475,
         1428,
         1428,
         1476,
         1428,
         1428,
         1477,
         1428,
         1478,
         1428,
         1479,
         1428,
         1428,
         1428,
         1428,
         1428,
         2472,
         2472,
         1428,
         1428,
         2473,
         2474,
         2475,
         2476,
         1428,
         1428,
         1428,
         1428,
         1428,
         1456,
         1456,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1428,
         1438,
         1428,
         1428,
         1449,
         1456,
         1456,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1468,
         1474,
         1480,
         1481,
         1482,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1475,
         1428,
         1428,
         1476,
         1428,
         1428,
         1477,
         1428,
         1478,
         1428,
         1479,
         1428,
         1428,
         1428,
         1428,
         1428,
         2472,
         2472,
         1428,
         1428,
         2473,
         2474,
         2475,
         2476,
         1428,
         1428,
         1428,
         1428,
         1428,
         1456,
         1456,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1428,
         1438,
         1428,
         1428,
         1449,
         1456,
         1456,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1468,
         1474,
         1481,
         1483,
         1484,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1475,
         1428,
         1428,
         1476,
         1428,
         1428,
         1477,
         1428,
         1478,
         1428,
         1479,
         1428,
         1428,
         1428,
         1428,
         1428,
         2472,
         2472,
         1428,
         1428,
         2473,
         2474,
         2475,
         2476,
         1428,
         1428,
         1428,
         1428,
         1428,
         1456,
         1456,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1428,
         1438,
         1428,
         1428,
         1449,
         1456,
         1456,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1468,
         1474,
         1482,
         1484,
         1485,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1475,
         1428,
         1428,
         1476,
         1428,
         1428,
         1477,
         1428,
         1478,
         1428,
         1479,
         1428,
         1428,
         1428,
         1428,
         1428,
         2472,
         2472,
         1428,
         1428,
         2473,
         2474,
         2475,
         2476,
         1428,
         1428,
         1428,
         1428,
         1428,
         1456,
         1456,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         1486,
         1486,
         1486,
         1486,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         1486,
         1487,
         1488,
         1489,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         1486,
         1488,
         1490,
         1491,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         1486,
         1489,
         1491,
         1492,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         1463,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         1493,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         1494,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         1495,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1496,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1497,
         1497,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1497,
         1497,
         1498,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1429,
         1439,
         1429,
         1429,
         1450,
         1457,
         1457,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1469,
         1475,
         1475,
         1475,
         1475,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1498,
         1499,
         1429,
         1429,
         1500,
         1429,
         1429,
         1501,
         1429,
         1502,
         1429,
         1503,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1429,
         1429,
         2477,
         2478,
         2479,
         2480,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         1504,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1505,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1430,
         1440,
         1430,
         1430,
         1451,
         1458,
         1458,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1470,
         1476,
         1476,
         1476,
         1476,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1500,
         1430,
         1505,
         1505,
         1430,
         1430,
         1506,
         1430,
         1507,
         1430,
         1508,
         1430,
         1430,
         1430,
         1430,
         1430,
         1458,
         1458,
         1430,
         1430,
         2481,
         2482,
         2483,
         2484,
         1430,
         1430,
         1430,
         1430,
         1430,
         1458,
         1458,
         1451,
         1451,
         1430,
         1430,
         1451,
         1451,
         1430,
         1430,
         1451,
         1451,
         1430,
         1430,
         1451,
         1451,
         1430,
         1430,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         2485,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1509,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1431,
         1441,
         1431,
         1431,
         1452,
         1459,
         1459,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1471,
         1477,
         1477,
         1477,
         1477,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1501,
         1431,
         1431,
         1506,
         1431,
         1509,
         1509,
         1431,
         1510,
         1431,
         1511,
         1431,
         1431,
         1431,
         1431,
         1431,
         1459,
         1459,
         1431,
         1431,
         2486,
         2487,
         2488,
         2489,
         1431,
         1431,
         1431,
         1431,
         1431,
         1459,
         1459,
         1452,
         1452,
         1431,
         1431,
         1452,
         1452,
         1431,
         1431,
         1452,
         1452,
         1431,
         1431,
         1452,
         1452,
         1431,
         1431,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1512,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1432,
         1442,
         1432,
         1432,
         1453,
         1460,
         1460,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1472,
         1478,
         1478,
         1478,
         1478,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1502,
         1432,
         1432,
         1507,
         1432,
         1432,
         1510,
         1512,
         1512,
         1432,
         1513,
         1432,
         1432,
         1432,
         1432,
         1432,
         1460,
         1460,
         1432,
         1432,
         2490,
         2491,
         2492,
         2493,
         1432,
         1432,
         1432,
         1432,
         1432,
         1460,
         1460,
         1453,
         1453,
         1432,
         1432,
         1453,
         1453,
         1432,
         1432,
         1453,
         1453,
         1432,
         1432,
         1453,
         1453,
         1432,
         1432,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1514,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1433,
         1443,
         1433,
         1433,
         1454,
         1461,
         1461,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1473,
         1479,
         1479,
         1479,
         1479,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1503,
         1433,
         1433,
         1508,
         1433,
         1433,
         1511,
         1433,
         1513,
         1514,
         1514,
         1433,
         1433,
         1433,
         1433,
         1433,
         1461,
         1461,
         1433,
         1433,
         2494,
         2495,
         2496,
         2497,
         1433,
         1433,
         1433,
         1433,
         1433,
         1461,
         1461,
         1454,
         1454,
         1433,
         1433,
         1454,
         1454,
         1433,
         1433,
         1454,
         1454,
         1433,
         1433,
         1454,
         1454,
         1433,
         1433,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         1515,
         1515,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         1515,
         46,
         1515,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         1515,
         1515,
         1515,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         1444,
         1425,
         1426,
         1426,
         46,
         46,
         2467,
         2467,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         1444,
         1426,
         1426,
         2498,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         2995,
         1426,
         1426,
         1425,
         1425,
         1444,
         2467,
         1425,
         1425,
         1444,
         2467,
         1425,
         1425,
         1444,
         2467,
         1425,
         1425,
         1444,
         2467,
         46,
         47,
         1444,
         1444,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         1445,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         2485,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         1444,
         1444,
         1426,
         1426,
         2458,
         46,
         2450,
         2451,
         2499,
         2500,
         46,
         46,
         46,
         1444,
         2993,
         2996,
         3101,
         1425,
         1425,
         1444,
         1445,
         1425,
         1425,
         1444,
         1445,
         1425,
         1425,
         1444,
         1445,
         1425,
         1425,
         1444,
         1445,
         1426,
         1435,
         1426,
         1426,
         1447,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1455,
         2472,
         2472,
         2472,
         2472,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1457,
         1426,
         1426,
         1458,
         1426,
         1426,
         1459,
         1426,
         1460,
         1426,
         1461,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         2463,
         2464,
         2465,
         2466,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1426,
         1436,
         1426,
         1426,
         1447,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1455,
         2472,
         2472,
         2472,
         2472,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1457,
         1426,
         1426,
         1458,
         1426,
         1426,
         1459,
         1426,
         1460,
         1426,
         1461,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         2463,
         2464,
         2465,
         2466,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         46,
         47,
         2458,
         2458,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         1465,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         2498,
         2458,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         2997,
         46,
         1426,
         1426,
         1425,
         1425,
         2458,
         1465,
         1425,
         1425,
         2458,
         1465,
         1425,
         1425,
         2458,
         1465,
         1425,
         1425,
         2458,
         1465,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         2501,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         2450,
         2454,
         2450,
         2450,
         2459,
         2463,
         2463,
         2450,
         2450,
         2450,
         2450,
         2450,
         2450,
         2468,
         2473,
         2473,
         2473,
         2473,
         2450,
         2450,
         2450,
         2450,
         2450,
         2450,
         2450,
         2450,
         2450,
         2450,
         2477,
         2450,
         2450,
         2481,
         2450,
         2450,
         2486,
         2450,
         2490,
         2450,
         2494,
         2450,
         2450,
         2450,
         2450,
         2450,
         2463,
         2463,
         2450,
         2450,
         2450,
         2502,
         2503,
         2504,
         2450,
         2450,
         2450,
         2450,
         2450,
         2463,
         2463,
         2459,
         2459,
         2450,
         2450,
         2459,
         2459,
         2450,
         2450,
         2459,
         2459,
         2450,
         2450,
         2459,
         2459,
         2450,
         2450,
         2451,
         2455,
         2451,
         2451,
         2460,
         2464,
         2464,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2469,
         2474,
         2474,
         2474,
         2474,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2478,
         2451,
         2451,
         2482,
         2451,
         2451,
         2487,
         2451,
         2491,
         2451,
         2495,
         2451,
         2451,
         2451,
         2451,
         2451,
         2464,
         2464,
         2451,
         2451,
         2502,
         2451,
         2505,
         2506,
         2451,
         2451,
         2451,
         2451,
         2451,
         2464,
         2464,
         2460,
         2460,
         2451,
         2451,
         2460,
         2460,
         2451,
         2451,
         2460,
         2460,
         2451,
         2451,
         2460,
         2460,
         2451,
         2451,
         2452,
         2456,
         2452,
         2452,
         2461,
         2465,
         2465,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2470,
         2475,
         2475,
         2475,
         2475,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2479,
         2452,
         2452,
         2483,
         2452,
         2452,
         2488,
         2452,
         2492,
         2452,
         2496,
         2452,
         2452,
         2452,
         2452,
         2499,
         2465,
         2465,
         2452,
         2452,
         2503,
         2505,
         2452,
         2507,
         2452,
         2452,
         2452,
         2452,
         2452,
         2465,
         2465,
         2461,
         2461,
         2452,
         2452,
         2461,
         2461,
         2452,
         2452,
         2461,
         2461,
         2452,
         2452,
         2461,
         2461,
         2452,
         2452,
         2453,
         2457,
         2453,
         2453,
         2462,
         2466,
         2466,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2471,
         2476,
         2476,
         2476,
         2476,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2480,
         2453,
         2453,
         2484,
         2453,
         2453,
         2489,
         2453,
         2493,
         2453,
         2497,
         2453,
         2453,
         2453,
         2453,
         2500,
         2466,
         2466,
         2453,
         2453,
         2504,
         2506,
         2507,
         2508,
         2453,
         2453,
         2453,
         2453,
         2453,
         2466,
         2466,
         2462,
         2462,
         2453,
         2453,
         2462,
         2462,
         2453,
         2453,
         2462,
         2462,
         2453,
         2453,
         2462,
         2462,
         2453,
         2453,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         2509,
         2509,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         2509,
         46,
         2509,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         46,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         46,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         2509,
         2509,
         2509,
         46,
         46,
         1426,
         1426,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         1425,
         1425,
         46,
         46,
         46,
         47,
         46,
         1444,
         1425,
         1426,
         1426,
         46,
         46,
         2994,
         2994,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         46,
         1444,
         1426,
         1426,
         2997,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         46,
         2998,
         1426,
         1426,
         1425,
         1425,
         1444,
         2994,
         1425,
         1425,
         1444,
         2994,
         1425,
         1425,
         1444,
         2994,
         1425,
         1425,
         1444,
         2994,
         46,
         47,
         2993,
         2993,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         1465,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         2995,
         2993,
         1426,
         1426,
         46,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         2998,
         46,
         1426,
         1426,
         1425,
         1425,
         2993,
         1465,
         1425,
         1425,
         2993,
         1465,
         1425,
         1425,
         2993,
         1465,
         1425,
         1425,
         2993,
         1465,
         1426,
         1435,
         1426,
         1426,
         1447,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1455,
         1456,
         1456,
         1456,
         1456,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1457,
         1426,
         1426,
         1458,
         1426,
         1426,
         1459,
         1426,
         1460,
         1426,
         1461,
         1426,
         1426,
         1426,
         1426,
         2996,
         1426,
         1426,
         1426,
         1426,
         2463,
         2464,
         2465,
         2466,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1426,
         1435,
         1426,
         1426,
         1447,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1455,
         1456,
         1456,
         1456,
         1456,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1457,
         1426,
         1426,
         1458,
         1426,
         1426,
         1459,
         1426,
         1460,
         1426,
         1461,
         1426,
         1426,
         1426,
         1426,
         3101,
         1426,
         1426,
         1426,
         1426,
         2463,
         2464,
         2465,
         2466,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1425,
         1434,
         1425,
         1425,
         1446,
         1447,
         1447,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1448,
         1449,
         1449,
         1449,
         1449,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1450,
         1425,
         1425,
         1451,
         1425,
         1425,
         1452,
         1425,
         1453,
         1425,
         1454,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1425,
         1425,
         2459,
         2460,
         2461,
         2462,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1446,
         3102,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1425,
         1434,
         1425,
         1425,
         1446,
         1447,
         1447,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1448,
         1449,
         1449,
         1449,
         1449,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1450,
         1425,
         1425,
         1451,
         1425,
         1425,
         1452,
         1425,
         1453,
         1425,
         1454,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1425,
         1425,
         2459,
         2460,
         2461,
         2462,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         3102,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         46,
         47,
         1444,
         1444,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         1445,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         1444,
         1444,
         1426,
         1426,
         2458,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         1444,
         2993,
         1426,
         1426,
         1425,
         1425,
         1444,
         3103,
         1425,
         1425,
         1444,
         3103,
         1425,
         1425,
         1444,
         3103,
         1425,
         1425,
         1444,
         3103,
         46,
         47,
         46,
         1445,
         1425,
         1426,
         1426,
         46,
         46,
         1465,
         1465,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         2467,
         1445,
         1426,
         1426,
         1465,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         2994,
         1465,
         1426,
         1426,
         1425,
         1425,
         3103,
         1465,
         1425,
         1425,
         3103,
         1465,
         1425,
         1425,
         3103,
         1465,
         1425,
         1425,
         3103,
         1465,
         1425,
         1434,
         1425,
         1425,
         1446,
         1447,
         1447,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1448,
         1449,
         1449,
         1449,
         1449,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1450,
         1425,
         1425,
         1451,
         1425,
         1425,
         1452,
         1425,
         1453,
         1425,
         1454,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1425,
         1425,
         2459,
         2460,
         2461,
         2462,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1446,
         1446,
         1425,
         1425,
         1446,
         3131,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1425,
         1434,
         1425,
         1425,
         1446,
         1447,
         1447,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1448,
         1449,
         1449,
         1449,
         1449,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1450,
         1425,
         1425,
         1451,
         1425,
         1425,
         1452,
         1425,
         1453,
         1425,
         1454,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1425,
         1425,
         2459,
         2460,
         2461,
         2462,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1446,
         1446,
         1425,
         1425,
         3131,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         46,
         47,
         1444,
         1444,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         1445,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         1444,
         1444,
         1426,
         1426,
         2458,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         1444,
         2993,
         1426,
         1426,
         1425,
         1425,
         1444,
         3103,
         1425,
         1425,
         1444,
         3132,
         1425,
         1425,
         1444,
         3132,
         1425,
         1425,
         1444,
         3132,
         46,
         47,
         46,
         1445,
         1425,
         1426,
         1426,
         46,
         46,
         1465,
         1465,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         2467,
         1445,
         1426,
         1426,
         1465,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         2994,
         1465,
         1426,
         1426,
         1425,
         1425,
         3103,
         1465,
         1425,
         1425,
         3132,
         1465,
         1425,
         1425,
         3132,
         1465,
         1425,
         1425,
         3132,
         1465,
         1425,
         1434,
         1425,
         1425,
         1446,
         1447,
         1447,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1448,
         1449,
         1449,
         1449,
         1449,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1450,
         1425,
         1425,
         1451,
         1425,
         1425,
         1452,
         1425,
         1453,
         1425,
         1454,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1425,
         1425,
         2459,
         2460,
         2461,
         2462,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         3140,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1425,
         1434,
         1425,
         1425,
         1446,
         1447,
         1447,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1448,
         1449,
         1449,
         1449,
         1449,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1450,
         1425,
         1425,
         1451,
         1425,
         1425,
         1452,
         1425,
         1453,
         1425,
         1454,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1425,
         1425,
         2459,
         2460,
         2461,
         2462,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         3140,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         46,
         47,
         1444,
         1444,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         1445,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         1444,
         1444,
         1426,
         1426,
         2458,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         1444,
         2993,
         1426,
         1426,
         1425,
         1425,
         1444,
         3103,
         1425,
         1425,
         1444,
         3132,
         1425,
         1425,
         1444,
         3141,
         1425,
         1425,
         1444,
         3141,
         46,
         47,
         46,
         1445,
         1425,
         1426,
         1426,
         46,
         46,
         1465,
         1465,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         2467,
         1445,
         1426,
         1426,
         1465,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         2994,
         1465,
         1426,
         1426,
         1425,
         1425,
         3103,
         1465,
         1425,
         1425,
         3132,
         1465,
         1425,
         1425,
         3141,
         1465,
         1425,
         1425,
         3141,
         1465,
         1425,
         1434,
         1425,
         1425,
         1446,
         1447,
         1447,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1448,
         1449,
         1449,
         1449,
         1449,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1450,
         1425,
         1425,
         1451,
         1425,
         1425,
         1452,
         1425,
         1453,
         1425,
         1454,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1425,
         1425,
         2459,
         2460,
         2461,
         2462,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         3149,
         1425,
         1425,
         1425,
         1434,
         1425,
         1425,
         1446,
         1447,
         1447,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1448,
         1449,
         1449,
         1449,
         1449,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1425,
         1450,
         1425,
         1425,
         1451,
         1425,
         1425,
         1452,
         1425,
         1453,
         1425,
         1454,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1425,
         1425,
         2459,
         2460,
         2461,
         2462,
         1425,
         1425,
         1425,
         1425,
         1425,
         1447,
         1447,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         1446,
         1446,
         1425,
         1425,
         3149,
         1446,
         1425,
         1425,
         46,
         47,
         1444,
         1444,
         1425,
         1426,
         1426,
         46,
         46,
         46,
         1445,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         1444,
         1444,
         1426,
         1426,
         2458,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         1444,
         2993,
         1426,
         1426,
         1425,
         1425,
         1444,
         3103,
         1425,
         1425,
         1444,
         3132,
         1425,
         1425,
         1444,
         3141,
         1425,
         1425,
         1444,
         3150,
         46,
         47,
         46,
         1445,
         1425,
         1426,
         1426,
         46,
         46,
         1465,
         1465,
         46,
         46,
         1427,
         1428,
         1428,
         1428,
         1428,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1429,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         1432,
         46,
         1433,
         46,
         46,
         46,
         2467,
         1445,
         1426,
         1426,
         1465,
         46,
         2450,
         2451,
         2452,
         2453,
         46,
         46,
         46,
         2994,
         1465,
         1426,
         1426,
         1425,
         1425,
         3103,
         1465,
         1425,
         1425,
         3132,
         1465,
         1425,
         1425,
         3141,
         1465,
         1425,
         1425,
         3150,
         1465,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         5,
         5,
         6,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         48,
         1710,
         1711,
         1712,
         1713,
         2659,
         2660,
         2661,
         2662,
         2663,
         2664,
      },
   },
   [nir_op_umul_unorm_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         49,
         49,
         49,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         50,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         51,
         52,
         51,
         51,
         1920,
         53,
         54,
         53,
         53,
         1921,
         1922,
         1923,
         1922,
         1922,
         1924,
         1925,
         1926,
         1925,
         1925,
         1927,
         51,
         52,
         51,
         51,
         1920,
         55,
         56,
         55,
         55,
         1928,
         57,
         58,
         57,
         57,
         1929,
         1930,
         1931,
         1930,
         1930,
         1932,
         1933,
         1934,
         1933,
         1933,
         1935,
         55,
         56,
         55,
         55,
         1928,
         51,
         52,
         51,
         51,
         1920,
         53,
         54,
         53,
         53,
         1921,
         1936,
         1937,
         1936,
         1936,
         1938,
         1925,
         1926,
         1925,
         1925,
         1927,
         51,
         52,
         51,
         51,
         1920,
         51,
         52,
         51,
         51,
         1920,
         53,
         54,
         53,
         53,
         1921,
         1922,
         1923,
         1922,
         1922,
         1924,
         1939,
         1940,
         1939,
         1939,
         1941,
         51,
         52,
         51,
         51,
         1920,
         51,
         52,
         51,
         51,
         1920,
         53,
         54,
         53,
         53,
         1921,
         1922,
         1923,
         1922,
         1922,
         1924,
         1925,
         1926,
         1925,
         1925,
         1927,
         51,
         52,
         51,
         51,
         1920,
      },
   },
   [nir_op_sdot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         59,
         60,
         61,
         62,
         61,
         62,
         63,
         64,
      },
   },
   [nir_op_udot_4x8_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         65,
         66,
         67,
         68,
         67,
         68,
         69,
         70,
      },
   },
   [nir_op_sdot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         71,
         71,
         72,
         72,
         72,
         72,
         73,
         73,
      },
   },
   [nir_op_udot_4x8_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         74,
         75,
         76,
         77,
         76,
         77,
         78,
         79,
      },
   },
   [nir_op_sdot_2x16_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         80,
         81,
         82,
         83,
         82,
         83,
         84,
         85,
      },
   },
   [nir_op_udot_2x16_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         86,
         87,
         88,
         89,
         88,
         89,
         90,
         91,
      },
   },
   [nir_op_sdot_2x16_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         92,
         92,
         93,
         93,
         93,
         93,
         94,
         94,
      },
   },
   [nir_op_udot_2x16_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         95,
         95,
         96,
         96,
         96,
         96,
         97,
         97,
      },
   },
   [nir_op_sudot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         98,
         99,
         100,
         101,
         102,
         103,
         104,
         105,
      },
   },
   [nir_op_sudot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         106,
         106,
         107,
         107,
         108,
         108,
         109,
         109,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         6,
         0,
         7,
         7,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         11,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         0,
         0,
         0,
         26,
         27,
         28,
         0,
         0,
         0,
         0,
         0,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         32,
         33,
         33,
         0,
         34,
         34,
         35,
         35,
         36,
         36,
         37,
         37,
         38,
         38,
         0,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         0,
         41,
         0,
         42,
         43,
         43,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         44,
         45,
         46,
         46,
         46,
         46,
         47,
         48,
         49,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         40,
         40,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         19,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         18,
         22,
         22,
         22,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         23,
         22,
         23,
         22,
         23,
         22,
         22,
         22,
         23,
         23,
         23,
         22,
         23,
         22,
         22,
         22,
         23,
         22,
         23,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         0,
         0,
         0,
         0,
         55,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         58,
         59,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         0,
         26,
         0,
         0,
         26,
         0,
         26,
         0,
         0,
         26,
         26,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         29,
         0,
         29,
         0,
         0,
         29,
         0,
         29,
         0,
         0,
         29,
         29,
         0,
         60,
         61,
         62,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         37,
         37,
         37,
         37,
         38,
         38,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         45,
         45,
         45,
         45,
         47,
         48,
         48,
         48,
         48,
         49,
         44,
         46,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         17,
         17,
         17,
         17,
         17,
         17,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         20,
         19,
         19,
         19,
         19,
         19,
         24,
         23,
         23,
         23,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         46,
         3,
         3,
         3,
         44,
         44,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         26,
         0,
         29,
         0,
         32,
         0,
         37,
         37,
         37,
         37,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         39,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         59,
         59,
         57,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         17,
         17,
         17,
         0,
         0,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         44,
         19,
         23,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         37,
         37,
         37,
         37,
         6,
         10,
         10,
         10,
         19,
         19,
         19,
         34,
         34,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         63,
         0,
         0,
         9,
         13,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
      },
      
      .num_filtered_states = 64,
      .table = (const uint16_t []) {
      
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         116,
         117,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         496,
         116,
         497,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         114,
         115,
         498,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         499,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         500,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         501,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         502,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         503,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         504,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         505,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         506,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         507,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         508,
         509,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         510,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         508,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         511,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         512,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         513,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         514,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         515,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         516,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         517,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         518,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         519,
         520,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         521,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         519,
         522,
         523,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         524,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         522,
         525,
         526,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         527,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         525,
         528,
         529,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         530,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         528,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         531,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         532,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         533,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         534,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         535,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         536,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         537,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         538,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         539,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2755,
         2756,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2757,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         495,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         543,
         544,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         545,
         543,
         546,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         543,
         540,
         541,
         547,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         548,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         549,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         550,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         551,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         552,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         553,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         554,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         555,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         556,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         557,
         558,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         559,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         560,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         561,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         562,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         563,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         564,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         565,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         566,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         567,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         568,
         569,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         570,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         571,
         572,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         573,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         571,
         574,
         575,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         576,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         580,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         581,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         582,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         583,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         584,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         585,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         586,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         587,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         588,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         2758,
         2759,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2760,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2761,
         2762,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2763,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2764,
         2765,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2766,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2767,
         2768,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2769,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         541,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         542,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         540,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         589,
         590,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         591,
         589,
         592,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         589,
         3126,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         596,
         597,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         598,
         596,
         599,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         593,
         594,
         600,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         601,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         602,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         603,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         604,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         605,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         606,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         607,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         608,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         609,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         610,
         611,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         612,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         610,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         613,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         614,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         615,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         616,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         617,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         618,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         619,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         620,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         621,
         622,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         623,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         621,
         624,
         625,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         626,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         624,
         627,
         628,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         629,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         630,
         631,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         632,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         633,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         634,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         635,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         636,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         637,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         638,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         639,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         640,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         641,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         2770,
         2771,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2772,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2773,
         2774,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2775,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2776,
         2777,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2778,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2779,
         2780,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2781,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         594,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         645,
         646,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         647,
         645,
         648,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         642,
         643,
         649,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         650,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         651,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         652,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         653,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         654,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         655,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         656,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         657,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         658,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         659,
         660,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         661,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         662,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         663,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         664,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         665,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         666,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         667,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         668,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         669,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         670,
         671,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         672,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         670,
         673,
         674,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         675,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         676,
         677,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         678,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         676,
         679,
         680,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         681,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         679,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         682,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         683,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         684,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         685,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         686,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         687,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         688,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         689,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         690,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         2782,
         2783,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2784,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2785,
         2786,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2787,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2788,
         2789,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2790,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2791,
         2792,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2793,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         643,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         644,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         642,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         694,
         695,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         696,
         694,
         697,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         698,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         691,
         692,
         699,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         700,
         701,
         700,
         702,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         703,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         700,
         691,
         692,
         691,
         691,
         704,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         705,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         706,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         707,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         708,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         709,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         710,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         711,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         712,
         713,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         715,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         716,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         717,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         718,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         719,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         720,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         721,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         722,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         723,
         724,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         725,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         723,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         729,
         730,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         731,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         732,
         733,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         734,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         732,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         735,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         736,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         737,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         738,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         739,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         740,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         741,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         742,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         743,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         2794,
         2795,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2796,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2797,
         2798,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2799,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2800,
         2801,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2802,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2803,
         2804,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2805,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         692,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         747,
         748,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         749,
         747,
         750,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         744,
         745,
         751,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         752,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         753,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         754,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         755,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         756,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         757,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         758,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         759,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         760,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         761,
         762,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         763,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         764,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         765,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         766,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         767,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         768,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         769,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         770,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         771,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         772,
         773,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         774,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         772,
         775,
         776,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         777,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         775,
         778,
         779,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         782,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         783,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         781,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         784,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         785,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         786,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         787,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         788,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         789,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         790,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         791,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         792,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         2806,
         2807,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2808,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2809,
         2810,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2811,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2812,
         2813,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2814,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2815,
         2816,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2817,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         796,
         797,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         798,
         796,
         799,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         800,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         793,
         794,
         801,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         802,
         803,
         802,
         804,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         805,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         802,
         793,
         794,
         793,
         793,
         806,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         807,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         808,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         809,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         810,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         811,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         812,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         813,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         814,
         815,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         816,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         817,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         818,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         819,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         820,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         821,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         822,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         823,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         824,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         825,
         826,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         827,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         828,
         829,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         830,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         828,
         831,
         832,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         833,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         831,
         834,
         835,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         836,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         834,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         837,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         838,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         839,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         840,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         841,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         842,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         843,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         844,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         845,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         2818,
         2819,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2820,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2821,
         2822,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2823,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2824,
         2825,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2826,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2827,
         2828,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2829,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         794,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         795,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         793,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         849,
         850,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         851,
         849,
         852,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         846,
         847,
         853,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         854,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         855,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         856,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         857,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         858,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         859,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         860,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         861,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         862,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         863,
         864,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         865,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         863,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         866,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         867,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         868,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         869,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         870,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         871,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         872,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         873,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         877,
         878,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         879,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         880,
         881,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         882,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         880,
         883,
         884,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         885,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         886,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         887,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         888,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         889,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         890,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         891,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         892,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         893,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         894,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         2830,
         2831,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2832,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2833,
         2834,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2835,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2836,
         2837,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2838,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2839,
         2840,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2841,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         847,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         848,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         846,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         898,
         899,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         900,
         898,
         901,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         898,
         895,
         896,
         902,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         903,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         904,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         905,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         906,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         907,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         908,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         909,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         910,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         911,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         912,
         913,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         914,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         912,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         915,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         916,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         917,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         918,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         919,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         920,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         921,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         922,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         923,
         924,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         925,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         926,
         927,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         928,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         926,
         929,
         930,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         931,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         929,
         932,
         933,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         934,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         932,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         935,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         936,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         937,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         938,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         939,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         940,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         941,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         942,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         943,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         2842,
         2843,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2844,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2845,
         2846,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2847,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2848,
         2849,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2850,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2851,
         2852,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2853,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         896,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         897,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         895,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         947,
         948,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         949,
         947,
         950,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         944,
         945,
         951,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         952,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         953,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         954,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         955,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         956,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         957,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         958,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         959,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         960,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         961,
         962,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         964,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         965,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         966,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         967,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         968,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         969,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         970,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         971,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         972,
         973,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         974,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         975,
         976,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         977,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         975,
         978,
         979,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         980,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         978,
         981,
         982,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         983,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         981,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         984,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         985,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         986,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         987,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         988,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         989,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         990,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         991,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         992,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         2854,
         2855,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2856,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2857,
         2858,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2859,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2860,
         2861,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2862,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2863,
         2864,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2865,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         945,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         996,
         997,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         998,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         993,
         994,
         1000,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         1001,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         1002,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         1003,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         1004,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         1005,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1006,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1007,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1008,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1009,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1010,
         1011,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1012,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         1010,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1013,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         1014,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1015,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1016,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1017,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1018,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1019,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1020,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1021,
         1022,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1024,
         1025,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1026,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1024,
         1027,
         1028,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1029,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1027,
         1030,
         1031,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1032,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         1030,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1033,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1034,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1035,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1036,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1037,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1038,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1039,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1040,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1041,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         2866,
         2867,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2868,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2869,
         2870,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2871,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2872,
         2873,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2874,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2875,
         2876,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2877,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         994,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         995,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         993,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1045,
         1046,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1047,
         1045,
         1048,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1042,
         1043,
         1049,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1050,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1051,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1052,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1053,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1054,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1055,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1056,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1057,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1058,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1059,
         1060,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1061,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1059,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1062,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1063,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1064,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1065,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1066,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1067,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1068,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1069,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1070,
         1071,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1072,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1070,
         1073,
         1074,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1075,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1073,
         1076,
         1077,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1078,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1076,
         1079,
         1080,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1081,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1079,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1082,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1083,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1084,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1085,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1086,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1087,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1088,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1089,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1090,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         2878,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         2879,
         2880,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2881,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2879,
         2882,
         2883,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2884,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2882,
         2885,
         2886,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2887,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2885,
         2888,
         2889,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2890,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1043,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1044,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1094,
         1095,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1096,
         1094,
         1097,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1094,
         1091,
         1092,
         1098,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1099,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1100,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1101,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1102,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1103,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1104,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1105,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1106,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1107,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1108,
         1109,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1110,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1108,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1111,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1112,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1113,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1114,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1115,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1116,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1117,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1118,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1119,
         1120,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1121,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1119,
         1122,
         1123,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1124,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1122,
         1125,
         1126,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1127,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1128,
         1129,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1130,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1131,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1132,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1133,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1134,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1135,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1136,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1137,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1138,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1139,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         2891,
         2892,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2893,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2894,
         2895,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2896,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2897,
         2898,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2899,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2900,
         2901,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2902,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1092,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1091,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1143,
         1144,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1145,
         1143,
         1146,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1143,
         1140,
         1141,
         1147,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1148,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1149,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1150,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1151,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1152,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1153,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1154,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1155,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1156,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1157,
         1158,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1159,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1157,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1160,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1161,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1162,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1163,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1164,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1165,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1166,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1167,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1168,
         1169,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1170,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1168,
         1171,
         1172,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1173,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1171,
         1174,
         1175,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1176,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1174,
         1177,
         1178,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1179,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1180,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1181,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1182,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1183,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1184,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1185,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1186,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1187,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1188,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         2903,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         2904,
         2905,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2906,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2904,
         2907,
         2908,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2909,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2907,
         2910,
         2911,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2912,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2910,
         2913,
         2914,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2915,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1141,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1142,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1140,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1192,
         1193,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1194,
         1192,
         1195,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1189,
         1190,
         1196,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1197,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1198,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1199,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1200,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1201,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1202,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1203,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1204,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1205,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1206,
         1207,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1208,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1209,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1210,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1211,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1212,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1213,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1214,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1215,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1216,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1217,
         1218,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1219,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1220,
         1221,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1222,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1223,
         1224,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1225,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1226,
         1227,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1228,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1229,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1230,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1231,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1232,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1233,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1234,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1235,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1236,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1237,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         2916,
         2917,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2918,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2919,
         2920,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2921,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2922,
         2923,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2924,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2925,
         2926,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2927,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1241,
         1242,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1243,
         1241,
         1244,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1241,
         1238,
         1239,
         1245,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1246,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1247,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1248,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1249,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1250,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1251,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1252,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1253,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1254,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1255,
         1256,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1257,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1255,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1258,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1259,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1260,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1261,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1262,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1263,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1264,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1265,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1266,
         1267,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1268,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1266,
         1269,
         1270,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1271,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1272,
         1273,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1274,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1275,
         1276,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1277,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1275,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1278,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1279,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1280,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1281,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1282,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1283,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1284,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1285,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1286,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         2928,
         2929,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2930,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2931,
         2932,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2933,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2934,
         2935,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2936,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2937,
         2938,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2939,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1239,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1240,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1238,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1290,
         1291,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1292,
         1290,
         1293,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1290,
         1287,
         1288,
         1294,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1295,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1296,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1297,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1298,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1299,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1300,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1301,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1302,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1303,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1304,
         1305,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1306,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1304,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1307,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1308,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1309,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1310,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1311,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1312,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1313,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1314,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1315,
         1316,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1317,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1315,
         1318,
         1319,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1320,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1318,
         1321,
         1322,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1323,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1321,
         1324,
         1325,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1326,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1324,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1327,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1328,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1329,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1330,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1331,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1332,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1333,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1334,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1335,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         2940,
         2941,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2942,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2943,
         2944,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2945,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2946,
         2947,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2948,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2949,
         2950,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2951,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1288,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1289,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         1287,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1336,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1337,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1338,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1192,
         1193,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1194,
         1192,
         1195,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1189,
         1190,
         1196,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1197,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1198,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1199,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1200,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1201,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1202,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1203,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1204,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1205,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1206,
         1207,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1208,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1209,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1210,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1211,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1212,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1213,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1214,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1215,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1216,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1217,
         1218,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1219,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1220,
         1221,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1222,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1223,
         1224,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1225,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1226,
         1227,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1228,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1229,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1230,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1231,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1232,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1233,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1234,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1235,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1236,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1237,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         2952,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         2916,
         2917,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2918,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2919,
         2920,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2921,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2922,
         2923,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2924,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2925,
         2926,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2927,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1192,
         1193,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1194,
         1192,
         1195,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1189,
         1190,
         1196,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1197,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1198,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1199,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1200,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1201,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1202,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1203,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1204,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1205,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1206,
         1207,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1208,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1209,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1210,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1211,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1212,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1213,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1214,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1215,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1216,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1217,
         1218,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1219,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1220,
         1221,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1222,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1223,
         1224,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1225,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1226,
         1227,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1228,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1229,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1230,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1231,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1232,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1233,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1234,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1235,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1236,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1237,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         2953,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         2916,
         2917,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2918,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2919,
         2920,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2921,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2922,
         2923,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2924,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2925,
         2926,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2927,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1192,
         1193,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1194,
         1192,
         1195,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1189,
         1190,
         1196,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1197,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1198,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1199,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1200,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1201,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1202,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1203,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1204,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1205,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1206,
         1207,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1208,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1206,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1209,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1210,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1211,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1212,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1213,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1214,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1215,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1216,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1217,
         1218,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1219,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1220,
         1221,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1222,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1220,
         1223,
         1224,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1225,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1223,
         1226,
         1227,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1228,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1226,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1229,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1230,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1231,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1232,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1233,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1234,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1235,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1236,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1237,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         2954,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         2916,
         2917,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2918,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2919,
         2920,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2921,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2922,
         2923,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2924,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2925,
         2926,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2927,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         451,
         112,
         452,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         453,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         464,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         465,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         463,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         466,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         477,
         478,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         479,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         477,
         480,
         481,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         482,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         480,
         483,
         484,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         485,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         483,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         486,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2734,
         2735,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2736,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2734,
         2737,
         2738,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2739,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2737,
         2740,
         2741,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2742,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2740,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         450,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         2,
         2,
         14,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         17,
         4,
         4,
         0,
         2,
         2,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         17,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         118,
         119,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1714,
         1714,
         1715,
         118,
         1715,
         119,
         119,
         1716,
         1717,
         1718,
         1719,
         1720,
         1721,
         1722,
         1723,
         119,
         2364,
         2365,
         2366,
         1716,
         2367,
         2368,
         3083,
         1714,
         1716,
         1724,
         1714,
         1725,
         1725,
         1714,
         1714,
         1714,
         1714,
         1714,
         1714,
         1714,
         1724,
         1724,
         1725,
         1714,
         1725,
         118,
         1717,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1714,
         1714,
         1715,
         118,
         1715,
         1715,
         1718,
         1725,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1725,
         1725,
         1715,
         1715,
         1715,
         1715,
         1719,
         1725,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1725,
         1725,
         1715,
         1715,
         1715,
         118,
         1720,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1714,
         1714,
         1715,
         118,
         1715,
         118,
         1721,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1714,
         1714,
         1715,
         118,
         1715,
         118,
         1722,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         1726,
         118,
         118,
         118,
         118,
         1714,
         2369,
         1715,
         118,
         1715,
         118,
         1723,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1714,
         1714,
         1715,
         118,
         1715,
         118,
         119,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         118,
         118,
         1727,
         118,
         118,
         1714,
         1714,
         1715,
         118,
         1715,
         118,
         2364,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1714,
         1714,
         1715,
         118,
         1715,
         118,
         2365,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1714,
         1714,
         1715,
         118,
         1715,
         1714,
         2366,
         1724,
         1714,
         1725,
         1725,
         1714,
         1714,
         1714,
         1714,
         1714,
         1714,
         1714,
         1724,
         1724,
         1725,
         1714,
         1725,
         1714,
         1716,
         1724,
         1714,
         1725,
         1725,
         1714,
         1714,
         2369,
         1714,
         1714,
         1714,
         1714,
         1724,
         2370,
         1725,
         1714,
         1725,
         1715,
         2367,
         1725,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1725,
         1725,
         1715,
         1715,
         1715,
         118,
         2368,
         1714,
         118,
         1715,
         1715,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1714,
         1714,
         1715,
         118,
         1715,
         1715,
         3083,
         1725,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1725,
         1725,
         1715,
         1715,
         1715,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         120,
         2164,
         2165,
         2166,
      },
   },
   [nir_op_ftrunc] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         121,
      },
   },
   [nir_op_ffloor] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         122,
      },
   },
   [nir_op_ffract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         123,
      },
   },
   [nir_op_fceil] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         124,
      },
   },
   [nir_search_op_b2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         125,
         2167,
         2168,
         2169,
         2170,
         2955,
         2956,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         126,
      },
   },
   [nir_op_fdot4] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         127,
         2154,
         2155,
         2156,
         2154,
         2154,
         2155,
         2156,
         2155,
         2155,
         2155,
         2156,
         2156,
         2156,
         2156,
         2156,
      },
   },
   [nir_op_vec4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         128,
         129,
         128,
         130,
         128,
         129,
         128,
         131,
         128,
         129,
         128,
         130,
         128,
         129,
         128,
         131,
      },
   },
   [nir_op_fdot3] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         132,
         2157,
         2158,
         2157,
         2157,
         2158,
         2158,
         2158,
         2158,
      },
   },
   [nir_op_vec3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         133,
         134,
         133,
         135,
         133,
         134,
         133,
         135,
      },
   },
   [nir_op_fdot2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         136,
         137,
         2159,
         137,
         137,
         2160,
         2159,
         2160,
         2159,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         138,
         139,
         138,
         138,
         140,
         141,
         140,
         140,
         138,
         139,
         138,
         1564,
         138,
         139,
         138,
         138,
      },
   },
   [nir_op_fsum2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         142,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         10,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         12,
         0,
         3,
         3,
         2,
         4,
         13,
         8,
         2,
         4,
         14,
         3,
         3,
         2,
         4,
         15,
         8,
         2,
         4,
         16,
         3,
         3,
         2,
         4,
         0,
         8,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         143,
         144,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         145,
         146,
         145,
         1540,
         145,
         1541,
         145,
         2360,
         145,
         145,
         1540,
         145,
         1540,
         145,
         1540,
         145,
         1540,
         1542,
         1543,
         1542,
         1544,
         1542,
         1545,
         1542,
         2361,
         1542,
         1542,
         1544,
         1542,
         1544,
         1542,
         1544,
         1542,
         1544,
         143,
         144,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1546,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         144,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1547,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         144,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         2362,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         2363,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         3033,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         3124,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         3130,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         3134,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         3139,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         3143,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         3148,
         143,
         1538,
         143,
         1539,
         143,
         2359,
         143,
         143,
         1538,
         143,
         1538,
         143,
         1538,
         143,
         1538,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         4,
         0,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         147,
         148,
         147,
         147,
         1548,
         147,
         149,
         150,
         149,
         149,
         1549,
         149,
         147,
         1550,
         147,
         147,
         1548,
         147,
         1551,
         1552,
         1551,
         1551,
         1553,
         1551,
         147,
         148,
         147,
         147,
         1548,
         147,
         147,
         1554,
         147,
         147,
         1548,
         147,
      },
   },
   [nir_op_inot] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         5,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         8,
         8,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         11,
         11,
         11,
         11,
         12,
         12,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         22,
         22,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         23,
         21,
         21,
         21,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         11,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         8,
         0,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         151,
         1906,
         1907,
         1908,
         1909,
         1910,
         1911,
         1912,
         1913,
         1914,
         1915,
         1916,
         1917,
         1918,
         1919,
         2510,
         2511,
         2512,
         2513,
         2514,
         2515,
         3029,
         3030,
         3031,
      },
   },
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         2,
         14,
         2,
         2,
         2,
         2,
         2,
         15,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         16,
         5,
         17,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         16,
         5,
         5,
         5,
         5,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         16,
         5,
         17,
         17,
         17,
         17,
         17,
         17,
         6,
         6,
         16,
         16,
         5,
         16,
         16,
         5,
         0,
         19,
         2,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         20,
         6,
         6,
         21,
         16,
         16,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         16,
         16,
         5,
         5,
         5,
         5,
         16,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         22,
         9,
         9,
         22,
         9,
         9,
         22,
         9,
         22,
         22,
         9,
         22,
         9,
         22,
         9,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         152,
         153,
         1728,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1728,
         1728,
         1728,
         152,
         152,
         152,
         1728,
         152,
         152,
         1729,
         154,
         155,
         1731,
         1732,
         1733,
         154,
         154,
         1734,
         1735,
         1736,
         1737,
         1738,
         154,
         1731,
         1731,
         1731,
         154,
         154,
         2604,
         1731,
         154,
         154,
         1736,
         152,
         1739,
         1740,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1740,
         1740,
         1740,
         152,
         152,
         152,
         1740,
         152,
         152,
         1729,
         152,
         153,
         1728,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1728,
         1728,
         1728,
         152,
         152,
         152,
         1728,
         152,
         152,
         1729,
         152,
         1741,
         1728,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1728,
         1728,
         1728,
         152,
         152,
         152,
         1728,
         152,
         152,
         1729,
         1742,
         1743,
         1744,
         1742,
         1742,
         1742,
         1742,
         1742,
         1742,
         1745,
         1742,
         1746,
         1742,
         1744,
         1744,
         1744,
         1742,
         1742,
         1742,
         1744,
         1742,
         1742,
         1745,
         1742,
         1747,
         1744,
         1742,
         1742,
         1742,
         1742,
         1742,
         1742,
         1745,
         1742,
         1746,
         1742,
         1744,
         1744,
         1744,
         1742,
         1742,
         1742,
         1744,
         1742,
         1742,
         1745,
         152,
         153,
         1728,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1728,
         1728,
         1728,
         152,
         152,
         152,
         1728,
         152,
         152,
         1729,
         152,
         1748,
         1728,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1728,
         1728,
         1728,
         152,
         152,
         152,
         1728,
         152,
         152,
         1729,
         1749,
         1750,
         1751,
         1749,
         1749,
         1749,
         1749,
         1749,
         1749,
         1752,
         1749,
         1753,
         1749,
         1751,
         1751,
         1751,
         1749,
         1749,
         1749,
         1751,
         1749,
         1749,
         1752,
         152,
         1754,
         1728,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1728,
         1728,
         1728,
         152,
         152,
         152,
         1728,
         152,
         152,
         1729,
         1755,
         1756,
         1757,
         1755,
         1755,
         1755,
         1755,
         1755,
         1755,
         1758,
         1755,
         1759,
         1755,
         1757,
         1757,
         1757,
         1755,
         1755,
         1755,
         1757,
         1755,
         1755,
         1758,
         152,
         153,
         1728,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         1760,
         1728,
         1728,
         1728,
         152,
         152,
         152,
         1728,
         152,
         152,
         1729,
         152,
         2605,
         1740,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1740,
         1740,
         1740,
         152,
         152,
         152,
         1740,
         152,
         152,
         1729,
         152,
         2606,
         1740,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1740,
         1740,
         1740,
         152,
         152,
         152,
         1740,
         152,
         152,
         1729,
         152,
         2607,
         1740,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1740,
         1740,
         1740,
         152,
         152,
         152,
         1740,
         152,
         152,
         1729,
         1742,
         2608,
         1744,
         1742,
         1742,
         1742,
         1742,
         1742,
         1742,
         1745,
         1742,
         1746,
         1742,
         1744,
         1744,
         1744,
         1742,
         1742,
         1742,
         1744,
         1742,
         1742,
         1745,
         1742,
         2609,
         1744,
         1742,
         1742,
         1742,
         1742,
         1742,
         1742,
         1745,
         1742,
         1746,
         1742,
         1744,
         1744,
         1744,
         1742,
         1742,
         1742,
         1744,
         1742,
         1742,
         1745,
         1742,
         1743,
         1744,
         1742,
         1742,
         1742,
         1742,
         1742,
         1742,
         1745,
         1742,
         1746,
         1742,
         1744,
         1744,
         1744,
         1742,
         1742,
         1742,
         1744,
         1742,
         1742,
         1745,
         152,
         3086,
         1740,
         152,
         152,
         152,
         152,
         152,
         152,
         1729,
         152,
         1730,
         152,
         1740,
         1740,
         1740,
         152,
         152,
         152,
         1740,
         152,
         152,
         1729,
         1742,
         3104,
         1744,
         1742,
         1742,
         1742,
         1742,
         1742,
         1742,
         1745,
         1742,
         1746,
         1742,
         1744,
         1744,
         1744,
         1742,
         1742,
         1742,
         1744,
         1742,
         1742,
         1745,
         1742,
         3105,
         1744,
         1742,
         1742,
         1742,
         1742,
         1742,
         1742,
         1745,
         1742,
         1746,
         1742,
         1744,
         1744,
         1744,
         1742,
         1742,
         1742,
         1744,
         1742,
         1742,
         1745,
         1749,
         3106,
         1751,
         1749,
         1749,
         1749,
         1749,
         1749,
         1749,
         1752,
         1749,
         1753,
         1749,
         1751,
         1751,
         1751,
         1749,
         1749,
         1749,
         1751,
         1749,
         1749,
         1752,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         14,
         2,
         15,
         2,
         2,
         2,
         2,
         2,
         16,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         7,
         7,
         7,
         7,
         7,
         7,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         18,
         2,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         156,
         157,
         1761,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1761,
         1761,
         1761,
         156,
         1761,
         158,
         159,
         1764,
         1765,
         1766,
         158,
         158,
         158,
         1767,
         1768,
         1769,
         1770,
         1771,
         158,
         1764,
         1764,
         1764,
         2610,
         1764,
         156,
         1772,
         1773,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1773,
         1773,
         1773,
         156,
         1773,
         156,
         157,
         1761,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1761,
         1761,
         1761,
         156,
         1761,
         156,
         1774,
         1761,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1761,
         1761,
         1761,
         156,
         1761,
         1775,
         1776,
         1777,
         1775,
         1775,
         1775,
         1775,
         1775,
         1775,
         1775,
         1778,
         1775,
         1779,
         1775,
         1777,
         1777,
         1777,
         1775,
         1777,
         1775,
         1780,
         1777,
         1775,
         1775,
         1775,
         1775,
         1775,
         1775,
         1775,
         1778,
         1775,
         1779,
         1775,
         1777,
         1777,
         1777,
         1775,
         1777,
         156,
         1781,
         1761,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1761,
         1761,
         1761,
         156,
         1761,
         156,
         1782,
         1761,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1761,
         1761,
         1761,
         156,
         1761,
         156,
         157,
         1761,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1761,
         1761,
         1761,
         156,
         1761,
         1783,
         1784,
         1785,
         1783,
         1783,
         1783,
         1783,
         1783,
         1783,
         1783,
         1786,
         1783,
         1787,
         1783,
         1785,
         1785,
         1785,
         1783,
         1785,
         156,
         1788,
         1761,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1761,
         1761,
         1761,
         156,
         1761,
         1789,
         1790,
         1791,
         1789,
         1789,
         1789,
         1789,
         1789,
         1789,
         1789,
         1792,
         1789,
         1793,
         1789,
         1791,
         1791,
         1791,
         1789,
         1791,
         156,
         157,
         1761,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         1794,
         1761,
         1761,
         1761,
         156,
         1761,
         156,
         2611,
         1773,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1773,
         1773,
         1773,
         156,
         1773,
         156,
         2612,
         1773,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1773,
         1773,
         1773,
         156,
         1773,
         156,
         2613,
         1773,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1773,
         1773,
         1773,
         156,
         1773,
         1775,
         1776,
         1777,
         1775,
         1775,
         1775,
         1775,
         1775,
         1775,
         1775,
         1778,
         1775,
         1779,
         1775,
         1777,
         1777,
         1777,
         1775,
         1777,
         156,
         3087,
         1773,
         156,
         156,
         156,
         156,
         156,
         156,
         156,
         1762,
         156,
         1763,
         156,
         1773,
         1773,
         1773,
         156,
         1773,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         2,
         2,
         14,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         17,
         4,
         4,
         0,
         2,
         2,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         17,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         160,
         161,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1795,
         1795,
         1796,
         160,
         1796,
         161,
         161,
         1797,
         1798,
         1799,
         1800,
         1801,
         1802,
         1803,
         1804,
         161,
         2371,
         2372,
         2373,
         1797,
         2374,
         2375,
         3084,
         1795,
         1797,
         1805,
         1795,
         1806,
         1806,
         1795,
         1795,
         1795,
         1795,
         1795,
         1795,
         1795,
         1805,
         1805,
         1806,
         1795,
         1806,
         160,
         1798,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1795,
         1795,
         1796,
         160,
         1796,
         1796,
         1799,
         1806,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1806,
         1806,
         1796,
         1796,
         1796,
         1796,
         1800,
         1806,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1806,
         1806,
         1796,
         1796,
         1796,
         160,
         1801,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1795,
         1795,
         1796,
         160,
         1796,
         160,
         1802,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1795,
         1795,
         1796,
         160,
         1796,
         160,
         1803,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         1807,
         160,
         160,
         160,
         160,
         1795,
         2376,
         1796,
         160,
         1796,
         160,
         1804,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1795,
         1795,
         1796,
         160,
         1796,
         160,
         161,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         160,
         160,
         1808,
         160,
         160,
         1795,
         1795,
         1796,
         160,
         1796,
         160,
         2371,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1795,
         1795,
         1796,
         160,
         1796,
         160,
         2372,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1795,
         1795,
         1796,
         160,
         1796,
         1795,
         2373,
         1805,
         1795,
         1806,
         1806,
         1795,
         1795,
         1795,
         1795,
         1795,
         1795,
         1795,
         1805,
         1805,
         1806,
         1795,
         1806,
         1795,
         1797,
         1805,
         1795,
         1806,
         1806,
         1795,
         1795,
         2376,
         1795,
         1795,
         1795,
         1795,
         1805,
         2377,
         1806,
         1795,
         1806,
         1796,
         2374,
         1806,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1806,
         1806,
         1796,
         1796,
         1796,
         160,
         2375,
         1795,
         160,
         1796,
         1796,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1795,
         1795,
         1796,
         160,
         1796,
         1796,
         3084,
         1806,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1806,
         1806,
         1796,
         1796,
         1796,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         162,
         163,
         162,
         2075,
         2075,
         2076,
         2076,
         162,
         162,
         164,
         165,
         2077,
         2078,
         2079,
         2080,
         2081,
         2082,
         164,
         162,
         2083,
         162,
         2075,
         2075,
         2076,
         2076,
         162,
         162,
         2084,
         2085,
         2084,
         2086,
         2086,
         2087,
         2087,
         2084,
         2084,
         2084,
         2088,
         2084,
         2086,
         2086,
         2087,
         2087,
         2084,
         2084,
         2089,
         2090,
         2089,
         2091,
         2091,
         2092,
         2092,
         2089,
         2089,
         2089,
         2093,
         2089,
         2091,
         2091,
         2092,
         2092,
         2089,
         2089,
         162,
         2094,
         162,
         2075,
         2075,
         2076,
         2076,
         2095,
         162,
         162,
         2717,
         162,
         2075,
         2075,
         2076,
         2076,
         162,
         162,
      },
   },
   [nir_op_ult] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         166,
         167,
         1973,
         166,
         166,
         1974,
         1974,
         1975,
         1975,
         166,
         166,
         168,
         169,
         1976,
         168,
         1977,
         1978,
         1979,
         1980,
         1981,
         1982,
         2718,
         166,
         167,
         1973,
         166,
         166,
         1974,
         1974,
         1975,
         1975,
         166,
         166,
         1983,
         1984,
         1985,
         1983,
         1983,
         1986,
         1986,
         1987,
         1987,
         1983,
         1983,
         166,
         1988,
         1973,
         166,
         166,
         1974,
         1974,
         1975,
         1975,
         166,
         166,
         1989,
         1990,
         1991,
         1989,
         1989,
         1992,
         1992,
         1993,
         1993,
         1989,
         1989,
         1989,
         1994,
         1991,
         1989,
         1989,
         1992,
         1992,
         1993,
         1993,
         1989,
         1989,
         1995,
         1996,
         1997,
         1995,
         1995,
         1998,
         1998,
         1999,
         1999,
         1995,
         1995,
         1995,
         2000,
         1997,
         1995,
         1995,
         1998,
         1998,
         1999,
         1999,
         1995,
         1995,
         166,
         2001,
         1973,
         166,
         166,
         1974,
         1974,
         1975,
         1975,
         2002,
         166,
         166,
         167,
         1973,
         166,
         166,
         1974,
         1974,
         1975,
         1975,
         166,
         166,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         170,
         171,
         170,
         2096,
         2096,
         2097,
         2097,
         170,
         170,
         170,
         170,
         170,
         172,
         173,
         2098,
         2099,
         2100,
         2101,
         2102,
         2103,
         172,
         172,
         172,
         172,
         170,
         2104,
         170,
         2096,
         2096,
         2097,
         2097,
         170,
         170,
         170,
         170,
         170,
         2105,
         2106,
         2105,
         2107,
         2107,
         2108,
         2108,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2109,
         2105,
         2107,
         2107,
         2108,
         2108,
         2105,
         2105,
         2105,
         2105,
         2105,
         2110,
         2111,
         2110,
         2112,
         2112,
         2113,
         2113,
         2110,
         2110,
         2110,
         2110,
         2110,
         2110,
         2114,
         2110,
         2112,
         2112,
         2113,
         2113,
         2110,
         2110,
         2110,
         2110,
         2110,
         170,
         2115,
         170,
         2096,
         2096,
         2097,
         2097,
         2116,
         170,
         170,
         170,
         170,
         170,
         2117,
         170,
         2096,
         2096,
         2097,
         2097,
         170,
         170,
         170,
         170,
         170,
         170,
         2118,
         170,
         2096,
         2096,
         2097,
         2097,
         170,
         170,
         170,
         170,
         170,
         170,
         2119,
         170,
         2096,
         2096,
         2097,
         2097,
         170,
         170,
         170,
         170,
         170,
         170,
         2719,
         170,
         2096,
         2096,
         2097,
         2097,
         170,
         170,
         170,
         170,
         170,
      },
   },
   [nir_op_uge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         174,
         174,
         2003,
         174,
         174,
         2004,
         2004,
         2005,
         2005,
         174,
         175,
         175,
         2006,
         175,
         2007,
         2008,
         2009,
         2010,
         2011,
         2012,
         174,
         174,
         2003,
         174,
         174,
         2004,
         2004,
         2005,
         2005,
         174,
         2013,
         2013,
         2014,
         2013,
         2013,
         2015,
         2015,
         2016,
         2016,
         2013,
         174,
         2017,
         2003,
         174,
         174,
         2004,
         2004,
         2005,
         2005,
         174,
         2018,
         2018,
         2019,
         2018,
         2018,
         2020,
         2020,
         2021,
         2021,
         2018,
         2018,
         2022,
         2019,
         2018,
         2018,
         2020,
         2020,
         2021,
         2021,
         2018,
         2023,
         2023,
         2024,
         2023,
         2023,
         2025,
         2025,
         2026,
         2026,
         2023,
         2023,
         2027,
         2024,
         2023,
         2023,
         2025,
         2025,
         2026,
         2026,
         2023,
         174,
         2028,
         2003,
         174,
         174,
         2004,
         2004,
         2005,
         2005,
         2029,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         0,
         13,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         11,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         9,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         176,
         177,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         177,
         177,
         1943,
         1944,
         1945,
         1946,
         1947,
         1948,
         1949,
         1950,
         1951,
         1952,
         1953,
         1954,
         1955,
         2720,
         1942,
         1943,
         1942,
         1942,
         1942,
         1942,
         1942,
         1942,
         1942,
         1942,
         1942,
         1942,
         1942,
         1942,
         1942,
         1942,
         176,
         1944,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1945,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1946,
         1942,
         176,
         176,
         1956,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1947,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1948,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1949,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1950,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         1957,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1951,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1958,
         176,
         176,
         176,
         176,
         176,
         176,
         1952,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1953,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1954,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         1955,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         2720,
         1942,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
         176,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         8,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         178,
         179,
         1959,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         179,
         179,
         1960,
         1961,
         1962,
         1963,
         1964,
         1965,
         1966,
         1967,
         1968,
         1969,
         2721,
         1959,
         1960,
         1959,
         1959,
         1959,
         1959,
         1959,
         1959,
         1959,
         1959,
         1959,
         1959,
         1959,
         178,
         1961,
         1959,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         1962,
         1959,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         1963,
         1959,
         178,
         178,
         1970,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         1964,
         1959,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         1965,
         1959,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         1966,
         1959,
         178,
         178,
         178,
         178,
         178,
         1971,
         178,
         178,
         178,
         178,
         178,
         1967,
         1959,
         178,
         178,
         178,
         178,
         178,
         178,
         1972,
         178,
         178,
         178,
         178,
         1968,
         1959,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         1969,
         1959,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         2721,
         1959,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         178,
         2722,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         9,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         10,
         2,
         2,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         6,
         6,
         6,
         12,
         6,
         12,
         6,
         6,
         12,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         12,
         12,
         6,
         6,
         12,
         12,
         12,
         6,
         6,
         12,
         6,
         12,
         6,
         12,
         7,
         7,
         13,
         7,
         8,
         8,
         8,
         14,
         14,
         8,
         13,
         7,
         7,
         7,
         13,
         7,
         7,
         7,
         13,
         7,
         13,
         7,
         7,
         13,
         7,
         13,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         2,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         180,
         181,
         1809,
         1810,
         180,
         180,
         1811,
         1812,
         1812,
         2614,
         1809,
         2615,
         2616,
         3034,
         3034,
         3035,
         181,
         181,
         1813,
         1814,
         1815,
         1816,
         1817,
         1818,
         1819,
         2617,
         1813,
         2618,
         2619,
         3036,
         3037,
         3038,
         1809,
         1813,
         1809,
         1820,
         1809,
         1809,
         1821,
         1822,
         1822,
         2614,
         1809,
         2615,
         2620,
         3039,
         3039,
         3035,
         1810,
         1814,
         1820,
         1810,
         1810,
         1810,
         1823,
         1824,
         1824,
         2621,
         1820,
         2622,
         2623,
         3040,
         3040,
         3041,
         180,
         1815,
         1809,
         1810,
         180,
         180,
         1811,
         1812,
         1812,
         2614,
         1809,
         2615,
         2616,
         3034,
         3034,
         3035,
         180,
         1816,
         1809,
         1810,
         180,
         1825,
         1811,
         1812,
         1812,
         2614,
         1809,
         2615,
         2616,
         3034,
         3034,
         3035,
         1811,
         1817,
         1821,
         1823,
         1811,
         1811,
         1811,
         1826,
         1826,
         2624,
         1821,
         2625,
         2616,
         3042,
         3042,
         3043,
         1812,
         1818,
         1822,
         1824,
         1812,
         1812,
         1826,
         1812,
         1812,
         2626,
         1822,
         2627,
         2628,
         3034,
         3034,
         3044,
         1812,
         1819,
         1822,
         1824,
         1812,
         1812,
         1826,
         1812,
         1812,
         2626,
         1822,
         2627,
         2628,
         3034,
         3034,
         3044,
         2614,
         2617,
         2614,
         2621,
         2614,
         2614,
         2624,
         2626,
         2626,
         2614,
         2614,
         2629,
         2630,
         3045,
         3045,
         3046,
         1809,
         1813,
         1809,
         1820,
         1809,
         1809,
         1821,
         1822,
         1822,
         2614,
         2631,
         2615,
         2620,
         3039,
         3039,
         3035,
         2615,
         2618,
         2615,
         2622,
         2615,
         2615,
         2625,
         2627,
         2627,
         2629,
         2615,
         2615,
         2632,
         3047,
         3047,
         3048,
         2616,
         2619,
         2620,
         2623,
         2616,
         2616,
         2616,
         2628,
         2628,
         2630,
         2620,
         2632,
         2616,
         3049,
         3049,
         3050,
         3034,
         3036,
         3039,
         3040,
         3034,
         3034,
         3042,
         3034,
         3034,
         3045,
         3039,
         3047,
         3049,
         3034,
         3034,
         3051,
         3034,
         3037,
         3039,
         3040,
         3034,
         3034,
         3042,
         3034,
         3034,
         3045,
         3039,
         3047,
         3049,
         3034,
         3034,
         3051,
         3035,
         3038,
         3035,
         3041,
         3035,
         3035,
         3043,
         3044,
         3044,
         3046,
         3035,
         3048,
         3050,
         3051,
         3051,
         3035,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         182,
         2138,
         2139,
         2140,
         2141,
         3122,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         9,
         2,
         10,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         14,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         7,
         7,
         7,
         14,
         14,
         14,
         14,
         7,
         7,
         14,
         7,
         7,
         14,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         13,
         13,
         6,
         12,
         12,
         0,
         12,
         0,
         12,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         183,
         184,
         1827,
         1828,
         183,
         183,
         183,
         1829,
         2633,
         1827,
         2634,
         183,
         2635,
         2635,
         2636,
         183,
         183,
         184,
         184,
         1830,
         1831,
         1832,
         184,
         1833,
         1834,
         2637,
         1830,
         2638,
         2639,
         2640,
         2641,
         2642,
         3107,
         3108,
         1827,
         1830,
         1827,
         1835,
         1827,
         1827,
         1827,
         1836,
         2633,
         1827,
         2634,
         1827,
         2643,
         2643,
         2644,
         1827,
         1827,
         1828,
         1831,
         1835,
         1828,
         1828,
         1828,
         1828,
         1837,
         2645,
         1835,
         2646,
         1828,
         2647,
         2647,
         2648,
         1828,
         1828,
         183,
         1832,
         1827,
         1828,
         183,
         183,
         183,
         1829,
         2633,
         1827,
         2634,
         183,
         2635,
         2635,
         2636,
         183,
         183,
         183,
         184,
         1827,
         1828,
         183,
         1838,
         183,
         1829,
         2633,
         1827,
         2634,
         183,
         2635,
         2635,
         2636,
         183,
         183,
         183,
         1833,
         1827,
         1828,
         183,
         183,
         183,
         1829,
         2633,
         1827,
         2634,
         183,
         2635,
         2635,
         2636,
         183,
         183,
         1829,
         1834,
         1836,
         1837,
         1829,
         1829,
         1829,
         1829,
         2649,
         1836,
         2650,
         1829,
         2651,
         2651,
         2636,
         1829,
         1829,
         2633,
         2637,
         2633,
         2645,
         2633,
         2633,
         2633,
         2649,
         2633,
         2633,
         2652,
         2633,
         2653,
         2653,
         2654,
         2633,
         2633,
         1827,
         1830,
         1827,
         1835,
         1827,
         1827,
         1827,
         1836,
         2633,
         2655,
         2634,
         1827,
         2643,
         2643,
         2644,
         1827,
         1827,
         2634,
         2638,
         2634,
         2646,
         2634,
         2634,
         2634,
         2650,
         2652,
         2634,
         2634,
         2634,
         2656,
         2656,
         2657,
         2634,
         2634,
         183,
         2639,
         1827,
         1828,
         183,
         183,
         183,
         1829,
         2633,
         1827,
         2634,
         183,
         2635,
         2635,
         2636,
         183,
         183,
         2635,
         2640,
         2643,
         2647,
         2635,
         2635,
         2635,
         2651,
         2653,
         2643,
         2656,
         2635,
         2635,
         2635,
         2658,
         2635,
         2635,
         2635,
         2641,
         2643,
         2647,
         2635,
         2635,
         2635,
         2651,
         2653,
         2643,
         2656,
         2635,
         2635,
         2635,
         2658,
         2635,
         2635,
         2636,
         2642,
         2644,
         2648,
         2636,
         2636,
         2636,
         2636,
         2654,
         2644,
         2657,
         2636,
         2658,
         2658,
         2636,
         2636,
         2636,
         183,
         3107,
         1827,
         1828,
         183,
         183,
         183,
         1829,
         2633,
         1827,
         2634,
         183,
         2635,
         2635,
         2636,
         183,
         183,
         183,
         3108,
         1827,
         1828,
         183,
         183,
         183,
         1829,
         2633,
         1827,
         2634,
         183,
         2635,
         2635,
         2636,
         183,
         183,
      },
   },
   [nir_op_imin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         7,
         2,
         8,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         9,
         4,
         9,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         5,
         10,
         5,
         6,
         11,
         11,
         6,
         10,
         5,
         5,
         10,
         5,
         5,
         10,
         10,
         5,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         9,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         185,
         186,
         1852,
         1853,
         1854,
         1855,
         1855,
         2687,
         1852,
         2688,
         3088,
         3088,
         186,
         186,
         1856,
         1857,
         1858,
         1859,
         1860,
         2689,
         1856,
         2690,
         3089,
         3090,
         1852,
         1856,
         1852,
         1861,
         1862,
         1863,
         1863,
         2687,
         1852,
         2691,
         3091,
         3091,
         1853,
         1857,
         1861,
         1853,
         1864,
         1865,
         1865,
         2692,
         1861,
         2693,
         3092,
         3092,
         1854,
         1858,
         1862,
         1864,
         1854,
         1866,
         1866,
         2694,
         1862,
         2688,
         3093,
         3093,
         1855,
         1859,
         1863,
         1865,
         1866,
         1855,
         1855,
         2695,
         1863,
         2696,
         3088,
         3088,
         1855,
         1860,
         1863,
         1865,
         1866,
         1855,
         1855,
         2695,
         1863,
         2696,
         3088,
         3088,
         2687,
         2689,
         2687,
         2692,
         2694,
         2695,
         2695,
         2687,
         2687,
         2697,
         3094,
         3094,
         1852,
         1856,
         1852,
         1861,
         1862,
         1863,
         1863,
         2687,
         2698,
         2691,
         3091,
         3091,
         2688,
         2690,
         2691,
         2693,
         2688,
         2696,
         2696,
         2697,
         2691,
         2688,
         3095,
         3095,
         3088,
         3089,
         3091,
         3092,
         3093,
         3088,
         3088,
         3094,
         3091,
         3095,
         3088,
         3088,
         3088,
         3090,
         3091,
         3092,
         3093,
         3088,
         3088,
         3094,
         3091,
         3095,
         3088,
         3088,
      },
   },
   [nir_op_imax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         6,
         2,
         7,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         4,
         4,
         9,
         9,
         0,
         0,
         8,
         0,
         8,
         8,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         5,
         5,
         10,
         10,
         10,
         5,
         10,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         187,
         188,
         1867,
         1868,
         187,
         1869,
         2699,
         1867,
         2700,
         2700,
         2701,
         188,
         188,
         1870,
         1871,
         1872,
         1873,
         2702,
         1870,
         2703,
         2704,
         2705,
         1867,
         1870,
         1867,
         1874,
         1867,
         1875,
         2699,
         1867,
         2706,
         2706,
         2707,
         1868,
         1871,
         1874,
         1868,
         1868,
         1876,
         2708,
         1874,
         2709,
         2709,
         2710,
         187,
         1872,
         1867,
         1868,
         187,
         1869,
         2699,
         1867,
         2700,
         2700,
         2701,
         1869,
         1873,
         1875,
         1876,
         1869,
         1869,
         2711,
         1875,
         2712,
         2712,
         2701,
         2699,
         2702,
         2699,
         2708,
         2699,
         2711,
         2699,
         2699,
         2713,
         2713,
         2714,
         1867,
         1870,
         1867,
         1874,
         1867,
         1875,
         2699,
         2715,
         2706,
         2706,
         2707,
         2700,
         2703,
         2706,
         2709,
         2700,
         2712,
         2713,
         2706,
         2700,
         2700,
         2716,
         2700,
         2704,
         2706,
         2709,
         2700,
         2712,
         2713,
         2706,
         2700,
         2700,
         2716,
         2701,
         2705,
         2707,
         2710,
         2701,
         2701,
         2714,
         2707,
         2716,
         2716,
         2701,
      },
   },
   [nir_op_umin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         5,
         2,
         5,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         2,
         6,
         3,
         6,
         3,
         6,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         189,
         190,
         2181,
         2182,
         189,
         2723,
         3096,
         190,
         190,
         2183,
         2184,
         190,
         2724,
         3097,
         2181,
         2183,
         2181,
         2185,
         2181,
         2723,
         3098,
         2182,
         2184,
         2185,
         2182,
         2182,
         2725,
         3096,
         189,
         190,
         2181,
         2182,
         2726,
         2723,
         3096,
         2723,
         2724,
         2723,
         2725,
         2723,
         2723,
         3099,
         3096,
         3097,
         3098,
         3096,
         3096,
         3099,
         3096,
      },
   },
   [nir_op_umax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         2,
         5,
         2,
         5,
         5,
         2,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         191,
         192,
         2186,
         191,
         2727,
         2728,
         192,
         192,
         2187,
         192,
         2729,
         2730,
         2186,
         2187,
         2186,
         2186,
         2731,
         2728,
         191,
         192,
         2186,
         2732,
         2727,
         2728,
         2727,
         2729,
         2731,
         2727,
         2727,
         2733,
         2728,
         2730,
         2728,
         2728,
         2733,
         2728,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         193,
         194,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         194,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         1555,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         1556,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         1557,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         1558,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         1559,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         1560,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         1561,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         2957,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
         193,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         195,
         1877,
         1878,
         1879,
         1880,
         1881,
         1882,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         196,
         1883,
         1884,
         1885,
         1886,
         1887,
         1888,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         197,
         1889,
         1890,
         1891,
         1892,
         1893,
         1894,
         1895,
         1896,
         1897,
         1898,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         198,
         2032,
         2033,
         2034,
         2035,
         2036,
         2037,
         2038,
         2039,
         2040,
         2041,
         2991,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         8,
         9,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         5,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         14,
         9,
         9,
         9,
         9,
         9,
         15,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         9,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         1,
         0,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         199,
         2042,
         2043,
         2044,
         2045,
         2046,
         2047,
         2048,
         2049,
         2050,
         2051,
         2052,
         2053,
         2054,
         2989,
         2990,
         3026,
         3027,
         3028,
      },
   },
   [nir_op_f2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         200,
         1899,
         1900,
         1901,
         1902,
         1903,
         1904,
         1905,
      },
   },
   [nir_op_i2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         201,
         2142,
         2143,
         2144,
         2145,
         2146,
         2147,
         2148,
         2149,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         202,
         203,
         202,
         202,
         202,
         203,
         202,
         202,
         202,
         1562,
         202,
         202,
         202,
         1563,
         202,
         202,
      },
   },
   [nir_op_extract_i16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         204,
         205,
         204,
         205,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         206,
         207,
         206,
         206,
         206,
         206,
         207,
         206,
         206,
         206,
         206,
         2188,
         206,
         206,
         206,
         206,
         2189,
         206,
         206,
         206,
         206,
         2190,
         206,
         206,
         206,
      },
   },
   [nir_op_ixor] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         4,
         5,
         6,
         7,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         12,
         13,
         14,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         2,
         2,
         3,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         5,
         4,
         4,
         5,
         5,
         6,
         6,
         7,
         6,
         7,
         6,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 21,
      .table = (const uint16_t []) {
      
         208,
         209,
         208,
         208,
         208,
         208,
         208,
         208,
         208,
         1516,
         208,
         1517,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1520,
         209,
         1521,
         209,
         1522,
         209,
         1523,
         1524,
         2962,
         2963,
         2964,
         2965,
         208,
         209,
         208,
         1525,
         208,
         208,
         208,
         208,
         208,
         1516,
         208,
         1517,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         208,
         209,
         1525,
         1525,
         208,
         208,
         208,
         208,
         208,
         1516,
         208,
         1517,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         208,
         209,
         208,
         208,
         208,
         1526,
         208,
         208,
         208,
         1516,
         208,
         1517,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         208,
         209,
         208,
         208,
         1526,
         1526,
         208,
         208,
         208,
         1516,
         208,
         1517,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         208,
         209,
         208,
         208,
         208,
         208,
         208,
         1527,
         208,
         1516,
         208,
         1517,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         208,
         209,
         208,
         208,
         208,
         208,
         1527,
         1527,
         208,
         1516,
         208,
         1517,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         208,
         209,
         208,
         208,
         208,
         208,
         208,
         208,
         208,
         1528,
         208,
         1517,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         1516,
         1520,
         1516,
         1516,
         1516,
         1516,
         1516,
         1516,
         1528,
         1528,
         1516,
         1529,
         1516,
         1530,
         1516,
         1531,
         1516,
         2966,
         2967,
         2968,
         2969,
         208,
         209,
         208,
         208,
         208,
         208,
         208,
         208,
         208,
         1516,
         208,
         1532,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         1517,
         1521,
         1517,
         1517,
         1517,
         1517,
         1517,
         1517,
         1517,
         1529,
         1532,
         1532,
         1517,
         1533,
         1517,
         1534,
         1517,
         2970,
         2971,
         2972,
         2973,
         208,
         209,
         208,
         208,
         208,
         208,
         208,
         208,
         208,
         1516,
         208,
         1517,
         208,
         1535,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         1518,
         1522,
         1518,
         1518,
         1518,
         1518,
         1518,
         1518,
         1518,
         1530,
         1518,
         1533,
         1535,
         1535,
         1518,
         1536,
         1518,
         2974,
         2975,
         2976,
         2977,
         208,
         209,
         208,
         208,
         208,
         208,
         208,
         208,
         208,
         1516,
         208,
         1517,
         208,
         1518,
         208,
         1537,
         208,
         2958,
         2959,
         2960,
         2961,
         1519,
         1523,
         1519,
         1519,
         1519,
         1519,
         1519,
         1519,
         1519,
         1531,
         1519,
         1534,
         1519,
         1536,
         1537,
         1537,
         1519,
         2978,
         2979,
         2980,
         2981,
         208,
         1524,
         208,
         208,
         208,
         208,
         208,
         208,
         208,
         1516,
         208,
         1517,
         208,
         1518,
         208,
         1519,
         208,
         2958,
         2959,
         2960,
         2961,
         2958,
         2962,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2966,
         2958,
         2970,
         2958,
         2974,
         2958,
         2978,
         2958,
         2958,
         2982,
         2983,
         2984,
         2959,
         2963,
         2959,
         2959,
         2959,
         2959,
         2959,
         2959,
         2959,
         2967,
         2959,
         2971,
         2959,
         2975,
         2959,
         2979,
         2959,
         2982,
         2959,
         2985,
         2986,
         2960,
         2964,
         2960,
         2960,
         2960,
         2960,
         2960,
         2960,
         2960,
         2968,
         2960,
         2972,
         2960,
         2976,
         2960,
         2980,
         2960,
         2983,
         2985,
         2960,
         2987,
         2961,
         2965,
         2961,
         2961,
         2961,
         2961,
         2961,
         2961,
         2961,
         2969,
         2961,
         2973,
         2961,
         2977,
         2961,
         2981,
         2961,
         2984,
         2986,
         2987,
         2988,
      },
   },
   [nir_op_slt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         210,
         211,
         212,
         213,
      },
   },
   [nir_op_sge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         214,
         215,
         216,
         217,
      },
   },
   [nir_op_seq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         218,
         218,
         218,
         218,
         218,
         218,
         218,
         218,
         2191,
         2192,
         2193,
         2194,
         218,
         2191,
         218,
         218,
         218,
         218,
         218,
         2192,
         218,
         218,
         218,
         218,
         218,
         2193,
         218,
         218,
         218,
         218,
         218,
         2194,
         218,
         218,
         218,
         218,
      },
   },
   [nir_op_sne] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         219,
         219,
         219,
         219,
         219,
         219,
         219,
         219,
         2195,
         2196,
         2197,
         2198,
         219,
         2195,
         219,
         219,
         219,
         219,
         219,
         2196,
         219,
         219,
         219,
         219,
         219,
         2197,
         219,
         219,
         219,
         219,
         219,
         2198,
         219,
         219,
         219,
         219,
      },
   },
   [nir_op_fall_equal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         220,
      },
   },
   [nir_op_fall_equal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         221,
      },
   },
   [nir_op_fall_equal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         222,
      },
   },
   [nir_op_fany_nequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         223,
      },
   },
   [nir_op_fany_nequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         224,
      },
   },
   [nir_op_fany_nequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         225,
      },
   },
   [nir_op_ball_iequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         226,
         226,
         226,
         226,
         226,
         226,
         2121,
         2122,
         226,
         2121,
         226,
         226,
         226,
         2122,
         226,
         226,
      },
   },
   [nir_op_ball_iequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         227,
         227,
         227,
         227,
         227,
         227,
         2123,
         2124,
         227,
         2123,
         227,
         227,
         227,
         2124,
         227,
         227,
      },
   },
   [nir_op_ball_iequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         228,
         228,
         228,
         228,
         228,
         228,
         2125,
         2126,
         228,
         2125,
         228,
         228,
         228,
         2126,
         228,
         228,
      },
   },
   [nir_op_bany_inequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         229,
         229,
         229,
         229,
         229,
         229,
         2171,
         2172,
         229,
         2171,
         229,
         229,
         229,
         2172,
         229,
         229,
      },
   },
   [nir_op_bany_inequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         230,
         230,
         230,
         230,
         230,
         230,
         2173,
         2174,
         230,
         2173,
         230,
         230,
         230,
         2174,
         230,
         230,
      },
   },
   [nir_op_bany_inequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         231,
         231,
         231,
         231,
         231,
         231,
         2175,
         2176,
         231,
         2175,
         231,
         231,
         231,
         2176,
         231,
         231,
      },
   },
   [nir_op_ball_fequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         232,
      },
   },
   [nir_op_ball_fequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         233,
      },
   },
   [nir_op_ball_fequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         234,
      },
   },
   [nir_op_bany_fnequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         235,
      },
   },
   [nir_op_bany_fnequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         236,
      },
   },
   [nir_op_bany_fnequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         237,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         238,
         238,
         239,
         239,
      },
   },
   [nir_op_urol] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         240,
      },
   },
   [nir_op_uror] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         241,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         242,
         2216,
         2685,
         2686,
         3085,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         5,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         243,
         2205,
         2206,
         2207,
         2208,
         2209,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         244,
         245,
         244,
         244,
         246,
         247,
         246,
         246,
         244,
         2217,
         244,
         244,
         244,
         2681,
         244,
         244,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         248,
         2210,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         249,
         2211,
         2212,
         2213,
         2214,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         250,
         2215,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         251,
         251,
         252,
         252,
      },
   },
   [nir_op_fsin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         253,
      },
   },
   [nir_op_fcos] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         254,
      },
   },
   [nir_op_fcsel] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         255,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
      },
   },
   [nir_op_f2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         256,
         2131,
         2132,
      },
   },
   [nir_op_f2ump] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         257,
         2133,
         2134,
      },
   },
   [nir_op_i2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         258,
         2150,
         2151,
      },
   },
   [nir_op_u2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         259,
         2152,
         2153,
      },
   },
   [nir_op_pack_64_2x32_split] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         260,
         260,
         260,
         260,
         260,
         1565,
         260,
         260,
         260,
      },
   },
   [nir_op_unpack_64_2x32_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         261,
         2055,
         2056,
      },
   },
   [nir_op_unpack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         262,
         2218,
         2219,
      },
   },
   [nir_op_pack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         263,
         2220,
         2603,
      },
   },
   [nir_op_unpack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         264,
         2222,
      },
   },
   [nir_op_pack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         265,
         2221,
      },
   },
   [nir_op_unpack_32_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         266,
         2057,
         2058,
      },
   },
   [nir_op_unpack_32_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         267,
         2059,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         268,
         2060,
         0,
         269,
         2060,
         2061,
         2062,
         2063,
         0,
         268,
         2060,
         0,
         269,
         2060,
         2061,
         2062,
         2063,
         0,
         268,
         2060,
         0,
         269,
         2060,
         2061,
         2062,
         2063,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         270,
         2064,
         0,
         271,
         2064,
         2065,
         2066,
         2067,
         0,
         270,
         2064,
         0,
         271,
         2064,
         2065,
         2066,
         2067,
         0,
         270,
         2064,
         0,
         271,
         2064,
         2065,
         2066,
         2067,
      },
   },
   [nir_op_pack_32_2x16_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         272,
      },
   },
   [nir_op_unpack_half_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         0,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         273,
         2068,
         2069,
         2070,
      },
   },
   [nir_op_unpack_half_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         274,
         2071,
      },
   },
   [nir_op_pack_half_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         2161,
         2162,
         2163,
      },
   },
   [nir_op_pack_half_2x16_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         275,
         276,
         277,
         278,
      },
   },
   [nir_op_pack_32_4x8_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         279,
      },
   },
   [nir_op_ussub_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         280,
         0,
         280,
      },
   },
   [nir_op_fsub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         281,
      },
   },
   [nir_op_uabs_usub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         282,
      },
   },
   [nir_op_uabs_isub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         283,
      },
   },
   [nir_op_find_lsb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         284,
      },
   },
   [nir_op_ifind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         285,
      },
   },
   [nir_op_ufind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         286,
      },
   },
   [nir_op_fmod] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         287,
      },
   },
   [nir_op_frem] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         288,
      },
   },
   [nir_op_uadd_carry] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         289,
      },
   },
   [nir_op_usub_borrow] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         290,
      },
   },
   [nir_op_bitfield_insert] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         291,
      },
   },
   [nir_op_ihadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         292,
      },
   },
   [nir_op_uhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         293,
      },
   },
   [nir_op_irhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         294,
      },
   },
   [nir_op_urhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         295,
      },
   },
   [nir_op_uadd_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         296,
      },
   },
   [nir_op_usub_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         297,
      },
   },
   [nir_op_iadd_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         298,
      },
   },
   [nir_op_isub_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         299,
      },
   },
   [nir_op_ibitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         300,
      },
   },
   [nir_op_ubitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         301,
      },
   },
   [nir_op_bitfield_select] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         302,
         0,
         0,
         302,
         0,
         2030,
         2031,
         2030,
         0,
         302,
         0,
         0,
         302,
         0,
         2030,
         2031,
         2030,
         0,
         302,
         0,
         0,
         302,
         0,
         2030,
         2031,
         2030,
      },
   },
   [nir_op_bfm] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         2072,
         2073,
         2074,
      },
   },
   [nir_op_pack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         303,
      },
   },
   [nir_op_pack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         304,
      },
   },
   [nir_op_pack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         305,
      },
   },
   [nir_op_pack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         306,
      },
   },
   [nir_op_unpack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         307,
      },
   },
   [nir_op_unpack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         308,
      },
   },
   [nir_op_unpack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         309,
      },
   },
   [nir_op_unpack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         310,
      },
   },
   [nir_op_isign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         311,
         2120,
      },
   },
   [nir_op_amul] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         312,
      },
   },
   [nir_op_umul24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         313,
      },
   },
   [nir_op_umad24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         314,
      },
   },
   [nir_op_imul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         315,
      },
   },
   [nir_op_umad24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         316,
      },
   },
   [nir_op_umul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         317,
      },
   },
   [nir_op_imad24_ir3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         318,
         319,
         320,
         319,
         320,
         321,
         322,
      },
   },
   [nir_op_imul24] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         323,
         323,
         323,
      },
   },
   [nir_op_b2b1] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         324,
      },
   },
   [nir_op_b2b8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         325,
      },
   },
   [nir_op_b2b16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         326,
      },
   },
   [nir_op_b2b32] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         327,
      },
   },
   [nir_op_ldexp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         328,
      },
   },
   [nir_op_ball_iequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2127,
         2128,
         0,
         2127,
         0,
         0,
         0,
         2128,
         0,
         0,
      },
   },
   [nir_op_bany_inequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2177,
         2178,
         0,
         2177,
         0,
         0,
         0,
         2178,
         0,
         0,
      },
   },
   [nir_op_ball_iequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2129,
         2130,
         0,
         2129,
         0,
         0,
         0,
         2130,
         0,
         0,
      },
   },
   [nir_op_bany_inequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2179,
         2180,
         0,
         2179,
         0,
         0,
         0,
         2180,
         0,
         0,
      },
   },
   [nir_op_fddx] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         329,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         330,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         331,
      },
   },
   [nir_op_fddy] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         332,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         333,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         334,
      },
   },
   [nir_op_umul_low] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         335,
         335,
         335,
      },
   },
   [nir_op_imadsh_mix16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         336,
         336,
         337,
         337,
         338,
         338,
      },
   },
   [nir_op_fisnormal] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         339,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_transform_offsets[] = {
   0,
   0,
   0,
   1,
   0,
   12,
   15,
   17,
   21,
   23,
   25,
   27,
   30,
   34,
   37,
   42,
   0,
   0,
   47,
   0,
   49,
   0,
   51,
   0,
   55,
   0,
   59,
   61,
   0,
   64,
   71,
   75,
   81,
   88,
   98,
   110,
   125,
   138,
   154,
   160,
   167,
   176,
   186,
   196,
   207,
   209,
   217,
   219,
   223,
   226,
   229,
   231,
   233,
   237,
   240,
   245,
   248,
   253,
   257,
   263,
   265,
   267,
   270,
   273,
   277,
   281,
   283,
   285,
   288,
   291,
   295,
   299,
   301,
   304,
   308,
   310,
   313,
   316,
   320,
   324,
   329,
   331,
   333,
   336,
   339,
   343,
   347,
   349,
   351,
   354,
   357,
   361,
   365,
   367,
   370,
   374,
   376,
   379,
   383,
   385,
   387,
   390,
   393,
   396,
   399,
   404,
   409,
   411,
   414,
   417,
   422,
   426,
   431,
   436,
   460,
   466,
   473,
   480,
   506,
   508,
   0,
   511,
   514,
   517,
   520,
   0,
   523,
   525,
   0,
   0,
   0,
   0,
   527,
   0,
   0,
   0,
   529,
   531,
   0,
   0,
   0,
   0,
   534,
   0,
   536,
   542,
   544,
   0,
   551,
   557,
   559,
   0,
   566,
   571,
   576,
   581,
   586,
   591,
   596,
   601,
   606,
   608,
   611,
   616,
   622,
   627,
   633,
   635,
   638,
   642,
   647,
   652,
   658,
   663,
   669,
   671,
   673,
   675,
   681,
   683,
   689,
   691,
   0,
   694,
   696,
   698,
   700,
   702,
   704,
   706,
   708,
   712,
   714,
   718,
   720,
   0,
   0,
   724,
   728,
   734,
   0,
   0,
   740,
   742,
   746,
   748,
   751,
   753,
   756,
   758,
   761,
   763,
   765,
   767,
   769,
   771,
   773,
   775,
   777,
   779,
   781,
   783,
   785,
   787,
   789,
   791,
   793,
   795,
   797,
   799,
   801,
   803,
   805,
   807,
   809,
   811,
   813,
   815,
   817,
   819,
   821,
   824,
   0,
   0,
   827,
   829,
   834,
   837,
   843,
   0,
   0,
   845,
   847,
   850,
   852,
   854,
   0,
   0,
   0,
   0,
   856,
   858,
   0,
   0,
   0,
   0,
   860,
   863,
   866,
   868,
   877,
   879,
   887,
   890,
   892,
   894,
   896,
   898,
   900,
   0,
   902,
   905,
   907,
   909,
   911,
   913,
   916,
   918,
   920,
   922,
   924,
   926,
   930,
   933,
   936,
   939,
   942,
   945,
   948,
   954,
   960,
   963,
   966,
   968,
   970,
   972,
   974,
   976,
   978,
   980,
   982,
   984,
   986,
   988,
   990,
   992,
   995,
   998,
   1001,
   1003,
   1006,
   1010,
   1014,
   1019,
   1023,
   1025,
   1027,
   1029,
   1031,
   1035,
   1037,
   1039,
   1041,
   1043,
   1045,
   1047,
   1049,
   1051,
   1053,
   1056,
   1058,
   1060,
   1063,
   1066,
   1068,
   1070,
   1082,
   1095,
   1107,
   1119,
   1131,
   1144,
   1157,
   1169,
   1181,
   1185,
   1189,
   1192,
   1195,
   1197,
   1202,
   1206,
   1210,
   1214,
   1218,
   1221,
   1223,
   1228,
   0,
   1230,
   1232,
   1234,
   1236,
   1238,
   1241,
   1244,
   1247,
   1249,
   1251,
   1253,
   1256,
   1259,
   1263,
   1267,
   1271,
   1275,
   1279,
   1284,
   1287,
   1291,
   1295,
   1298,
   1301,
   1303,
   1306,
   1309,
   1312,
   1315,
   1318,
   1321,
   1325,
   1329,
   1333,
   1336,
   1339,
   1341,
   1343,
   1345,
   1347,
   1350,
   1353,
   1356,
   1358,
   1360,
   1363,
   1366,
   1369,
   1373,
   1377,
   1381,
   1384,
   1387,
   1390,
   1393,
   1397,
   1401,
   1405,
   1408,
   1411,
   1414,
   1418,
   1422,
   1426,
   1429,
   1432,
   1436,
   1440,
   1444,
   1447,
   1450,
   1455,
   1460,
   1464,
   1468,
   1473,
   1477,
   1481,
   1485,
   1489,
   1492,
   1494,
   1500,
   1507,
   1512,
   1520,
   1525,
   1530,
   1538,
   1546,
   1554,
   1562,
   1570,
   1576,
   1586,
   1592,
   1599,
   1611,
   1616,
   1623,
   1631,
   1639,
   1647,
   1655,
   1663,
   1671,
   1677,
   1684,
   1692,
   1698,
   1705,
   1713,
   1718,
   1724,
   1731,
   1736,
   1742,
   1749,
   1757,
   1762,
   1767,
   1775,
   1780,
   1785,
   1790,
   1795,
   1800,
   1808,
   1817,
   1824,
   1834,
   1841,
   1848,
   1858,
   1868,
   1878,
   1888,
   1898,
   1906,
   1918,
   1926,
   1935,
   1949,
   1956,
   1965,
   1975,
   1985,
   1995,
   2005,
   2015,
   2025,
   2033,
   2042,
   2052,
   2060,
   2069,
   2079,
   2086,
   2094,
   2103,
   2110,
   2118,
   2127,
   2137,
   2144,
   2151,
   2161,
   2168,
   2175,
   2182,
   2189,
   2196,
   2201,
   2207,
   2214,
   2220,
   2245,
   2253,
   2259,
   2268,
   2274,
   2280,
   2289,
   2298,
   2307,
   2316,
   2325,
   2332,
   2343,
   2350,
   2358,
   2371,
   2377,
   2385,
   2394,
   2403,
   2412,
   2421,
   2430,
   2439,
   2446,
   2454,
   2463,
   2470,
   2478,
   2487,
   2493,
   2500,
   2508,
   2514,
   2521,
   2529,
   2538,
   2544,
   2550,
   2559,
   2565,
   2571,
   2577,
   2583,
   2589,
   2594,
   2618,
   2625,
   2630,
   2635,
   2641,
   2648,
   2654,
   2679,
   2687,
   2693,
   2702,
   2708,
   2714,
   2723,
   2732,
   2741,
   2750,
   2759,
   2766,
   2777,
   2784,
   2792,
   2805,
   2811,
   2819,
   2828,
   2837,
   2846,
   2855,
   2864,
   2873,
   2880,
   2888,
   2897,
   2904,
   2912,
   2921,
   2927,
   2934,
   2942,
   2948,
   2955,
   2963,
   2972,
   2978,
   2984,
   2993,
   2999,
   3005,
   3011,
   3017,
   3023,
   3029,
   3036,
   3044,
   3051,
   3077,
   3086,
   3093,
   3103,
   3110,
   3117,
   3127,
   3137,
   3147,
   3157,
   3167,
   3175,
   3187,
   3195,
   3204,
   3218,
   3225,
   3234,
   3244,
   3254,
   3264,
   3274,
   3284,
   3294,
   3302,
   3311,
   3321,
   3329,
   3338,
   3348,
   3355,
   3363,
   3372,
   3379,
   3387,
   3396,
   3406,
   3413,
   3420,
   3430,
   3437,
   3444,
   3451,
   3458,
   3465,
   3472,
   3480,
   3489,
   3497,
   3524,
   3534,
   3542,
   3551,
   3562,
   3570,
   3579,
   3588,
   3598,
   3606,
   3617,
   3628,
   3639,
   3650,
   3661,
   3670,
   3683,
   3692,
   3702,
   3717,
   3725,
   3735,
   3746,
   3757,
   3768,
   3779,
   3790,
   3801,
   3810,
   3820,
   3831,
   3840,
   3850,
   3861,
   3869,
   3878,
   3888,
   3896,
   3905,
   3915,
   3926,
   3934,
   3942,
   3953,
   3961,
   3969,
   3977,
   3985,
   3993,
   4000,
   4008,
   4017,
   4025,
   4052,
   4062,
   4070,
   4081,
   4089,
   4097,
   4108,
   4119,
   4130,
   4141,
   4152,
   4161,
   4174,
   4183,
   4193,
   4208,
   4216,
   4226,
   4237,
   4248,
   4259,
   4270,
   4281,
   4292,
   4301,
   4311,
   4322,
   4331,
   4341,
   4352,
   4360,
   4369,
   4379,
   4387,
   4396,
   4406,
   4417,
   4425,
   4433,
   4444,
   4452,
   4460,
   4468,
   4476,
   4484,
   4492,
   4501,
   4511,
   4520,
   4548,
   4559,
   4568,
   4578,
   4590,
   4599,
   4609,
   4619,
   4630,
   4639,
   4651,
   4663,
   4675,
   4687,
   4699,
   4709,
   4723,
   4733,
   4744,
   4760,
   4769,
   4780,
   4792,
   4804,
   4816,
   4828,
   4840,
   4852,
   4862,
   4873,
   4885,
   4895,
   4906,
   4918,
   4927,
   4937,
   4948,
   4957,
   4967,
   4978,
   4990,
   4999,
   5008,
   5020,
   5029,
   5038,
   5047,
   5056,
   5065,
   5071,
   5078,
   5086,
   5093,
   5119,
   5128,
   5135,
   5145,
   5152,
   5159,
   5169,
   5179,
   5189,
   5199,
   5209,
   5217,
   5229,
   5237,
   5246,
   5260,
   5267,
   5276,
   5286,
   5296,
   5306,
   5316,
   5326,
   5336,
   5344,
   5353,
   5363,
   5371,
   5380,
   5390,
   5397,
   5405,
   5414,
   5421,
   5429,
   5438,
   5448,
   5455,
   5462,
   5472,
   5479,
   5486,
   5493,
   5500,
   5507,
   5514,
   5522,
   5531,
   5539,
   5566,
   5576,
   5584,
   5595,
   5603,
   5611,
   5622,
   5633,
   5644,
   5655,
   5666,
   5675,
   5688,
   5697,
   5707,
   5722,
   5730,
   5740,
   5751,
   5762,
   5773,
   5784,
   5795,
   5806,
   5815,
   5825,
   5836,
   5845,
   5855,
   5866,
   5874,
   5883,
   5893,
   5901,
   5910,
   5920,
   5931,
   5939,
   5947,
   5958,
   5966,
   5974,
   5982,
   5990,
   5998,
   6005,
   6013,
   6022,
   6030,
   6057,
   6067,
   6075,
   6086,
   6094,
   6102,
   6113,
   6124,
   6135,
   6146,
   6157,
   6166,
   6179,
   6188,
   6198,
   6213,
   6221,
   6231,
   6242,
   6253,
   6264,
   6275,
   6286,
   6297,
   6306,
   6316,
   6327,
   6336,
   6346,
   6357,
   6365,
   6374,
   6384,
   6392,
   6401,
   6411,
   6422,
   6430,
   6438,
   6449,
   6457,
   6465,
   6473,
   6481,
   6489,
   6497,
   6506,
   6516,
   6525,
   6553,
   6564,
   6573,
   6585,
   6594,
   6603,
   6615,
   6627,
   6639,
   6651,
   6663,
   6673,
   6687,
   6697,
   6708,
   6724,
   6733,
   6744,
   6756,
   6768,
   6780,
   6792,
   6804,
   6816,
   6826,
   6837,
   6849,
   6859,
   6870,
   6882,
   6891,
   6901,
   6912,
   6921,
   6931,
   6942,
   6954,
   6963,
   6972,
   6984,
   6993,
   7002,
   7011,
   7020,
   7029,
   7034,
   7040,
   7047,
   7053,
   7078,
   7086,
   7092,
   7101,
   7107,
   7113,
   7122,
   7131,
   7140,
   7149,
   7158,
   7165,
   7176,
   7183,
   7191,
   7204,
   7210,
   7218,
   7227,
   7236,
   7245,
   7254,
   7263,
   7272,
   7279,
   7287,
   7296,
   7303,
   7311,
   7320,
   7326,
   7333,
   7341,
   7347,
   7354,
   7362,
   7371,
   7377,
   7383,
   7392,
   7398,
   7404,
   7410,
   7416,
   7422,
   7427,
   7433,
   7440,
   7446,
   7471,
   7479,
   7485,
   7494,
   7500,
   7506,
   7515,
   7524,
   7533,
   7542,
   7551,
   7558,
   7569,
   7576,
   7584,
   7597,
   7603,
   7611,
   7620,
   7629,
   7638,
   7647,
   7656,
   7665,
   7672,
   7680,
   7689,
   7696,
   7704,
   7713,
   7719,
   7726,
   7734,
   7740,
   7747,
   7755,
   7764,
   7770,
   7776,
   7785,
   7791,
   7797,
   7803,
   7809,
   7815,
   7821,
   7828,
   7836,
   7843,
   7869,
   7878,
   7885,
   7895,
   7902,
   7909,
   7919,
   7929,
   7939,
   7949,
   7959,
   7967,
   7979,
   7987,
   7996,
   8010,
   8017,
   8026,
   8036,
   8046,
   8056,
   8066,
   8076,
   8086,
   8094,
   8103,
   8113,
   8121,
   8130,
   8140,
   8147,
   8155,
   8164,
   8171,
   8179,
   8188,
   8198,
   8205,
   8212,
   8222,
   8229,
   8236,
   8243,
   8250,
   8257,
   8262,
   8268,
   8275,
   8281,
   8306,
   8314,
   8320,
   8329,
   8335,
   8341,
   8350,
   8359,
   8368,
   8377,
   8386,
   8393,
   8404,
   8411,
   8419,
   8432,
   8438,
   8446,
   8455,
   8464,
   8473,
   8482,
   8491,
   8500,
   8507,
   8515,
   8524,
   8531,
   8539,
   8548,
   8554,
   8561,
   8569,
   8575,
   8582,
   8590,
   8599,
   8605,
   8611,
   8620,
   8626,
   8632,
   8638,
   8644,
   8650,
   8655,
   8661,
   8668,
   8674,
   8699,
   8707,
   8713,
   8722,
   8728,
   8734,
   8743,
   8752,
   8761,
   8770,
   8779,
   8786,
   8797,
   8804,
   8812,
   8825,
   8831,
   8839,
   8848,
   8857,
   8866,
   8875,
   8884,
   8893,
   8900,
   8908,
   8917,
   8924,
   8932,
   8941,
   8947,
   8954,
   8962,
   8968,
   8975,
   8983,
   8992,
   8998,
   9004,
   9013,
   9019,
   9025,
   9031,
   9037,
   9043,
   9049,
   9056,
   9064,
   9071,
   9097,
   9106,
   9113,
   9123,
   9130,
   9137,
   9147,
   9157,
   9167,
   9177,
   9187,
   9195,
   9207,
   9215,
   9224,
   9238,
   9245,
   9254,
   9264,
   9274,
   9284,
   9294,
   9304,
   9314,
   9322,
   9331,
   9341,
   9349,
   9358,
   9368,
   9375,
   9383,
   9392,
   9399,
   9407,
   9416,
   9426,
   9433,
   9440,
   9450,
   9457,
   9464,
   9471,
   9478,
   9485,
   9491,
   9498,
   9504,
   0,
   9509,
   9515,
   9517,
   9521,
   9528,
   9532,
   9539,
   9544,
   9551,
   9560,
   9565,
   9570,
   9577,
   9586,
   9591,
   9594,
   9598,
   9601,
   9604,
   9608,
   9612,
   9615,
   9618,
   9627,
   9640,
   9654,
   9663,
   9673,
   9682,
   9694,
   9704,
   9714,
   9723,
   9732,
   9735,
   9739,
   9744,
   9749,
   9753,
   9757,
   9761,
   9766,
   9771,
   9775,
   9779,
   9783,
   9787,
   9791,
   9794,
   9797,
   9800,
   9803,
   9806,
   9811,
   9817,
   9828,
   9840,
   9846,
   9858,
   9871,
   9875,
   9880,
   9891,
   9903,
   9908,
   9920,
   9933,
   9935,
   9940,
   9945,
   9949,
   9953,
   9956,
   9966,
   9972,
   9977,
   9983,
   9988,
   9993,
   9998,
   10003,
   10008,
   10012,
   10016,
   10020,
   10023,
   10026,
   10029,
   10031,
   10034,
   10038,
   10042,
   10045,
   10048,
   10053,
   10058,
   10064,
   10069,
   10073,
   10078,
   10084,
   10090,
   10095,
   10100,
   10103,
   10105,
   10109,
   10113,
   10117,
   10120,
   10124,
   10129,
   10134,
   10138,
   10142,
   10146,
   10149,
   10153,
   10158,
   10163,
   10167,
   10171,
   10173,
   10175,
   10178,
   10181,
   10184,
   10188,
   10191,
   10195,
   10200,
   10205,
   10209,
   10213,
   10218,
   10221,
   10225,
   10229,
   10232,
   10235,
   10241,
   10252,
   10264,
   10270,
   10282,
   10295,
   10299,
   10304,
   10314,
   10325,
   10330,
   10341,
   10353,
   10355,
   10359,
   10363,
   10367,
   10371,
   10376,
   10384,
   10389,
   10394,
   10398,
   10402,
   10412,
   10417,
   10423,
   10428,
   10433,
   10438,
   10443,
   10448,
   10452,
   10456,
   10460,
   10463,
   10467,
   10471,
   10474,
   10477,
   10482,
   10487,
   10491,
   10495,
   10499,
   10502,
   10505,
   10508,
   10513,
   10519,
   10524,
   10529,
   10534,
   10539,
   10544,
   10548,
   10552,
   10556,
   0,
   10561,
   10567,
   10569,
   10574,
   10585,
   10594,
   10599,
   10609,
   10616,
   10621,
   10627,
   0,
   10634,
   10640,
   10645,
   10655,
   10670,
   10685,
   10700,
   10705,
   10710,
   10715,
   10723,
   10738,
   0,
   10746,
   10749,
   10752,
   10755,
   10758,
   10761,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   10763,
   10766,
   10769,
   10771,
   10774,
   10777,
   10780,
   10783,
   10785,
   10787,
   10792,
   10794,
   10796,
   10801,
   10808,
   10816,
   10821,
   10827,
   10832,
   10838,
   10843,
   10847,
   10849,
   10851,
   10853,
   0,
   10855,
   0,
   0,
   10857,
   0,
   0,
   10860,
   10868,
   10876,
   10885,
   10893,
   10902,
   10909,
   10916,
   10924,
   10934,
   10941,
   10948,
   10950,
   10952,
   10956,
   10958,
   10960,
   0,
   0,
   10962,
   0,
   0,
   10965,
   0,
   0,
   10968,
   10971,
   10974,
   0,
   10976,
   10978,
   10980,
   10985,
   10991,
   10998,
   11005,
   11013,
   11020,
   11029,
   11036,
   11041,
   11049,
   11057,
   11070,
   11083,
   11090,
   11100,
   11108,
   11116,
   11125,
   11139,
   11153,
   11165,
   11180,
   11193,
   11206,
   11219,
   11235,
   11250,
   11264,
   11278,
   11295,
   11311,
   11326,
   11339,
   11355,
   11369,
   11383,
   11391,
   11402,
   11411,
   11420,
   11429,
   11436,
   11446,
   11454,
   11462,
   11469,
   11476,
   11486,
   11496,
   11504,
   11515,
   11526,
   11536,
   11547,
   11559,
   11570,
   11582,
   11595,
   11609,
   11622,
   11629,
   11637,
   11645,
   11653,
   11656,
   11660,
   11664,
   11668,
   11671,
   11674,
   11679,
   11683,
   11687,
   11692,
   11696,
   11700,
   11704,
   11708,
   11712,
   11716,
   11722,
   11728,
   11734,
   11740,
   11746,
   11753,
   11759,
   11765,
   11772,
   11778,
   11784,
   11790,
   11796,
   11802,
   11809,
   11815,
   11821,
   11827,
   11834,
   11841,
   11848,
   11855,
   11861,
   11867,
   11873,
   11880,
   11887,
   11894,
   11900,
   11906,
   11912,
   11919,
   11926,
   11933,
   11946,
   11952,
   11958,
   11964,
   11971,
   11977,
   11983,
   11989,
   11995,
   12001,
   12007,
   12013,
   12019,
   12026,
   12032,
   12038,
   12044,
   12051,
   12058,
   12065,
   12072,
   12079,
   12085,
   12091,
   12097,
   12104,
   12111,
   12118,
   12124,
   12130,
   12136,
   12143,
   12150,
   12157,
   12170,
   12173,
   12176,
   12181,
   12185,
   12189,
   12194,
   12198,
   12202,
   12206,
   12210,
   12214,
   12218,
   12224,
   12230,
   12233,
   12236,
   12239,
   12241,
   12245,
   12249,
   12253,
   12257,
   12261,
   12264,
   12269,
   12273,
   12277,
   12280,
   12284,
   12287,
   12290,
   12293,
   12296,
   12299,
   12302,
   12305,
   12309,
   12312,
   12316,
   12319,
   12323,
   12327,
   12331,
   12334,
   0,
   12336,
   12338,
   0,
   12343,
   12346,
   12349,
   12352,
   12358,
   12363,
   12373,
   12377,
   12381,
   12384,
   12387,
   12390,
   12392,
   12395,
   12398,
   12401,
   12403,
   12406,
   12410,
   12414,
   12417,
   12421,
   12424,
   12427,
   12430,
   12433,
   12436,
   12439,
   12442,
   12445,
   12448,
   12452,
   12456,
   12460,
   12464,
   12466,
   12468,
   12472,
   12476,
   12478,
   12482,
   12484,
   12486,
   12490,
   12494,
   12496,
   12503,
   12511,
   12516,
   12521,
   12526,
   12533,
   12541,
   12546,
   12551,
   12556,
   12558,
   12560,
   12562,
   12564,
   12566,
   12568,
   12570,
   12572,
   12574,
   0,
   12576,
   12578,
   12580,
   12582,
   12584,
   12586,
   12588,
   12590,
   12592,
   12594,
   12596,
   12601,
   12607,
   12613,
   12621,
   12630,
   12635,
   12642,
   12650,
   12656,
   12663,
   12670,
   12679,
   12689,
   12695,
   12703,
   12712,
   12721,
   12732,
   12744,
   12750,
   12758,
   12767,
   12770,
   12777,
   12791,
   12798,
   12805,
   12819,
   12833,
   12839,
   12851,
   12863,
   12869,
   12875,
   12882,
   12889,
   12895,
   12907,
   12919,
   12922,
   12929,
   12943,
   12950,
   12957,
   12971,
   12985,
   12997,
   13009,
   13016,
   13023,
   13029,
   13041,
   13053,
   13056,
   13059,
   13062,
   13067,
   13072,
   13077,
   13083,
   13088,
   13094,
   13104,
   13107,
   13111,
   13115,
   13119,
   13123,
   13127,
   13130,
   13134,
   13138,
   13142,
   13146,
   13151,
   13154,
   13158,
   13162,
   13166,
   13170,
   13175,
   13184,
   13206,
   13209,
   13212,
   13215,
   13218,
   13221,
   13224,
   13228,
   13231,
   13235,
   13243,
   13246,
   13250,
   13254,
   13258,
   13261,
   13264,
   13268,
   13272,
   13276,
   13280,
   13283,
   13287,
   13291,
   13295,
   13299,
   13307,
   13329,
   13331,
   13334,
   13346,
   13356,
   13363,
   13370,
   13377,
   13416,
   13435,
   13442,
   13449,
   13461,
   13467,
   13477,
   13484,
   13491,
   13498,
   13505,
   13511,
   13527,
   13569,
   13576,
   13583,
   13590,
   13602,
   13605,
   13608,
   13612,
   13617,
   13621,
   13623,
   13625,
   13628,
   13631,
   13633,
   13635,
   13638,
   13641,
   13644,
   13647,
   13651,
   13654,
   13656,
   13658,
   13661,
   13667,
   13673,
   13679,
   13685,
   13692,
   13698,
   13705,
   13716,
   13723,
   13729,
   13737,
   13744,
   13751,
   13760,
   13766,
   13774,
   13781,
   13788,
   13797,
   13809,
   13834,
   13840,
   13846,
   13852,
   13858,
   13865,
   13871,
   13878,
   13889,
   13896,
   13902,
   13910,
   13917,
   13924,
   13933,
   13939,
   13947,
   13954,
   13961,
   13970,
   13982,
   14007,
   14013,
   14019,
   14025,
   14028,
   14031,
   14034,
   14037,
   14040,
   14043,
   14046,
   14048,
   14050,
   14052,
   14054,
   14056,
   14058,
   14060,
   14062,
   14064,
   14068,
   14070,
   14072,
   14076,
   14080,
   14082,
   14085,
   14087,
   14089,
   14091,
   14093,
   14095,
   14097,
   14099,
   14101,
   14103,
   14105,
   14107,
   14111,
   14116,
   14122,
   14125,
   14129,
   14132,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   14136,
   14138,
   14141,
   14144,
   14147,
   14150,
   14153,
   14156,
   14158,
   14160,
   14162,
   14164,
   14167,
   14169,
   14174,
   14178,
   14181,
   14184,
   14189,
   14193,
   14197,
   14201,
   14205,
   14209,
   14213,
   14217,
   14221,
   14225,
   14229,
   14233,
   14236,
   14239,
   14243,
   14246,
   14249,
   14253,
   14255,
   14257,
   14259,
   14261,
   14263,
   14266,
   14268,
   14270,
   14272,
   14274,
   14276,
   14278,
   14284,
   14286,
   14288,
   14290,
   14292,
   14294,
   14296,
   14298,
   14302,
   14306,
   14310,
   14314,
   14318,
   14323,
   14328,
   14333,
   14338,
   14343,
   14347,
   14351,
   14356,
   14361,
   14366,
   14371,
   14375,
   14379,
   14383,
   14387,
   14390,
   14393,
   14398,
   14403,
   14408,
   14413,
   14416,
   14419,
   14424,
   14429,
   14434,
   14439,
   14442,
   14445,
   14450,
   14455,
   14460,
   14465,
   14468,
   14471,
   14476,
   14481,
   14486,
   14491,
   14495,
   14499,
   14505,
   14511,
   14517,
   14523,
   14527,
   14531,
   14537,
   14543,
   14549,
   14555,
   14559,
   14563,
   14569,
   14575,
   14581,
   14587,
   14590,
   14593,
   14598,
   14603,
   14608,
   14613,
   14616,
   14619,
   14624,
   14629,
   14634,
   14639,
   14644,
   14649,
   14654,
   14659,
   14664,
   14669,
   14674,
   14679,
   14686,
   14693,
   14700,
   14707,
   14714,
   14721,
   14723,
   14727,
   14731,
   14735,
   14739,
   14751,
   14764,
   14778,
   14792,
   14806,
   14820,
   14825,
   14830,
   14835,
   14840,
   14846,
   14852,
   14858,
   14864,
   14870,
   14876,
   14882,
   14888,
   14893,
   14898,
   14903,
   14908,
   14913,
   14918,
   14923,
   14928,
   14935,
   14942,
   14949,
   14956,
   14963,
   0,
   14970,
   14972,
   14977,
   14982,
   14986,
   14991,
   14996,
   14999,
   0,
   15003,
   15005,
   15010,
   15016,
   15023,
   15027,
   15031,
   15037,
   15042,
   15046,
   15050,
   15055,
   15059,
   15063,
   15069,
   15074,
   15078,
   15082,
   15087,
   0,
   0,
   15091,
   15093,
   15104,
   15111,
   15118,
   15127,
   15137,
   15142,
   15144,
   15146,
   15149,
   15153,
   0,
   0,
   15155,
   15157,
   0,
   0,
   15161,
   15164,
   15167,
   15170,
   15174,
   0,
   0,
   15178,
   15180,
   0,
   0,
   15184,
   15186,
   15188,
   15193,
   15197,
   15201,
   15206,
   0,
   15208,
   15210,
   15221,
   15229,
   15240,
   15249,
   15258,
   15274,
   15287,
   15303,
   15317,
   15331,
   15342,
   15350,
   15361,
   15370,
   15379,
   15389,
   15401,
   15411,
   15424,
   15435,
   15446,
   15460,
   15471,
   15479,
   15490,
   15499,
   15508,
   15517,
   15529,
   15539,
   15549,
   15554,
   15559,
   15564,
   15569,
   15576,
   15583,
   15590,
   15597,
   15601,
   15607,
   15613,
   15619,
   15625,
   15631,
   15637,
   15643,
   15649,
   15653,
   15659,
   15665,
   15671,
   15677,
   15684,
   15689,
   15694,
   15699,
   15704,
   15710,
   15716,
   15722,
   15728,
   15735,
   15742,
   15749,
   15756,
   15758,
   15765,
   15772,
   15779,
   15786,
   15792,
   15798,
   15804,
   15810,
   15816,
   15822,
   15828,
   15834,
   15840,
   15845,
   15850,
   15853,
   15861,
   15869,
   15877,
   15885,
   15893,
   15901,
   15906,
   15909,
   15911,
   15913,
   15915,
   15917,
   15919,
   15921,
   15924,
   15930,
   15932,
   15937,
   15942,
   15947,
   15952,
   15961,
   15970,
   15980,
   15992,
   16000,
   16011,
   16022,
   16033,
   16045,
   16047,
   16051,
   16058,
   16061,
   16067,
   16073,
   16079,
   16085,
   16089,
   16096,
   16099,
   16105,
   16111,
   16117,
   16123,
   16130,
   16140,
   16143,
   16148,
   16156,
   16160,
   16167,
   16174,
   16181,
   16188,
   16193,
   16201,
   16205,
   16212,
   16219,
   16226,
   16233,
   16237,
   16244,
   16247,
   16253,
   16259,
   16265,
   16271,
   16275,
   16282,
   16285,
   16291,
   16297,
   16303,
   16309,
   16316,
   16319,
   16325,
   16331,
   16337,
   16343,
   16346,
   16352,
   16361,
   16370,
   16379,
   16388,
   16393,
   16398,
   16403,
   16408,
   16419,
   16427,
   16435,
   16443,
   16451,
   16459,
   16467,
   16472,
   16475,
   16477,
   16483,
   16490,
   16497,
   16504,
   16511,
   16519,
   16525,
   16533,
   16540,
   16547,
   16551,
   16555,
   16559,
   16564,
   16569,
   16574,
   16579,
   16584,
   16589,
   16594,
   16599,
   16604,
   16608,
   16612,
   16616,
   16621,
   16627,
   16631,
   16637,
   16641,
   16645,
   16647,
   16651,
   16655,
   16659,
   16662,
   16664,
   16668,
   16672,
   16675,
   16680,
   16685,
   16690,
   16693,
   16698,
   16703,
   16708,
   16711,
   16716,
   16720,
   16726,
   16730,
   16734,
   16740,
   16744,
   16748,
   16752,
   16756,
   16760,
   16763,
   16767,
   16770,
   16773,
   16779,
   16785,
   16791,
   16797,
   16802,
   16808,
   16816,
   16825,
   16830,
   16835,
   16837,
   16839,
   16845,
   16847,
   0,
   0,
   0,
   16853,
   16855,
   16860,
   16864,
   16868,
   16872,
   16876,
   16881,
   16886,
   16891,
   16896,
   16900,
   16904,
   16910,
   16914,
   16918,
   16920,
   16924,
   16928,
   16930,
   16933,
   16937,
   16940,
   16945,
   16950,
   16953,
   16958,
   16963,
   16966,
   16970,
   16976,
   16980,
   16984,
   16991,
   16996,
   17003,
   17011,
   17019,
   17022,
   17026,
   17032,
   17036,
   17039,
   17041,
   17045,
   17049,
   17055,
   17058,
   17061,
   17065,
   17072,
   17080,
   17089,
   17096,
   17104,
   17113,
   17120,
   17128,
   17137,
   17144,
   17152,
   17161,
   17170,
   17180,
   17191,
   17200,
   17210,
   17221,
   17230,
   17240,
   17251,
   17260,
   17270,
   17281,
   17289,
   17298,
   17308,
   17316,
   17325,
   17335,
   17343,
   17352,
   17362,
   17370,
   17379,
   17389,
   17397,
   17406,
   17416,
   17424,
   17433,
   17443,
   17451,
   17460,
   17470,
   17478,
   17487,
   17497,
   17506,
   17516,
   17527,
   17536,
   17546,
   17557,
   17566,
   17576,
   17587,
   17596,
   17606,
   17617,
   17627,
   17638,
   17650,
   17660,
   17671,
   17683,
   17693,
   17704,
   17716,
   17726,
   17737,
   17749,
   17759,
   17770,
   17782,
   17792,
   17803,
   17815,
   17825,
   17836,
   17848,
   17858,
   17869,
   17881,
   17892,
   17904,
   17917,
   17928,
   17940,
   17953,
   17964,
   17976,
   17989,
   18000,
   18012,
   18025,
   18034,
   18044,
   18055,
   18064,
   18074,
   18085,
   18094,
   18104,
   18115,
   18124,
   18134,
   18145,
   18155,
   18166,
   18178,
   18188,
   18199,
   18211,
   18221,
   18232,
   18244,
   18254,
   18265,
   18277,
   18287,
   18298,
   18310,
   18320,
   18331,
   18343,
   18353,
   18364,
   18376,
   18386,
   18397,
   18409,
   18420,
   18432,
   18445,
   18456,
   18468,
   18481,
   18492,
   18504,
   18517,
   18528,
   18540,
   18553,
   18559,
   18567,
   18576,
   18586,
   18594,
   18603,
   18613,
   18621,
   18630,
   18640,
   18648,
   18657,
   18667,
   18675,
   18684,
   18694,
   18702,
   18711,
   18721,
   18729,
   18738,
   18748,
   18756,
   18765,
   18775,
   18782,
   18791,
   18801,
   18812,
   18821,
   18831,
   18842,
   18851,
   18861,
   18872,
   18881,
   18891,
   18902,
   18910,
   18919,
   18929,
   18937,
   18946,
   18956,
   18964,
   18973,
   18983,
   18991,
   19000,
   19010,
   19018,
   19027,
   19037,
   19045,
   19054,
   19064,
   19072,
   19081,
   19091,
   19099,
   19108,
   19118,
   19127,
   19137,
   19148,
   19157,
   19167,
   19178,
   19187,
   19197,
   19208,
   19217,
   19227,
   19238,
   19245,
   19252,
   19259,
   19261,
   19263,
   19268,
   19273,
   19278,
   19283,
   19288,
   19294,
   19300,
   19306,
   19312,
   19319,
   19326,
   19333,
   19340,
   19347,
   19354,
   19361,
   19368,
   19374,
   19380,
   19386,
   19392,
   19398,
   19404,
   19410,
   19416,
   19424,
   19432,
   19440,
   19448,
   19456,
   19464,
   19469,
   19512,
   19555,
   19575,
   19580,
   19584,
   19588,
   19594,
   19597,
   19603,
   19609,
   19622,
   19634,
   19638,
   19645,
   19652,
   19656,
   19666,
   19670,
   19675,
   19680,
   19688,
   19693,
   19701,
   19706,
   19714,
   19722,
   19733,
   19738,
   19746,
   19752,
   19761,
   19767,
   19776,
   19781,
   19789,
   0,
   19794,
   19802,
   19810,
   0,
   0,
   0,
   19818,
   19825,
   19831,
   19834,
   19837,
   19841,
   19847,
   19851,
   19855,
   19859,
   19863,
   19867,
   19871,
   19874,
   19879,
   19883,
   19888,
   19892,
   19897,
   19902,
   0,
   0,
   19906,
   19913,
   19920,
   19922,
   0,
   0,
   0,
   0,
   19924,
   19927,
   0,
   0,
   0,
   0,
   19930,
   19934,
   19938,
   0,
   0,
   0,
   19940,
   19942,
   0,
   19944,
   19955,
   19971,
   19982,
   19994,
   20008,
   20020,
   20025,
   20030,
   20032,
   20039,
   20046,
   20049,
   20052,
   20056,
   20060,
   20064,
   20068,
   20073,
   20078,
   20081,
   20086,
   20090,
   20095,
   20100,
   20104,
   20108,
   20110,
   20118,
   20127,
   20134,
   20137,
   20141,
   20149,
   20157,
   20162,
   20170,
   20181,
   20192,
   20206,
   20220,
   20225,
   20236,
   20239,
   20242,
   0,
   20246,
   20249,
   20255,
   20264,
   20272,
   20285,
   20297,
   20304,
   20310,
   20314,
   20316,
   20319,
   20325,
   20334,
   20347,
   20359,
   20366,
   20372,
   20376,
   20378,
   20381,
   20387,
   20396,
   20409,
   20421,
   20428,
   20434,
   20439,
};

static const nir_algebraic_table nir_opt_algebraic_table = {
   .transforms = nir_opt_algebraic_transforms,
   .transform_offsets = nir_opt_algebraic_transform_offsets,
   .pass_op_table = nir_opt_algebraic_pass_op_table,
   .values = nir_opt_algebraic_values,
   .expression_cond = nir_opt_algebraic_expression_cond,
   .variable_cond = nir_opt_algebraic_variable_cond,
};

bool
nir_opt_algebraic(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[109];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(5477 == ARRAY_SIZE(nir_opt_algebraic_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ffloor;
   condition_flags[22] = !options->lower_ffloor;
   condition_flags[23] = options->lower_ffract;
   condition_flags[24] = options->lower_fceil;
   condition_flags[25] = options->lower_ffma16;
   condition_flags[26] = options->lower_ffma32;
   condition_flags[27] = options->lower_ffma64;
   condition_flags[28] = options->fuse_ffma16;
   condition_flags[29] = options->fuse_ffma32;
   condition_flags[30] = options->fuse_ffma64;
   condition_flags[31] = options->lower_fdph;
   condition_flags[32] = !options->lower_fdph;
   condition_flags[33] = options->lower_fdot;
   condition_flags[34] = !options->lower_fsat;
   condition_flags[35] = !options->lower_iabs;
   condition_flags[36] = options->lower_fsat;
   condition_flags[37] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[38] = !options->lower_fsign;
   condition_flags[39] = options->lower_umax;
   condition_flags[40] = options->lower_umin;
   condition_flags[41] = !options->lower_umax;
   condition_flags[42] = !options->lower_umin;
   condition_flags[43] = options->lower_scmp;
   condition_flags[44] = options->lower_vector_cmp;
   condition_flags[45] = !options->lower_rotate;
   condition_flags[46] = options->lower_rotate;
   condition_flags[47] = options->lower_fpow;
   condition_flags[48] = !options->lower_fpow;
   condition_flags[49] = options->lower_fdiv;
   condition_flags[50] = options->lower_fsqrt;
   condition_flags[51] = !options->lower_fsqrt;
   condition_flags[52] = options->lower_sincos;
   condition_flags[53] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[54] = !options->lower_extract_byte;
   condition_flags[55] = !options->lower_extract_word;
   condition_flags[56] = options->has_pack_32_4x8;
   condition_flags[57] = options->lower_pack_64_2x32_split;
   condition_flags[58] = options->lower_pack_32_2x16_split;
   condition_flags[59] = options->lower_unpack_64_2x32_split;
   condition_flags[60] = options->lower_unpack_32_2x16_split;
   condition_flags[61] = options->lower_fmod;
   condition_flags[62] = options->lower_uadd_carry;
   condition_flags[63] = options->lower_usub_borrow;
   condition_flags[64] = options->lower_bitfield_insert;
   condition_flags[65] = options->lower_hadd;
   condition_flags[66] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[67] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat;
   condition_flags[69] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[70] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[73] = options->lower_bitfield_insert_to_shifts;
   condition_flags[74] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[75] = options->lower_bitfield_extract;
   condition_flags[76] = options->lower_bitfield_extract_to_shifts;
   condition_flags[77] = options->lower_ifind_msb;
   condition_flags[78] = options->lower_find_msb_to_reverse;
   condition_flags[79] = options->lower_find_lsb;
   condition_flags[80] = options->lower_extract_byte;
   condition_flags[81] = options->lower_extract_word;
   condition_flags[82] = options->lower_pack_unorm_2x16;
   condition_flags[83] = options->lower_pack_unorm_4x8;
   condition_flags[84] = options->lower_pack_snorm_2x16;
   condition_flags[85] = options->lower_pack_snorm_4x8;
   condition_flags[86] = options->lower_unpack_unorm_2x16;
   condition_flags[87] = options->lower_unpack_unorm_4x8;
   condition_flags[88] = options->lower_unpack_snorm_2x16;
   condition_flags[89] = options->lower_unpack_snorm_4x8;
   condition_flags[90] = options->lower_pack_split;
   condition_flags[91] = options->lower_isign;
   condition_flags[92] = !options->lower_isign;
   condition_flags[93] = options->lower_fsign;
   condition_flags[94] = !options->has_imul24;
   condition_flags[95] = !options->has_umul24;
   condition_flags[96] = !options->has_umad24;
   condition_flags[97] = options->has_imul24;
   condition_flags[98] = options->has_umad24;
   condition_flags[99] = options->has_umul24;
   condition_flags[100] = options->has_fused_comp_and_csel;
   condition_flags[101] = options->lower_iadd_sat;
   condition_flags[102] = options->support_8bit_alu;
   condition_flags[103] = options->support_16bit_alu;
   condition_flags[104] = options->lower_ldexp;
   condition_flags[105] = !options->lower_bitfield_reverse;
   condition_flags[106] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[107] = options->lower_fisnormal;
   condition_flags[108] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 15
 * transforms:
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b'))
 */


static const nir_search_value_union nir_opt_algebraic_before_ffma_values[] = {
   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 1 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 2, 3 },
      0,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 7, 8 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1912_0_0 -> 0 in the cache */
   /* search1912_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1912_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 10, 3 },
      0,
   } },

   /* replace1912_0_0 -> 5 in the cache */
   /* replace1912_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1912_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 12, 8 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1913_0_0 -> 0 in the cache */
   /* search1913_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1913_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 14, 3 },
      0,
   } },

   /* replace1913_0_0 -> 5 in the cache */
   /* replace1913_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1913_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 16, 8 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1914_0_0 -> 0 in the cache */
   /* search1914_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1914_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 18, 3 },
      0,
   } },

   /* replace1914_0_0 -> 5 in the cache */
   /* replace1914_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1914_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 20, 8 },
      -1,
   } },

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search1915_0_0 -> 5 in the cache */
   /* search1915_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search1915_1_0 -> 5 in the cache */
   /* search1915_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 22, 23 },
      -1,
   } },

   /* replace1915_0 -> 5 in the cache */
   /* replace1915_1_0 -> 8 in the cache */
   /* replace1915_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 5, 25 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search1916_0_0 -> 5 in the cache */
   /* search1916_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search1916_1_0 -> 5 in the cache */
   /* search1916_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 27, 28 },
      -1,
   } },

   /* replace1916_0 -> 5 in the cache */
   /* replace1916_1_0 -> 8 in the cache */
   /* replace1916_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 5, 30 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1917_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 33, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search1918_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1918_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 36, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search1919_1_0 -> 39 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 40, 42 },
      -1,
   } },

   /* replace1919 -> 41 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search1920_0 -> 39 in the cache */
   /* search1920_1_0_0 -> 39 in the cache */
   /* search1920_1_0 -> 40 in the cache */
   /* search1920_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 40, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 39, 44 },
      -1,
   } },

   /* replace1920 -> 41 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search1921_0_0 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search1921_1_0 -> 39 in the cache */
   /* search1921_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 46, 47 },
      -1,
   } },

   /* replace1921 -> 41 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search1922_0 -> 39 in the cache */
   /* search1922_1_0_0 -> 39 in the cache */
   /* search1922_1_0 -> 46 in the cache */
   /* search1922_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 46, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 39, 49 },
      -1,
   } },

   /* replace1922 -> 41 in the cache */

   /* ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a') */
   /* search1923_0_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 51 },
      0,
   } },
   /* search1923_1_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 53 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 52, 54, 55 },
      -1,
   } },

   /* replace1923_0_0 -> 51 in the cache */
   /* replace1923_0_1 -> 53 in the cache */
   /* replace1923_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 51, 53, 55 },
      -1,
   } },
   /* replace1923_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 57, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a') */
   /* search1924_0_0 -> 39 in the cache */
   /* search1924_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 53 },
      0,
   } },
   /* search1924_1_0 -> 39 in the cache */
   /* search1924_1_1 -> 51 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 51 },
      0,
   } },
   /* search1924_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 59, 60, 55 },
      -1,
   } },

   /* replace1924_0_0 -> 53 in the cache */
   /* replace1924_0_1 -> 51 in the cache */
   /* replace1924_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 53, 51, 55 },
      -1,
   } },
   /* replace1924_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 62, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 64, 65 },
      0,
   } },
   /* search1925_1_0 -> 64 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 64, 67 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 66, 68, 69 },
      -1,
   } },

   /* replace1925_0_0 -> 69 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 71, 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 69, 74 },
      -1,
   } },
   /* replace1925_1_0 -> 64 in the cache */
   /* replace1925_1_1 -> 72 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 64, 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 75, 76 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_before_ffma_expression_cond[] = {
   (is_used_once),
};

static const nir_search_variable_cond nir_opt_algebraic_before_ffma_variable_cond[] = {
   (is_not_const),
};

static const struct transform nir_opt_algebraic_before_ffma_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 24, 26, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 29, 31, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 56, 58, 0 },
   { 61, 63, 0 },
   { 70, 77, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_before_ffma_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         2,
         3,
         19,
         3,
         3,
         20,
         19,
         20,
         19,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         4,
         5,
         28,
         5,
         5,
         29,
         28,
         29,
         28,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         0,
         5,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         6,
         7,
         6,
         6,
         12,
         13,
         31,
         32,
         7,
         7,
         7,
         7,
         14,
         15,
         33,
         34,
         6,
         7,
         16,
         6,
         12,
         13,
         31,
         32,
         6,
         7,
         6,
         6,
         12,
         17,
         31,
         32,
         12,
         14,
         12,
         12,
         12,
         18,
         32,
         32,
         13,
         15,
         13,
         17,
         18,
         13,
         35,
         36,
         31,
         33,
         31,
         31,
         32,
         35,
         31,
         32,
         32,
         34,
         32,
         32,
         32,
         36,
         32,
         32,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         9,
         8,
         8,
         21,
         22,
         37,
         38,
         9,
         9,
         9,
         9,
         23,
         24,
         39,
         40,
         8,
         9,
         25,
         8,
         21,
         22,
         37,
         38,
         8,
         9,
         8,
         8,
         21,
         26,
         37,
         38,
         21,
         23,
         21,
         21,
         21,
         27,
         38,
         38,
         22,
         24,
         22,
         26,
         27,
         22,
         41,
         42,
         37,
         39,
         37,
         37,
         38,
         41,
         37,
         38,
         38,
         40,
         38,
         38,
         38,
         42,
         38,
         38,
      },
   },
   [nir_op_fneg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_before_ffma_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   14,
   18,
   20,
   22,
   24,
   26,
   28,
   30,
   32,
   35,
   39,
   41,
   43,
   47,
   49,
   52,
   54,
   57,
   61,
   66,
   68,
   71,
   73,
   76,
   80,
};

static const nir_algebraic_table nir_opt_algebraic_before_ffma_table = {
   .transforms = nir_opt_algebraic_before_ffma_transforms,
   .transform_offsets = nir_opt_algebraic_before_ffma_transform_offsets,
   .pass_op_table = nir_opt_algebraic_before_ffma_pass_op_table,
   .values = nir_opt_algebraic_before_ffma_values,
   .expression_cond = nir_opt_algebraic_before_ffma_expression_cond,
   .variable_cond = nir_opt_algebraic_before_ffma_variable_cond,
};

bool
nir_opt_algebraic_before_ffma(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[109];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(78 == ARRAY_SIZE(nir_opt_algebraic_before_ffma_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ffloor;
   condition_flags[22] = !options->lower_ffloor;
   condition_flags[23] = options->lower_ffract;
   condition_flags[24] = options->lower_fceil;
   condition_flags[25] = options->lower_ffma16;
   condition_flags[26] = options->lower_ffma32;
   condition_flags[27] = options->lower_ffma64;
   condition_flags[28] = options->fuse_ffma16;
   condition_flags[29] = options->fuse_ffma32;
   condition_flags[30] = options->fuse_ffma64;
   condition_flags[31] = options->lower_fdph;
   condition_flags[32] = !options->lower_fdph;
   condition_flags[33] = options->lower_fdot;
   condition_flags[34] = !options->lower_fsat;
   condition_flags[35] = !options->lower_iabs;
   condition_flags[36] = options->lower_fsat;
   condition_flags[37] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[38] = !options->lower_fsign;
   condition_flags[39] = options->lower_umax;
   condition_flags[40] = options->lower_umin;
   condition_flags[41] = !options->lower_umax;
   condition_flags[42] = !options->lower_umin;
   condition_flags[43] = options->lower_scmp;
   condition_flags[44] = options->lower_vector_cmp;
   condition_flags[45] = !options->lower_rotate;
   condition_flags[46] = options->lower_rotate;
   condition_flags[47] = options->lower_fpow;
   condition_flags[48] = !options->lower_fpow;
   condition_flags[49] = options->lower_fdiv;
   condition_flags[50] = options->lower_fsqrt;
   condition_flags[51] = !options->lower_fsqrt;
   condition_flags[52] = options->lower_sincos;
   condition_flags[53] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[54] = !options->lower_extract_byte;
   condition_flags[55] = !options->lower_extract_word;
   condition_flags[56] = options->has_pack_32_4x8;
   condition_flags[57] = options->lower_pack_64_2x32_split;
   condition_flags[58] = options->lower_pack_32_2x16_split;
   condition_flags[59] = options->lower_unpack_64_2x32_split;
   condition_flags[60] = options->lower_unpack_32_2x16_split;
   condition_flags[61] = options->lower_fmod;
   condition_flags[62] = options->lower_uadd_carry;
   condition_flags[63] = options->lower_usub_borrow;
   condition_flags[64] = options->lower_bitfield_insert;
   condition_flags[65] = options->lower_hadd;
   condition_flags[66] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[67] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat;
   condition_flags[69] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[70] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[73] = options->lower_bitfield_insert_to_shifts;
   condition_flags[74] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[75] = options->lower_bitfield_extract;
   condition_flags[76] = options->lower_bitfield_extract_to_shifts;
   condition_flags[77] = options->lower_ifind_msb;
   condition_flags[78] = options->lower_find_msb_to_reverse;
   condition_flags[79] = options->lower_find_lsb;
   condition_flags[80] = options->lower_extract_byte;
   condition_flags[81] = options->lower_extract_word;
   condition_flags[82] = options->lower_pack_unorm_2x16;
   condition_flags[83] = options->lower_pack_unorm_4x8;
   condition_flags[84] = options->lower_pack_snorm_2x16;
   condition_flags[85] = options->lower_pack_snorm_4x8;
   condition_flags[86] = options->lower_unpack_unorm_2x16;
   condition_flags[87] = options->lower_unpack_unorm_4x8;
   condition_flags[88] = options->lower_unpack_snorm_2x16;
   condition_flags[89] = options->lower_unpack_snorm_4x8;
   condition_flags[90] = options->lower_pack_split;
   condition_flags[91] = options->lower_isign;
   condition_flags[92] = !options->lower_isign;
   condition_flags[93] = options->lower_fsign;
   condition_flags[94] = !options->has_imul24;
   condition_flags[95] = !options->has_umul24;
   condition_flags[96] = !options->has_umad24;
   condition_flags[97] = options->has_imul24;
   condition_flags[98] = options->has_umad24;
   condition_flags[99] = options->has_umul24;
   condition_flags[100] = options->has_fused_comp_and_csel;
   condition_flags[101] = options->lower_iadd_sat;
   condition_flags[102] = options->support_8bit_alu;
   condition_flags[103] = options->support_16bit_alu;
   condition_flags[104] = options->lower_ldexp;
   condition_flags[105] = !options->lower_bitfield_reverse;
   condition_flags[106] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[107] = options->lower_fisnormal;
   condition_flags[108] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_before_ffma_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 183
 * transforms:
 *    ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b'))
 *    ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b'))
 *    ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))
 *    ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a'))
 *    ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')))
 *    ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a')))
 *    ('fneg', ('fneg', 'a')) => a
 *    ('~fadd@16', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmulz', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('fadd', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fneg', 'a') => ('fmul', 'a', -1.0)
 *    ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b')
 *    ('ineg', 'a') => ('isub', 0, 'a')
 *    ('iabs', 'a') => ('imax', 'a', ('ineg', 'a'))
 *    ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c')
 *    ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c'))
 *    ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0))
 *    ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0))
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd')))
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ior', 'a', 'a') => a
 *    ('iand', 'a', 'a') => a
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b')
 *    ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a')
 *    ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b'))
 *    ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b'))
 *    ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38)
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g')))
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b'))
 *    ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c'))
 *    ('ishl', 'a', 0) => a
 *    ('ishl', 'a', -32) => a
 *    ('ishr', 'a', 0) => a
 *    ('ishr', 'a', -32) => a
 *    ('ushr', 'a', 0) => a
 *    ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1)
 *    ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2)
 *    ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3)
 *    ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1)
 *    ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b')
 *    ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b')
 *    ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b')))
 *    ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a')
 *    ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a')
 *    ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a')
 *    ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a')
 *    ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a')
 *    ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a')
 *    ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a')
 *    ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a')
 *    ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a')
 *    ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a')
 *    ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a')
 *    ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a')
 *    ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a')
 *    ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a')
 *    ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a')
 *    ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a')
 *    ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a')
 *    ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a')
 *    ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a')
 *    ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a')
 *    ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a')
 *    ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b')
 *    ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b')
 *    ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b')
 *    ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b')
 *    ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b')
 *    ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b')
 *    ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b')
 *    ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b')
 *    ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c')
 *    ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c')
 *    ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b')
 *    ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b')
 *    ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b')
 *    ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b')
 *    ('f2fmp', 'a') => ('f2f16', 'a')
 *    ('f2imp', 'a') => ('f2i16', 'a')
 *    ('f2ump', 'a') => ('f2u16', 'a')
 *    ('i2imp', 'a') => ('i2i16', 'a')
 *    ('i2fmp', 'a') => ('i2f16', 'a')
 *    ('i2imp', 'a') => ('u2u16', 'a')
 *    ('u2fmp', 'a') => ('u2f16', 'a')
 *    ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf)
 */


static const nir_search_value_union nir_opt_algebraic_late_values[] = {
   /* ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace1926_0 -> 0 in the cache */
   /* replace1926_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b') */
   /* search1927_0_0_0 -> 0 in the cache */
   /* search1927_0_0_1 -> 1 in the cache */
   /* search1927_0_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 2 },
      0,
   } },
   /* search1927_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace1927_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace1927_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b') */
   /* search1928_0 -> 3 in the cache */
   /* search1928_1_0 -> 0 in the cache */
   /* search1928_1_1 -> 1 in the cache */
   /* search1928_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace1928_0_0 -> 0 in the cache */
   /* replace1928_0 -> 9 in the cache */
   /* replace1928_1 -> 1 in the cache */
   /* replace1928 -> 10 in the cache */

   /* ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b')) */
   /* search1929_0 -> 3 in the cache */
   /* search1929_1_0_0 -> 0 in the cache */
   /* search1929_1_0_1 -> 1 in the cache */
   /* search1929_1_0 -> 2 in the cache */
   /* search1929_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace1929_0 -> 0 in the cache */
   /* replace1929_1_0 -> 1 in the cache */
   /* replace1929_1 -> 5 in the cache */
   /* replace1929 -> 6 in the cache */

   /* ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   /* search1930_0_0 -> 0 in the cache */
   /* search1930_0_1 -> 1 in the cache */
   /* search1930_0 -> 2 in the cache */
   /* search1930_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace1930_0 -> 0 in the cache */
   /* replace1930_1_0 -> 1 in the cache */
   /* replace1930_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search1931_0_0_0 -> 0 in the cache */
   /* search1931_0_0_1 -> 1 in the cache */
   /* search1931_0_0 -> 2 in the cache */
   /* search1931_0 -> 7 in the cache */
   /* search1931_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace1931_0_0 -> 0 in the cache */
   /* replace1931_0 -> 9 in the cache */
   /* replace1931_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search1932_0 -> 3 in the cache */
   /* search1932_1_0 -> 0 in the cache */
   /* search1932_1_1 -> 1 in the cache */
   /* search1932_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace1932_0_0 -> 0 in the cache */
   /* replace1932_0 -> 9 in the cache */
   /* replace1932_1 -> 1 in the cache */
   /* replace1932 -> 16 in the cache */

   /* ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search1933_0 -> 3 in the cache */
   /* search1933_1_0_0 -> 0 in the cache */
   /* search1933_1_0_1 -> 1 in the cache */
   /* search1933_1_0 -> 2 in the cache */
   /* search1933_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace1933_0 -> 0 in the cache */
   /* replace1933_1_0 -> 1 in the cache */
   /* replace1933_1 -> 5 in the cache */
   /* replace1933 -> 14 in the cache */

   /* ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search1934_0_0 -> 0 in the cache */
   /* search1934_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1934_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace1934_0 -> 0 in the cache */
   /* replace1934_1_0 -> 1 in the cache */
   /* replace1934_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search1935_0_0 -> 0 in the cache */
   /* search1935_0_1 -> 1 in the cache */
   /* search1935_0 -> 19 in the cache */
   /* search1935_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace1935_0 -> 0 in the cache */
   /* replace1935_1_0 -> 1 in the cache */
   /* replace1935_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1936_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 1 },
      0,
   } },
   /* search1936_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 25, 3 },
      -1,
   } },

   /* replace1936_0 -> 0 in the cache */
   /* replace1936_1_0 -> 1 in the cache */
   /* replace1936_1 -> 5 in the cache */
   /* replace1936 -> 14 in the cache */

   /* ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search1937_0_0_0 -> 24 in the cache */
   /* search1937_0_0_1 -> 1 in the cache */
   /* search1937_0_0 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 25 },
      0,
   } },
   /* search1937_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 27, 3 },
      -1,
   } },

   /* replace1937_0_0 -> 0 in the cache */
   /* replace1937_0 -> 9 in the cache */
   /* replace1937_1 -> 1 in the cache */
   /* replace1937 -> 16 in the cache */

   /* ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search1938_0 -> 3 in the cache */
   /* search1938_1_0 -> 24 in the cache */
   /* search1938_1_1 -> 1 in the cache */
   /* search1938_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 25 },
      -1,
   } },

   /* replace1938_0_0 -> 0 in the cache */
   /* replace1938_0 -> 9 in the cache */
   /* replace1938_1 -> 1 in the cache */
   /* replace1938 -> 16 in the cache */

   /* ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search1939_0 -> 3 in the cache */
   /* search1939_1_0_0 -> 24 in the cache */
   /* search1939_1_0_1 -> 1 in the cache */
   /* search1939_1_0 -> 25 in the cache */
   /* search1939_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 27 },
      -1,
   } },

   /* replace1939_0 -> 0 in the cache */
   /* replace1939_1_0 -> 1 in the cache */
   /* replace1939_1 -> 5 in the cache */
   /* replace1939 -> 14 in the cache */

   /* ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search1940_0_0 -> 24 in the cache */
   /* search1940_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 24, 1 },
      0,
   } },
   /* search1940_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace1940_0 -> 0 in the cache */
   /* replace1940_1_0 -> 1 in the cache */
   /* replace1940_1 -> 5 in the cache */
   /* replace1940 -> 21 in the cache */

   /* ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search1941_0_0 -> 24 in the cache */
   /* search1941_0_1 -> 1 in the cache */
   /* search1941_0 -> 31 in the cache */
   /* search1941_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace1941_0 -> 0 in the cache */
   /* replace1941_1_0 -> 1 in the cache */
   /* replace1941_1 -> 5 in the cache */
   /* replace1941 -> 23 in the cache */

   /* ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')) */
   /* search1942_0_0 -> 0 in the cache */
   /* search1942_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search1942_1_0_0 -> 0 in the cache */
   /* search1942_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1942_1_1_0 -> 1 in the cache */
   /* search1942_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 34, 37 },
      -1,
   } },

   /* replace1942_0_0 -> 0 in the cache */
   /* replace1942_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* replace1942_1_0 -> 1 in the cache */
   /* replace1942_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 39, 40 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search1943_1_0 -> 42 in the cache */
   /* search1943_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 44, 45 },
      -1,
   } },

   /* replace1943_0 -> 43 in the cache */
   /* replace1943_1_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 43, 47 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))) */
   /* search1944_0_0 -> 0 in the cache */
   /* search1944_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search1944_1_0_0 -> 0 in the cache */
   /* search1944_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1944_1_1_0 -> 1 in the cache */
   /* search1944_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 50, 51 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 49, 52 },
      -1,
   } },

   /* replace1944_0_0_0 -> 0 in the cache */
   /* replace1944_0_0_1 -> 1 in the cache */
   /* replace1944_0_0 -> 39 in the cache */
   /* replace1944_0_1_0 -> 1 in the cache */
   /* replace1944_0_1_1 -> 0 in the cache */
   /* replace1944_0_1 -> 40 in the cache */
   /* replace1944_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 41 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a'))) */
   /* search1945_0_0 -> 42 in the cache */
   /* search1945_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search1945_1_0 -> 42 in the cache */
   /* search1945_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 55, 56 },
      -1,
   } },

   /* replace1945_0_0 -> 43 in the cache */
   /* replace1945_0_1_0 -> 42 in the cache */
   /* replace1945_0_1 -> 47 in the cache */
   /* replace1945_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 48 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   /* search1946_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 59 },
      -1,
   } },

   /* replace1946 -> 42 in the cache */

   /* ('~fadd@16', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 61, 62 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 63, 64 },
      -1,
   } },

   /* replace1947_0 -> 61 in the cache */
   /* replace1947_1 -> 62 in the cache */
   /* replace1947_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 61, 62, 64 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 67, 68 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 69, 70 },
      -1,
   } },

   /* replace1948_0 -> 67 in the cache */
   /* replace1948_1 -> 68 in the cache */
   /* replace1948_2 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 68, 70 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 73, 74 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 75, 76 },
      -1,
   } },

   /* replace1949_0 -> 73 in the cache */
   /* replace1949_1 -> 74 in the cache */
   /* replace1949_2 -> 76 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 73, 74, 76 },
      -1,
   } },

   /* ('~fadd@32', ('fmulz', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1950_0_0 -> 67 in the cache */
   /* search1950_0_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 67, 68 },
      -1,
   } },
   /* search1950_1 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 79, 70 },
      -1,
   } },

   /* replace1950_0 -> 67 in the cache */
   /* replace1950_1 -> 68 in the cache */
   /* replace1950_2 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 67, 68, 70 },
      -1,
   } },

   /* ('fadd', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search1951_0 -> 0 in the cache */
   /* search1951_1_0 -> 1 in the cache */
   /* search1951_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* replace1951_0 -> 0 in the cache */
   /* replace1951_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('fneg', 'a') => ('fmul', 'a', -1.0) */
   /* search1952_0 -> 42 in the cache */
   /* search1952 -> 59 in the cache */

   /* replace1952_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 42, 84 },
      -1,
   } },

   /* ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b') */
   /* search1953_0 -> 0 in the cache */
   /* search1953_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 86 },
      -1,
   } },

   /* replace1953_0 -> 0 in the cache */
   /* replace1953_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('ineg', 'a') => ('isub', 0, 'a') */
   /* search1954_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 42 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace1954_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 90, 42 },
      -1,
   } },

   /* ('iabs', 'a') => ('imax', 'a', ('ineg', 'a')) */
   /* search1955_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace1955_0 -> 42 in the cache */
   /* replace1955_1_0 -> 42 in the cache */
   /* replace1955_1 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 42, 89 },
      -1,
   } },

   /* ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 94, 95 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 96, 97 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 99, 100, 101 },
      -1,
   } },

   /* ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c') */
   /* search1957_0_0 -> 94 in the cache */
   /* search1957_0_1 -> 95 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 94, 95 },
      0,
   } },
   /* search1957_1 -> 97 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 103, 97 },
      -1,
   } },

   /* replace1957_0 -> 99 in the cache */
   /* replace1957_1_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },
   /* replace1957_2 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 99, 105, 101 },
      -1,
   } },

   /* ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c')) */
   /* search1958_0_0 -> 94 in the cache */
   /* search1958_0_1 -> 95 in the cache */
   /* search1958_0 -> 103 in the cache */
   /* search1958_1 -> 97 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 103, 97 },
      -1,
   } },

   /* replace1958_0 -> 99 in the cache */
   /* replace1958_1_0 -> 100 in the cache */
   /* replace1958_1 -> 105 in the cache */
   /* replace1958_2_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 99, 105, 108 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0)) */
   /* search1959_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 61 },
      -1,
   } },
   /* search1959_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 110, 62 },
      1,
   } },

   /* replace1959_0_0 -> 61 in the cache */
   /* replace1959_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 62 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 113, 114 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 112, 115 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0)) */
   /* search1960_0 -> 61 in the cache */
   /* search1960_1_0 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 62 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 117 },
      1,
   } },

   /* replace1960_0_0 -> 61 in the cache */
   /* replace1960_0_1 -> 62 in the cache */
   /* replace1960_0 -> 112 in the cache */
   /* replace1960_1_0 -> 114 in the cache */
   /* replace1960_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 114, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 112, 119 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 122 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 121, 123 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace1961_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 125, 122 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search1962_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 127, 128 },
      -1,
   } },

   /* replace1962_0 -> 0 in the cache */
   /* replace1962_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search1963_0_0 -> 0 in the cache */
   /* search1963_0 -> 127 in the cache */
   /* search1963_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 127, 128 },
      -1,
   } },

   /* replace1963_0 -> 0 in the cache */
   /* replace1963_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search1964_0_0 -> 0 in the cache */
   /* search1964_0 -> 127 in the cache */
   /* search1964_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 127, 128 },
      -1,
   } },

   /* replace1964_0 -> 0 in the cache */
   /* replace1964_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search1965_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 42 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 135, 136 },
      -1,
   } },

   /* replace1965_0 -> 42 in the cache */
   /* replace1965_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 42, 136 },
      -1,
   } },

   /* ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd'))) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 139, 140 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 142, 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 141, 144 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 3,
      { 145, 146 },
      -1,
   } },

   /* replace1966_0_0 -> 139 in the cache */
   /* replace1966_0_1_0 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 139, 148 },
      -1,
   } },
   /* replace1966_1_0 -> 142 in the cache */
   /* replace1966_1_1_0 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 142, 150 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 149, 151 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search1967_0_0 -> 0 in the cache */
   /* search1967_0 -> 9 in the cache */
   /* search1967_1_0 -> 1 in the cache */
   /* search1967_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace1967_0 -> 1 in the cache */
   /* replace1967_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search1968_0_0 -> 0 in the cache */
   /* search1968_0 -> 9 in the cache */
   /* search1968_1_0 -> 1 in the cache */
   /* search1968_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace1968_0 -> 1 in the cache */
   /* replace1968_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search1969_0_0 -> 0 in the cache */
   /* search1969_0 -> 9 in the cache */
   /* search1969_1_0 -> 1 in the cache */
   /* search1969_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace1969_0 -> 1 in the cache */
   /* replace1969_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search1970_0_0 -> 0 in the cache */
   /* search1970_0 -> 9 in the cache */
   /* search1970_1_0 -> 1 in the cache */
   /* search1970_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace1970_0 -> 1 in the cache */
   /* replace1970_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search1971_0_0 -> 42 in the cache */
   /* search1971_0 -> 59 in the cache */
   /* search1971_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 59, 84 },
      -1,
   } },

   /* replace1971_0 -> 136 in the cache */
   /* replace1971_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 136, 42 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search1972_0 -> 84 in the cache */
   /* search1972_1_0 -> 42 in the cache */
   /* search1972_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 84, 59 },
      -1,
   } },

   /* replace1972_0 -> 42 in the cache */
   /* replace1972_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 42, 136 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search1973_0_0 -> 42 in the cache */
   /* search1973_0 -> 59 in the cache */
   /* search1973_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 59, 84 },
      -1,
   } },

   /* replace1973_0 -> 136 in the cache */
   /* replace1973_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 136, 42 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search1974_0 -> 84 in the cache */
   /* search1974_1_0 -> 42 in the cache */
   /* search1974_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 84, 59 },
      -1,
   } },

   /* replace1974_0 -> 42 in the cache */
   /* replace1974_1 -> 136 in the cache */
   /* replace1974 -> 138 in the cache */

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search1975_0_0 -> 42 in the cache */
   /* search1975_0 -> 59 in the cache */
   /* search1975_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 59, 84 },
      -1,
   } },

   /* replace1975_0 -> 136 in the cache */
   /* replace1975_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 136, 42 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search1976_0 -> 84 in the cache */
   /* search1976_1_0 -> 42 in the cache */
   /* search1976_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 84, 59 },
      -1,
   } },

   /* replace1976_0 -> 42 in the cache */
   /* replace1976_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 42, 136 },
      -1,
   } },

   /* ('ior', 'a', 'a') => a */
   /* search1977_0 -> 42 in the cache */
   /* search1977_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace1977 -> 42 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search1978_0 -> 42 in the cache */
   /* search1978_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace1978 -> 42 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 174 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 175 },
      0,
   } },
   /* search1979_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 176, 136 },
      -1,
   } },

   /* replace1979_0_0 -> 136 in the cache */
   /* replace1979_0_1_0 -> 42 in the cache */
   /* replace1979_0_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 136, 59 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 178 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b') */
   /* search1980_0 -> 0 in the cache */
   /* search1980_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1980_0 -> 0 in the cache */
   /* replace1980_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b') */
   /* search1981_0 -> 0 in the cache */
   /* search1981_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1981_0 -> 0 in the cache */
   /* replace1981_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b') */
   /* search1982_0 -> 0 in the cache */
   /* search1982_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1982_0 -> 0 in the cache */
   /* replace1982_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b') */
   /* search1983_0 -> 0 in the cache */
   /* search1983_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1983_0 -> 0 in the cache */
   /* replace1983_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search1984_0_0 -> 139 in the cache */
   /* search1984_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 139, 140 },
      0,
   } },
   /* search1984_1_0 -> 139 in the cache */
   /* search1984_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 139, 142 },
      0,
   } },
   /* search1984_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 188, 189, 143 },
      -1,
   } },

   /* replace1984_0_0 -> 140 in the cache */
   /* replace1984_0_1 -> 142 in the cache */
   /* replace1984_0_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 140, 142, 143 },
      -1,
   } },
   /* replace1984_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 191, 139 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search1985_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 193, 194 },
      -1,
   } },

   /* replace1985_0 -> 194 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace1985_2 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 194, 196, 67 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search1986_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xc000000000000000 /* -2.0 */ },
   } },
   /* search1986_2 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 198, 194 },
      -1,
   } },

   /* replace1986_0 -> 194 in the cache */
   /* replace1986_1 -> 196 in the cache */
   /* replace1986_2_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 194, 196, 200 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search1987_0 -> 67 in the cache */
   /* search1987_1 -> 198 in the cache */
   /* search1987_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 198, 196 },
      -1,
   } },

   /* replace1987_0 -> 196 in the cache */
   /* replace1987_1 -> 194 in the cache */
   /* replace1987_2 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 196, 194, 67 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search1988_0 -> 67 in the cache */
   /* search1988_1 -> 193 in the cache */
   /* search1988_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 193, 196 },
      -1,
   } },

   /* replace1988_0 -> 196 in the cache */
   /* replace1988_1 -> 194 in the cache */
   /* replace1988_2_0 -> 67 in the cache */
   /* replace1988_2 -> 200 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 196, 194, 200 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search1989_0_0 -> 193 in the cache */
   /* search1989_0_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 193, 67 },
      0,
   } },
   /* search1989_1 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 206, 194 },
      -1,
   } },

   /* replace1989_0 -> 194 in the cache */
   /* replace1989_1 -> 196 in the cache */
   /* replace1989_2 -> 67 in the cache */
   /* replace1989 -> 197 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search1990_0_0 -> 198 in the cache */
   /* search1990_0_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 198, 67 },
      0,
   } },
   /* search1990_1 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 208, 194 },
      -1,
   } },

   /* replace1990_0 -> 194 in the cache */
   /* replace1990_1 -> 196 in the cache */
   /* replace1990_2_0 -> 67 in the cache */
   /* replace1990_2 -> 200 in the cache */
   /* replace1990 -> 201 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search1991_0_0 -> 198 in the cache */
   /* search1991_0_1 -> 67 in the cache */
   /* search1991_0 -> 208 in the cache */
   /* search1991_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 208, 196 },
      -1,
   } },

   /* replace1991_0 -> 196 in the cache */
   /* replace1991_1 -> 194 in the cache */
   /* replace1991_2 -> 67 in the cache */
   /* replace1991 -> 203 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search1992_0_0 -> 193 in the cache */
   /* search1992_0_1 -> 67 in the cache */
   /* search1992_0 -> 206 in the cache */
   /* search1992_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 206, 196 },
      -1,
   } },

   /* replace1992_0 -> 196 in the cache */
   /* replace1992_1 -> 194 in the cache */
   /* replace1992_2_0 -> 67 in the cache */
   /* replace1992_2 -> 200 in the cache */
   /* replace1992 -> 205 in the cache */

   /* ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 212, 214 },
      -1,
   } },
   /* search1993_1 -> 213 in the cache */
   /* search1993_2 -> 213 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 215, 213, 213 },
      -1,
   } },

   /* replace1993_0 -> 213 in the cache */
   /* replace1993_1 -> 212 in the cache */
   /* replace1993_2 -> 213 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 213, 212, 213 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search1994_0 -> 67 in the cache */
   /* search1994_1 -> 193 in the cache */
   /* search1994_2_0_0 -> 67 in the cache */
   /* search1994_2_0_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 67, 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 218 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 193, 219 },
      -1,
   } },

   /* replace1994_0 -> 67 in the cache */
   /* replace1994_1 -> 196 in the cache */
   /* replace1994_2 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 67, 196, 67 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search1995_0 -> 67 in the cache */
   /* search1995_1 -> 193 in the cache */
   /* search1995_2_0_0 -> 67 in the cache */
   /* search1995_2_0 -> 200 in the cache */
   /* search1995_2_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 200, 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 67, 193, 222 },
      -1,
   } },

   /* replace1995_0 -> 67 in the cache */
   /* replace1995_1 -> 196 in the cache */
   /* replace1995_2 -> 67 in the cache */
   /* replace1995 -> 221 in the cache */

   /* ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search1996_0 -> 67 in the cache */
   /* search1996_1_0 -> 67 in the cache */
   /* search1996_1 -> 200 in the cache */
   /* search1996_2_0 -> 193 in the cache */
   /* search1996_2_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 193, 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 67, 200, 224 },
      -1,
   } },

   /* replace1996_0 -> 67 in the cache */
   /* replace1996_1 -> 196 in the cache */
   /* replace1996_2 -> 67 in the cache */
   /* replace1996 -> 221 in the cache */

   /* ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search1997_0 -> 67 in the cache */
   /* search1997_1_0 -> 193 in the cache */
   /* search1997_1_1_0 -> 67 in the cache */
   /* search1997_1_1 -> 200 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 193, 200 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 67, 226 },
      -1,
   } },

   /* replace1997_0 -> 67 in the cache */
   /* replace1997_1 -> 196 in the cache */
   /* replace1997_2 -> 67 in the cache */
   /* replace1997 -> 221 in the cache */

   /* ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 228, 229 },
      0,
   } },
   /* search1998_1_0 -> 228 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 231 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 230, 232 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace1998_1_0 -> 229 in the cache */
   /* replace1998_1_1 -> 231 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 229, 231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 234, 235 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b')) */
   /* search1999_0_0 -> 228 in the cache */
   /* search1999_0_1 -> 229 in the cache */
   /* search1999_0 -> 230 in the cache */
   /* search1999_1_0 -> 228 in the cache */
   /* search1999_1_1 -> 231 in the cache */
   /* search1999_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 230, 232 },
      -1,
   } },

   /* replace1999_0 -> 234 in the cache */
   /* replace1999_1_0 -> 229 in the cache */
   /* replace1999_1_1 -> 231 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 229, 231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 234, 238 },
      -1,
   } },

   /* ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 240 },
      -1,
   } },
   /* search2000_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 241, 43 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x47efffffe0000000 /* 3.4028234663852886e+38 */ },
   } },
   /* search2000_2_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 242, 243, 244 },
      -1,
   } },

   /* replace2000_0_0 -> 42 in the cache */
   /* replace2000_0 -> 244 in the cache */
   /* replace2000_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 244, 243 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g'))) */
   { .variable = {
      { nir_search_value_variable, -7 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 251, 252 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 2,
      { 249, 250, 253 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 3,
      { 247, 248, 254 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 255, 256 },
      -1,
   } },

   /* replace2001_0 -> 247 in the cache */
   /* replace2001_1 -> 248 in the cache */
   /* replace2001_2_0 -> 249 in the cache */
   /* replace2001_2_1 -> 250 in the cache */
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 258, 259, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 249, 250, 261 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 247, 248, 262 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, -5 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 266, 267 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 264, 265, 268 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 269, 270 },
      -1,
   } },

   /* replace2002_0 -> 264 in the cache */
   /* replace2002_1 -> 265 in the cache */
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 272, 273, 274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 264, 265, 275 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g'))) */
   /* search2003_0_0_0 -> 247 in the cache */
   /* search2003_0_0_1 -> 248 in the cache */
   /* search2003_0_0_2_0 -> 249 in the cache */
   /* search2003_0_0_2_1 -> 250 in the cache */
   /* search2003_0_0_2_2_0 -> 251 in the cache */
   /* search2003_0_0_2_2_1 -> 252 in the cache */
   /* search2003_0_0_2_2 -> 253 in the cache */
   /* search2003_0_0_2 -> 254 in the cache */
   /* search2003_0_0 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 255 },
      -1,
   } },
   /* search2003_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 277, 256 },
      -1,
   } },

   /* replace2003_0_0 -> 247 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 247 },
      -1,
   } },
   /* replace2003_1 -> 248 in the cache */
   /* replace2003_2_0_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 249 },
      -1,
   } },
   /* replace2003_2_1 -> 250 in the cache */
   /* replace2003_2_2_0_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 258 },
      -1,
   } },
   /* replace2003_2_2_1 -> 259 in the cache */
   /* replace2003_2_2_2 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 281, 259, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 280, 250, 282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 279, 248, 283 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g'))) */
   /* search2004_0_0 -> 67 in the cache */
   /* search2004_0_1 -> 68 in the cache */
   /* search2004_0_2_0 -> 70 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      3, 1,
      { 286, 287 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 2,
      { 70, 285, 288 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 3,
      { 67, 68, 289 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 290, 291 },
      -1,
   } },

   /* replace2004_0 -> 67 in the cache */
   /* replace2004_1 -> 68 in the cache */
   /* replace2004_2_0 -> 70 in the cache */
   /* replace2004_2_1 -> 285 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 293, 294, 295 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 70, 285, 296 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 67, 68, 297 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e')) */
   /* search2005_0_0 -> 67 in the cache */
   /* search2005_0_1 -> 68 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 299, 300 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 67, 68, 301 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 302, 303 },
      -1,
   } },

   /* replace2005_0 -> 67 in the cache */
   /* replace2005_1 -> 68 in the cache */
   /* replace2005_2_0 -> 70 in the cache */
   /* replace2005_2_1 -> 285 in the cache */
   /* replace2005_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 70, 285, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 67, 68, 305 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g'))) */
   /* search2006_0_0_0 -> 67 in the cache */
   /* search2006_0_0_1 -> 68 in the cache */
   /* search2006_0_0_2_0 -> 70 in the cache */
   /* search2006_0_0_2_1 -> 285 in the cache */
   /* search2006_0_0_2_2_0 -> 286 in the cache */
   /* search2006_0_0_2_2_1 -> 287 in the cache */
   /* search2006_0_0_2_2 -> 288 in the cache */
   /* search2006_0_0_2 -> 289 in the cache */
   /* search2006_0_0 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 290 },
      -1,
   } },
   /* search2006_1 -> 291 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 307, 291 },
      -1,
   } },

   /* replace2006_0_0 -> 67 in the cache */
   /* replace2006_0 -> 200 in the cache */
   /* replace2006_1 -> 68 in the cache */
   /* replace2006_2_0_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 70 },
      -1,
   } },
   /* replace2006_2_1 -> 285 in the cache */
   /* replace2006_2_2_0_0 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 293 },
      -1,
   } },
   /* replace2006_2_2_1 -> 294 in the cache */
   /* replace2006_2_2_2 -> 295 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 310, 294, 295 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 309, 285, 311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 200, 68, 312 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search2007_0 -> 67 in the cache */
   /* search2007_1 -> 68 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 67, 68, 314 },
      -1,
   } },

   /* replace2007 -> 314 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search2008_0 -> 67 in the cache */
   /* search2008_1 -> 68 in the cache */
   /* search2008_2 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 67, 68, 314 },
      -1,
   } },

   /* replace2008 -> 314 in the cache */

   /* ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b')) */
   /* search2009_0 -> 67 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 67, 317, 318 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace2009_0_1_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 70 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 320, 321 },
      -1,
   } },
   /* replace2009_1_0 -> 67 in the cache */
   /* replace2009_1_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 67, 68 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 322, 323 },
      -1,
   } },

   /* ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c')) */
   /* search2010_0 -> 67 in the cache */
   /* search2010_1 -> 317 in the cache */
   /* search2010_2 -> 318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 67, 317, 318 },
      -1,
   } },

   /* replace2010_0_0 -> 67 in the cache */
   /* replace2010_0_1_0_0 -> 68 in the cache */
   /* replace2010_0_1_0_1 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 68, 70 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 326 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 67, 327 },
      -1,
   } },
   /* replace2010_1_0 -> 70 in the cache */
   /* replace2010_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 328, 321 },
      -1,
   } },

   /* ('ishl', 'a', 0) => a */
   /* search2011_0 -> 42 in the cache */
   /* search2011_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 314 },
      -1,
   } },

   /* replace2011 -> 42 in the cache */

   /* ('ishl', 'a', -32) => a */
   /* search2012_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x20 /* -32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 331 },
      -1,
   } },

   /* replace2012 -> 42 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search2013_0 -> 42 in the cache */
   /* search2013_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 314 },
      -1,
   } },

   /* replace2013 -> 42 in the cache */

   /* ('ishr', 'a', -32) => a */
   /* search2014_0 -> 42 in the cache */
   /* search2014_1 -> 331 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 331 },
      -1,
   } },

   /* replace2014 -> 42 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search2015_0 -> 42 in the cache */
   /* search2015_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 42, 314 },
      -1,
   } },

   /* replace2015 -> 42 in the cache */

   /* ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2016_0_0 -> 0 in the cache */
   /* search2016_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 336, 337 },
      -1,
   } },

   /* replace2016_0 -> 0 in the cache */
   /* replace2016_1 -> 1 in the cache */
   /* replace2016 -> 336 in the cache */

   /* ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2017_0_0 -> 0 in the cache */
   /* search2017_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search2017_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 339, 337 },
      -1,
   } },

   /* replace2017_0 -> 0 in the cache */
   /* replace2017_1 -> 1 in the cache */
   /* replace2017 -> 336 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2018_0_0 -> 0 in the cache */
   /* search2018_0_1 -> 1 in the cache */
   /* search2018_0 -> 336 in the cache */
   /* search2018_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 336, 337 },
      -1,
   } },

   /* replace2018_0 -> 0 in the cache */
   /* replace2018_1 -> 1 in the cache */
   /* replace2018 -> 339 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2019_0_0 -> 0 in the cache */
   /* search2019_0_1 -> 1 in the cache */
   /* search2019_0 -> 339 in the cache */
   /* search2019_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 339, 337 },
      -1,
   } },

   /* replace2019_0 -> 0 in the cache */
   /* replace2019_1 -> 1 in the cache */
   /* replace2019 -> 339 in the cache */

   /* ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2020_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 343 },
      -1,
   } },

   /* replace2020_0 -> 61 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 61, 345 },
      -1,
   } },

   /* ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2021_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 347 },
      -1,
   } },

   /* replace2021_0 -> 61 in the cache */
   /* replace2021_1 -> 345 in the cache */
   /* replace2021 -> 346 in the cache */

   /* ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2022_0_0 -> 61 in the cache */
   /* search2022_0 -> 343 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 343 },
      -1,
   } },

   /* replace2022_0 -> 61 in the cache */
   /* replace2022_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 61, 345 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2023_0_0 -> 61 in the cache */
   /* search2023_0 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 347 },
      -1,
   } },

   /* replace2023_0 -> 61 in the cache */
   /* replace2023_1 -> 345 in the cache */
   /* replace2023 -> 350 in the cache */

   /* ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2024_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 352 },
      -1,
   } },

   /* replace2024_0 -> 67 in the cache */
   /* replace2024_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2025_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 355 },
      -1,
   } },

   /* replace2025_0 -> 67 in the cache */
   /* replace2025_1 -> 314 in the cache */
   /* replace2025 -> 354 in the cache */

   /* ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2026_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 357 },
      -1,
   } },

   /* replace2026_0 -> 67 in the cache */
   /* replace2026_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2027_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 360 },
      -1,
   } },

   /* replace2027_0 -> 67 in the cache */
   /* replace2027_1 -> 314 in the cache */
   /* replace2027 -> 359 in the cache */

   /* ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2028_0_0 -> 67 in the cache */
   /* search2028_0 -> 352 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 352 },
      -1,
   } },

   /* replace2028_0 -> 67 in the cache */
   /* replace2028_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2029_0_0 -> 67 in the cache */
   /* search2029_0 -> 355 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 355 },
      -1,
   } },

   /* replace2029_0 -> 67 in the cache */
   /* replace2029_1 -> 314 in the cache */
   /* replace2029 -> 363 in the cache */

   /* ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2030_0_0 -> 67 in the cache */
   /* search2030_0 -> 357 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 357 },
      -1,
   } },

   /* replace2030_0 -> 67 in the cache */
   /* replace2030_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2031_0_0 -> 67 in the cache */
   /* search2031_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 360 },
      -1,
   } },

   /* replace2031_0 -> 67 in the cache */
   /* replace2031_1 -> 314 in the cache */
   /* replace2031 -> 366 in the cache */

   /* ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1) */
   /* search2032_0_0 -> 67 in the cache */
   /* search2032_0_1 -> 314 in the cache */
   /* search2032_0 -> 354 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 354, 368 },
      -1,
   } },

   /* replace2032_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 67, 370 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2) */
   /* search2033_0_0 -> 67 in the cache */
   /* search2033_0_1 -> 314 in the cache */
   /* search2033_0 -> 354 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 354, 372 },
      -1,
   } },

   /* replace2033_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 67, 374 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3) */
   /* search2034_0_0 -> 67 in the cache */
   /* search2034_0_1 -> 314 in the cache */
   /* search2034_0 -> 354 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 354, 376 },
      -1,
   } },

   /* replace2034_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 67, 378 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1) */
   /* search2035_0_0 -> 67 in the cache */
   /* search2035_0_1 -> 368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 67, 368 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00 /* 65280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 380, 381 },
      -1,
   } },

   /* replace2035_0 -> 67 in the cache */
   /* replace2035_1 -> 370 in the cache */
   /* replace2035 -> 371 in the cache */

   /* ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2) */
   /* search2036_0_0 -> 67 in the cache */
   /* search2036_0_1 -> 372 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 67, 372 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff0000 /* 16711680 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 383, 384 },
      -1,
   } },

   /* replace2036_0 -> 67 in the cache */
   /* replace2036_1 -> 374 in the cache */
   /* replace2036 -> 375 in the cache */

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3) */
   /* search2037_0_0 -> 67 in the cache */
   /* search2037_0_1 -> 376 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 67, 376 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 386, 387 },
      -1,
   } },

   /* replace2037_0 -> 67 in the cache */
   /* replace2037_1 -> 378 in the cache */
   /* replace2037 -> 379 in the cache */

   /* ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3) */
   /* search2038_0 -> 67 in the cache */
   /* search2038_1 -> 376 in the cache */
   /* search2038 -> 386 in the cache */

   /* replace2038_0 -> 67 in the cache */
   /* replace2038_1 -> 378 in the cache */
   /* replace2038 -> 379 in the cache */

   /* ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1) */
   /* search2039_0 -> 67 in the cache */
   /* search2039_1 -> 372 in the cache */
   /* search2039 -> 383 in the cache */

   /* replace2039_0 -> 67 in the cache */
   /* replace2039_1 -> 370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 67, 370 },
      -1,
   } },

   /* ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b') */
   /* search2040_0_0 -> 0 in the cache */
   /* search2040_0_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 337 },
      -1,
   } },
   /* search2040_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 390, 1 },
      -1,
   } },

   /* replace2040_0 -> 0 in the cache */
   /* replace2040_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b') */
   /* search2041_0_0 -> 0 in the cache */
   /* search2041_0_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 337 },
      -1,
   } },
   /* search2041_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 393, 1 },
      -1,
   } },

   /* replace2041_0 -> 0 in the cache */
   /* replace2041_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 396, 397 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2042_1_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 399, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 398, 400 },
      -1,
   } },

   /* replace2042_0_0 -> 396 in the cache */
   /* replace2042_0_1 -> 399 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 396, 399 },
      -1,
   } },
   /* replace2042_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 402, 397 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2043_0_0 -> 396 in the cache */
   /* search2043_0_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 396, 397 },
      0,
   } },
   /* search2043_1_0 -> 399 in the cache */
   /* search2043_1_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 399, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 404, 405 },
      -1,
   } },

   /* replace2043_0_0 -> 396 in the cache */
   /* replace2043_0_1 -> 399 in the cache */
   /* replace2043_0 -> 402 in the cache */
   /* replace2043_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 402, 397 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2044_0_0 -> 61 in the cache */
   /* search2044_0_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 61, 345 },
      0,
   } },
   /* search2044_1_0 -> 62 in the cache */
   /* search2044_1_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 62, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 408, 409 },
      -1,
   } },

   /* replace2044_0_0 -> 61 in the cache */
   /* replace2044_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 61, 62 },
      -1,
   } },
   /* replace2044_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 411, 345 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2045_0_0 -> 61 in the cache */
   /* search2045_0_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 61, 345 },
      0,
   } },
   /* search2045_1_0 -> 62 in the cache */
   /* search2045_1_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 62, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 413, 414 },
      -1,
   } },

   /* replace2045_0_0 -> 61 in the cache */
   /* replace2045_0_1 -> 62 in the cache */
   /* replace2045_0 -> 411 in the cache */
   /* replace2045_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 411, 345 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2046_0_0 -> 67 in the cache */
   /* search2046_0_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 67, 314 },
      0,
   } },
   /* search2046_1_0 -> 68 in the cache */
   /* search2046_1_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 68, 314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 417, 418 },
      -1,
   } },

   /* replace2046_0_0 -> 67 in the cache */
   /* replace2046_0_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 67, 68 },
      -1,
   } },
   /* replace2046_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 420, 314 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2047_0_0 -> 67 in the cache */
   /* search2047_0_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 67, 314 },
      0,
   } },
   /* search2047_1_0 -> 68 in the cache */
   /* search2047_1_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 68, 314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 422, 423 },
      -1,
   } },

   /* replace2047_0_0 -> 67 in the cache */
   /* replace2047_0_1 -> 68 in the cache */
   /* replace2047_0 -> 420 in the cache */
   /* replace2047_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 420, 314 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2048_0_0 -> 73 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 73, 426 },
      0,
   } },
   /* search2048_1_0 -> 74 in the cache */
   /* search2048_1_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 74, 426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 427, 428 },
      -1,
   } },

   /* replace2048_0_0 -> 73 in the cache */
   /* replace2048_0_1 -> 74 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 73, 74 },
      -1,
   } },
   /* replace2048_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 430, 426 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2049_0_0 -> 73 in the cache */
   /* search2049_0_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 73, 426 },
      0,
   } },
   /* search2049_1_0 -> 74 in the cache */
   /* search2049_1_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 74, 426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 432, 433 },
      -1,
   } },

   /* replace2049_0_0 -> 73 in the cache */
   /* replace2049_0_1 -> 74 in the cache */
   /* replace2049_0 -> 430 in the cache */
   /* replace2049_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 430, 426 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2050_0 -> 114 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2050_1_1_0 -> 62 in the cache */
   /* search2050_1_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 62, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 436, 437 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 114, 438 },
      -1,
   } },

   /* replace2050_0_0 -> 114 in the cache */
   /* replace2050_0_1_0 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 114, 440 },
      -1,
   } },
   /* replace2050_1_0 -> 62 in the cache */
   /* replace2050_1_1 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 62, 436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 441, 442 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b'))) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2051_1 -> 345 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 345, 447 },
      -1,
   } },

   /* replace2051_0_0_0 -> 444 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 444, 449 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 1,
      { 451 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2052_0 -> 196 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2052_1_1_0 -> 68 in the cache */
   /* search2052_1_1_1 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 68, 194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 453, 454 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 196, 455 },
      -1,
   } },

   /* replace2052_0_0 -> 196 in the cache */
   /* replace2052_0_1_0 -> 453 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 453 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 196, 457 },
      -1,
   } },
   /* replace2052_1_0 -> 68 in the cache */
   /* replace2052_1_1 -> 453 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 68, 453 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 458, 459 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b'))) */
   /* search2053_0 -> 444 in the cache */
   /* search2053_1 -> 314 in the cache */
   /* search2053_2_0_0 -> 445 in the cache */
   /* search2053_2_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 314, 461 },
      -1,
   } },

   /* replace2053_0_0_0 -> 444 in the cache */
   /* replace2053_0_0_1 -> 449 in the cache */
   /* replace2053_0_0 -> 450 in the cache */
   /* replace2053_0 -> 451 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 1,
      { 451 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2054_1_1_0 -> 74 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 74, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 465, 467 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 464, 468 },
      -1,
   } },

   /* replace2054_0_0 -> 464 in the cache */
   /* replace2054_0_1_0 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 464, 470 },
      -1,
   } },
   /* replace2054_1_0 -> 74 in the cache */
   /* replace2054_1_1 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 74, 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 471, 472 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b'))) */
   /* search2055_0 -> 444 in the cache */
   /* search2055_1 -> 426 in the cache */
   /* search2055_2_0_0 -> 445 in the cache */
   /* search2055_2_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 426, 474 },
      -1,
   } },

   /* replace2055_0_0_0 -> 444 in the cache */
   /* replace2055_0_0_1 -> 449 in the cache */
   /* replace2055_0_0 -> 450 in the cache */
   /* replace2055_0 -> 451 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 1,
      { 451 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2056_0 -> 444 in the cache */
   /* search2056_1_0 -> 140 in the cache */
   /* search2056_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 140, 142 },
      0,
   } },
   /* search2056_2_0 -> 140 in the cache */
   /* search2056_2_1 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 140, 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 477, 478 },
      -1,
   } },

   /* replace2056_0 -> 140 in the cache */
   /* replace2056_1_0 -> 444 in the cache */
   /* replace2056_1_1 -> 142 in the cache */
   /* replace2056_1_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 142, 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 140, 480 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2057_0 -> 444 in the cache */
   /* search2057_1_0 -> 140 in the cache */
   /* search2057_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 140, 142 },
      -1,
   } },
   /* search2057_2_0 -> 140 in the cache */
   /* search2057_2_1 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 140, 143 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 482, 483 },
      -1,
   } },

   /* replace2057_0 -> 140 in the cache */
   /* replace2057_1_0 -> 444 in the cache */
   /* replace2057_1_1 -> 142 in the cache */
   /* replace2057_1_2 -> 143 in the cache */
   /* replace2057_1 -> 480 in the cache */
   /* replace2057 -> 481 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2058_0 -> 444 in the cache */
   /* search2058_1_0 -> 265 in the cache */
   /* search2058_1_1 -> 272 in the cache */
   /* search2058_1_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 272, 273 },
      0,
   } },
   /* search2058_2_0 -> 265 in the cache */
   /* search2058_2_1 -> 272 in the cache */
   /* search2058_2_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 272, 274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 485, 486 },
      -1,
   } },

   /* replace2058_0 -> 265 in the cache */
   /* replace2058_1 -> 272 in the cache */
   /* replace2058_2_0 -> 444 in the cache */
   /* replace2058_2_1 -> 273 in the cache */
   /* replace2058_2_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 273, 274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 272, 488 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2059_0 -> 444 in the cache */
   /* search2059_1_0 -> 265 in the cache */
   /* search2059_1_1 -> 272 in the cache */
   /* search2059_1_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 272, 273 },
      -1,
   } },
   /* search2059_2_0 -> 265 in the cache */
   /* search2059_2_1 -> 272 in the cache */
   /* search2059_2_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 272, 274 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 490, 491 },
      -1,
   } },

   /* replace2059_0 -> 265 in the cache */
   /* replace2059_1 -> 272 in the cache */
   /* replace2059_2_0 -> 444 in the cache */
   /* replace2059_2_1 -> 273 in the cache */
   /* replace2059_2_2 -> 274 in the cache */
   /* replace2059_2 -> 488 in the cache */
   /* replace2059 -> 489 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2060_0 -> 444 in the cache */
   /* search2060_1_0 -> 265 in the cache */
   /* search2060_1_1 -> 272 in the cache */
   /* search2060_1_2 -> 273 in the cache */
   /* search2060_1 -> 485 in the cache */
   /* search2060_2_0 -> 265 in the cache */
   /* search2060_2_1 -> 274 in the cache */
   /* search2060_2_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 274, 273 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 485, 493 },
      -1,
   } },

   /* replace2060_0 -> 265 in the cache */
   /* replace2060_1_0 -> 444 in the cache */
   /* replace2060_1_1 -> 272 in the cache */
   /* replace2060_1_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 272, 274 },
      -1,
   } },
   /* replace2060_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 495, 273 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2061_0 -> 444 in the cache */
   /* search2061_1_0 -> 265 in the cache */
   /* search2061_1_1 -> 272 in the cache */
   /* search2061_1_2 -> 273 in the cache */
   /* search2061_1 -> 490 in the cache */
   /* search2061_2_0 -> 265 in the cache */
   /* search2061_2_1 -> 274 in the cache */
   /* search2061_2_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 274, 273 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 490, 497 },
      -1,
   } },

   /* replace2061_0 -> 265 in the cache */
   /* replace2061_1_0 -> 444 in the cache */
   /* replace2061_1_1 -> 272 in the cache */
   /* replace2061_1_2 -> 274 in the cache */
   /* replace2061_1 -> 495 in the cache */
   /* replace2061_2 -> 273 in the cache */
   /* replace2061 -> 496 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2062_0 -> 444 in the cache */
   /* search2062_1_0 -> 68 in the cache */
   /* search2062_1_1 -> 70 in the cache */
   /* search2062_1_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 70, 285 },
      0,
   } },
   /* search2062_2_0 -> 68 in the cache */
   /* search2062_2_1 -> 70 in the cache */
   /* search2062_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 70, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 499, 500 },
      -1,
   } },

   /* replace2062_0 -> 68 in the cache */
   /* replace2062_1 -> 70 in the cache */
   /* replace2062_2_0 -> 444 in the cache */
   /* replace2062_2_1 -> 285 in the cache */
   /* replace2062_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 285, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 70, 502 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2063_0 -> 444 in the cache */
   /* search2063_1_0 -> 68 in the cache */
   /* search2063_1_1 -> 70 in the cache */
   /* search2063_1_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 70, 285 },
      -1,
   } },
   /* search2063_2_0 -> 68 in the cache */
   /* search2063_2_1 -> 70 in the cache */
   /* search2063_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 70, 293 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 504, 505 },
      -1,
   } },

   /* replace2063_0 -> 68 in the cache */
   /* replace2063_1 -> 70 in the cache */
   /* replace2063_2_0 -> 444 in the cache */
   /* replace2063_2_1 -> 285 in the cache */
   /* replace2063_2_2 -> 293 in the cache */
   /* replace2063_2 -> 502 in the cache */
   /* replace2063 -> 503 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2064_0 -> 444 in the cache */
   /* search2064_1_0 -> 68 in the cache */
   /* search2064_1_1 -> 70 in the cache */
   /* search2064_1_2 -> 285 in the cache */
   /* search2064_1 -> 499 in the cache */
   /* search2064_2_0 -> 68 in the cache */
   /* search2064_2_1 -> 293 in the cache */
   /* search2064_2_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 293, 285 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 499, 507 },
      -1,
   } },

   /* replace2064_0 -> 68 in the cache */
   /* replace2064_1_0 -> 444 in the cache */
   /* replace2064_1_1 -> 70 in the cache */
   /* replace2064_1_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 70, 293 },
      -1,
   } },
   /* replace2064_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 509, 285 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2065_0 -> 444 in the cache */
   /* search2065_1_0 -> 68 in the cache */
   /* search2065_1_1 -> 70 in the cache */
   /* search2065_1_2 -> 285 in the cache */
   /* search2065_1 -> 504 in the cache */
   /* search2065_2_0 -> 68 in the cache */
   /* search2065_2_1 -> 293 in the cache */
   /* search2065_2_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 293, 285 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 504, 511 },
      -1,
   } },

   /* replace2065_0 -> 68 in the cache */
   /* replace2065_1_0 -> 444 in the cache */
   /* replace2065_1_1 -> 70 in the cache */
   /* replace2065_1_2 -> 293 in the cache */
   /* replace2065_1 -> 509 in the cache */
   /* replace2065_2 -> 285 in the cache */
   /* replace2065 -> 510 in the cache */

   /* ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a') */
   /* search2066_0_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 514 },
      -1,
   } },

   /* replace2066_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a') */
   /* search2067_0_0_0 -> 67 in the cache */
   /* search2067_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 517 },
      -1,
   } },

   /* replace2067_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a') */
   /* search2068_0_0_0 -> 67 in the cache */
   /* search2068_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 520 },
      -1,
   } },

   /* replace2068_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a') */
   /* search2069_0_0_0 -> 67 in the cache */
   /* search2069_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 523 },
      -1,
   } },

   /* replace2069_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a') */
   /* search2070_0_0_0 -> 67 in the cache */
   /* search2070_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 526 },
      -1,
   } },

   /* replace2070_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a') */
   /* search2071_0_0_0 -> 67 in the cache */
   /* search2071_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 529 },
      -1,
   } },

   /* replace2071_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a') */
   /* search2072_0_0_0 -> 67 in the cache */
   /* search2072_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 532 },
      -1,
   } },

   /* replace2072_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a') */
   /* search2073_0_0_0 -> 67 in the cache */
   /* search2073_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 535 },
      -1,
   } },

   /* replace2073_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a') */
   /* search2074_0_0_0 -> 67 in the cache */
   /* search2074_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 538 },
      -1,
   } },

   /* replace2074_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a') */
   /* search2075_0_0_0 -> 67 in the cache */
   /* search2075_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 541 },
      -1,
   } },

   /* replace2075_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a') */
   /* search2076_0_0_0 -> 67 in the cache */
   /* search2076_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 544 },
      -1,
   } },

   /* replace2076_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a') */
   /* search2077_0_0_0 -> 67 in the cache */
   /* search2077_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 547 },
      -1,
   } },

   /* replace2077_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a') */
   /* search2078_0_0_0 -> 67 in the cache */
   /* search2078_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 550 },
      -1,
   } },

   /* replace2078_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a') */
   /* search2079_0_0_0 -> 67 in the cache */
   /* search2079_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 553 },
      -1,
   } },

   /* replace2079_0 -> 67 in the cache */
   /* replace2079 -> 200 in the cache */

   /* ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a') */
   /* search2080_0_0_0 -> 67 in the cache */
   /* search2080_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 555 },
      -1,
   } },

   /* replace2080_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a') */
   /* search2081_0_0_0 -> 67 in the cache */
   /* search2081_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 558 },
      -1,
   } },

   /* replace2081_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a') */
   /* search2082_0_0_0 -> 67 in the cache */
   /* search2082_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 561 },
      -1,
   } },

   /* replace2082_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a') */
   /* search2083_0_0_0 -> 67 in the cache */
   /* search2083_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 564 },
      -1,
   } },

   /* replace2083_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a') */
   /* search2084_0_0_0 -> 67 in the cache */
   /* search2084_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 567 },
      -1,
   } },

   /* replace2084_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a') */
   /* search2085_0_0_0 -> 67 in the cache */
   /* search2085_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 570 },
      -1,
   } },

   /* replace2085_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a') */
   /* search2086_0_0_0 -> 67 in the cache */
   /* search2086_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 573 },
      -1,
   } },

   /* replace2086_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b') */
   /* search2087_0_0_0 -> 67 in the cache */
   /* search2087_0_0 -> 513 in the cache */
   /* search2087_0_1_0 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 68 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 577 },
      -1,
   } },

   /* replace2087_0 -> 67 in the cache */
   /* replace2087_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b') */
   /* search2088_0_0_0 -> 67 in the cache */
   /* search2088_0_0 -> 513 in the cache */
   /* search2088_0_1_0 -> 68 in the cache */
   /* search2088_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 580 },
      -1,
   } },

   /* replace2088_0 -> 67 in the cache */
   /* replace2088_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b') */
   /* search2089_0_0_0 -> 67 in the cache */
   /* search2089_0_0 -> 513 in the cache */
   /* search2089_0_1_0 -> 68 in the cache */
   /* search2089_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 583 },
      -1,
   } },

   /* replace2089_0 -> 67 in the cache */
   /* replace2089_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b') */
   /* search2090_0_0_0 -> 67 in the cache */
   /* search2090_0_0 -> 513 in the cache */
   /* search2090_0_1_0 -> 68 in the cache */
   /* search2090_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 586 },
      -1,
   } },

   /* replace2090_0 -> 67 in the cache */
   /* replace2090_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b') */
   /* search2091_0_0_0 -> 67 in the cache */
   /* search2091_0_0 -> 513 in the cache */
   /* search2091_0_1_0 -> 68 in the cache */
   /* search2091_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 589 },
      -1,
   } },

   /* replace2091_0 -> 67 in the cache */
   /* replace2091_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b') */
   /* search2092_0_0_0 -> 67 in the cache */
   /* search2092_0_0 -> 513 in the cache */
   /* search2092_0_1_0 -> 68 in the cache */
   /* search2092_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 592 },
      -1,
   } },

   /* replace2092_0 -> 67 in the cache */
   /* replace2092_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b') */
   /* search2093_0_0_0 -> 67 in the cache */
   /* search2093_0_0 -> 513 in the cache */
   /* search2093_0_1_0 -> 68 in the cache */
   /* search2093_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 595 },
      -1,
   } },

   /* replace2093_0 -> 67 in the cache */
   /* replace2093_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b') */
   /* search2094_0_0_0 -> 67 in the cache */
   /* search2094_0_0 -> 513 in the cache */
   /* search2094_0_1_0 -> 68 in the cache */
   /* search2094_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 598 },
      -1,
   } },

   /* replace2094_0 -> 67 in the cache */
   /* replace2094_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c') */
   /* search2095_0_0_0 -> 67 in the cache */
   /* search2095_0_0 -> 513 in the cache */
   /* search2095_0_1_0 -> 68 in the cache */
   /* search2095_0_1 -> 576 in the cache */
   /* search2095_0_2_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 70 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 513, 576, 601 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 602 },
      -1,
   } },

   /* replace2095_0 -> 67 in the cache */
   /* replace2095_1 -> 68 in the cache */
   /* replace2095_2 -> 70 in the cache */
   /* replace2095 -> 72 in the cache */

   /* ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c') */
   /* search2096_0_0_0 -> 67 in the cache */
   /* search2096_0_0 -> 513 in the cache */
   /* search2096_0_1_0 -> 68 in the cache */
   /* search2096_0_1 -> 576 in the cache */
   /* search2096_0_2_0 -> 70 in the cache */
   /* search2096_0_2 -> 601 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 513, 576, 601 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 604 },
      -1,
   } },

   /* replace2096_0 -> 67 in the cache */
   /* replace2096_1 -> 68 in the cache */
   /* replace2096_2 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 67, 68, 70 },
      -1,
   } },

   /* ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b') */
   /* search2097_0_0 -> 67 in the cache */
   /* search2097_0 -> 513 in the cache */
   /* search2097_1_0 -> 68 in the cache */
   /* search2097_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 513, 576 },
      -1,
   } },

   /* replace2097_0 -> 67 in the cache */
   /* replace2097_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b') */
   /* search2098_0_0 -> 67 in the cache */
   /* search2098_0 -> 513 in the cache */
   /* search2098_1_0 -> 68 in the cache */
   /* search2098_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 513, 576 },
      -1,
   } },

   /* replace2098_0 -> 67 in the cache */
   /* replace2098_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b') */
   /* search2099_0_0 -> 67 in the cache */
   /* search2099_0 -> 513 in the cache */
   /* search2099_1_0 -> 68 in the cache */
   /* search2099_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 513, 576 },
      -1,
   } },

   /* replace2099_0 -> 67 in the cache */
   /* replace2099_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b') */
   /* search2100_0_0 -> 67 in the cache */
   /* search2100_0 -> 513 in the cache */
   /* search2100_1_0 -> 68 in the cache */
   /* search2100_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 513, 576 },
      -1,
   } },

   /* replace2100_0 -> 67 in the cache */
   /* replace2100_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('f2fmp', 'a') => ('f2f16', 'a') */
   /* search2101_0 -> 67 in the cache */
   /* search2101 -> 513 in the cache */

   /* replace2101_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('f2imp', 'a') => ('f2i16', 'a') */
   /* search2102_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2102_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('f2ump', 'a') => ('f2u16', 'a') */
   /* search2103_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2103_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('i2imp', 'a') => ('i2i16', 'a') */
   /* search2104_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2104_0 -> 67 in the cache */
   /* replace2104 -> 360 in the cache */

   /* ('i2fmp', 'a') => ('i2f16', 'a') */
   /* search2105_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2105_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('i2imp', 'a') => ('u2u16', 'a') */
   /* search2106_0 -> 67 in the cache */
   /* search2106 -> 620 in the cache */

   /* replace2106_0 -> 67 in the cache */
   /* replace2106 -> 357 in the cache */

   /* ('u2fmp', 'a') => ('u2f16', 'a') */
   /* search2107_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2107_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf) */
   /* search2108_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisfinite,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2108_0_0 -> 42 in the cache */
   /* replace2108_0 -> 47 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x7ff0000000000000 /* inf */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 47, 626 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_late_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
};

static const nir_search_variable_cond nir_opt_algebraic_late_variable_cond[] = {
   (is_finite),
   (is_not_const),
   (is_gt_0_and_lt_1),
   (is_not_fmul),
   (is_not_negative),
   (is_not_const_and_not_fsign),
};

static const struct transform nir_opt_algebraic_late_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 89, 91, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 92, 93, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 180, 181, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 183, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 184, 185, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 187, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 195, 197, 17 },
   { 199, 201, 17 },
   { 202, 203, 17 },
   { 204, 205, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 314, 0 },
   { 319, 324, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 314, 0 },
   { 325, 329, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 42, 0 },
   { 332, 42, 0 },
   { 386, 379, 119 },
   { 383, 389, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 42, 0 },
   { 334, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 513, 615, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 616, 617, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 618, 619, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 620, 360, 0 },
   { 620, 357, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 621, 622, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 623, 624, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 625, 627, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 10, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 124, 126, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 161, 162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 611, 612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 42, 0 },
   { 59, 85, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 16, 0 },
   { 29, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { 26, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 155, 156, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 130, 0 },
   { 137, 138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 609, 610, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 20, 21, 0 },
   { 32, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 132, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 158, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 607, 608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 22, 23, 0 },
   { 33, 23, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 134, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 159, 160, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 613, 614, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 192, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 479, 481, 0 },
   { 484, 481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 487, 489, 0 },
   { 492, 489, 0 },
   { 494, 496, 0 },
   { 498, 496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 501, 503, 0 },
   { 506, 503, 0 },
   { 508, 510, 0 },
   { 512, 510, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 239, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 207, 197, 17 },
   { 209, 201, 17 },
   { 210, 203, 17 },
   { 211, 205, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 82, 83, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 29 },
   { 82, 83, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 80, 81, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 118, 120, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 116, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 116, 115 },
   { 118, 120, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 225, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { 382, 371, 119 },
   { 385, 375, 119 },
   { 388, 379, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 48, 0 },
   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { 401, 403, 0 },
   { 410, 412, 0 },
   { 419, 421, 0 },
   { 429, 431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 57, 58, 0 },
   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 172, 42, 0 },
   { 406, 407, 0 },
   { 415, 416, 0 },
   { 424, 425, 0 },
   { 434, 435, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 98, 102, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 88, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 104, 106, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 88, 111 },
   { 98, 102, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 98, 102, 114 },
   { 104, 106, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 88, 111 },
   { 104, 106, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 109, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 340, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 341, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 42, 0 },
   { 332, 42, 0 },
   { 369, 371, 119 },
   { 373, 375, 119 },
   { 377, 379, 119 },
   { 386, 379, 119 },
   { 383, 389, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 346, 54 },
   { 353, 354, 54 },
   { 358, 359, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 348, 346, 54 },
   { 356, 354, 54 },
   { 361, 359, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 54 },
   { 362, 363, 54 },
   { 365, 366, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 351, 350, 54 },
   { 364, 363, 54 },
   { 367, 366, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 12, 6, 0 },
   { 163, 164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 8, 10, 0 },
   { 161, 162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 18, 14, 0 },
   { 30, 14, 0 },
   { 167, 138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { 28, 16, 0 },
   { 165, 166, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 220, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 221, 17 },
   { 225, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 195, 197, 17 },
   { 199, 201, 17 },
   { 202, 203, 17 },
   { 204, 205, 17 },
   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { 220, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { 223, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { 225, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 306, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 177, 179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 439, 443, 14 },
   { 456, 460, 16 },
   { 469, 473, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 207, 197, 17 },
   { 209, 201, 17 },
   { 210, 203, 17 },
   { 211, 205, 17 },
   { 439, 443, 14 },
   { 456, 460, 16 },
   { 469, 473, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 306, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 271, 276, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 304, 306, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 271, 276, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 304, 306, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 29 },
   { 271, 276, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 29 },
   { 304, 306, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 117 },
   { 304, 306, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 554, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 587, 588, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 605, 606, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 593, 594, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 584, 585, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 578, 579, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 603, 72, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 565, 566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 574, 575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 562, 563, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 515, 516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 518, 519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 521, 522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 524, 525, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 527, 528, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 530, 531, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 533, 534, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 536, 537, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 539, 540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 542, 543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 545, 546, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 549, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 551, 552, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 557, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 559, 560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 568, 569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 571, 572, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 581, 582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 590, 591, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 596, 597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 599, 600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 448, 452, 0 },
   { 462, 463, 0 },
   { 475, 476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 245, 246, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 38, 41, 0 },
   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 53, 54, 0 },
   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 298, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 298, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 257, 263, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 292, 298, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 257, 263, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 292, 298, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 29 },
   { 257, 263, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 29 },
   { 292, 298, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 117 },
   { 271, 276, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 117 },
   { 292, 298, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 117 },
   { 304, 306, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 298, 117 },
   { 304, 306, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 117 },
   { 292, 298, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 278, 284, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 308, 313, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 278, 284, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 308, 313, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 82, 83, 109 },
   { 278, 284, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 28 },
   { 71, 72, 29 },
   { 77, 78, 30 },
   { 82, 83, 109 },
   { 308, 313, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 29 },
   { 82, 83, 109 },
   { 278, 284, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 29 },
   { 82, 83, 109 },
   { 308, 313, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 271, 276, 117 },
   { 278, 284, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 271, 276, 117 },
   { 308, 313, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 278, 284, 117 },
   { 304, 306, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 304, 306, 117 },
   { 308, 313, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 257, 263, 117 },
   { 278, 284, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 257, 263, 117 },
   { 308, 313, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 278, 284, 117 },
   { 292, 298, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 292, 298, 117 },
   { 308, 313, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 109 },
   { 278, 284, 117 },
   { 308, 313, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_late_pass_op_table[nir_num_search_ops] = {
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         52,
         53,
         0,
         165,
         0,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         0,
         56,
         0,
         0,
         56,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         57,
         0,
         0,
         166,
         0,
         56,
         0,
         0,
         56,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         7,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         3,
         9,
         4,
         8,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         10,
         0,
         10,
         12,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         2,
         3,
         97,
         98,
         98,
         99,
         2,
         97,
         98,
         98,
         181,
         182,
         234,
         235,
         251,
         252,
         3,
         3,
         100,
         101,
         102,
         103,
         3,
         183,
         184,
         185,
         186,
         187,
         236,
         237,
         253,
         254,
         97,
         100,
         97,
         104,
         104,
         105,
         97,
         97,
         104,
         104,
         188,
         189,
         238,
         239,
         251,
         252,
         98,
         101,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         98,
         102,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         99,
         103,
         105,
         106,
         106,
         99,
         99,
         105,
         106,
         106,
         192,
         193,
         242,
         243,
         257,
         258,
         2,
         3,
         97,
         98,
         98,
         99,
         107,
         97,
         98,
         98,
         181,
         182,
         234,
         235,
         251,
         252,
         97,
         183,
         97,
         104,
         104,
         105,
         97,
         97,
         104,
         104,
         188,
         189,
         238,
         239,
         251,
         252,
         98,
         184,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         98,
         185,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         181,
         186,
         188,
         190,
         190,
         192,
         181,
         188,
         190,
         190,
         181,
         194,
         244,
         245,
         259,
         260,
         182,
         187,
         189,
         191,
         191,
         193,
         182,
         189,
         191,
         191,
         194,
         182,
         246,
         247,
         261,
         262,
         234,
         236,
         238,
         240,
         240,
         242,
         234,
         238,
         240,
         240,
         244,
         246,
         234,
         248,
         263,
         264,
         235,
         237,
         239,
         241,
         241,
         243,
         235,
         239,
         241,
         241,
         245,
         247,
         248,
         235,
         265,
         266,
         251,
         253,
         251,
         255,
         255,
         257,
         251,
         251,
         255,
         255,
         259,
         261,
         263,
         265,
         251,
         267,
         252,
         254,
         252,
         256,
         256,
         258,
         252,
         252,
         256,
         256,
         260,
         262,
         264,
         266,
         267,
         252,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         4,
         58,
         59,
         60,
         61,
         62,
         249,
         250,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         63,
         64,
         0,
         0,
         167,
         0,
         0,
         65,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         66,
         0,
         67,
         0,
         0,
         67,
         0,
         0,
         68,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         69,
         0,
         0,
         0,
         168,
         0,
         67,
         0,
         0,
         67,
         0,
         0,
         169,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         5,
         6,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         70,
         71,
         72,
         73,
         6,
         5,
         70,
         5,
         5,
         5,
         5,
         5,
         5,
         71,
         5,
         74,
         5,
         5,
         5,
         5,
         72,
         5,
         5,
         5,
         5,
         5,
         5,
         73,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         5,
         5,
         5,
         5,
         75,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         8,
         76,
         77,
         78,
         8,
         7,
         76,
         7,
         7,
         7,
         7,
         7,
         77,
         7,
         79,
         7,
         7,
         7,
         78,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         80,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         114,
         9,
         9,
         9,
         9,
         115,
         9,
         116,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         231,
         9,
         9,
         116,
         9,
         9,
         9,
         9,
         231,
         9,
         114,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         117,
         9,
         9,
         9,
         9,
         231,
         231,
         9,
         9,
         9,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         1,
         1,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         232,
         10,
         10,
         10,
         118,
         10,
         232,
         10,
         10,
         118,
         119,
         10,
         10,
         10,
         10,
         10,
         10,
         120,
         10,
         10,
         232,
         232,
         10,
         10,
         10,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         11,
         12,
         89,
         90,
         11,
         228,
         12,
         12,
         91,
         92,
         12,
         229,
         89,
         91,
         89,
         93,
         89,
         228,
         90,
         92,
         93,
         90,
         90,
         230,
         11,
         12,
         89,
         90,
         94,
         228,
         228,
         229,
         228,
         230,
         228,
         228,
      },
   },
   [nir_op_fmulz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         14,
         122,
         123,
         124,
         122,
         122,
         125,
         126,
         123,
         125,
         123,
         127,
         124,
         126,
         127,
         124,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         15,
      },
   },
   [nir_op_iabs] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         16,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         17,
         17,
         128,
         128,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         108,
         109,
         110,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         18,
         141,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         81,
         81,
         0,
         0,
         81,
         82,
         0,
         0,
         0,
         0,
         83,
      },
   },
   [nir_op_fdot2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         19,
      },
   },
   [nir_op_fdot3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         20,
      },
   },
   [nir_op_fdot4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         21,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         22,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         84,
         84,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         7,
         4,
         8,
         7,
         3,
         0,
         0,
         9,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         173,
         177,
         173,
         174,
         174,
         173,
         178,
         179,
         179,
         173,
         175,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         113,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         177,
         173,
         174,
         174,
         173,
         178,
         179,
         179,
         173,
         175,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         95,
         0,
         0,
         0,
         96,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         227,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         25,
         142,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         26,
         143,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         28,
         0,
         29,
         0,
         28,
         0,
         29,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         30,
         0,
         31,
         0,
         30,
         0,
         31,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         32,
         0,
         0,
         32,
         0,
         0,
         133,
         0,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         33,
         0,
         33,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         34,
         0,
         34,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         129,
         35,
         35,
         35,
         130,
         35,
         35,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         36,
         37,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         131,
         36,
         36,
         36,
         132,
         36,
         36,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         38,
         135,
         136,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         39,
         137,
         138,
      },
   },
   [nir_op_insert_u8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         134,
         134,
      },
   },
   [nir_op_insert_u16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         139,
         139,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         40,
         0,
         40,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         41,
         41,
         41,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         42,
         42,
         42,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         140,
      },
   },
   [nir_op_inot] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         43,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 32,
      .table = (const uint16_t []) {
      
         0,
         195,
         196,
         197,
         198,
         199,
         200,
         201,
         202,
         203,
         204,
         205,
         206,
         207,
         208,
         209,
         210,
         211,
         212,
         213,
         214,
         215,
         216,
         217,
         218,
         219,
         220,
         221,
         222,
         223,
         224,
         225,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         144,
      },
   },
   [nir_op_f2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         44,
      },
   },
   [nir_op_fceil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         145,
      },
   },
   [nir_op_fcos] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         146,
      },
   },
   [nir_op_fddx] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         147,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         148,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         149,
      },
   },
   [nir_op_fddy] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         150,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         151,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         152,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         153,
      },
   },
   [nir_op_ffloor] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         154,
      },
   },
   [nir_op_ffract] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         155,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         156,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         157,
      },
   },
   [nir_op_fround_even] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         158,
      },
   },
   [nir_op_fsign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         159,
      },
   },
   [nir_op_fsin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         160,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         161,
      },
   },
   [nir_op_fmod] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         162,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         163,
      },
   },
   [nir_op_frem] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         164,
      },
   },
   [nir_op_f2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         45,
      },
   },
   [nir_op_f2ump] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         46,
      },
   },
   [nir_op_i2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         47,
      },
   },
   [nir_op_i2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         48,
      },
   },
   [nir_op_u2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         49,
      },
   },
   [nir_op_fisfinite] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         50,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_late_transform_offsets[] = {
   0,
   0,
   0,
   0,
   1,
   0,
   0,
   0,
   0,
   3,
   5,
   0,
   0,
   0,
   0,
   7,
   9,
   0,
   0,
   11,
   13,
   15,
   17,
   0,
   19,
   0,
   0,
   0,
   24,
   26,
   29,
   31,
   34,
   39,
   42,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   44,
   46,
   48,
   50,
   53,
   55,
   57,
   59,
   61,
   63,
   65,
   67,
   69,
   71,
   73,
   75,
   78,
   80,
   82,
   84,
   87,
   89,
   92,
   94,
   96,
   99,
   101,
   104,
   106,
   0,
   108,
   110,
   112,
   115,
   117,
   119,
   121,
   0,
   123,
   0,
   125,
   0,
   127,
   130,
   135,
   0,
   0,
   0,
   0,
   0,
   0,
   140,
   0,
   142,
   144,
   148,
   150,
   152,
   156,
   164,
   166,
   171,
   174,
   0,
   179,
   181,
   183,
   0,
   186,
   0,
   188,
   193,
   195,
   198,
   204,
   207,
   209,
   0,
   215,
   217,
   219,
   221,
   224,
   227,
   230,
   232,
   234,
   236,
   238,
   240,
   248,
   250,
   254,
   258,
   262,
   266,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   268,
   271,
   274,
   278,
   282,
   0,
   284,
   286,
   288,
   290,
   292,
   294,
   297,
   303,
   306,
   309,
   312,
   314,
   316,
   319,
   326,
   337,
   339,
   341,
   344,
   347,
   352,
   357,
   360,
   363,
   366,
   368,
   370,
   372,
   374,
   376,
   378,
   380,
   382,
   384,
   386,
   388,
   390,
   392,
   394,
   396,
   398,
   400,
   402,
   404,
   406,
   408,
   410,
   412,
   414,
   416,
   418,
   420,
   422,
   424,
   426,
   428,
   432,
   434,
   436,
   438,
   440,
   443,
   0,
   446,
   448,
   450,
   452,
   454,
   457,
   460,
   465,
   470,
   473,
   476,
   479,
   482,
   485,
   488,
   491,
   493,
   495,
   498,
   501,
   504,
   507,
   513,
   519,
   523,
   527,
   531,
   535,
   539,
   543,
   547,
   551,
   555,
   559,
};

static const nir_algebraic_table nir_opt_algebraic_late_table = {
   .transforms = nir_opt_algebraic_late_transforms,
   .transform_offsets = nir_opt_algebraic_late_transform_offsets,
   .pass_op_table = nir_opt_algebraic_late_pass_op_table,
   .values = nir_opt_algebraic_late_values,
   .expression_cond = nir_opt_algebraic_late_expression_cond,
   .variable_cond = nir_opt_algebraic_late_variable_cond,
};

bool
nir_opt_algebraic_late(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[121];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(628 == ARRAY_SIZE(nir_opt_algebraic_late_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ffloor;
   condition_flags[22] = !options->lower_ffloor;
   condition_flags[23] = options->lower_ffract;
   condition_flags[24] = options->lower_fceil;
   condition_flags[25] = options->lower_ffma16;
   condition_flags[26] = options->lower_ffma32;
   condition_flags[27] = options->lower_ffma64;
   condition_flags[28] = options->fuse_ffma16;
   condition_flags[29] = options->fuse_ffma32;
   condition_flags[30] = options->fuse_ffma64;
   condition_flags[31] = options->lower_fdph;
   condition_flags[32] = !options->lower_fdph;
   condition_flags[33] = options->lower_fdot;
   condition_flags[34] = !options->lower_fsat;
   condition_flags[35] = !options->lower_iabs;
   condition_flags[36] = options->lower_fsat;
   condition_flags[37] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[38] = !options->lower_fsign;
   condition_flags[39] = options->lower_umax;
   condition_flags[40] = options->lower_umin;
   condition_flags[41] = !options->lower_umax;
   condition_flags[42] = !options->lower_umin;
   condition_flags[43] = options->lower_scmp;
   condition_flags[44] = options->lower_vector_cmp;
   condition_flags[45] = !options->lower_rotate;
   condition_flags[46] = options->lower_rotate;
   condition_flags[47] = options->lower_fpow;
   condition_flags[48] = !options->lower_fpow;
   condition_flags[49] = options->lower_fdiv;
   condition_flags[50] = options->lower_fsqrt;
   condition_flags[51] = !options->lower_fsqrt;
   condition_flags[52] = options->lower_sincos;
   condition_flags[53] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[54] = !options->lower_extract_byte;
   condition_flags[55] = !options->lower_extract_word;
   condition_flags[56] = options->has_pack_32_4x8;
   condition_flags[57] = options->lower_pack_64_2x32_split;
   condition_flags[58] = options->lower_pack_32_2x16_split;
   condition_flags[59] = options->lower_unpack_64_2x32_split;
   condition_flags[60] = options->lower_unpack_32_2x16_split;
   condition_flags[61] = options->lower_fmod;
   condition_flags[62] = options->lower_uadd_carry;
   condition_flags[63] = options->lower_usub_borrow;
   condition_flags[64] = options->lower_bitfield_insert;
   condition_flags[65] = options->lower_hadd;
   condition_flags[66] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[67] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat;
   condition_flags[69] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[70] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[73] = options->lower_bitfield_insert_to_shifts;
   condition_flags[74] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[75] = options->lower_bitfield_extract;
   condition_flags[76] = options->lower_bitfield_extract_to_shifts;
   condition_flags[77] = options->lower_ifind_msb;
   condition_flags[78] = options->lower_find_msb_to_reverse;
   condition_flags[79] = options->lower_find_lsb;
   condition_flags[80] = options->lower_extract_byte;
   condition_flags[81] = options->lower_extract_word;
   condition_flags[82] = options->lower_pack_unorm_2x16;
   condition_flags[83] = options->lower_pack_unorm_4x8;
   condition_flags[84] = options->lower_pack_snorm_2x16;
   condition_flags[85] = options->lower_pack_snorm_4x8;
   condition_flags[86] = options->lower_unpack_unorm_2x16;
   condition_flags[87] = options->lower_unpack_unorm_4x8;
   condition_flags[88] = options->lower_unpack_snorm_2x16;
   condition_flags[89] = options->lower_unpack_snorm_4x8;
   condition_flags[90] = options->lower_pack_split;
   condition_flags[91] = options->lower_isign;
   condition_flags[92] = !options->lower_isign;
   condition_flags[93] = options->lower_fsign;
   condition_flags[94] = !options->has_imul24;
   condition_flags[95] = !options->has_umul24;
   condition_flags[96] = !options->has_umad24;
   condition_flags[97] = options->has_imul24;
   condition_flags[98] = options->has_umad24;
   condition_flags[99] = options->has_umul24;
   condition_flags[100] = options->has_fused_comp_and_csel;
   condition_flags[101] = options->lower_iadd_sat;
   condition_flags[102] = options->support_8bit_alu;
   condition_flags[103] = options->support_16bit_alu;
   condition_flags[104] = options->lower_ldexp;
   condition_flags[105] = !options->lower_bitfield_reverse;
   condition_flags[106] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[107] = options->lower_fisnormal;
   condition_flags[108] = !options->vectorize_vec2_16bit;
   condition_flags[109] = options->has_fsub;
   condition_flags[110] = options->lower_fneg;
   condition_flags[111] = options->has_isub || options->lower_ineg;
   condition_flags[112] = options->lower_ineg;
   condition_flags[113] = options->lower_iabs;
   condition_flags[114] = options->has_iadd3;
   condition_flags[115] = options->vectorize_vec2_16bit;
   condition_flags[116] = options->fdot_replicates;
   condition_flags[117] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[118] = options->avoid_ternary_with_two_constants;
   condition_flags[119] = !options->lower_insert_byte;
   condition_flags[120] = !options->lower_insert_word;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_late_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 19
 * transforms:
 *    ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b')
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b')
 *    ('fneg', ('fneg', 'a')) => a
 *    ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b')
 *    ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b'))
 *    ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c'))
 *    ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c')
 *    ('fneg', ('fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b'))
 *    ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a'))
 *    ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a'))
 */


static const nir_search_value_union nir_opt_algebraic_distribute_src_mods_values[] = {
   /* ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2109_0 -> 0 in the cache */
   /* replace2109_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 8 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 9, 10 },
      -1,
   } },

   /* replace2110_0 -> 6 in the cache */
   /* replace2110_1 -> 8 in the cache */
   /* replace2110_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      -1,
   } },

   /* ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b') */
   /* search2111_0_0 -> 0 in the cache */
   /* search2111_0 -> 1 in the cache */
   /* search2111_1_0 -> 2 in the cache */
   /* search2111_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2111_0 -> 0 in the cache */
   /* replace2111_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b') */
   /* search2112_0_0 -> 0 in the cache */
   /* search2112_0 -> 1 in the cache */
   /* search2112_1_0 -> 2 in the cache */
   /* search2112_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2112_0 -> 0 in the cache */
   /* replace2112_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b') */
   /* search2113_0_0 -> 0 in the cache */
   /* search2113_0 -> 1 in the cache */
   /* search2113_1_0 -> 2 in the cache */
   /* search2113_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2113_0 -> 0 in the cache */
   /* replace2113_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 20 },
      -1,
   } },

   /* replace2114 -> 19 in the cache */

   /* ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b') */
   /* search2115_0_0 -> 0 in the cache */
   /* search2115_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2115_0_0 -> 0 in the cache */
   /* replace2115_0 -> 1 in the cache */
   /* replace2115_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b')) */
   /* search2116_0_0 -> 0 in the cache */
   /* search2116_0_1 -> 2 in the cache */
   /* search2116_0 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2116_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2116_1_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 26, 27 },
      -1,
   } },

   /* ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c')) */
   /* search2117_0_0 -> 6 in the cache */
   /* search2117_0_1 -> 8 in the cache */
   /* search2117_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 29 },
      -1,
   } },

   /* replace2117_0_0 -> 6 in the cache */
   /* replace2117_0 -> 7 in the cache */
   /* replace2117_1 -> 8 in the cache */
   /* replace2117_2_0 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 10 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 8, 31 },
      -1,
   } },

   /* ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c') */
   /* search2118_0_0 -> 6 in the cache */
   /* search2118_0_1 -> 8 in the cache */
   /* search2118_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 33 },
      -1,
   } },

   /* replace2118_0_0 -> 6 in the cache */
   /* replace2118_0 -> 7 in the cache */
   /* replace2118_1_0 -> 8 in the cache */
   /* replace2118_1 -> 9 in the cache */
   /* replace2118_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 7, 9, 10 },
      -1,
   } },

   /* ('fneg', ('fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2119_0_0 -> 0 in the cache */
   /* search2119_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 36 },
      -1,
   } },

   /* replace2119_0_0 -> 0 in the cache */
   /* replace2119_0 -> 1 in the cache */
   /* replace2119_1_0 -> 2 in the cache */
   /* replace2119_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2120_0_0 -> 0 in the cache */
   /* search2120_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 39 },
      -1,
   } },

   /* replace2120_0_0 -> 0 in the cache */
   /* replace2120_0 -> 1 in the cache */
   /* replace2120_1_0 -> 2 in the cache */
   /* replace2120_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2121_0_0 -> 0 in the cache */
   /* search2121_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 42 },
      -1,
   } },

   /* replace2121_0_0 -> 0 in the cache */
   /* replace2121_0 -> 1 in the cache */
   /* replace2121_1_0 -> 2 in the cache */
   /* replace2121_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b') */
   /* search2122_0_0 -> 0 in the cache */
   /* search2122_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 45 },
      -1,
   } },

   /* replace2122_0_0 -> 0 in the cache */
   /* replace2122_0 -> 1 in the cache */
   /* replace2122_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b') */
   /* search2123_0_0 -> 0 in the cache */
   /* search2123_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 48 },
      -1,
   } },

   /* replace2123_0_0 -> 0 in the cache */
   /* replace2123_0 -> 1 in the cache */
   /* replace2123_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b') */
   /* search2124_0_0 -> 0 in the cache */
   /* search2124_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 51 },
      -1,
   } },

   /* replace2124_0_0 -> 0 in the cache */
   /* replace2124_0 -> 1 in the cache */
   /* replace2124_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b')) */
   /* search2125_0_0 -> 0 in the cache */
   /* search2125_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 54 },
      -1,
   } },

   /* replace2125_0 -> 0 in the cache */
   /* replace2125_1_0 -> 2 in the cache */
   /* replace2125_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a')) */
   /* search2126_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 19 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2126_0_0 -> 19 in the cache */
   /* replace2126_0 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 20 },
      -1,
   } },

   /* ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a')) */
   /* search2127_0_0 -> 19 in the cache */
   /* search2127_0 -> 57 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2127_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 61 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_distribute_src_mods_expression_cond[] = {
   (is_used_once),
};


static const struct transform nir_opt_algebraic_distribute_src_mods_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 23, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 21, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 30, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 47, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 49, 50, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 53, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 40, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 43, 44, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 56, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 59, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 25, 28, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 62, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 5, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 12, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 18, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_distribute_src_mods_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         2,
         2,
         2,
         28,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         7,
         8,
         9,
         10,
         11,
         12,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         1,
         3,
         4,
         5,
         6,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         3,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         4,
         4,
         4,
         4,
         4,
         4,
         29,
         29,
      },
   },
   [nir_op_fdot2_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         5,
         5,
         5,
         30,
      },
   },
   [nir_op_fdot3_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         6,
         6,
         6,
         31,
      },
   },
   [nir_op_fdot4_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         7,
         7,
         7,
         32,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         26,
         27,
      },
   },
   [nir_op_flrp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         8,
      },
   },
   [nir_op_fadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_fmin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_fmax] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_fdph_replicated] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         12,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_distribute_src_mods_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   13,
   15,
   17,
   19,
   21,
   23,
   25,
   27,
   29,
   31,
   33,
   35,
   37,
};

static const nir_algebraic_table nir_opt_algebraic_distribute_src_mods_table = {
   .transforms = nir_opt_algebraic_distribute_src_mods_transforms,
   .transform_offsets = nir_opt_algebraic_distribute_src_mods_transform_offsets,
   .pass_op_table = nir_opt_algebraic_distribute_src_mods_pass_op_table,
   .values = nir_opt_algebraic_distribute_src_mods_values,
   .expression_cond = nir_opt_algebraic_distribute_src_mods_expression_cond,
   .variable_cond = NULL,
};

bool
nir_opt_algebraic_distribute_src_mods(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[121];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(63 == ARRAY_SIZE(nir_opt_algebraic_distribute_src_mods_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ffloor;
   condition_flags[22] = !options->lower_ffloor;
   condition_flags[23] = options->lower_ffract;
   condition_flags[24] = options->lower_fceil;
   condition_flags[25] = options->lower_ffma16;
   condition_flags[26] = options->lower_ffma32;
   condition_flags[27] = options->lower_ffma64;
   condition_flags[28] = options->fuse_ffma16;
   condition_flags[29] = options->fuse_ffma32;
   condition_flags[30] = options->fuse_ffma64;
   condition_flags[31] = options->lower_fdph;
   condition_flags[32] = !options->lower_fdph;
   condition_flags[33] = options->lower_fdot;
   condition_flags[34] = !options->lower_fsat;
   condition_flags[35] = !options->lower_iabs;
   condition_flags[36] = options->lower_fsat;
   condition_flags[37] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[38] = !options->lower_fsign;
   condition_flags[39] = options->lower_umax;
   condition_flags[40] = options->lower_umin;
   condition_flags[41] = !options->lower_umax;
   condition_flags[42] = !options->lower_umin;
   condition_flags[43] = options->lower_scmp;
   condition_flags[44] = options->lower_vector_cmp;
   condition_flags[45] = !options->lower_rotate;
   condition_flags[46] = options->lower_rotate;
   condition_flags[47] = options->lower_fpow;
   condition_flags[48] = !options->lower_fpow;
   condition_flags[49] = options->lower_fdiv;
   condition_flags[50] = options->lower_fsqrt;
   condition_flags[51] = !options->lower_fsqrt;
   condition_flags[52] = options->lower_sincos;
   condition_flags[53] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[54] = !options->lower_extract_byte;
   condition_flags[55] = !options->lower_extract_word;
   condition_flags[56] = options->has_pack_32_4x8;
   condition_flags[57] = options->lower_pack_64_2x32_split;
   condition_flags[58] = options->lower_pack_32_2x16_split;
   condition_flags[59] = options->lower_unpack_64_2x32_split;
   condition_flags[60] = options->lower_unpack_32_2x16_split;
   condition_flags[61] = options->lower_fmod;
   condition_flags[62] = options->lower_uadd_carry;
   condition_flags[63] = options->lower_usub_borrow;
   condition_flags[64] = options->lower_bitfield_insert;
   condition_flags[65] = options->lower_hadd;
   condition_flags[66] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[67] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat;
   condition_flags[69] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[70] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[73] = options->lower_bitfield_insert_to_shifts;
   condition_flags[74] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[75] = options->lower_bitfield_extract;
   condition_flags[76] = options->lower_bitfield_extract_to_shifts;
   condition_flags[77] = options->lower_ifind_msb;
   condition_flags[78] = options->lower_find_msb_to_reverse;
   condition_flags[79] = options->lower_find_lsb;
   condition_flags[80] = options->lower_extract_byte;
   condition_flags[81] = options->lower_extract_word;
   condition_flags[82] = options->lower_pack_unorm_2x16;
   condition_flags[83] = options->lower_pack_unorm_4x8;
   condition_flags[84] = options->lower_pack_snorm_2x16;
   condition_flags[85] = options->lower_pack_snorm_4x8;
   condition_flags[86] = options->lower_unpack_unorm_2x16;
   condition_flags[87] = options->lower_unpack_unorm_4x8;
   condition_flags[88] = options->lower_unpack_snorm_2x16;
   condition_flags[89] = options->lower_unpack_snorm_4x8;
   condition_flags[90] = options->lower_pack_split;
   condition_flags[91] = options->lower_isign;
   condition_flags[92] = !options->lower_isign;
   condition_flags[93] = options->lower_fsign;
   condition_flags[94] = !options->has_imul24;
   condition_flags[95] = !options->has_umul24;
   condition_flags[96] = !options->has_umad24;
   condition_flags[97] = options->has_imul24;
   condition_flags[98] = options->has_umad24;
   condition_flags[99] = options->has_umul24;
   condition_flags[100] = options->has_fused_comp_and_csel;
   condition_flags[101] = options->lower_iadd_sat;
   condition_flags[102] = options->support_8bit_alu;
   condition_flags[103] = options->support_16bit_alu;
   condition_flags[104] = options->lower_ldexp;
   condition_flags[105] = !options->lower_bitfield_reverse;
   condition_flags[106] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[107] = options->lower_fisnormal;
   condition_flags[108] = !options->vectorize_vec2_16bit;
   condition_flags[109] = options->has_fsub;
   condition_flags[110] = options->lower_fneg;
   condition_flags[111] = options->has_isub || options->lower_ineg;
   condition_flags[112] = options->lower_ineg;
   condition_flags[113] = options->lower_iabs;
   condition_flags[114] = options->has_iadd3;
   condition_flags[115] = options->vectorize_vec2_16bit;
   condition_flags[116] = options->fdot_replicates;
   condition_flags[117] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[118] = options->avoid_ternary_with_two_constants;
   condition_flags[119] = !options->lower_insert_byte;
   condition_flags[120] = !options->lower_insert_word;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_distribute_src_mods_table);
      }
   }

   return progress;
}

